/*---  TABLAS---- */
--------------------
CREATE TABLE estados  
(
 ID   NUMBER PRIMARY KEY,
 des  CHAR(20) NOT NULL   
 CONSTRAINT CH_estado_des CHECK (des=UPPER(des)) --restricci majuscules per l'atribut desEstado
);
-------- PAIS -------------
CREATE TABLE pais  
(
  ID        NUMBER                  CONSTRAINT PK_pais      PRIMARY KEY ,    -- pk	
  des       VARCHAR2  (50 CHAR)     CONSTRAINT NN_pais_des  NOT NULL,        -- nn
  cod       VARCHAR   (5  CHAR)     CONSTRAINT NN_pais_cod  NOT NULL        --nn
);
-------- PROVINCIA -- 
CREATE TABLE PROVINCIA (
  ID            NUMBER              CONSTRAINT  PK_provincia          PRIMARY KEY, 	
  des           VARCHAR2(50 CHAR)   CONSTRAINT  NN_provincia_des      NOT NULL,
  pais                              CONSTRAINT  FK_provincia_pais   REFERENCES pais(ID) NOT NULL
);
----------- LOCALIDAD -- 
CREATE TABLE LOCALIDAD 
(
  ID            NUMBER            CONSTRAINT    PK_localidad              PRIMARY KEY, 	
  des           VARCHAR2(50 CHAR) CONSTRAINT    NN_localidad__des         NOT NULL,
  provincia                       CONSTRAINT    FK_localidad_provincia    REFERENCES provincia(ID) NOT NULL
); 
------------ VIA ---------
CREATE TABLE VIA 
(
  ID    NUMBER              CONSTRAINT PK_via       PRIMARY KEY, 	
  des   VARCHAR2(50 BYTE)   CONSTRAINT NN_via__des  NOT NULL
);
------- UBICACIONES  ----------
CREATE TABLE UBICACIONES  
(
 ID                 NUMBER                  CONSTRAINT PK_ubicaciones             PRIMARY KEY, 
 via                                        CONSTRAINT FK1_ubicaciones_via        REFERENCES VIA(ID)         NOT NULL,
 dir                VARCHAR2  (50 CHAR)     CONSTRAINT NN_ubicaciones_dir                                    NOT NULL,
 num                VARCHAR2  (5 CHAR)      CONSTRAINT NN_ubicaciones_num                                    NOT NULL,
 pis                VARCHAR2  (5 CHAR)      NULL, --CONSTRAINT NN_ubicaciones_piso                                   NOT NULL,
 pta                VARCHAR2  (10 CHAR)     NULL, --CONSTRAINT NN_ubicaciones_puerta                                 NOT NULL,
 codigoPostal       VARCHAR2  (10 CHAR)     CONSTRAINT NN_ubicaciones_codigoPostal                           NOT NULL,
 localidad                                  CONSTRAINT FK2_ubicaciones_localidad  REFERENCES LOCALIDAD(ID)   NOT NULL
); 
-- tCliente -- tipos de cliente
CREATE TABLE tCliente  
(
  ID        NUMBER                CONSTRAINT PK_tCliente       PRIMARY KEY,
  des       VARCHAR2(20 CHAR)     CONSTRAINT NN_tCliente_des   NOT NULL
);
-- CLIENTES 
CREATE TABLE clientes 
 (
 ID           NUMBER                    CONSTRAINT PK_clientes            PRIMARY KEY,
 estado                                 CONSTRAINT FK1_clientes_estado    REFERENCES estados(ID)  NOT NULL,   --fk,nn
 tipo 	   		                CONSTRAINT FK2_clientes_tipo      REFERENCES tCliente(ID) NOT NULL,   --fk,nn
 nifCif       VARCHAR2(10 CHAR)         CONSTRAINT AK_clientes_nifCif     UNIQUE NOT NULL,                    --ak,nn                      
 nom          VARCHAR2(50 CHAR)         CONSTRAINT NN_clientes_nom        NOT NULL ,         --nn
 ape1         VARCHAR2(50 CHAR)         CONSTRAINT NN_clientes_ape1       NOT NULL ,         --nn
 ape2         VARCHAR2(50 CHAR)         NULL,           
 email        VARCHAR2(50 CHAR)         NULL,
 tMovil       VARCHAR (11 CHAR)         NULL,
 ubica                                  CONSTRAINT FK3_clientes_ubica     REFERENCES UBICACIONES(ID) NOT NULL,    --fk
 fechaAlta    DATE                      CONSTRAINT NN_clientes_fechaAlta  NOT NULL,                               --nn
-- fechaAlta    DATE    DEFAULT(sysdate)  CONSTRAINT NN_clientes_fechaAlta  NOT NULL,                               --nn
 fechaMod     DATE    NULL          
);
------- EMPRESAS  ----------
CREATE TABLE empresas  
(
 ID               NUMBER CONSTRAINT                   PK_empresas                                     PRIMARY KEY,       --pk
 cif              VARCHAR2(10 CHAR)       CONSTRAINT  AK_empresas_Cif                               UNIQUE NOT NULL,   --ak,nn   
 des              VARCHAR(50 CHAR)        CONSTRAINT  NN_empresas_des                               NOT NULL,          --nn
 estado                                   CONSTRAINT  FK_empresas_estado  REFERENCES estados(ID)    NOT NULL,     --fk
 fechaEstado      DATE                    CONSTRAINT  NN_empresas_fechaEstado                       NOT NULL
);
------- MODELOS  ----------
CREATE TABLE modelos 
(
 ID             NUMBER              CONSTRAINT  PK_modelos            PRIMARY KEY,
 des            VARCHAR(50 CHAR)                                                              NOT NULL,
 anyoFabrica    VARCHAR(4 CHAR)     CONSTRAINT  NN_modelos_anyoFabrica                        NOT NULL, 
 empresa                            CONSTRAINT  FK_modelos_empresa    REFERENCES empresas(ID) NOT NULL,
 estado                             CONSTRAINT  FK_modelos_idEstado   REFERENCES estados(ID)  NOT NULL,
 fechaEstado    DATE                NULL,
 obs            VARCHAR(50 CHAR)    NULL
);
------- CONTADORES  ----------
CREATE TABLE contadores  
(
 ID             NUMBER            CONSTRAINT PK_contadores                PRIMARY KEY,
 modelo                           CONSTRAINT FK1_contadores_modelo        REFERENCES  modelos(ID)         NOT NULL,
 ubica                            CONSTRAINT FK2_contadores_ubica         REFERENCES  ubicaciones(ID)     NOT NULL,
 estado                           CONSTRAINT FK3_contadores_estado        REFERENCES  estados(ID)         NOT NULL,
 fechaEstado    DATE              CONSTRAINT NN_contadores_fechaEstado                                    NOT NULL, 
 numSerie       VARCHAR(20 CHAR)  CONSTRAINT NN_contadores_numSerie                                       NOT NULL
);
------- CONTRATOS  ----------
CREATE TABLE contratos  
(
 ID             NUMBER        CONSTRAINT PK_contratos             PRIMARY KEY,
 cliente                      CONSTRAINT FK1_contratos_cliente    REFERENCES  clientes(ID)    NOT NULL,
 contador                     CONSTRAINT FK2_contratos_contador   REFERENCES  contadores(ID)  NOT NULL,
 estado                       CONSTRAINT FK3_contratos_estado     REFERENCES  estados(ID)     NOT NULL,
 fechaEstado    DATE          CONSTRAINT NN_contratos_fechaEstado                             NOT NULL,
 pContrato      NUMBER (9,2)  CONSTRAINT NN_contratos_pContrato                               NOT NULL,
 obs            VARCHAR(50 CHAR)         NULL
);
-- TABLA ECENTRAL   -Emisiones Central-
CREATE TABLE eCentral
(
 ID               NUMBER              CONSTRAINT    PK_eCentral               PRIMARY KEY,
 des              VARCHAR(20 CHAR)    CONSTRAINT    NN_eCentral_des                                   NOT NULL
);
-- TABLA CCENTRAL  -CLASE DE CENTRAL- --ns
CREATE TABLE cCentral
(
 ID               NUMBER              CONSTRAINT    PK_cCentral               PRIMARY KEY,
 des              VARCHAR(20 CHAR)    CONSTRAINT    NN_cCentral_des                                   NOT NULL
);
-- TIPO CENTRALES 
CREATE TABLE tCentral 
(
 ID               NUMBER              CONSTRAINT    PK_tCentral                 PRIMARY KEY,
 des              VARCHAR(20 CHAR)    CONSTRAINT    NN_tCentral_des                                       NOT NULL,
 estado                               CONSTRAINT    FK1_tCentral_estado         REFERENCES estados(ID)    NOT NULL,
 fechaEstado      DATE                CONSTRAINT    NN_tCentral_fechaEstado                               NOT NULL,
 emision                              CONSTRAINT    FK2_tCentral_emision        REFERENCES eCentral(ID)   NOT NULL,
 cantidad         NUMBER(9,2)         CONSTRAINT    NN_tCentral_cantidad                                  NOT NULL,
 obs              VARCHAR(50 CHAR)    NULL
);
-- TABLA tInspeccion   -tipo de inspeccion
CREATE TABLE tInspeccion
(
 ID               NUMBER              CONSTRAINT    PK_tInspeccion              PRIMARY KEY,
 des              VARCHAR(20 CHAR)    CONSTRAINT    NN_tInspeccion_des                                       NOT NULL,
 estado                               CONSTRAINT    FK_tInspeccion_estado        REFERENCES estados(ID)      NOT NULL,
 fechaEstado      DATE                CONSTRAINT    NN_tInspeccion_fechaEstado                               NOT NULL
);
-- CENTRALES
CREATE TABLE centrales 
(
 ID               NUMBER              CONSTRAINT    PK_centrales                PRIMARY KEY,
 des              VARCHAR(50 CHAR)    CONSTRAINT    NN_centrales_des                                        NOT NULL,
 estado                               CONSTRAINT    FK1_centrales_estado        REFERENCES estados(ID)      NOT NULL,
 fechaEstado      DATE                CONSTRAINT    NN_centrales_fechaEstado                                NOT NULL,
 clase                                CONSTRAINT    FK2_centrales_clase         REFERENCES cCentral(ID)     NOT NULL,
 tipo                                 CONSTRAINT    FK3_centrales_tipo          REFERENCES tCentral(ID)     NOT NULL,
 eMax             NUMBER(9,2)         CONSTRAINT    NN_centrales_eMax                                       NOT NULL,
 eMin             NUMBER(9,2)         CONSTRAINT    NN_centrales_eMin                                       NOT NULL,
 inspeccion                           CONSTRAINT    FK4_centrales_inspeccion    REFERENCES tInspeccion(ID)  NOT NULL,
 fIns             DATE                CONSTRAINT    NN_centrales_fIns                                       NOT NULL,
 ubica                                CONSTRAINT    FK5_centrales_ubica         REFERENCES ubicaciones(ID)  NOT NULL,
 obs              VARCHAR(50 CHAR)                  NULL
);
--LINEA
CREATE TABLE linea 
(
 ID             NUMBER        CONSTRAINT PK_linea             PRIMARY KEY,
 estado                       CONSTRAINT FK_linea_estado      REFERENCES estados(ID) NOT NULL,
 fechaEstado    DATE          CONSTRAINT NN_linea_fechaEstado NOT NULL,
 cMax           NUMERIC(9,2)  CONSTRAINT NN_linea_cMax        NOT NULL,
 obs            VARCHAR(50 CHAR)                              NULL
);
-- LINEAS
CREATE TABLE lineas 
(
 ID             NUMBER    CONSTRAINT      PK_lineas             PRIMARY KEY,
 estado                   CONSTRAINT      FK1_lineas_estado     REFERENCES estados(ID)      NOT NULL,
 fechaEstado  DATE        CONSTRAINT      NN_lineas_fechaEstado                             NOT NULL,
 linea                    CONSTRAINT      FK2_lineas_linea      REFERENCES linea(ID)        NOT NULL,
 c1                       CONSTRAINT      FK3_lineas_c1         REFERENCES centrales(ID)    NOT NULL,
 c2              NUMBER   CONSTRAINT      NN_lineas_c2                                      NOT NULL,
 obs                      VARCHAR(50 CHAR)   NULL
--dual            INTEGER  CONSTRAINT CH_lineas_dual CHECK (dual = 0 OR dual =1)              NULL  
);
--  TABLA tLectura  -tipo de lecturas---
CREATE TABLE tLectura 
(
 ID           NUMBER    CONSTRAINT PK_tLectura            PRIMARY KEY,
 des          VARCHAR2(20 CHAR)                           NOT NULL 
);
-- LECTURAS
CREATE TABLE lecturas 
(
 ID               NUMBER            CONSTRAINT      PK_lecturas                   PRIMARY KEY,
 contador                           CONSTRAINT      FK1_lecturas_contador         REFERENCES  contadores(ID)  NOT NULL, 
 fechaLectura     DATE              CONSTRAINT      NN_lecturas_fechaLectura                                  NOT NULL,
 tipo                               CONSTRAINT      FK2_lecturas_tipo             REFERENCES  tLectura(ID)    NOT NULL, 
 anterior         NUMBER(9,2)       NULL,
 actual           NUMBER(9,2)       NULL,
 consumo          NUMBER(9,2)       CONSTRAINT      NN_lecturas_consumo           NOT NULL              
);
-- CONSUMOS
CREATE TABLE consumos 
(
 ID             NUMBER          CONSTRAINT      PK_consumos               PRIMARY KEY,
 contador                       CONSTRAINT      FK_consumos_contador      REFERENCES contadores(ID) NOT NULL, 
 anyo     NUMBER  CONSTRAINT      NN_consumos_anyo          NOT NULL,
 mes      NUMBER  CONSTRAINT      NN_consumos_mes           NOT NULL,
 consumo       NUMBER(9,2)       -- CONSTRAINT NN_consumos_consumo  
);
--- LOG --
CREATE TABLE Log(
  idLog         NUMBER              CONSTRAINT PK_log               PRIMARY KEY, 
  procesoLog    VARCHAR2(50 BYTE)   CONSTRAINT NN_procesoLog_Log    NOT NULL, 
  fechaLog      VARCHAR2(50 BYTE)   CONSTRAINT NN_fechaHoraLog_Log  NOT NULL, 
  entradaLog    VARCHAR2(500 BYTE)  CONSTRAINT NN_entradaLog_Log    NOT NULL, 
  salidaLog     VARCHAR2(500 BYTE)  CONSTRAINT NN_salidaLog_Log     NOT NULL, 
  RSPLog        VARCHAR2(500 BYTE)  CONSTRAINT NN_RSPLog_log        NOT NULL
  );

--ESTADISTICAS
----------------
               
CREATE TABLE E_1 --Donada una central de producci, el consum dels comptadors que depenen de la central.
(
 ID                   NUMBER          CONSTRAINT        PK_e_1                                             PRIMARY KEY,
 central                              CONSTRAINT        FK_e_1_central           REFERENCES centrales(ID)  NOT NULL,
 consumoContadores    NUMBER(9,2)     CONSTRAINT        NN_e_1_consumoContadores                           NOT NULL,
  fecha                VARCHAR2(11 CHAR)   CONSTRAINT   NN_e_1_fecha                                       NOT NULL
);
-- Donada una lnia de comunicaci i un any concret, el valor mitj de lenergia consumida, tenint en compte que aquest
-- consum depn dels comptadors que salimenten mitjanant  aquesta lnia.
-- Si un comptador pot fer servir dues lnies, suposeu que les dues lnies computen el consum per
-- garantir que les lnies estan ben dimensionades en cas de caiguda dalguna delles.

CREATE TABLE E_2                     
(
 ID                   NUMBER             CONSTRAINT      PK_e_2                                PRIMARY KEY,
 linea                                   CONSTRAINT      FK_e_2_linea     REFERENCES  linea(ID) NOT NULL,
 anyo                 NUMBER             CONSTRAINT      NN_e_2_anyo                           NOT NULL, 
 consumoEnergiaMedio  NUMBER(9,2)        CONSTRAINT      NN_e_2_consumoEnergiaMedio            NOT NULL
);
CREATE TABLE E_3   -- E3_Lnia que ha estat ms carregada a nivell denergia consumida. 
(
 ID                   NUMBER             CONSTRAINT      PK_e_3                                PRIMARY KEY,
 linea                                   CONSTRAINT      FK_e_3_linea    REFERENCES  linea(ID) NOT NULL,
 consumoContadores    NUMBER(9,2)        CONSTRAINT      NN_e_3_consumoContadores              NOT NULL,
 fecha                VARCHAR2(11 CHAR)   CONSTRAINT     NN_e_3_fecha                          NOT NULL
);
CREATE TABLE E_4    -- E4 Donat un any concret: percentatge de lnies que superen el 50% denergia consumida.
(
 ID                   NUMBER             CONSTRAINT      PK_e_4                                PRIMARY KEY,
 anyo                 NUMBER             CONSTRAINT      NN_e_4_anyo                           NOT NULL, 
 perLineaMas50        NUMBER(9,2)        CONSTRAINT      NN_e_4_perLineaMas50                  NOT NULL
);
CREATE TABLE E_5    -- E5 Donat un any concret: el nombre de centrals de producci que generen menys del 30% de producci.
(
 ID                       NUMBER             CONSTRAINT      PK_e_5                                    PRIMARY KEY,
 anyo                     NUMBER             CONSTRAINT      NN_e_5_anyo                               NOT NULL, 
 cenProduccionMenos30     NUMBER(9,2)        CONSTRAINT      NN_e_5_cenProduccionMenos30               NOT NULL
);
CREATE TABLE E_6    -- E6 Top-10 de comptadors que histricament han tingut ms consum.
(
 ID                     NUMBER             CONSTRAINT      PK_e_6                                         PRIMARY KEY,
 contador                                  CONSTRAINT      FK_e_6_contador   REFERENCES  contadores(ID)   NOT NULL,
 consumo                NUMBER(9,2)        CONSTRAINT      NN_e_6_consumo                                 NOT NULL
);
CREATE TABLE E_7    -- E7 Consum mig de tots dels clients.
(
 ID                     NUMBER              CONSTRAINT      PK_e_7                                          PRIMARY KEY,
 cliente                                    CONSTRAINT      FK_e_7_cliente       REFERENCES  clientes(ID)   NOT NULL,
 consumoMedio           NUMBER(9,2)         CONSTRAINT      NN_e7_consumoMedio                              NOT NULL
);
-------------
--CONSULTAS
------------
--CONSULTA 1  a
CREATE TABLE C1     --consultarCiudadFecha 
(
 ID                   NUMBER             CONSTRAINT      PK_C1                                           PRIMARY KEY,
 contrato             NUMBER             CONSTRAINT      FK_C1_contrato    REFERENCES   contratos(ID)     NOT NULL, 
 pContratada          NUMBER(9,2)        CONSTRAINT      NN_C1_pContratada                                NOT NULL, 
 tpConsumo            NUMBER(9,2)        CONSTRAINT      NN_C1_tpConsumo                                  NOT NULL,
 mConsumo             NUMBER(9,2)        CONSTRAINT      NN_C1_mConsumo                                   NOT NULL,
 anyo                 NUMBER             CONSTRAINT      NN_C1_anyo          NOT NULL,
 mes                  NUMBER             CONSTRAINT      NN_C1_mes           NOT NULL
 --fecha                VARCHAR2(11 CHAR)   CONSTRAINT     NN_C1_pInicial                                   NOT NULL
);

--CONSULTA 2   b
CREATE TABLE C2     --consultarCentralesDistribucionMasEnergia 
(
 ID                   NUMBER             CONSTRAINT      PK_C2                                            PRIMARY KEY,
 central              NUMBER             CONSTRAINT      FK_C2_central     REFERENCES   centrales(ID)     NOT NULL, 
 ubica                NUMBER             CONSTRAINT      NN_C2_ubica                                      NOT NULL, 
 eEmitida             NUMBER(9,2)        CONSTRAINT      NN_C2_eEmitida                                   NOT NULL,
 eMax                 NUMBER(9,2)        CONSTRAINT      NN_C2_eMax                                       NOT NULL
);

--CONSULTA 3    c
CREATE TABLE C3     --consultarLineasMasCargadasCapacidadMaxima 
(
 ID                   NUMBER             CONSTRAINT      PK_C3                                            PRIMARY KEY,
 linea                NUMBER             CONSTRAINT      FK_C3_linea     REFERENCES   lineas(ID)          NOT NULL, 
 cLinea               NUMBER(9,2)        CONSTRAINT      NN_C3_cLinea                                     NOT NULL, 
 eAmplia              NUMBER(9,2)        CONSTRAINT      NN_C3_eAmplia                                    NOT NULL
);
--CONSULTA 4   d
CREATE TABLE C4     --consultarClientesContadoresAltaDisponibiliad 
(
 ID                   NUMBER             CONSTRAINT      PK_C4                                            PRIMARY KEY,
 dni                  VARCHAR2(10 CHAR)  CONSTRAINT      NN_C4_dni                                        NOT NULL, 
 contrato             NUMBER             CONSTRAINT      FK1_C4_contrato    REFERENCES   contratos(ID)    NOT NULL, 
 modelo               NUMBER             CONSTRAINT      FK2_C4_modelo      REFERENCES   modelos(ID)      NOT NULL
);
--CONSULTA 5 e
CREATE TABLE C5     --consultarConsumoContadoresCentralIntervaloTiempo 
(
 ID                   NUMBER             CONSTRAINT      PK_C5                                               PRIMARY KEY,
 central              NUMBER             CONSTRAINT      FK_C5_central      REFERENCES    centrales(ID)       NOT NULL, 
 contador             NUMBER              CONSTRAINT      NN_C5_contador     REFERENCES    contadores(ID)      NOT NULL, 
 consumo              NUMBER(9,2)        CONSTRAINT      NN_C5_consumo                                        NOT NULL,
 eProd                NUMBER(9,2)        CONSTRAINT      NN_C5_eProd                                          NOT NULL,
 pInicial             VARCHAR2(11 CHAR)   CONSTRAINT     NN_C5_pInicial                                      NOT NULL,
 pFinal               VARCHAR2(11 CHAR)   CONSTRAINT     NN_C5_pFinal                                        NOT NULL
);

--CONSULTA 6 f
CREATE TABLE C6     --consultarPercentLecturasPresencialTelematica 
(
 ID                   NUMBER             CONSTRAINT       PK_C6                                               PRIMARY KEY,
 telematica           NUMBER             CONSTRAINT       FK1_C6_telematica     REFERENCES    tLectura(ID)    NOT NULL, 
 presencial           NUMBER             CONSTRAINT       FK2_C6_presencial     REFERENCES    tLectura(ID)    NOT NULL, 
 pTelematica          NUMBER(9,2)        CONSTRAINT       NN_C6_pTelematica                                   NOT NULL,
 pPresencial          NUMBER(9,2)        CONSTRAINT       NN_C6_pPresencial                                   NOT NULL,
 total                NUMBER(9,2)        CONSTRAINT       NN_C6_total                                         NOT NULL,
 pInicial             VARCHAR2(11 CHAR)   CONSTRAINT      NN_C6_pInicial                                      NOT NULL,
 pFinal               VARCHAR2(11 CHAR)   CONSTRAINT      NN_C6_pFinal                                        NOT NULL
);

--CONSULTA 7 g
CREATE TABLE C7     --consultarContadoresAntiguedad 
(
 ID                   NUMBER             CONSTRAINT      PK_C7                                               PRIMARY KEY,
 contador             NUMBER             CONSTRAINT      FK1_C7_contador    REFERENCES    contadores(ID)     NOT NULL, 
 anyos                NUMBER             CONSTRAINT      NN_C7_anyos                                         NOT NULL,
 fabrica              VARCHAR2(4 CHAR)   CONSTRAINT      NN_C7_fabrica                                       NOT NULL,
 fechaConsulta        DATE  
);

/*-- FIN CREACIN TABLES  --*/
