/* GESTOR_ALTAS */
CREATE OR REPLACE
PROCEDURE altaCentralDistribucion(
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaCentralDistribucion
PROPSITO: gestiona el alta de una Central de DISTRIBUCION
PARAMETERS: n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT: n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaCentralDistribucion('BCN_D4',1,to_char(sysdate,'DD/MM/YYYY'),2,3,20,10,1,to_char(sysdate,'DD/MM/YYYY'),500,null,rst);
******************************************************************************/
n_des_ins             VARCHAR2(50);
n_obs_ins             VARCHAR2(50);
dist_test                       INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
ins_test                        INTEGER;
err_msg         		VARCHAR2 (100);
dup_dist                        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
des_nulo  			EXCEPTION;
dup_ins                         EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);
--verificamos que los campos nulos no sean nulos
IF   (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_clase IS NULL)
	OR (n_tipo IS NULL)
	OR (n_eMax IS NULL)
	OR (n_eMin IS NULL)
	OR (n_inspeccion IS NULL)
	OR (n_fIns IS NULL)
	OR (n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;
--verificamos si existe la descripcin de la  Central
SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_central;
END IF;
-- obtener el codigo de la central de Distribucion
SELECT id
INTO dist_test
FROM ccentral
WHERE
ccentral.des='DISTRIBUCION' OR 
ccentral.DES='DISTRIBUCIN';
IF (dist_test = 0)
THEN
RAISE dup_dist; 
END IF;

IF (n_clase <> dist_test)
THEN
RAISE dup_dist; -- no es central de Distribucion
END IF;

--verificamos exista la clase de central y que sea de Central de Distribucion

SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; 
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

--verificamos  que exista el tipo de inspeccion
SELECT COUNT (*)
INTO ins_test
FROM tInspeccion
WHERE tInspeccion.id = n_inspeccion;
IF (ins_test = 0)   
THEN
RAISE dup_ins; 
END IF;


-- insertamos la nueva central
INSERT INTO centrales
(des,estado,fechaEstado,clase,tipo,eMax,eMin,inspeccion,fIns,ubica,obs)
VALUES
(n_des_ins,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs_ins);

-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta CENTRAL OK: ' || n_des_ins); 
    rst:='OK, Alta CENTRAL  ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA CENTRAL: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION
WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta  Central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacion  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;

WHEN dup_dist
THEN
    rst := 'ERROR: No es CENTRAL DE DISTRIBUCION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || dist_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ins
THEN
    rst := 'ERROR: No existe el tipo de inspeccion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_inspeccion: ' || n_inspeccion, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. altaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaCentralDistribucion;
/
CREATE OR REPLACE
PROCEDURE altaCentralProduccion(
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaCentral
PROPSITO: gestiona el alta de una Central de PRODUCCION
PARAMETERS: n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT: n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaCentralProduccion('BARCELONA_2',1,to_char(sysdate,'DD/MM/YYYY'),1,3,20,10,1,'15/05/2012',1,null,rst);
******************************************************************************/
n_des_ins             VARCHAR2(50);
n_obs_ins             VARCHAR2(50);


prod_test                       INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
ins_test                        INTEGER;

err_msg         		VARCHAR2 (100);
dup_prod                        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
dup_ins                         EXCEPTION;
des_nulo  			EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);

--verificamos que los campos nulos no sean nulos
IF   (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_clase IS NULL)
	OR (n_tipo IS NULL)
	OR (n_eMax IS NULL)
	OR (n_eMin IS NULL)
	OR (n_inspeccion IS NULL)
	OR (n_fIns IS NULL)
	OR (n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;



--verificamos si existe la descripcin de la  Central
SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_central;
END IF;

-- obtener el codigo de la central de produccion
SELECT id
INTO prod_test
FROM ccentral
WHERE
ccentral.des='PRODUCCION' OR 
ccentral.DES='PRODUCCIN';
IF (prod_test = 0)
THEN
RAISE dup_prod; 
END IF;

IF (n_clase <> prod_test)
THEN
RAISE dup_prod; -- no es central de produccion
END IF;

--verificamos exista la clase de central y que sea de Central de Produccion

SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; 
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

--verificamos  que exista el tipo de inspeccion
SELECT COUNT (*)
INTO ins_test
FROM tInspeccion
WHERE tInspeccion.id = n_inspeccion;
IF (ins_test = 0)   
THEN
RAISE dup_ins; 
END IF;


-- insertamos la nueva central
INSERT INTO centrales
(des,estado,fechaEstado,clase,tipo,eMax,eMin,inspeccion,fIns,ubica,obs)
VALUES
(n_des_ins,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs_ins);


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta CENTRAL OK: ' || n_des_ins); 
    rst:='OK, Alta Central de Produccin  ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA CENTRAL: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION
WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta  Central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;


WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacion  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;


WHEN dup_prod
THEN
    rst := 'ERROR: No es CENTRAL DE PRODUCCION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || prod_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ins
THEN
    rst := 'ERROR: No existe el tipo de inspeccion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_inspeccion: ' || n_inspeccion, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. altaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaCentralProduccion;
/
create or replace PROCEDURE altaClaseCentral(
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaClaseCentral
PROPSITO: gestiona el alta de un Clase de Central
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido sxito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaClaseCentral('DISTRIBUCIN', rst);
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_ccentral    		EXCEPTION;
desCCentral_nulo  	EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo CCENTRAL.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desCCentral_nulo;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM ccentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_ccentral;
END IF;
-- insertamos el nuevo tipo de ccentral
INSERT INTO ccentral(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de CCENTRAL: ' || n_des_ins); 
    rst:='Ok, Alta Tipo CCENTRAL  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_ccentral
THEN
    rst := 'ERROR: Ya existe este tipo de  CCENTRAL';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desCCentral_nulo
THEN
    rst := 'ERROR: el tipo de CCENTRAL  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaClaseCentral;
/
CREATE OR REPLACE
PROCEDURE altaClientes (
n_estado            IN NUMBER,
n_tipo              IN NUMBER,
n_nifCif            IN VARCHAR2,
n_nom               IN VARCHAR2,
n_ape1              IN VARCHAR2,
n_ape2              IN VARCHAR2,
n_email             IN VARCHAR2,
n_tMovil            IN VARCHAR2,
n_ubica             IN NUMBER,
n_fechaAlta         IN VARCHAR2,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaCliente
PROPSITO: gestiona el alta de un cliente en la tabla clientes
PARAMETERS: n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,
n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod, rst
INPUT: n_estado, n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,
n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaClientes(1,4,'43073208X', 'Alberto', 'Ramos', null, 'aramossa@uoc.edu','34671535222',1,'17/04/2012',null, rst);
******************************************************************************/

n_nifCif_ins          VARCHAR2(10 CHAR);
n_nom_ins             VARCHAR2(50 CHAR);
n_ape1_ins            VARCHAR2(50 CHAR);
n_ape2_ins            VARCHAR2(50 CHAR);
n_email_ins           VARCHAR2(50 CHAR);
n_tMovil_ins          VARCHAR2(11 CHAR);
n_ubica_ins           NUMBER;
n_fechaAlta_ins       VARCHAR2(11 CHAR);
n_fechaMod_ins        VARCHAR2(11 CHAR);

estado_test         INTEGER;
tipo_test           INTEGER;
nifCif_test         INTEGER;
ubica_test          INTEGER;

err_msg             VARCHAR2(100);

dup_estado          EXCEPTION;
dup_tipo            EXCEPTION;
dup_nifCif          EXCEPTION;
dup_ubica           EXCEPTION;

dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_nifCif_ins        := SUBSTR (n_nifCif, 1, 10);
n_nom_ins           := SUBSTR (n_nom, 1, 50);
n_ape1_ins          := SUBSTR (n_ape1, 1, 50);
n_ape2_ins          := SUBSTR (n_ape2, 1, 50);
n_email_ins         := SUBSTR (n_email, 1, 50);
n_tMovil_ins        := SUBSTR (n_tMovil, 1, 11);
n_fechaAlta_ins     := SUBSTR (n_fechaAlta, 1, 11);
n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_estado          IS NULL)
OR (n_tipo            IS NULL)
OR (n_nifCif_ins      IS NULL)
OR (n_nom_ins         IS NULL)
OR (n_ape1_ins        IS NULL)
OR (n_ubica           IS NULL)
OR (n_fechaAlta_ins   IS NULL)
THEN
RAISE dup_des;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--comprobar tipo cliente
SELECT COUNT (*)
INTO tipo_test
FROM TCLIENTE
WHERE tCliente.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;

--comprobar que la ubicacion exista 

SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.ID = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;

--verificamos que el nifCifel cliente  no exista
SELECT COUNT (*)
INTO nifCif_test
FROM CLIENTES
WHERE nifCif = n_nifCif_ins;
IF (nifCif_test > 0)
THEN
RAISE dup_nifCif;
END IF;


-- insertamos el nuevo cliente
INSERT INTO CLIENTES (estado,
tipo,
nifCif,
nom,
ape1,
ape2,
email,
tMovil,
ubica,
fechaAlta,
fechaMod)

VALUES (n_estado,
n_tipo,
n_nifCif_ins,
n_nom_ins, 
n_ape1_ins,
n_ape2_ins,
n_email_ins,
n_tMovil_ins,
n_ubica,
n_fechaAlta_ins,
n_fechaMod_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('cliente: ' || n_ape1_ins 
    ||','
    || n_ape2_ins
    ||','
    ||n_nom    
    ); 
    rst:='Ok, Alta cliente   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado: '
|| n_estado 
|| ', '
||'n_tipo  : ' 
|| n_tipo
|| ', ' 
||'n_nifCif  : ' 
|| n_nifCif 
|| ', ' 
||'n_nom: ' 
|| n_nom 
|| ', ' 
||'n_ape1: '
|| n_ape1 
|| ', '
||'n_ape2: '
|| n_ape2
|| ', '
||'n_email: '
|| n_email 
|| ', ' 
||'n_tMovil: '
|| n_tMovil 
|| ', ' 
||'n_ubica: '
|| n_ubica 
|| ', ' 
||'n_fechaAlta: '
|| n_fechaAlta 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION
WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tipo
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_tipo : ' || n_tipo  ); 
     rst := 'ERROR: NO existe TIPO CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el TIPO CLIENTE ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_tipo : ' || n_tipo 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_nifCif
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_nifCif : ' || n_nifCif_ins  ); 
     rst := 'ERROR:  ya existe este NIF / CIF';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: ya  existe el NIF - CIFT ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_nifCif : ' || n_nifCif 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe la UBICACION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la UBICACION ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica : ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado: '
|| n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_nifCif: '
|| n_nifCif 
, 'rst', rst, rst);
ROLLBACK;
END altaClientes;
/
CREATE OR REPLACE
PROCEDURE altaConsumos(
n_contador          IN NUMBER,
n_anyo     	    IN NUMBER,
n_mes               IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaConsumos
PROPSITO: gestiona el alta en la tabla de consumos
PARAMETERS:  n_contador,n_anyo, n_mes,n_consumo, rst
INPUT:   n_contador, n_anyo,n_mes,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaConsumos(1,2011,1,12 rst)
******************************************************************************/

contador_test           INTEGER;
err_msg                 VARCHAR2 (100);
dup_contador            EXCEPTION;
dup_null                EXCEPTION;

BEGIN

--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_anyo              IS NULL)
OR (n_mes               IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;


--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;
-- insertamos el nuevo registro en consumos
INSERT INTO consumos(
contador,
anyo,
mes,
consumo
)
VALUES (
n_contador,
n_anyo,
n_mes,
n_consumo
);
-- Fin de las operaciones
rst := 'OK';
DBMS_OUTPUT.PUT_LINE('n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo);

DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes_ins: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END altaConsumos;
/
CREATE OR REPLACE
PROCEDURE altaContadores(
n_modelo         	IN NUMBER,
n_ubica         	IN NUMBER,
n_estado         	IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
n_numSerie         	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaContadores
PROPSITO: gestiona el alta de un contador en la tabla contadores
PARAMETERS: n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie,rst
INPUT: n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaContadores(1,1,1,to_char(sysdate,'DD/MM/YYYY'), 'n/s_1', rst);
******************************************************************************/
n_fechaEstado_ins       VARCHAR2(11 CHAR);
n_numSerie_ins          VARCHAR2(20);

modelo_test             NUMBER;
ubica_test              NUMBER;
estado_test             NUMBER;

err_msg                 VARCHAR2(100);
  dup_modelo            EXCEPTION;
dup_ubica               EXCEPTION;
dup_estado              EXCEPTION;
  dup_des               EXCEPTION;

BEGIN


n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 
n_numSerie_ins      := SUBSTR(n_numSerie, 1, 20);


--verificamos que los campos no nulos no sean nulos
IF (n_modelo          IS NULL)
OR (n_ubica           IS NULL)
OR (n_estado          IS NULL)
OR (n_fechaEstado_ins IS NULL)
OR (n_numSerie_ins    IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que existe el modelo
SELECT COUNT (*)
INTO modelo_test
FROM MODELOS
WHERE ID = n_modelo;
IF (modelo_test = 0)
THEN
RAISE dup_modelo;
END IF;
--comprobar que existe la  ubicacion
SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--insertamos el nuevo contador
INSERT INTO CONTADORES 
(modelo,
ubica,
estado,
fechaEstado,
numSerie)

VALUES 
(n_modelo,
n_ubica,
n_estado,
n_fechaEstado_ins,
n_numSerie_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_modelo : ' || n_modelo ); 
    rst:='Ok, Alta contador   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' 
|| n_modelo 
|| ', ' 
||'n_ubica  : '
|| n_ubica
|| ', ' 
||'n_estado  : '
|| n_estado
|| ', ' 
||'n_fechaEstado: '
|| n_fechaEstado_ins
|| ', ' 
||'n_numSerie: '
|| n_numSerie_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_modelo
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_modelo : ' || n_modelo  ); 
     rst := 'ERROR: No existe Modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' || n_modelo  
, 'rst', rst, rst);

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe ubicacin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica: ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: No existe Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado ' || n_estado
|| ', '
||'n_fechaEstado: ' || n_fechaEstado 
, 'rst', rst, rst);

ROLLBACK;
WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCcontador', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);
ROLLBACK;
END altaContadores;
/
create or replace PROCEDURE altaContratos(
n_cliente           	IN NUMBER,
n_contador          	IN NUMBER,
n_estado            	IN NUMBER,
n_fechaEstado       	IN VARCHAR2,
n_pContrato         	IN NUMBER,
n_obs             	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaContratos
PROPSITO: gestiona el alta de un contraato en la tabla contratos
PARAMETERS: n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs, rst
INPUT:      n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs
PROCEDURE: altaLecturas(n_contador,n_fechaEstado_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaContratos(1,1,1,to_char(sysdate,'DD/MM/YYYY'),30,'obs_contrato', rst);
******************************************************************************/

n_fechaEstado_ins     VARCHAR2(11 CHAR);
n_obs_ins             VARCHAR2(50 CHAR);

cliente_test		INTEGER;
contador_test		INTEGER;
estado_test             INTEGER;
err_msg                 VARCHAR2(100);

n_anterior    NUMBER;
n_actual      NUMBER;
n_tipo        NUMBER;
n_consumo     NUMBER;
dup_cliente		EXCEPTION;
dup_contador	        EXCEPTION;
dup_estado		EXCEPTION;
dup_des                 EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  	:= SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins               := SUBSTR (n_obs, 1, 50);

-- inicializo contadores de lecturas y consumos 
n_anterior := 0;
n_actual   := 0; 
n_tipo     := 1;
n_consumo  := 0;
--verificamos que los campos no nulos no sean nulos

IF (n_cliente        		IS NULL)
OR (n_contador       		IS NULL)
OR (n_estado      		IS NULL)
OR (n_fechaEstado_ins           IS NULL)
OR (n_pContrato        	        IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que exista el  cliente
SELECT COUNT (*)
INTO cliente_test
FROM CLIENTES
WHERE CLIENTES.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

-- comprobar que exista el contador
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE contadores.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;
--comprobar que exista el estado 
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
-- insertamos el nuevo contrato
INSERT INTO CONTRATOS (
cliente,
contador,
estado,
fechaEstado,
pContrato,
obs
)
VALUES (
n_cliente,
n_contador,
n_estado,
n_fechaEstado_ins,
n_pContrato,
n_obs_ins
);
-- llamada procedure: actualiza lecturas y en lecturas llama procedure altaConsumo
altaLecturas(n_contador,n_fechaEstado_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
'n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
    ); 
    rst:='Ok, Alta contrato   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente: '
|| n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
COMMIT;

-- tratamiento de excepciones

EXCEPTION

WHEN dup_cliente
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_cliente : ' || n_cliente  ); 
     rst := 'ERROR: NO existe el CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el CLIENTE ';
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente  : ' || n_cliente
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_contador: ' || n_contador  ); 
     rst := 'ERROR:  NO  existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el CONTADOR';
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: ' || n_contador
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente: '
|| n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato 
||'n_obs: '
|| n_obs 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente: '
|| n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
ROLLBACK;
END altaContratos;
/
create or replace PROCEDURE altaEmisionCentral(
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEmisionCentral
PROPSITO: gestiona el alta de un tipo de emisin o especificidad de la  Central
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaEmisionCentral('CO2', rst)
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_ecentral    		EXCEPTION;
desecentral_nulo  	        EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo ECentral.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desECentral_nulo;
END IF;
--verificamos si existe el tipo de emisin
SELECT COUNT (*)
INTO des_test
FROM ECentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_ECentral;
END IF;
-- insertamos el nuevo tipo de ECentral
INSERT INTO ECentral(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de ECentral: ' || n_des_ins); 
    rst:='Ok, Alta Tipo ECentral  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_ECentral
THEN
    rst := 'ERROR: Ya existe este tipo de  ECentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desECentral_nulo
THEN
    rst := 'ERROR: el tipo de ECentral  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaEmisionCentral;
/
create or replace PROCEDURE altaEmpresa(
n_cif			IN VARCHAR2,
n_des 		IN VARCHAR2,
n_estado 		IN NUMBER,
n_fechaEstado	IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEmpresa
PROPSITO: gestiona el alta de una EMPRESA
PARAMETERS: n_cif,n_des,n_estado,n_fechaEstado, rst
INPUT: n_cif,n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaEmpresa('s121214','empresa3',5,'01/05/2012',rst);
******************************************************************************/
n_des_ins       		VARCHAR2 (50);

cif_test				INTEGER;
des_test        		INTEGER;
estado_test				INTEGER;

err_msg         	VARCHAR2 (100);

dup_cif			EXCEPTION;
dup_des    		EXCEPTION;
dup_estado			EXCEPTION;
des_nulo  			EXCEPTION;


BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);

--verificamos si el hay campos nulos
IF (n_cif IS NULL)
OR (n_des_ins IS NULL)
OR (n_estado IS NULL)
OR (n_fechaEstado IS NULL)
THEN
RAISE des_nulo;
END IF;

--verificamos si existe el cif de la empresa
SELECT COUNT (*)
INTO cif_test
FROM empresas
WHERE empresas.cif = n_cif;
IF (cif_test > 0)
THEN
RAISE dup_cif;
END IF;

--verificamos si existe la descripcin de la empresa
SELECT COUNT (*)
INTO des_test
FROM empresas
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos si existe el estado  de la empresa
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;



-- insertamos el nuevo tipo de empresa
INSERT INTO empresas
(cif,des,estado,fechaEstado)
VALUES
(n_cif,n_des_ins,n_estado,n_fechaEstado);


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de EMPRESA: ' || n_des_ins); 
    rst:='Ok, Alta EMPRESA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_cif
THEN
    rst := 'ERROR: Ya existe este CIF';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif

, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe este NOMBRE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif

, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO existe este ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
|| 'estado'
|| n_estado
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Empresa : ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaEmpresa;
/
create or replace PROCEDURE altaEstados(
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEstados
PROPSITO: gestiona el alta de un estado
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido scito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaEstado('ALTA', rst)
******************************************************************************/
n_des_ins       VARCHAR2 (50);
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_estados      EXCEPTION;
desEstado_nulo      EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo estados.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desEstado_nulo;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM ESTADOS
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_estados;
END IF;
-- insertamos el nuevo tipo de ESTADOS
INSERT INTO ESTADOS(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de ESTADOS: ' || n_des_ins); 
    rst:='Ok, Alta Tipo ESTADOS  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaESTADOS', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_estados
THEN
    rst := 'ERROR: Ya existe este tipo de  ESTADOS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaESTADOS', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desEstado_nulo
THEN
    rst := 'ERROR: el tipo de ESTADOS  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaESTADOS', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaESTADOS', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaEstados;
/
CREATE OR REPLACE
PROCEDURE altaLectura(
n_contador        IN NUMBER,
n_fechaLectura    IN VARCHAR2,
n_tipo            IN NUMBER,
n_lectura         IN NUMBER,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLectura
PROPSITO: gestiona el alta de una lectura de contador
PARAMETERS:   n_contador, n_fechaLectura,n_tipo,n_lectura,rst
INPUT:        n_contador, n_fechaLectura,n_tipo,n_lectura
PROCEDURE: altaLectura(n_contador,n_fechaLectura_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLectura(1, to_char(sysdate,'DD/MM/YYYY'),1,1212, rst);

******************************************************************************/
n_fechaLectura_ins      VARCHAR2 ( 11 CHAR);
contador_test           INTEGER;
cont_central      INTEGER;
i     integer;
tipo_test               INTEGER;
anterior_test           INTEGER;
n_anterior              NUMBER;
n_actual                NUMBER;
n_consumo               NUMBER;
err_msg                 VARCHAR2 (100);
dup_contador            EXCEPTION;
dup_tipo                EXCEPTION;
dup_null                EXCEPTION;

--proceso
BEGIN
-- comprobamos longitud de cadenas
n_fechaLectura_ins       := SUBSTR (n_fechaLectura, 1, 50);

--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_fechaLectura_ins  IS NULL)
OR (n_tipo              IS NULL)
OR (n_lectura           IS NULL)
THEN
RAISE dup_null;
END IF;

-- obtenemos el numero de centrales de produccin activas
select  count (*)
INTO cont_central
from centrales, ccentral
where
 ccentral.ID = centrales.CLASE
and centrales.CLASE = 2;
--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--verificamos que exista el tipo de  lectura
SELECT COUNT (*)
INTO tipo_test
FROM TLECTURA
WHERE tLectura.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;

-- obtener la lectura anterior del contador
        SELECT lecturas.ANTERIOR
        INTO n_anterior
        FROM lecturas
        WHERE lecturas.CONTADOR= n_contador
        AND  lecturas.FECHALECTURA <= n_fechaLectura_ins
        AND  ROWNUM=1;

-- obtener la lectura actual del contador
        SELECT lecturas.ACTUAL
        INTO n_actual
        FROM lecturas
        WHERE lecturas.CONTADOR= n_contador
        AND  lecturas.FECHALECTURA <= n_fechaLectura_ins
        AND  ROWNUM=1;

-- calcular los campos de lecturas
n_anterior := n_actual;
n_actual    := n_lectura;
n_consumo := (n_actual - n_anterior);

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_actual : ' || n_actual );
    DBMS_OUTPUT.PUT_LINE('n_lectura : ' || n_lectura ); 
    DBMS_OUTPUT.PUT_LINE('n_anterior : ' || n_anterior ); 
    DBMS_OUTPUT.PUT_LINE('n_consumo : ' || n_consumo ); 
    DBMS_OUTPUT.PUT_LINE('');  

-- insertamos la nueva lectura; llamada a procedimiento 

altaLecturas(n_contador,n_fechaLectura_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);
/*
-- actualizar estadisticas E_1
i  := 1;
while (i <= cont_central)  loop  
altaE1(i,getConsumoCentral(i),rst);
cont_central := cont_central + 1;
end loop;
*/

-- Fin de las operaciones
rst := 'OK: Lectura actualizada en Lecturas y Consumos';


altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_tipo
THEN
    rst := 'ERROR: Ya existe esta descripcion del tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
 err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END altaLectura;
/
CREATE OR REPLACE
PROCEDURE altaLecturas (
n_contador          IN NUMBER,
n_fechaLectura      IN VARCHAR2,
n_tipo              IN NUMBER,
n_anterior          IN NUMBER,
n_actual            IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLecturas
PROPSITO: gestiona el alta en la tabla de Lecturas
PARAMETERS:  n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo, rst
INPUT:   n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo
PROCEDURE EXTERNA:  altaConsumos(n_contador, n_anyo, n_mes, n_consumo,rst);
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLecturas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,1, rst)
******************************************************************************/
n_fechaLectura_ins      VARCHAR2 ( 11 CHAR);
n_anyo                  VARCHAR2(4 CHAR);
n_mes                   VARCHAR2(2 CHAR);
nn_anyo	          NUMBER;
nn_mes		  NUMBER;
contador_test           INTEGER;
tipo_test               INTEGER;
err_msg                 VARCHAR2 (100);
dup_contador            EXCEPTION;
dup_tipo                EXCEPTION;
dup_null                EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_fechaLectura_ins       := SUBSTR (n_fechaLectura, 1, 11);
n_anyo             := SUBSTR (n_fechaLectura_ins, 7, 4);
n_mes              := SUBSTR (n_fechaLectura_ins, 4, 2);
nn_anyo     := to_number(n_anyo,9999);
nn_mes      := to_number(n_mes,99);
--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_fechaLectura_ins  IS NULL)
OR (n_tipo              IS NULL)
OR (n_anterior          IS NULL)
OR (n_actual            IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;
--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;
--verificamos que  exista el tipo de lectura
SELECT COUNT (*)
INTO tipo_test
FROM TLECTURA
WHERE tLectura.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;
-- insertamos el nuevo registro en lecturas
INSERT INTO lecturas(
contador,
fechaLectura,
tipo,
anterior,
actual,
consumo
)
VALUES (
n_contador,
n_fechaLectura_ins,
n_tipo,
n_anterior,
n_actual,
n_consumo
);
-- Fin de las operaciones
rst := 'OK: lectura aceptada ';

altaConsumos(n_contador, nn_anyo, nn_mes, n_consumo,rst);

altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_tipo
THEN
    rst := 'ERROR: NO este  tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END altaLecturas;
/
CREATE OR REPLACE
PROCEDURE altaLinea(

n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_cMax                  IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLinea
PROPSITO: gestiona el alta de una Linea
PARAMETERS: n_estado, n_fechaEstado, n_cMax, n_obs, rst
INPUT: n_estado, n_fechaEstado, n_cMax, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLinea(1,'10/05/2012',100,null,rst);
******************************************************************************/

n_obs_ins       VARCHAR2 (50);
err_msg         VARCHAR2 (100);
des_nulo      EXCEPTION;
BEGIN
n_obs_ins := SUBSTR (n_obs, 1, 50);
--verificamos si hay campos no nulos: nulos
IF 	    (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_cMax IS NULL)
THEN
RAISE des_nulo;
END IF;

-- insertamos el nuevo tipo de linea
INSERT INTO linea(estado,fechaEstado,cMax,obs)
VALUES (n_estado,n_fechaEstado,n_cMax,n_obs_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de linea: ' || n_estado
    || ' fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax)    ; 
    rst:='OK, Alta de linea  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'altaLinea:' || n_estado
    || 'fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax 
, 'rst', rst, rst);
COMMIT;
EXCEPTION


WHEN des_nulo
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' fecha  linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' fecha  de linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;
END altaLinea;
/
CREATE OR REPLACE
PROCEDURE altaLineas(

n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_linea                 IN NUMBER,
n_c1                    IN NUMBER,
n_c2                    IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLineaS
PROPSITO: gestiona el alta de las lineas conectadas
PARAMETERS: n_estado, n_fechaEstado, n_linea,n_c1,n_c2, n_obs, rst
INPUT: n_estado, n_fechaEstado, n_linea, n_c1, n_c2, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,NULL,rst);
******************************************************************************/

n_obs_ins             VARCHAR2 (50);
n_fechaEstado_ins     VARCHAR2(11);
linea_test            INTEGER;
estado_test           INTEGER;
c1_test               INTEGER;  
c2_test               INTEGER;
err_msg               VARCHAR2 (100);

dup_estado            EXCEPTION;
dup_linea             EXCEPTION;
dup_c1                EXCEPTION;
dup_c2                EXCEPTION;
dup_c1_c2             EXCEPTION;
des_null              EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins := SUBSTR (n_obs, 1, 50);
--verificamos si hay campos no nulos: nulos
IF 	  (n_estado             IS NULL)
          OR (n_fechaEstado_ins IS NULL)
          OR (n_linea           IS NULL)
          OR (n_c1              IS NULL)
          OR (n_c2              IS NULL)
THEN
RAISE des_null;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
--comprobar existe la linea
SELECT COUNT (*)
INTO linea_test
FROM LINEA
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
--comprobar existe la central en c1
SELECT COUNT (*)
INTO c1_test
FROM CENTRALES
WHERE centrales.ID = n_c1;
IF (c1_test = 0)
THEN
RAISE dup_c1;
END IF;
--comprobar existe la central o contador en c2
SELECT COUNT (*)
INTO c2_test
FROM CENTRALES, CONTADORES
WHERE centrales.id = n_c2
or contadores.id = n_c2;
IF (c2_test = 0)
THEN
RAISE dup_c2;
END IF;
/*
-- comprobar que no conectamos dos iguales
IF ( n_c1 = n_c2 )
THEN
RAISE dup_c1_c2;
END IF;
*/
-- insertamos el alta de la linea de conexion
INSERT INTO lineas(
estado,
fechaEstado,
linea,
c1,
c2,
obs)
VALUES (
n_estado,
n_fechaEstado_ins,
n_linea,
n_c1,
n_c2,
n_obs_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Alta de linea: '
    ||' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins
    ); 
    rst:='OK, Alta de lineas  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN des_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_linea
THEN
    rst := 'ERROR: NO existe LINEA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1
THEN
    rst := 'ERROR: No es una Central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c2
THEN
    rst := 'ERROR: No es Central ni Contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1_c2
THEN
    rst := 'ERROR: No se pueden  conectar: conexiones iguales';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
END altaLineas;
/
CREATE OR REPLACE
PROCEDURE altaLocalidad (
n_id  IN NUMBER,
n_des IN VARCHAR2,
n_provincia IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altalocalidad
PROPSITO: gestiona el alta de un localidad en la tabla localidad
PARAMETERS: n_id, n_des,n_provincia, rst
INPUT: n_id, n_des, n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altalocalidad(50,'Mataro',10, rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
des_test        INTEGER;
provincia_test  INTEGER;
err_msg         VARCHAR2 (100);
dup_des         EXCEPTION;
dup_id          EXCEPTION;
dup_provincia   EXCEPTION;
dup_null        EXCEPTION;

BEGIN
n_des_ins       := SUBSTR (n_des, 1, 50);
--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL) OR (n_des IS NULL) OR (n_provincia IS NULL)  THEN
RAISE dup_null;
END IF;
--Verificamos si el codigo de la localidad existe
SELECT COUNT (*)
INTO id_test
FROM localidad
WHERE ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;

--verificamos si existe la descripcion de la localidad
SELECT COUNT (*)
INTO des_test
FROM localidad
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;
provincia_test:=0;
--verificamos si existe el codigo de la provincia
SELECT COUNT (*)
INTO provincia_test
FROM provincia
WHERE provincia.ID = n_provincia;
IF (provincia_test = 0)
THEN
RAISE dup_provincia;
END IF;
DBMS_OUTPUT.ENABLE;
-- insertamos la nueva localidad
INSERT INTO localidad(ID,des,provincia) VALUES (n_id,n_des_ins,n_provincia);
-- Fin de las operaciones
rst := 'OK';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
        );  
        DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este cdigo localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_provincia
THEN
    rst := 'ERROR: NO  existe provincia';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos que NO tienen datos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' 
|| n_id
||' n_des:' 
||n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;
END altalocalidad;
/
create or replace PROCEDURE altaLog (
   n_procesoLog           IN    VARCHAR2, 
   n_fechaLog             IN    varchar2,
   n_entradaLog           IN    VARCHAR2, 
   n_salidaLog            IN    VARCHAR2,
   n_RSPLog               IN    VARCHAR2, 
   rst                    OUT   VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      altaLog
   PROP?ITO:    gestiona el alta de un log en la tabla log                
   PARAMETERS:  n_procesoLog, fechaLog, entradaLog, n_salidaLog, rst
   INPUT:       n_procesoLog, fechaLog, entradaLog, n_salidaLog
   OUTPUT:      rst
   RETORNA:     'Alta realizada con Exito' si la operacion ha tenido exito, 
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:    altaLog('AT', 'AUSTRIA', rst);
******************************************************************************/
   n_procesoLog_ins           VARCHAR2 (50);
   n_fechaLog_ins             varchar2 (50);
   n_entradaLog_ins           VARCHAR2 (500);
   n_salidaLog_ins            VARCHAR2 (500);
   n_RSPLog_ins               VARCHAR2 (500);
   err_msg                    VARCHAR2 (100);
   hayCamposNulos             EXCEPTION;
BEGIN
   n_procesoLog_ins       := SUBSTR (n_procesoLog, 1, 50);
   n_fechaLog_ins         := SUBSTR (n_fechaLog, 1, 50);
   n_entradaLog_ins       := SUBSTR (n_entradaLog, 1, 500);
   n_salidaLog_ins        := SUBSTR (n_salidaLog, 1, 500);
   n_RSPLog_ins           := SUBSTR (n_RSPLog, 1, 500);
 
 -- insertamos el nuevo log
   INSERT INTO LOG(procesoLog, fechaLog, entradaLog, salidaLog, RSPLog) 
          VALUES (n_procesoLog_ins, n_fechaLog_ins, n_entradaLog_ins, n_salidaLog_ins, n_RSPLog_ins);
   --verificamos que los campos no nulos no sean nulos
   IF (n_procesoLog_ins IS NULL) OR (n_fechaLog_ins IS NULL) OR (n_entradaLog_ins IS NULL) 
      OR (n_salidaLog_ins IS NULL) OR (n_RSPLog_ins IS NULL)
   THEN 
   RAISE hayCamposNulos;
   END IF; 
   
   -- Fin de las operaciones
   rst := 'Nuevo registro en la tabla LOG';   
   COMMIT;
EXCEPTION
WHEN hayCamposNulos
 THEN
      rst := 'ERROR: hay NO nulos :sin contenido';   
      ROLLBACK;  
WHEN OTHERS
   THEN
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rst := 'ERROR:' || err_msg;
      ROLLBACK;
END altaLog;
/
CREATE OR REPLACE
PROCEDURE altaModelos(
n_des            	IN VARCHAR2,
n_anyoFabrica        	IN VARCHAR2,
n_empresa            	IN NUMBER,
n_estado             	IN NUMBER,
n_fechaEstado		IN VARCHAR2,
n_obs              	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaModelo
PROPSITO: gestiona el alta de un modelo en la tabla modelos
PARAMETERS: n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs,rst;
INPUT: n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaModelos('Modelo_1','2012',1,1,to_char(sysdate,'DD/MM/YYYY'),'obs_modelo_1', rst);
******************************************************************************/

n_des_ins             VARCHAR2(50 CHAR);
n_anyoFabrica_ins     VARCHAR2(4  CHAR);
n_fechaEstado_ins      VARCHAR2(11 CHAR);
n_obs_ins             VARCHAR2(50 CHAR);


empresa_test		INTEGER;
estado_test         INTEGER;

err_msg             VARCHAR2(100);

dup_empresa          EXCEPTION;
dup_estado            EXCEPTION;

dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_des_ins        		:= SUBSTR (n_des,1,10);
n_anyoFabrica_ins         	:= SUBSTR (n_anyoFabrica,1,4);
n_fechaEstado_ins     		:= SUBSTR (n_fechaEstado,1,11);
n_obs_ins      			:= SUBSTR (n_obs,1,50);


--verificamos que los campos no nulos no sean nulos

IF (n_des		      	IS NULL)
OR (n_anyoFabrica_ins      IS NULL)
OR (n_empresa         	IS NULL)
OR (n_estado          	IS NULL)
OR (n_fechaEstado_ins   	IS NULL)
THEN
RAISE dup_des;
END IF;



--comprobar que exista la empresa
SELECT COUNT (*)
INTO empresa_test
FROM EMPRESAS
WHERE empresas.id = n_empresa;
IF (empresa_test = 0)
THEN
RAISE dup_empresa;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- insertamos el nuevo modelo
INSERT INTO MODELOS (des,
anyoFabrica,
empresa,
estado,
fechaEstado,
obs)

VALUES (
n_des_ins,
n_anyoFabrica_ins,
n_empresa, 
n_estado,
n_fechaEstado_ins,
n_obs_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
          'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs    
    ); 
    rst:='Ok, Alta Modelo   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_des
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs  
        , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	' n_estado: '
        ||n_estado
	, 'rst', rst, rst);
ROLLBACK;


WHEN dup_empresa
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_empresa : ' || n_empresa  ); 
     rst := 'ERROR: NO existe la EMPRESA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la EMPRESA ';
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_empresa: '
        ||n_empresa
	, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
ROLLBACK;
END altaModelos;
/
CREATE OR REPLACE
PROCEDURE altaPais (
n_id    IN NUMBER,
n_des   IN VARCHAR2,
n_cod   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaPais
PROPSITO: gestiona el alta de un pais en la tabla pais
PARAMETERS:  n_id, n_des,,n_cod, rst
INPUT:  n_id, n_des, n_cod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaPais(1,'Espaa','ES', rst)
******************************************************************************/
n_des_ins         VARCHAR2 ( 50 CHAR);
n_cod_ins         VARCHAR2  ( 5 CHAR );
id_test           INTEGER;
des_test          INTEGER;
cod_test          INTEGER;
err_msg           VARCHAR2 (100);
dup_id            EXCEPTION;
dup_des           EXCEPTION;
dup_cod           EXCEPTION;
dup_null          EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_des_ins       := SUBSTR (n_des, 1, 50);
n_cod_ins       := SUBSTR (n_cod, 1, 5);
--comprobamos campos no nulos que no esten vacios
IF (n_id  IS NULL)
OR (n_des IS NULL)
OR (n_cod IS NULL)
THEN
RAISE dup_null;
END IF;

--Verificamos que no exista el  codigo del pais 
SELECT COUNT (*)
INTO id_test
FROM PAIS
WHERE pais.ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;

--verificamos que no exista la descripcion del PAIS
SELECT COUNT (*)
INTO des_test
FROM PAIS
WHERE pais.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos que no exista  el codigo corto  del PAIS
SELECT COUNT (*)
INTO cod_test
FROM PAIS
WHERE pais.COD = n_cod_ins;
--IF (cod_test > 0)  -- no lo implemento por no tener todos los codigos
--THEN
--RAISE dup_cod;
--END IF;

-- insertamos el nuevo PAIS
INSERT INTO PAIS(ID,des,cod) VALUES (n_id,n_des_ins,n_cod_ins);
-- Fin de las operaciones
--rst := 'OK';

    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Alta de Pais '
||' n_id: ' 
|| n_id
||' n_des: '
|| n_des
); 
    rst:='OK';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: ' 
|| n_id
||' n_des: '
|| n_des
||' n_cod: '
|| n_cod
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este id de PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe este PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_des: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_cod
THEN
    rst := 'ERROR: Ya existe el codigo  de Pais ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cod: ' || n_cod
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
||' n_cod'
||n_cod
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
||' n_cod'
||n_cod
, 'rst', rst, rst);
ROLLBACK;
END altaPais;
/
CREATE OR REPLACE
PROCEDURE altaProvincia (
n_id      IN NUMBER,
n_des     IN VARCHAR2,
n_pais    IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaProvincia
PROPSITO: gestiona el alta de una provincia en la tabla provincia
PARAMETERS: n_id, n_des, n_pais rst
INPUT: n_id, n_des, n_pais
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaProvincia(2,'BARCELONA',1,rst); 
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
des_test        INTEGER;
pais_test       INTEGER;
err_msg         VARCHAR2 (100);
dup_id          EXCEPTION;
dup_des         EXCEPTION;
dup_pais        EXCEPTION;
dup_null        EXCEPTION;

BEGIN
n_des_ins       := SUBSTR (n_des, 1, 50);

--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL) OR (n_des IS NULL) OR (n_pais IS NULL)  THEN
RAISE dup_null;
END IF;
--Verificamos si el codigo de la provincia existe
SELECT COUNT (*)
INTO id_test
FROM PROVINCIA
WHERE provincia.ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;

--verificamos si existe la Provincia
SELECT COUNT (*)
INTO des_test
FROM PROVINCIA
WHERE provincia.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

pais_test:=0;
--verificamos si existe el PAIS
SELECT COUNT (*)
INTO pais_test
FROM PAIS
WHERE pais.ID = n_pais;
IF (pais_test = 0)
THEN
RAISE dup_pais;
END IF;

--DBMS_OUTPUT.ENABLE;
-- insertamos la nueva PROVINCIA

INSERT INTO PROVINCIA(ID,des,pais) VALUES (n_id,n_des_ins,n_pais);
-- Fin de las operaciones
rst := 'OK';
    DBMS_OUTPUT.PUT_LINE('Alta Provincia '
||'n_id:'
|| n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
);  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este cdigo PROVINCIA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta PROVINCIA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_des: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_pais
THEN
    rst := 'ERROR: NO  existe PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_pais: ' || n_pais
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos que NO tienen datos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;
END altaProvincia;
/
create or replace PROCEDURE altaTipoCentral(
n_des 		        IN VARCHAR2,
n_estado 		IN NUMBER,
n_fechaEstado	        IN VARCHAR2,
n_emision		IN NUMBER,
n_cantidad		IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaTipoCentral
PROPSITO: gestiona el alta de un TIPO  de Central
PARAMETERS: n_des,n_estado,n_fechaEstado,n_emision,n_cantidad,
n_obs	, rst
INPUT: n_des,n_estado,n_fechaEstado,n_emision,n_cantidad,
n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaTipoCentral('NUCLEAR',1,'01/05/2012',1,20,NULL,rst)
******************************************************************************/
n_des_ins       		VARCHAR2 (50);

des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_tcentral    		EXCEPTION;
desTCentral_nulo  	EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo tcentral.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desTCentral_nulo;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM tcentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_tcentral;
END IF;
-- insertamos el nuevo tipo de tcentral
INSERT INTO tcentral
(des,estado,fechaEstado,emision,cantidad,obs)
VALUES
(n_des_ins,n_estado,n_fechaEstado,n_emision,n_cantidad,n_obs);


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de tcentral: ' || n_des_ins); 
    rst:='Ok, Alta Tipo tcentral  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_tcentral
THEN
    rst := 'ERROR: Ya existe este tipo de  tcentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desTCentral_nulo
THEN
    rst := 'ERROR: el tipo de tcentral  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaTipoCentral;
/
create or replace PROCEDURE altaTipoCliente(
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaTipoCliente
PROPSITO: gestiona el alta de un tipo decliente
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaTipoCliente('PARTICULAR', rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_des      EXCEPTION;
des_nulo      EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo tCliente.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE des_nulo;
END IF;
--verificamos si existe el tipo de Cliente
SELECT COUNT (*)
INTO des_test
FROM tCliente
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;
-- insertamos el nuevo tipo de Cliente
INSERT INTO tCliente(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de Cliente: ' || n_des_ins); 
    rst:='Ok, Alta Tipo Cliente  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_des
THEN
    rst := 'ERROR: Ya existe este tipo de  Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN des_nulo
THEN
    rst := 'ERROR: el tipo de Cliente  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaTipoCliente;
/
CREATE OR REPLACE
PROCEDURE altaTipoInspeccion(
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaTipoInspeccion
PROPSITO: gestiona el alta de un tipo de inspeccin
PARAMETERS: n_des,n_estado,n_fechaEstado, rst
INPUT: n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaTipoInspeccion('ANUAL',to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
n_des_ins             VARCHAR2(20);
n_fechaEstado_ins     VARCHAR2(11);
des_test        		INTEGER;
estado_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_des    		        EXCEPTION;
dup_estado      		EXCEPTION;
dup_null  			EXCEPTION;

BEGIN
n_des_ins                     := SUBSTR (n_des, 1, 20);
n_fechaEstado_ins             := SUBSTR (n_fechaEstado, 1, 11);
--verificamos que los campos nulos no sean nulos
IF          (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;
--verificamos si ya existe la descripcin 
SELECT COUNT (*)
INTO des_test
FROM TINSPECCION
WHERE tInspeccion.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos si existe el estado
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado; 
END IF;

-- insertamos el nuevo tipo de inspeccion
INSERT INTO tinspeccion
(des,estado,fechaEstado)
VALUES
(n_des_ins,n_estado,n_fechaEstado_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta Tipo Inspeccion  OK: '
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins); 
    rst:='OK, Alta Tipo Inspeccion  OK: ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_des
THEN
    rst := 'ERROR: Ya  existe la descripcion ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_null
THEN
    rst := 'ERROR: Hay campos NO nulos:  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA Tipo Inspeccion: ' 
|| n_des_ins
|| ' Estado: ' 
|| n_estado
||' fechaEstado: ' 
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA Tipo Inspeccion: ' || n_des
, 'rst', rst, rst);
ROLLBACK;
END altaTipoInspeccion;
/
CREATE OR REPLACE
PROCEDURE altaTipoLectura (
n_id    IN NUMBER,
n_des   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaTipoLectura
PROPSITO: gestiona el alta de un tipo de lecturas
PARAMETERS:  n_id, n_des, rst
INPUT:  n_id, n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaTipoLectura(1,'PRESENCIAL', rst)
******************************************************************************/
n_des_ins         VARCHAR2 ( 50 CHAR);
id_test           INTEGER;
des_test          INTEGER;
err_msg           VARCHAR2 (100);
dup_id            EXCEPTION;
dup_des           EXCEPTION;
dup_null          EXCEPTION;
BEGIN
-- comprobamos longitud de cadenas
n_des_ins       := SUBSTR (n_des, 1, 50);
--comprobamos campos no nulos que no esten vacios
IF (n_id  IS NULL)
OR (n_des IS NULL)
THEN
RAISE dup_null;
END IF;
--Verificamos que no exista el  codigo del tipo de  lectura 
SELECT COUNT (*)
INTO id_test
FROM tLectura
WHERE tLectura.ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;
--verificamos que no exista la descripcion del tipo de lectura
SELECT COUNT (*)
INTO des_test
FROM TLECTURA
WHERE tLectura.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;
-- insertamos el nuevo tipo de lectura
INSERT INTO tLectura(ID,des) VALUES (n_id,n_des_ins);
-- Fin de las operaciones
rst := 'OK';
altaLog('Proc. altaTipoLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: ' 
|| n_id
||' n_des: '
|| n_des
, 'rst', rst, rst);
COMMIT;
---------------
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este id de tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_des: '
|| n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta descripcion del tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_des
||' n_des: '
|| n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaTipoLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
, 'rst', rst, rst);
ROLLBACK;
END altaTipoLectura;
/
create or replace PROCEDURE altaUbicaciones (
n_via               IN NUMBER,
n_dir               IN VARCHAR2,
n_num               IN VARCHAR2,
n_pis               IN VARCHAR2,
n_pta               IN VARCHAR2,
n_codigoPostal      IN VARCHAR,
n_localidad          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaUbicaciones
PROPSITO: gestiona el alta de una Ubicacion en la tabla ubicaciones
PARAMETERS: n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad, rst
INPUT: n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaUbicacion(1,'del pez','2','1r','2a','08330',1, rst);
******************************************************************************/
n_dir_ins           VARCHAR2 (50);
n_num_ins           VARCHAR2 (5);
n_pis_ins           VARCHAR2 (5);
n_pta_ins           VARCHAR2 (10);
n_codigoPostal_ins  VARCHAR  (10);

via_test          INTEGER;
localidad_test    INTEGER;
dup_via           EXCEPTION;
dup_localidad     EXCEPTION;
err_msg           VARCHAR2 (100);
des_nulo          EXCEPTION;
BEGIN
-- controlar la longitud de las entradas
n_dir_ins               := SUBSTR (n_dir, 1, 50);
n_num_ins               := SUBSTR (n_num, 1, 5);
n_pis_ins               := SUBSTR (n_pis, 1, 5);
n_pta_ins               := SUBSTR (n_pta, 1, 10);
n_codigoPostal_ins      := SUBSTR (n_codigoPostal, 1, 10);
--verificamos que los campos no nulos no sean nulos
IF (n_via             IS NULL)
OR (n_dir             IS NULL)
OR (n_num             IS NULL)
OR (n_codigoPostal    IS NULL)
OR (n_localidad       IS NULL)
THEN
RAISE des_nulo;
END IF;
--Verificamos que exista la via
SELECT COUNT (*)
INTO via_test
FROM via
WHERE via.id = n_via;
IF (via_test = 0)
THEN
RAISE dup_via;
END IF;
--verificamos que eixsta la localidad
SELECT COUNT (*)
INTO localidad_test
FROM localidad
WHERE localidad.id = n_localidad;
IF (localidad_test = 0)
THEN
RAISE dup_localidad;
END IF;

-- insertamos la nueva ubicacion
INSERT INTO ubicaciones(
via
,dir
,num
,pis
,pta
,codigoPostal
,localidad)
VALUES (n_via
,n_dir_ins
,n_num_ins
,n_pis_ins
,n_pta_ins
,n_codigoPostal_ins
,n_localidad);
-- Fin de las operaciones
rst := 'OK';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE(
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
);  
        DBMS_OUTPUT.PUT_LINE(rst); 
        
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_via
THEN
      rst := 'ERROR: No existe este cdigo de via';
      DBMS_OUTPUT.ENABLE;    
      DBMS_OUTPUT.PUT_LINE('');  
      DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_localidad
THEN
    rst := 'ERROR: NO  existe localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
        rst := 'ERROR: hay campos nulos que no tienen datos';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');  
        DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc: altaUbicacion: ' 
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
END altaUbicaciones;
/
create or replace PROCEDURE altaVia (
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaVia
PROPSITO: gestiona el alta de una via
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaVia('Rambla', rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_desVia      EXCEPTION;
desVia_nulo      EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo Via.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desVia_nulo;
END IF;
--verificamos si existe el tipo de via
SELECT COUNT (*)
INTO des_test
FROM VIA
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_desVia;
END IF;
-- insertamos el nuevo tipo de via
INSERT INTO VIA(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de via: ' || n_des_ins); 
    rst:='Ok, Alta Tipo Via  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_desVia
THEN
    rst := 'ERROR: Ya existe este tipo de  Via';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desVia_nulo
THEN
    rst := 'ERROR: el tipo de via  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaVia;
/* FIN GESTOR_ALTAS */