/* GESTOR_BAJAS */
CREATE OR REPLACE
PROCEDURE bajaCentral(
n_id		IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaCentral
PROPSITO: gestiona la baja lgica de una  Central
PARAMETERS: n_id,n_estado,n_fechaEstado, rst
INPUT: n_id,n_estado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaCentral(1,to_char(sysdate,'DD/MM/YYYY'),  rst);
******************************************************************************/
n_estado				INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;

err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	EXCEPTION;



BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11);

--verificamos que los campos nulos no sean nulos
IF   		(n_id 		IS NULL)
	OR 	(n_fechaEstado	IS NULL)
THEN
RAISE dup_null;
END IF;

-- verificamos que la Central a modificar exista

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;

-- cambio a estado de baja
UPDATE centrales
SET
centrales.ESTADO = estado_test,
centrales.FECHAESTADO =n_fechaEstado_ins
WHERE
centrales.ID = n_id;

-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('BAJA Lgica de la Central OK: ' || n_id); 
    rst:='OK, BAJA LOGICA DE LA  CENTRAL ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_estado: '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: NO existe esta  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_estado: '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral: ' 
|| 'n_id: '
||  n_id
|| ' n_estad0: '
||  n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: No existe el estado BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral: ' 
|| 'n_id: '
||  n_id
|| ' n_estad0: '
||  n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral' 
||  n_id
|| ' n_estad0: '
||  n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins 
, 'rst', rst, rst);
ROLLBACK;

END bajaCentral;
/
CREATE OR REPLACE
PROCEDURE bajaClientes(
n_id                IN NUMBER,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaClientes
PROPSITO: gestiona la baja lgica de  un cliente en la tabla clientes
PARAMETERS: n_id,n_fechaMod, rst
INPUT: n_id,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaClientes(3,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/

n_fechaMod_ins      VARCHAR2(11 CHAR);
n_estado			NUMBER;
id_test             INTEGER;
estado_test         INTEGER;
err_msg             VARCHAR2(100);
dup_id              EXCEPTION;
dup_estado          EXCEPTION;
dup_null             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas

n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_id              IS NULL)
OR (n_fechaMod		IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM CLIENTES
WHERE clientes.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;


-- modificamos el cliente ESTADO A BAJA
UPDATE CLIENTES
SET
estado      = n_estado,
fechaMod    = n_fechaMod_ins
WHERE
clientes.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id: ' || n_id ); 
    rst:='Ok, BAJA logica del cliente realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
|| ', '
||'n_estado: '
|| n_estado 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el CODIGO DEL CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  CODIGO DEL CLIENTE ';
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;
END bajaClientes;
/
CREATE OR REPLACE
PROCEDURE bajaContadores(

n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:     bajaContadores
PROPSITO:  gestiona la baja lgica del contador ( cambio de estado en la tabla contadores
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT:      n_id,n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaContadores(1,to_char(sysdate,'DD/MM/YYYY'),  rst);
******************************************************************************/
n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;

err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	        EXCEPTION;

BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos no nulos no sean nulos
IF (n_id		      IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM contadores
WHERE contadores.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;



-- cambio a estado de baja
UPDATE CONTADORES 
SET
contadores.ESTADO = estado_test,
contadores.FECHAESTADO =n_fechaEstado_ins
WHERE
contadores.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id ); 
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || estado_test ); 
    rst:='Ok, cambio de estado a BAJA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
 , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: No existe el Contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id  
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  );
    rst := 'ERROR: No existe el Estado de BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado ' || n_estado
|| ', '
||'n_fechaEstado: ' || n_fechaEstado 
, 'rst', rst, rst);

ROLLBACK;
WHEN dup_null
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;
END bajaContadores;

/
CREATE OR REPLACE
PROCEDURE bajaContratos(
n_id			IN NUMBER,
n_fechaEstado       	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaContratos
PROPSITO: gestiona la baja lgica de un contraato en la tabla contratos
PARAMETERS: n_id, n_fechaEstado, rst
INPUT: n_id, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaContratos(1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/

n_fechaEstado_ins     VARCHAR2(11 CHAR);
n_contador              NUMBER;
id_test			INTEGER;
n_estado		NUMBER;
estado_test         	INTEGER;
err_msg             	VARCHAR2(100);
dup_id              	EXCEPTION;
dup_estado          	EXCEPTION;
dup_null                EXCEPTION;

BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  	:= SUBSTR (n_fechaEstado, 1, 11);
--verificamos que los campos no nulos no sean nulos
IF (n_id        		IS NULL)
OR (n_fechaEstado_ins           IS NULL)
THEN
RAISE dup_null;
END IF;
--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM contratos
WHERE contratos.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;
-- modificamos el contrato  A BAJA
UPDATE contratos
SET
estado       = n_estado,
fechaEstado  = n_fechaEstado_ins
WHERE
contratos.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
 ); 
    rst:='Ok, Baja Lgica del contrato  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
COMMIT;

-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el CONTRATO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el CONTRATO ';
altaLog('Proc. bajaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_contador: ' || n_contador  ); 
     rst := 'ERROR:  NO  existe el Estado de BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el estado de BAJA';
altaLog('Proc. bajaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;



WHEN dup_null
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;
END bajaContratos;
/
CREATE OR REPLACE
PROCEDURE bajaEmpresa(
n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaEmpresa
PROPSITO: gestiona la baja lgica de una empresa
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT:      n_id,n_estado, n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaEmpresa(1,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null                        EXCEPTION;


BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos no nulos no sean nulos
IF (n_id		      IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM empresas
WHERE empresas.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;



-- cambio a estado de baja
UPDATE empresas
SET
empresas.ESTADO = estado_test,
empresas.FECHAESTADO = n_fechaEstado_ins
WHERE
empresas.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
        'Baja Empresa: '
 	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins); 
    rst:='Ok, Baja EMPRESA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: NO existe la empresa';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins

, 'rst', rst, rst);
ROLLBACK;


WHEN dup_estado
THEN
    rst := 'ERROR: NO existe el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

END bajaEmpresa;
/
CREATE OR REPLACE
PROCEDURE bajaLinea(
n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaLinea
PROPSITO: gestiona la baja lgica de una linea  
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT: n_id, n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaLineas(1,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/

n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);

--verificamos si hay campos no nulos: nulos
IF 	     (n_id     		     IS NULL)
          OR (n_fechaEstado		IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM linea
WHERE linea.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;



-- cambio a estado de baja
UPDATE linea
SET
linea.ESTADO = estado_test,
linea.FECHAESTADO = n_fechaEstado_ins
WHERE
linea.ID = n_id;

-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Baja de linea: '
	||'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    ); 
    rst:='OK, Baja de linea  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe Linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	 
	 n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	 
	 n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

END bajaLinea;
/
CREATE OR REPLACE
PROCEDURE bajaLineas(

n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaLineas
PROPSITO: gestiona la baja lgica de lineas  conectadas
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT: n_id,n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaLineas(1,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/

n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);

--verificamos si hay campos no nulos: nulos
IF 	     (n_id     		IS NULL)
          OR (n_fechaEstado	IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM lineas
WHERE lineas.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;
-- cambio a estado de baja
UPDATE lineas
SET
lineas.ESTADO = estado_test,
lineas.FECHAESTADO = n_fechaEstado_ins
WHERE
lineas.ID = n_id;

-- Fin de las operaciones


    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Baja de linea: '
	||'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    ); 
    rst:='OK, Baja de lineas lgica  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe Lineas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	 
	 n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	 
	 n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	
        'n_id: ' 
	||n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

END bajaLineas;
/
CREATE OR REPLACE
PROCEDURE bajaModelos(
n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaModelos
PROPSITO: gestiona la baja lgica de un modelo en la tabla modelos
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT:      n_id,n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaModelos(1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/
n_estado				INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	EXCEPTION;


BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos no nulos no sean nulos
IF (n_id		      IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM modelos
WHERE modelos.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;



-- cambio a estado de baja
UPDATE modelos
SET
modelos.ESTADO = estado_test,
modelos.FECHAESTADO = n_fechaEstado_ins
WHERE
modelos.ID = n_id;

-- Fin de las operaciones    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins  
    ); 
    rst:='Ok, baja Modelo   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
		'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
        , 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        	'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
        , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
	, 'rst', rst, rst);
ROLLBACK;


WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
		'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins  ); 
     rst := 'ERROR: NO existe el modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la EMPRESA ';
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
	, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
		'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
        , 'rst', rst, rst);
ROLLBACK;
END bajaModelos;
/
CREATE OR REPLACE
PROCEDURE bajaTipoCentral(
n_id				IN NUMBER,
n_fechaEstado       	IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaTipoCentral
PROPSITO: gestiona la baja lgica de un TIPO  de Central
PARAMETERS: n_id, n_fechaEstado, rst
INPUT: n_id, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: bajaTipoCentral(1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/
n_fechaEstado_ins     VARCHAR2(11 CHAR);

n_contador              NUMBER;
id_test			INTEGER;
n_estado			NUMBER;
estado_test         	INTEGER;
err_msg             	VARCHAR2(100);
dup_id              	EXCEPTION;
dup_estado          	EXCEPTION;
dup_null             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  	:= SUBSTR (n_fechaEstado, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_id        		IS NULL)
OR (n_fechaEstado_ins           IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM tCentral
WHERE tCentral.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;


-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Baja de tipo de tcentral: '
||'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado); 
    rst:='Ok, Baja Tipo tcentral  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral:'
|| ' n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
,'rst',rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el tipo de  tcentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: '
|| 'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
	'n_id: '
	|| n_id
	||'n_estado  : ' 
	|| n_estado  
	||'n_fechaEstado: ' 
	|| n_fechaEstado   ); 
     rst := 'ERROR:  NO  existe el Estado de BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el estado de BAJA';
altaLog('Proc. bajaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' 
||'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: '
||'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado, 'rst', rst, rst);
ROLLBACK;
END bajaTipoCentral;
/
CREATE OR REPLACE
PROCEDURE bajaTipoInspeccion(
n_id         	     IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaTipoInspeccion
PROPSITO: gestiona la baja lgica de un tipo de inspeccin
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT: n_id,n_estado, n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: bajaTipoInspeccion(1,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	        EXCEPTION;

BEGIN
n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos nulos no sean nulos
IF                 (n_id IS NULL)
		OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;



--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM tInspeccion
WHERE tInspeccion.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;


-- cambio a estado de baja
UPDATE tInspeccion
SET
tInspeccion.ESTADO = estado_test,
tInspeccion.FECHAESTADO =n_fechaEstado_ins
WHERE
tInspeccion.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Baja  Tipo Inspeccion  OK: '
	||'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins); 
    rst:='OK, Baja Tipo Inspeccion  OK: ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
    , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el tipo de inspeccin ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: Hay campos NO nulos:  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;
END bajaTipoInspeccion;
/* FIN_GESTOR_BAJAS */