/* GESTOR_MODIFICA */
CREATE OR REPLACE
PROCEDURE modificaCentral(
n_id			IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 		IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaCentral
PROPSITO: gestiona la modificacin  de una Central
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT: n_id, n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaCentral
( 1,'GAROA',1,'01/05/2012',1,1,20,10,1,'15/05/2012',1,'OBS_CENTRAL',rst)
******************************************************************************/

n_des_ins             	VARCHAR2(50);
n_obs_ins             	VARCHAR2(50);

id_test				INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
err_msg         		VARCHAR2 (100);

dup_central_id 		        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
des_nulo  			EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);

--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR 	(n_des_ins IS NULL)
	OR 	(n_estado IS NULL)
	OR 	(n_fechaEstado IS NULL)
	OR 	(n_clase IS NULL)
	OR 	(n_tipo IS NULL)
	OR 	(n_eMax IS NULL)
	OR 	(n_eMin IS NULL)
	OR 	(n_inspeccion IS NULL)
	OR 	(n_fIns IS NULL)
	OR 	(n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;

-- verificamos que la Central a modificar exista

SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_central_id;
END IF;

-- verificamos que la descripcion  a modificar exista

SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_central;
END IF;

--verificamos que existe la clase de la  Central
SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; -- no existe la clase de central
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

-- modificamos la central
UPDATE centrales
SET
des 		= n_des_ins,
estado 		= n_estado,
fechaEstado 	= n_fechaEstado,
clase 		= n_clase,
tipo		= n_tipo,
eMax 		= n_eMax,
eMin 		= n_eMin,
inspeccion 	= n_inspeccion,
fIns 		= n_fIns,
ubica 		= n_ubica,
obs 		= n_obs
WHERE
centrales.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica CENTRAL OK: ' || n_des_ins); 
    rst:='OK, Modifica CENTRAL ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'MODIFICA CENTRAL: ' || n_id
||', ' || 'descripcin: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION
WHEN dup_central_id
THEN
    rst := 'ERROR: NO existe esta  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'CDIGO CENTRAL: ' || n_id, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta descripcin de  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;


WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacin  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;


WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. modificaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaCentral;
/
CREATE OR REPLACE
PROCEDURE modificaCentralDistribucion(
n_id			IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaCentralDistribucion
PROPSITO: gestiona la modificacin de una  Central de DISTRIBUCION
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT:n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaCentralDistribucion(1,'BCN_D4',1,to_char(sysdate,'DD/MM/YYYY'),2,3,20,10,1,to_char(sysdate,'DD/MM/YYYY'),500,null,rst);
******************************************************************************/
n_des_ins             VARCHAR2(50);
n_obs_ins             VARCHAR2(50);
id_test			INTEGER;
dist_test                       INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
ins_test                        INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			EXCEPTION;
dup_dist                        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
des_nulo  			EXCEPTION;
dup_ins                         EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);
--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_clase IS NULL)
	OR (n_tipo IS NULL)
	OR (n_eMax IS NULL)
	OR (n_eMin IS NULL)
	OR (n_inspeccion IS NULL)
	OR (n_fIns IS NULL)
	OR (n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;
/*
--verificamos si existe la descripcin de la  Central
SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_central;
END IF;
*/
-- obtener el codigo de la central de Distribucion
SELECT id
INTO dist_test
FROM ccentral
WHERE
ccentral.des='DISTRIBUCION' OR 
ccentral.DES='DISTRIBUCIN';
IF (dist_test = 0)
THEN
RAISE dup_dist; 
END IF;

IF (n_clase <> dist_test)
THEN
RAISE dup_dist; -- no es central de Distribucion
END IF;
--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


--verificamos exista la clase de central y que sea de Central de Distribucion

SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; 
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

--verificamos  que exista el tipo de inspeccion
SELECT COUNT (*)
INTO ins_test
FROM tInspeccion
WHERE tInspeccion.id = n_inspeccion;
IF (ins_test = 0)   
THEN
RAISE dup_ins; 
END IF;

--modificamos la Central de Distribucin

UPDATE centrales
SET
des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado
,clase =n_clase
,tipo= n_tipo
,eMax= n_eMax
,eMin = n_eMin
,inspeccion = n_inspeccion
,fIns = n_fIns
,ubica = n_ubica
,obs =n_obs_ins
WHERE
centrales.id = n_id;


-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica Central Distribucin OK: ' || n_id); 
    rst:='OK, Modificacin Central Distribucin  ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA CENTRAL: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el cdigo de la central de Distribucin '||n_id;
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el cdigo de la Central de Distribucin ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta descripcin de  Central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacion  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;

WHEN dup_dist
THEN
    rst := 'ERROR: No es CENTRAL DE DISTRIBUCION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || dist_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ins
THEN
    rst := 'ERROR: No existe el tipo de inspeccion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_inspeccion: ' || n_inspeccion, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. altaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaCentralDistribucion;
/
CREATE OR REPLACE
PROCEDURE modificaCentralProduccion(
n_id			IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaCentralProduccion
PROPSITO: gestiona la modificacin de una  Central de Produccin
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT:n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaCentralProduccion(1,'BCN_P4',1,to_char(sysdate,'DD/MM/YYYY'),2,3,20,10,1,to_char(sysdate,'DD/MM/YYYY'),500,null,rst);
******************************************************************************/
n_des_ins             VARCHAR2(50);
n_obs_ins             VARCHAR2(50);
id_test			INTEGER;
dist_test                       INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
ins_test                        INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			EXCEPTION;
dup_dist                        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
des_nulo  			EXCEPTION;
dup_ins                         EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);
--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_clase IS NULL)
	OR (n_tipo IS NULL)
	OR (n_eMax IS NULL)
	OR (n_eMin IS NULL)
	OR (n_inspeccion IS NULL)
	OR (n_fIns IS NULL)
	OR (n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;
/*
--verificamos si existe la descripcin de la  Central
SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_central;
END IF;
*/
-- obtener el codigo de la central de Distribucion
SELECT id
INTO dist_test
FROM ccentral
WHERE
ccentral.des='PRODUCCION' OR 
ccentral.DES='PRODUCCIN';
IF (dist_test = 0)
THEN
RAISE dup_dist; 
END IF;

IF (n_clase <> dist_test)
THEN
RAISE dup_dist; -- no es central de Produccin
END IF;
--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


--verificamos exista la clase de central y que sea de Central de Distribucion

SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; 
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

--verificamos  que exista el tipo de inspeccion
SELECT COUNT (*)
INTO ins_test
FROM tInspeccion
WHERE tInspeccion.id = n_inspeccion;
IF (ins_test = 0)   
THEN
RAISE dup_ins; 
END IF;

--modificamos la Central de Produccin

UPDATE centrales
SET
des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado
,clase =n_clase
,tipo= n_tipo
,eMax= n_eMax
,eMin = n_eMin
,inspeccion = n_inspeccion
,fIns = n_fIns
,ubica = n_ubica
,obs =n_obs_ins
WHERE
centrales.id = n_id;


-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica Central ProduccinOK: ' || n_id); 
    rst:='OK, Modificacin Central Produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica CENTRAL: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el cdigo de la central de Produccin'||n_id;
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el cdigo de la Central de Distribucin ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta descripcin de  Central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacion  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;

WHEN dup_dist
THEN
    rst := 'ERROR: No es CENTRAL DE PRODUCCION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || dist_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ins
THEN
    rst := 'ERROR: No existe el tipo de inspeccion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_inspeccion: ' || n_inspeccion, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. altaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaCentralProduccion;
/
create or replace PROCEDURE modificaClaseCentral(
n_id 	 IN NUMBER,
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaClaseCentral
PROPSITO: gestiona la modificacin de una Clase de Central
PARAMETERS: n_id,n_des, rst
INPUT: n_id,n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaClaseCentral(1,'DISTRIBUCIN', rst);
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
id_test        		        INTEGER;
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			        EXCEPTION;
dup_ccentral    		EXCEPTION;
desCCentral_nulo  	        EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--Verificamos si el codigo de la clase de central existe
SELECT COUNT (*)
INTO id_test
FROM ccentral
WHERE ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--verificamos si el campo CCENTRAL.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desCCentral_nulo;
END IF;
--verificamos si existe la descripcion de la central
/*
SELECT COUNT (*)
INTO des_test
FROM ccentral
WHERE des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_ccentral;
END IF;
*/
-- modificamos la  clase de central
UPDATE ccentral
SET
des = n_des_ins
WHERE
ccentral.id = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modificado  tipo de CCENTRAL: ' || n_id); 
    rst:='Ok, Modifica Tipo CCENTRAL  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe este cdigo localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: Ya existe este nombre de   CCENTRAL';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desCCentral_nulo
THEN
    rst := 'ERROR: el tipo de CCENTRAL  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaClaseCentral;
/
CREATE OR REPLACE
PROCEDURE modificaClientes(
n_id                IN NUMBER,
n_estado            IN NUMBER,
n_tipo              IN NUMBER,
n_nifCif            IN VARCHAR2,
n_nom               IN VARCHAR2,
n_ape1              IN VARCHAR2,
n_ape2              IN VARCHAR2,
n_email             IN VARCHAR2,
n_tMovil            IN VARCHAR2,
n_ubica             IN NUMBER,
n_fechaAlta         IN VARCHAR2,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaClientes
PROPSITO: gestiona la modificacin  del estado de un cliente en la tabla clientes
PARAMETERS: n_id,n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,
n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod, rst
INPUT: n_id, n_estado, n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaClientes(1,1,4,'43073208X', 'Alberto', 'Ramos', null, 'aramossa@uoc.edu','34671535222',1,'17/04/2012',null, rst);
******************************************************************************/

n_nifCif_ins          VARCHAR2(10 CHAR);
n_nom_ins             VARCHAR2(50 CHAR);
n_ape1_ins            VARCHAR2(50 CHAR);
n_ape2_ins            VARCHAR2(50 CHAR);
n_email_ins           VARCHAR2(50 CHAR);
n_tMovil_ins          VARCHAR2(11 CHAR);
n_ubica_ins           NUMBER;
n_fechaAlta_ins       VARCHAR2(11 CHAR);
n_fechaMod_ins        VARCHAR2(11 CHAR);
id_test			INTEGER;
estado_test         INTEGER;
tipo_test           INTEGER;
nifCif_test         INTEGER;
ubica_test          INTEGER;

err_msg             VARCHAR2(100);
dup_id		    EXCEPTION;
dup_estado          EXCEPTION;
dup_tipo            EXCEPTION;
dup_nifCif          EXCEPTION;
dup_ubica           EXCEPTION;

dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_nifCif_ins        := SUBSTR (n_nifCif, 1, 10);
n_nom_ins           := SUBSTR (n_nom, 1, 50);
n_ape1_ins          := SUBSTR (n_ape1, 1, 50);
n_ape2_ins          := SUBSTR (n_ape2, 1, 50);
n_email_ins         := SUBSTR (n_email, 1, 50);
n_tMovil_ins        := SUBSTR (n_tMovil, 1, 11);
n_fechaAlta_ins     := SUBSTR (n_fechaAlta, 1, 11);
n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos
IF (n_id			IS NULL)
OR (n_estado          IS NULL)
OR (n_tipo            IS NULL)
OR (n_nifCif_ins      IS NULL)
OR (n_nom_ins         IS NULL)
OR (n_ape1_ins        IS NULL)
OR (n_ubica           IS NULL)
OR (n_fechaAlta_ins   IS NULL)
THEN
RAISE dup_des;
END IF;

--Verificamos que  exista el ID del cliente 
SELECT COUNT (*)
INTO id_test
FROM clientes
WHERE clientes.ID = n_id;
IF (id_test =0 )
THEN
RAISE dup_id;
END IF;
-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--comprobar tipo cliente
SELECT COUNT (*)
INTO tipo_test
FROM TCLIENTE
WHERE tCliente.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;

--comprobar que la ubicacion exista 

SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.ID = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;

--verificamos que el nifCifel cliente  exista
SELECT COUNT (*)
INTO nifCif_test
FROM CLIENTES
WHERE nifCif = n_nifCif_ins;
IF (nifCif_test = 0)
THEN
RAISE dup_nifCif;
END IF;

-- insertamos el nuevo cliente
UPDATE  CLIENTES
SET
estado           = n_estado
,tipo           =  n_tipo
,nifCif  	=	n_nifCif
,nom		=	n_nom_ins 
,ape1		=	n_ape1_ins
,ape2		=	n_ape2_ins
,email	        =	  n_email_ins
,tMovil	        =	n_tMovil_ins
,ubica	        =	n_ubica
,fechaAlta	=	n_fechaAlta_ins
,fechaMod 	= 	n_fechaMod_ins
where 
clientes.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('cliente: ' || n_ape1_ins 
    ||','
    || n_ape2_ins
    ||','
    ||n_nom    
    ); 
    rst:='Ok, Modifica cliente  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado: '
|| n_estado 
|| ', '
||'n_tipo  : ' 
|| n_tipo
|| ', ' 
||'n_nifCif  : ' 
|| n_nifCif 
|| ', ' 
||'n_nom: ' 
|| n_nom 
|| ', ' 
||'n_ape1: '
|| n_ape1 
|| ', '
||'n_ape2: '
|| n_ape2
|| ', '
||'n_email: '
|| n_email 
|| ', ' 
||'n_tMovil: '
|| n_tMovil 
|| ', ' 
||'n_ubica: '
|| n_ubica 
|| ', ' 
||'n_fechaAlta: '
|| n_fechaAlta 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe  este id de clientes';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tipo
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_tipo : ' || n_tipo  ); 
     rst := 'ERROR: NO existe TIPO CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el TIPO CLIENTE ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_tipo : ' || n_tipo 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_nifCif
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_nifCif : ' || n_nifCif_ins  ); 
     rst := 'ERROR:  ya existe este NIF / CIF';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: ya  existe el NIF - CIFT ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_nifCif : ' || n_nifCif 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe la UBICACION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la UBICACION ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica : ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado: '
|| n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modifcaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_nifCif: '
|| n_nifCif 
, 'rst', rst, rst);
ROLLBACK;
END modificaClientes;
/
CREATE OR REPLACE
PROCEDURE modificaClientesEstado(
n_id                IN NUMBER,
n_estado            IN NUMBER,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaClientesEstado
PROPSITO: gestiona la modificacion  del estado de  un cliente en la tabla clientes
PARAMETERS: n_id,n_estado,n_fechaMod, rst
INPUT: n_id,n_estado,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaClientesEstado(3,1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/

n_fechaMod_ins      VARCHAR2(11 CHAR);

id_test             INTEGER;
estado_test         INTEGER;
err_msg             VARCHAR2(100);
dup_id              EXCEPTION;
dup_estado          EXCEPTION;
dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas

n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_id              IS NULL)
OR (n_estado          IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM CLIENTES
WHERE clientes.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- modificamos el cliente
UPDATE CLIENTES
SET
estado      = n_estado,
fechaMod    = n_fechaMod_ins
WHERE
clientes.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id: ' || n_id ); 
    rst:='Ok, Modificacion de estado de cliente realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
|| ', '
||'n_estado: '
|| n_estado 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el CODIGO DEL CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  CODIGO DEL CLIENTE ';
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;
END modificaClientesEstado;
/
CREATE OR REPLACE
PROCEDURE modificaConsumos(
n_id		    IN NUMBER,	
n_contador          IN NUMBER,
n_anyo     	    IN NUMBER,
n_mes               IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaConsumos
PROPSITO: gestiona el alta en la tabla de consumos
PARAMETERS:  n_id,n_contador,n_anyo, n_mes,n_consumo, rst
INPUT:   n_id,n_contador, n_anyo,n_mes,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaConsumos(1,1,2012,2,12 rst);
******************************************************************************/
id_test			INTEGER;
contador_test           INTEGER;
err_msg                 VARCHAR2 (100);
dup_id			EXCEPTION;
dup_contador            EXCEPTION;
dup_null                EXCEPTION;

BEGIN

--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_anyo              IS NULL)
OR (n_mes               IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;
--Verificamos exista el  el id de consumos 
SELECT COUNT (*)
INTO id_test
FROM consumos
WHERE consumos.ID = n_id;
IF (contador_test = 0)
THEN
RAISE dup_id;
END IF;

--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;


-- modificamos el registro de consumos
UPDATE  consumos
SET
contador  	= n_contador
,anyo 	        = n_anyo
,mes 		= n_mes
,consumo 	= n_consumo
Where
consumos.id = n_id;
-- Fin de las operaciones
--rst := 'OK';
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Consumo modificado: ' || n_contador 
    ||','|| n_anyo 
    ||','||n_mes  
    ||','||n_consumo
    ); 
    rst:='Ok, modificaConsumos   realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

altaLog('Proc. modificaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el id de Consumos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
|| n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
|| n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
|| n_id
||' n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
|| n_id
||' n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END modificaConsumos;
/
CREATE OR REPLACE
PROCEDURE modificaContadores(
n_id			IN NUMBER,
n_modelo         	IN NUMBER,
n_ubica         	IN NUMBER,
n_estado         	IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
n_numSerie         	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaContadores
PROPSITO: gestiona la modificacin  de un contador en la tabla contadores
PARAMETERS: n_id,n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie,rst
INPUT: n_id,n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaContadores(1,1,1,1,to_char(sysdate,'DD/MM/YYYY'), 'n/s_1', rst);
******************************************************************************/
n_fechaEstado_ins       VARCHAR2(11 CHAR);
n_numSerie_ins          VARCHAR2(20);
id_test                 INTEGER;
modelo_test             INTEGER;
ubica_test              INTEGER;
estado_test             INTEGER;
err_msg                 VARCHAR2(100);
dup_id                  EXCEPTION;
dup_modelo            EXCEPTION;
dup_ubica               EXCEPTION;
dup_estado              EXCEPTION;
dup_des               EXCEPTION;

BEGIN


n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 
n_numSerie_ins      := SUBSTR(n_numSerie, 1, 20);


--verificamos que los campos no nulos no sean nulos
IF (n_id 			IS NULL)
OR (n_modelo          IS NULL)
OR (n_ubica           IS NULL)
OR (n_estado          IS NULL)
OR (n_fechaEstado_ins IS NULL)
OR (n_numSerie_ins    IS NULL)
THEN
RAISE dup_des;
END IF;



--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM contadores
WHERE contadores.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--comprobar que existe el modelo
SELECT COUNT (*)
INTO modelo_test
FROM MODELOS
WHERE ID = n_modelo;
IF (modelo_test = 0)
THEN
RAISE dup_modelo;
END IF;
--comprobar que existe la  ubicacion
SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--modificamos el contador
UPDATE contadores
SET
modelo = n_modelo
,ubica = n_ubica
,estado = n_estado
,fechaEstado = n_fechaEstado_ins
,numSerie= n_numSerie_ins
WHERE
contadores.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'n_modelo: ' 
|| n_modelo 
|| ', ' 
||'n_ubica  : '
|| n_ubica
|| ', ' 
||'n_estado  : '
|| n_estado
|| ', ' 
||'n_fechaEstado: '
|| n_fechaEstado_ins
|| ', ' 
||'n_numSerie: '
|| n_numSerie_ins); 
    rst:='Ok, Modifica contador   realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' 
|| n_modelo 
|| ', ' 
||'n_ubica  : '
|| n_ubica
|| ', ' 
||'n_estado  : '
|| n_estado
|| ', ' 
||'n_fechaEstado: '
|| n_fechaEstado_ins
|| ', ' 
||'n_numSerie: '
|| n_numSerie_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el Cdigo del contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  Cdigo del contador ';
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_modelo
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_modelo : ' || n_modelo  ); 
     rst := 'ERROR: No existe Modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' || n_modelo  
, 'rst', rst, rst);

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe ubicacin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica: ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: No existe Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado ' || n_estado
|| ', '
||'n_fechaEstado: ' || n_fechaEstado 
, 'rst', rst, rst);

ROLLBACK;
WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);
ROLLBACK;
END modificaContadores;
/
CREATE OR REPLACE
PROCEDURE modificaContratos(
n_id				IN NUMBER,
n_cliente           	IN NUMBER,
n_contador          	IN NUMBER,
n_estado            	IN NUMBER,
n_fechaEstado       	IN VARCHAR2,
n_pContrato         	IN NUMBER,
n_obs             	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaContratos
PROPSITO: gestiona la modificacin de un contraato en la tabla contratos
PARAMETERS: n_id,n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs, rst
INPUT: n_id,n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaContratos(1,1,1,1,to_char(sysdate,'DD/MM/YYYY'),30,'obs_contrato', rst);
******************************************************************************/

n_fechaEstado_ins     	VARCHAR2(11 CHAR);
n_obs_ins             	VARCHAR2(50 CHAR);
id_test				INTEGER;
cliente_test			INTEGER;
contador_test			INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);

n_anterior    NUMBER;
n_actual      NUMBER;
n_tipo        NUMBER;
n_consumo     NUMBER;
dup_cliente			EXCEPTION;
dup_contador	        	EXCEPTION;
dup_estado				EXCEPTION;
dup_des                 	EXCEPTION;
dup_id				EXCEPTION;

BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  		:= SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins               	:= SUBSTR (n_obs, 1, 50);

-- inicializo contadores de lecturas y consumos 
n_anterior := 0;
n_actual   := 0; 
n_tipo     := 1;
n_consumo  := 0;
--verificamos que los campos no nulos no sean nulos

IF (n_id	        		IS NULL)
OR (n_cliente        		IS NULL)
OR (n_contador       		IS NULL)
OR (n_estado      		IS NULL)
OR (n_fechaEstado_ins       IS NULL)
OR (n_pContrato        	IS NULL)
THEN
RAISE dup_des;
END IF;

--Verificamos que que exista el id del contrato 
SELECT COUNT (*)
INTO id_test
FROM contratos
WHERE contratos.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--comprobar que exista el  cliente
SELECT COUNT (*)
INTO cliente_test
FROM CLIENTES
WHERE CLIENTES.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

-- comprobar que exista el contador
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE contadores.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;


--comprobar que exista el estado 

SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;



-- modificamos el contrato
UPDATE contratos
SET
cliente 		= n_cliente
,contador 		= n_contador
,estado 		= n_estado
,fechaEstado 	= n_fechaEstado_ins
,pContrato 	= n_pContrato
,obs 			= n_fechaEstado_ins
WHERE
contratos.id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
    ); 
    rst:='Ok, Modifica contrato  con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
COMMIT;

-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el id del Contrato';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaContrato', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_cliente
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_cliente : ' || n_cliente  ); 
     rst := 'ERROR: NO existe el CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el CLIENTE ';
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente  : ' || n_cliente
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_contador: ' || n_contador  ); 
     rst := 'ERROR:  NO  existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el CONTADOR';
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: ' || n_contador
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato 
||'n_obs: '
|| n_obs 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
ROLLBACK;
END modificaContratos;
/
CREATE OR REPLACE
PROCEDURE modificaEmisionCentral(
n_id  IN NUMBER,
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaEmisionCentral
PROPSITO: gestiona la modificacin  de un tipo de emisin o especificidad de la  Central
PARAMETERS: n_id,n_des, rst
INPUT: n_id,n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido sxito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaEmisionCentral(1,'CO2', rst)
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
id_test			        INTEGER;
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_id                          EXCEPTION;
dup_ecentral    		EXCEPTION;
desecentral_nulo  	        EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo ECentral.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desECentral_nulo;
END IF;
--verificamos que exista el id de estado
SELECT COUNT (*)
INTO id_test
FROM ECentral
WHERE des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_id;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM ECentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_ECentral;
END IF;
--modificamos la emisin de la eCentral
UPDATE ecentral
SET
des =	n_des_ins	
WHERE
eCentral.id = n_id;

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('Modifica ECentral:' 
||' n_id'
||n_id
||' n_des'
|| n_des_ins);
    rst:='Ok, Modifica Tipo ECentral  realizado con xito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ECentral:'
 ||' n_id'
||n_id
||' n_des'
|| n_des
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe este  id de  ECentral';
    DBMS_OUTPUT.PUT_LINE('n_id'||n_id||' n_des'||n_des);  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ECentral: '
||' n_id'
||n_id
||' n_des'
|| n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN desECentral_nulo
THEN
    rst := 'ERROR: el tipo de ECentral  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('Modifica ECentral:' 
||' n_id'
||n_id
||' n_des'
|| n_des);  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ECentral:'
||' n_id'
||n_id
||' n_des'
|| n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_ECentral
THEN
    rst := 'ERROR: Ya existe este tipo de  ECentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ECentral:'
||' n_id'
||n_id
||' n_des'
|| n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ECentral:'
||' n_id'
||n_id
||' n_des'
|| n_des
, 'rst', rst, rst);
ROLLBACK;
END modificaEmisionCentral;
/
CREATE OR REPLACE
PROCEDURE modificaEmpresa(
n_id		IN VARCHAR2,
n_cif		IN VARCHAR2,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaEmpresa
PROPSITO: gestiona la modificacin de una EMPRESA
PARAMETERS: n_id,n_cif,n_des,n_estado,n_fechaEstado, rst
INPUT: n_cif,n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaEmpresa(1's121214','empresa3',5,'01/05/2012',rst);
******************************************************************************/
n_des_ins       	VARCHAR2 (50);
n_fechaEstado_ins    	VARCHAR2 (11);
id_test			INTEGER;
estado_test		INTEGER;
err_msg         	VARCHAR2 (100);
dup_id			EXCEPTION;
dup_estado		EXCEPTION;
des_nulo  		EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);
--verificamos si el hay campos nulos
IF (n_id	IS NULL)
OR (n_cif       IS NULL)
OR (n_des_ins   IS NULL)
OR (n_estado    IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE des_nulo;
END IF;
--verificamos si existe el estado  de la empresa
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- modificamos la  empresa
UPDATE empresas
SET
cif = n_cif
,des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado_ins
WHERE
empresas.id = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Modifica EMPRESA :'
|| n_des
|| 'cif: '
|| n_cif); 
    rst:='Ok, Modificacin  EMPRESA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica EMPRESA :'
|| n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe el id de Empesa';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO existe este ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica EMPRESA :' || n_des
|| 'cif: '
|| n_cif
|| 'estado'
|| n_estado
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Empresa : ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaEmpresa;
/
CREATE OR REPLACE
PROCEDURE modificaEstadoCentral(
n_id		IN NUMBER,
n_estado 		IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaEstadoCentral
PROPSITO: gestiona la modificacin  del estado de  Central
PARAMETERS: n_id,n_estado, rst
INPUT: n_id,n_estado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaEstadoCentral(1,2,rst);
******************************************************************************/

id_test				INTEGER;
err_msg 	        		VARCHAR2 (100);
dup_central_id 	           EXCEPTION;
des_nulo  			EXCEPTION;

BEGIN

--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR 	(n_estado IS NULL)
THEN
RAISE des_nulo;
END IF;


-- verificamos que la Central a modificar exista

SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_central_id;
END IF;


-- modificamos la central cambio de estado
UPDATE centrales
SET
estado 	= n_estado                       
WHERE
centrales.id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('CAMBIO DE ESTADO OK: ' || n_estado); 
    rst:='OK, CAMBIO DE ESTADO CENTRAL ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaEstadoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_estado: '
|| n_estado
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_central_id
THEN
    rst := 'ERROR: NO existe esta  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEstadoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_estado: '
|| n_estado
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaEstadoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. modificaEstadoCentral: ' 
|| 'n_id: '
||  n_id
|| ' n_estad0: '
||  n_estado
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaEstadoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. modificaEstadoCentral ' || n_id, 'rst', rst, rst);
ROLLBACK;
END modificaEstadoCentral;
/
CREATE OR REPLACE
PROCEDURE modificaEstados(
n_id  IN NUMBER,
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaEstados
PROPSITO: gestiona la modificacin de un estado
PARAMETERS: n_id,n_des, rst
INPUT: n_id,n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaEstados('ALTA', rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_estados     EXCEPTION;
dup_id          EXCEPTION;
desEstado_nulo  EXCEPTION;

BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo estados.des es nulo
IF (n_id		 IS NULL)
OR (n_des_ins 	IS NULL)
 THEN
RAISE desEstado_nulo;
END IF;
SELECT COUNT(*)
INTO id_test
FROM estados
WHERE estados.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM ESTADOS
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_estados;
END IF;

-- modificamos la tabla de  ESTADOS
UPDATE estados
SET
id	= n_id,
des  = n_des
WHERE 
estados.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica el  tipo de ESTADOS: ' || n_des_ins); 
    rst:='Ok, Modifica Tipo ESTADOS  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaEstados', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe el id del Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEstados', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estados
THEN
    rst := 'ERROR: Ya existe este tipo de  ESTADOS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEstados', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desEstado_nulo
THEN
    rst := 'ERROR: el tipo de ESTADOS  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaEstados', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaEstados', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaEstados;
/
CREATE OR REPLACE
PROCEDURE modificaLecturas(
n_id		    IN NUMBER,
n_contador          IN NUMBER,
n_fechaLectura      IN VARCHAR2,
n_tipo              IN NUMBER,
n_anterior          IN NUMBER,
n_actual            IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaLecturas
PROPSITO: gestiona el alta en la tabla de Lecturas
PARAMETERS:  n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo, rst
INPUT:   n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaLecturas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,1, rst)
******************************************************************************/
n_fechaLectura_ins      VARCHAR2 ( 11 CHAR);

id_test		        INTEGER;
contador_test           INTEGER;
tipo_test               INTEGER;
err_msg                 VARCHAR2 (100);
dup_id		        EXCEPTION;
dup_contador            EXCEPTION;
dup_tipo                EXCEPTION;
dup_null                EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_fechaLectura_ins       := SUBSTR (n_fechaLectura, 1, 50);
--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_fechaLectura_ins  IS NULL)
OR (n_tipo              IS NULL)
OR (n_anterior          IS NULL)
OR (n_actual            IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;


--Verificamos exista la lectura 
SELECT COUNT (*)
INTO id_test
FROM LECTURAS
WHERE lecturas.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--verificamos que  exista el tipo de lectura
SELECT COUNT (*)
INTO tipo_test
FROM TLECTURA
WHERE tLectura.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;



-- modificamos la tupla de lecturas
UPDATE lecturas
SET
lecturas.CONTADOR 	= n_contador,
lecturas.FECHALECTURA 	= n_fechaLectura_ins,
lecturas.TIPO		= n_tipo,
lecturas.ANTERIOR	= n_anterior,
lecturas.ACTUAL		= n_actual,
lecturas.CONSUMO	= n_consumo
WHERE
lecturas.ID = n_id;

-- Fin de las operaciones
rst := 'OK';

altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;



WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_tipo
THEN
    rst := 'ERROR: NO este  tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END modificaLecturas;
/
CREATE OR REPLACE
PROCEDURE modificaLinea(
n_id			IN NUMBER,
n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_cMax                  IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaLinea
PROPSITO: gestiona la modificin de una linea
PARAMETERS: n_id,n_estado, n_fechaEstado, n_cMax, n_obs, rst
INPUT: n_id,n_estado, n_fechaEstado, n_cMax, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaLinea(1,1,'10/05/2012',10000,null,rst);
******************************************************************************/

id_test		INTEGER;
n_obs_ins       VARCHAR2 (50);
err_msg         VARCHAR2 (100);
dup_id		EXCEPTION;
des_nulo        EXCEPTION;

BEGIN
-- compobar longitud de cadenas
n_obs_ins := SUBSTR (n_obs, 1, 50);

--verificamos si hay campos no nulos: nulos
        IF   (n_id          IS NULL)
        OR   (n_estado      IS NULL)
        OR   (n_fechaEstado IS NULL)
        OR   (n_cMax        IS NULL)
        THEN
        RAISE des_nulo;
        END IF;

--Verificamos que que exista el id de la linea 
SELECT COUNT (*)
INTO id_test
FROM linea
WHERE linea.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
-- hacemos la modificacin de la lnea
UPDATE linea
SET
 estado =  n_estado
,fechaEstado = n_fechaEstado
,cMax =n_cMax
,obs = n_obs_ins
WHERE  linea.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica linea: ' 
    || n_id
    ||' n_estado'
    || n_estado
    || 'fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax)    ; 
    rst:='OK, Modifica linea  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'modificaLinea:' 
    || n_id
    ||' n_estado'
    || n_estado
    || ' fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax 
, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe la lnea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'fecha  linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'fecha  de linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;
END modificaLinea;
/
CREATE OR REPLACE
PROCEDURE modificaLineas(

n_id			IN NUMBER,
n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_linea                 IN NUMBER,
n_c1                    IN NUMBER,
n_c2                    IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaLineas
PROPSITO: gestiona la modificacin   de las lineas conectadas
PARAMETERS: n_id,n_estado, n_fechaEstado,n_linea, n_c1,n_c2, n_obs, rst
INPUT: n_id,n_estado, n_fechaEstado, n_linea, n_c1, n_c2, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaLineas(1,1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,NULL,rst);
******************************************************************************/
id_test		      INTEGER;
n_obs_ins             VARCHAR2 (50);
n_fechaEstado_ins     VARCHAR2(11);
linea_test            INTEGER;
estado_test           INTEGER;
c1_test               INTEGER;  
c2_test               INTEGER;
err_msg               VARCHAR2 (100);
dup_id		      EXCEPTION;
dup_estado            EXCEPTION;
dup_linea             EXCEPTION;
dup_c1                EXCEPTION;
dup_c2                EXCEPTION;
dup_c1_c2             EXCEPTION;
des_null              EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins := SUBSTR (n_obs, 1, 50);
--verificamos si hay campos no nulos: nulos
IF 	     (n_id              IS NULL)
	  OR (n_estado          IS NULL)
          OR (n_fechaEstado_ins IS NULL)
          OR (n_linea           IS NULL)
          OR (n_c1              IS NULL)
          OR (n_c2              IS NULL)
THEN
RAISE des_null;
END IF;

--Verificamos que no exista el  codigo del pais 
SELECT COUNT (*)
INTO id_test
FROM lineas
WHERE lineas.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
--comprobar existe la linea
SELECT COUNT (*)
INTO linea_test
FROM LINEA
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
--comprobar existe la central en c1
SELECT COUNT (*)
INTO c1_test
FROM CENTRALES
WHERE centrales.ID = n_c1;
IF (c1_test = 0)
THEN
RAISE dup_c1;
END IF;
--comprobar existe la central o contador en c2
SELECT COUNT (*)
INTO c2_test
FROM CENTRALES, CONTADORES
WHERE centrales.id = n_c2
or contadores.id = n_c2;
IF (c2_test = 0)
THEN
RAISE dup_c2;
END IF;
-- comprobar que no conectamos dos iguales
IF ( n_c1 = n_c2 )
THEN
RAISE dup_c1_c2;
END IF;
-- insertamos el alta de la linea de conexion
UPDATE  lineas
SET
estado        = n_estado
,fechaEstado  = n_fechaEstado_ins
,linea        = n_linea
,c1           = n_c1
,c2           = n_c2
,obs          = n_obs_ins
WHERE 
lineas.id = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Modifica  lineas: '
    || ' n_id'
    || n_id
    ||' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins
    ); 
    rst:='OK, Modificacin  de lneas  realizada con xito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_id: '
    || n_id
    || ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe el id de Lneas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
, 'rst', rst, rst);
ROLLBACK;
WHEN des_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_linea
THEN
    rst := 'ERROR: NO existe LINEA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1
THEN
    rst := 'ERROR: No es una Central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c2
THEN
    rst := 'ERROR: No es Central ni Contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1_c2
THEN
    rst := 'ERROR: No se pueden  conectar: conexiones iguales';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
END modificaLineas;
/
create or replace PROCEDURE altaUbicaciones (
 
n_via               IN NUMBER,
n_dir               IN VARCHAR2,
n_num               IN VARCHAR2,
n_pis               IN VARCHAR2,
n_pta               IN VARCHAR2,
n_codigoPostal      IN VARCHAR,
n_localidad          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaUbicaciones
PROPSITO: gestiona el alta de una Ubicacion en la tabla ubicaciones
PARAMETERS: n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad, rst
INPUT: n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaUbicacion(1,'del pez','2','1r','2a','08330',1, rst);
******************************************************************************/
n_dir_ins           VARCHAR2 (50);
n_num_ins           VARCHAR2 (5);
n_pis_ins           VARCHAR2 (5);
n_pta_ins           VARCHAR2 (10);
n_codigoPostal_ins  VARCHAR  (10);

via_test          INTEGER;
localidad_test    INTEGER;
dup_via           EXCEPTION;
dup_localidad     EXCEPTION;
err_msg           VARCHAR2 (100);
des_nulo          EXCEPTION;

BEGIN
-- controlar la longitud de las entradas
n_dir_ins               := SUBSTR (n_dir, 1, 50);
n_num_ins               := SUBSTR (n_num, 1, 5);
n_pis_ins               := SUBSTR (n_pis, 1, 5);
n_pta_ins               := SUBSTR (n_pta, 1, 10);
n_codigoPostal_ins      := SUBSTR (n_codigoPostal, 1, 10);


--verificamos que los campos no nulos no sean nulos
IF (n_via             IS NULL)
OR (n_dir             IS NULL)
OR (n_num             IS NULL)
OR (n_codigoPostal    IS NULL)
OR (n_localidad       IS NULL)
THEN
RAISE des_nulo;
END IF;
--Verificamos que exista la via
SELECT COUNT (*)
INTO via_test
FROM via
WHERE via.id = n_via;
IF (via_test = 0)
THEN
RAISE dup_via;
END IF;


--verificamos que eixsta la localidad

SELECT COUNT (*)
INTO localidad_test
FROM localidad
WHERE localidad.id = n_localidad;
IF (localidad_test = 0)
THEN
RAISE dup_localidad;
END IF;

-- insertamos la nueva ubicacion
INSERT INTO ubicaciones(
via
,dir
,num
,pis
,pta
,codigoPostal
,localidad)
VALUES (n_via
,n_dir_ins
,n_num_ins
,n_pis_ins
,n_pta_ins
,n_codigoPostal_ins
,n_localidad);
-- Fin de las operaciones
rst := 'OK';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE(
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
);  
        DBMS_OUTPUT.PUT_LINE(rst); 
        
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_via
THEN
      rst := 'ERROR: No existe este cdigo de via';
      DBMS_OUTPUT.ENABLE;    
      DBMS_OUTPUT.PUT_LINE('');  
      DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_localidad
THEN
    rst := 'ERROR: NO  existe localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
        rst := 'ERROR: hay campos nulos que no tienen datos';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');  
        DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc: altaUbicacion: ' 
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
END altaUbicaciones;
/
CREATE OR REPLACE
PROCEDURE modificaModelos(
n_id                    IN NUMBER,
n_des            	IN VARCHAR2,
n_anyoFabrica        	IN VARCHAR2,
n_empresa            	IN NUMBER,
n_estado             	IN NUMBER,
n_fechaEstado		IN VARCHAR2,
n_obs              	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaModelos
PROPSITO: gestiona la modificacin de un modelo en la tabla modelos
PARAMETERS: n_id,n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs,rst;
INPUT: n_id,n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaModelos(1,'Modelo_1','2012',1,1,to_char(sysdate,'DD/MM/YYYY'),'obs_modelo_1', rst);
******************************************************************************/

n_des_ins             VARCHAR2(50 CHAR);
n_anyoFabrica_ins     VARCHAR2(4  CHAR);
n_fechaEstado_ins      VARCHAR2(11 CHAR);
n_obs_ins             VARCHAR2(50 CHAR);
id_test			INTEGER;
empresa_test		INTEGER;
estado_test         INTEGER;
err_msg             VARCHAR2(100);
dup_id			EXCEPTION;
dup_empresa          EXCEPTION;
dup_estado            EXCEPTION;
dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_des_ins        		:= SUBSTR (n_des,1,10);
n_anyoFabrica_ins         	:= SUBSTR (n_anyoFabrica,1,4);
n_fechaEstado_ins     		:= SUBSTR (n_fechaEstado,1,11);
n_obs_ins      			:= SUBSTR (n_obs,1,50);


--verificamos que los campos no nulos no sean nulos
IF (n_id		      	IS NULL)
OR (n_des		      	IS NULL)
OR (n_anyoFabrica_ins      IS NULL)
OR (n_empresa         	IS NULL)
OR (n_estado          	IS NULL)
OR (n_fechaEstado_ins   	IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que exista la empresa
SELECT COUNT (*)
INTO empresa_test
FROM EMPRESAS
WHERE empresas.id = n_empresa;
IF (empresa_test = 0)
THEN
RAISE dup_empresa;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- modificamos el modelo
UPDATE modelos
SET
des 			= n_des_ins,
anyoFabrica 	= n_anyoFabrica_ins,
empresa 		= n_empresa,
estado 		= n_Estado,
fechaEstado 	= n_fechaEstado_ins,
obs 			= n_obs_ins
WHERE 
modelos.id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
          'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs    
    ); 
    rst:='Ok, Modifica Modelo   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_des
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs  
        , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	' n_estado: '
        ||n_estado
	, 'rst', rst, rst);
ROLLBACK;


WHEN dup_empresa
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_empresa : ' || n_empresa  ); 
     rst := 'ERROR: NO existe la EMPRESA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la EMPRESA ';
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_empresa: '
        ||n_empresa
	, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
ROLLBACK;
END modificaModelos;
/
CREATE OR REPLACE
PROCEDURE modificaPais(
n_id    IN NUMBER,
n_des   IN VARCHAR2,
n_cod   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaPais
PROPSITO: gestiona la modificacin de un pais en la tabla pais
PARAMETERS:  n_id, n_des,,n_cod, rst
INPUT:  n_id, n_des, n_cod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaPais(1,'Espaa','ES', rst);
******************************************************************************/
n_des_ins         VARCHAR2 ( 50 CHAR);
n_cod_ins         VARCHAR2  ( 5 CHAR );
id_test           INTEGER;
des_test          INTEGER;
cod_test          INTEGER;
err_msg           VARCHAR2 (100);
dup_id            EXCEPTION;
dup_des           EXCEPTION;
dup_cod           EXCEPTION;
dup_null          EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_des_ins       := SUBSTR (n_des, 1, 50);
n_cod_ins       := SUBSTR (n_cod, 1, 5);
--comprobamos campos no nulos que no esten vacios
IF (n_id  IS NULL)
OR (n_des IS NULL)
OR (n_cod IS NULL)
THEN
RAISE dup_null;
END IF;
--Verificamos que no exista el  codigo del pais 
SELECT COUNT (*)
INTO id_test
FROM PAIS
WHERE pais.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--verificamos que no exista la descripcion del PAIS
SELECT COUNT (*)
INTO des_test
FROM PAIS
WHERE pais.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;
-- modificamos el  PAIS
UPDATE PAIS
SET
des = n_des_ins,
cod = n_cod_ins
Where 
id = n_id;

--rst := 'OK';
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica Pais ' || n_des_ins); 
    rst:='Ok, Modifica Pais con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

altaLog('Proc. modificaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: ' 
|| n_id
||' n_des: '
|| n_des
||' n_cod: '
|| n_cod
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: NO existe este id de PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe este PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_des: ' || n_des
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
||' n_cod'
||n_cod
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
||' n_cod'
||n_cod
, 'rst', rst, rst);
ROLLBACK;
END modificaPais;
/
CREATE OR REPLACE
PROCEDURE modificaProvincia(
n_id      IN NUMBER,
n_des     IN VARCHAR2,
n_pais    IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaProvincia
PROPSITO: gestiona la modificacin de una provincia en la tabla provincia
PARAMETERS: n_id, n_des, n_pais rst
INPUT: n_id, n_des, n_pais
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaProvincia(2,'BARCELONA',1,rst); 
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
pais_test       INTEGER;

err_msg         VARCHAR2 (100);
dup_id          EXCEPTION;
dup_des         EXCEPTION;
dup_pais        EXCEPTION;

dup_null        EXCEPTION;

BEGIN
n_des_ins       := SUBSTR (n_des, 1, 50);

--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL) OR (n_des IS NULL) OR (n_pais IS NULL)  THEN
RAISE dup_null;
END IF;
--Verificamos si el codigo de la provincia existe
SELECT COUNT (*)
INTO id_test
FROM PROVINCIA
WHERE provincia.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;



pais_test:=0;
--verificamos si existe el PAIS
SELECT COUNT (*)
INTO pais_test
FROM PAIS
WHERE pais.ID = n_pais;
IF (pais_test = 0)
THEN
RAISE dup_pais;
END IF;

--modificamos la provincia

UPDATE provincia
SET
des = n_des_ins,
pais = n_pais
WHERE
id = n_id;

rst := 'OK';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE('Modificacin de la provincia '|| n_id); 
DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este cdigo PROVINCIA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_pais
THEN
    rst := 'ERROR: NO  existe PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_pais: ' || n_pais
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos que NO tienen datos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;
END modificaProvincia;
/
create or replace PROCEDURE modificaTipoCentral(
n_id			IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 		IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_emision		IN NUMBER,
n_cantidad		IN NUMBER,
n_obs			IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaTipoCentral
PROPSITO: gestiona la modificacin de un tipo   de Central
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado,n_emision,n_cantidad, n_obs, rst
INPUT: n_id,n_des,n_estado,n_fechaEstado,n_emision,n_cantidad,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaTipoCentral('NUCLEAR',1,'01/05/2012',1,20,NULL,rst);
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
id_test			INTEGER;
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			EXCEPTION;
dup_tcentral    		EXCEPTION;
desTCentral_nulo  	EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo tcentral.des es nulo
IF ( n_id IS NULL)
OR  (n_des_ins IS NULL) THEN
RAISE desTCentral_nulo;
END IF;

--Verificamos si el codigo del tipo  de central existe
SELECT COUNT (*)
INTO id_test
FROM tcentral
WHERE ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM tcentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_tcentral;
END IF;
-- insertamos el nuevo tipo de tcentral
INSERT INTO tcentral
(des,estado,fechaEstado,emision,cantidad,obs)
VALUES
(n_des_ins,n_estado,n_fechaEstado,n_emision,n_cantidad,n_obs);


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica  de tipo de tcentral: ' || n_des_ins); 
    rst:='Ok, Modifica  Tipo tcentral  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe este cdigo de tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: Ya existe este tipo de  tcentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desTCentral_nulo
THEN
    rst := 'ERROR: el tipo de tcentral  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaTipoCentral;
/
create or replace PROCEDURE modificaTipoCliente(
n_id  IN VARCHAR2,
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaTipoCliente
PROPSITO: gestiona la modificacin de un tipo de cliente
PARAMETERS: n_id,n_des, rst
INPUT: n_id,n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaTipoCliente('PARTICULAR', rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test		INTEGER;
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_id		EXCEPTION;
dup_des      EXCEPTION;
des_nulo      EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo tCliente.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE des_nulo;
END IF;


--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM tcliente
WHERE tcliente.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--verificamos si existe el tipo de Cliente
SELECT COUNT (*)
INTO des_test
FROM tCliente
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;


-- modificacmos el tipo de Cliente
UPDATE tcliente
SET
des = n_des_ins
WHERE
tcliente.id = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica  de tipo de Cliente: ' || n_id); 
    rst:='Ok, Modifica Tipo Cliente  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
--rst := 'OK';
altaLog('Proc. modificaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el tipo de Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  CODIGO DEL tipo de cliente ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta descripcin del  tipo de  Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN des_nulo
THEN
    rst := 'ERROR: el tipo de Cliente  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaTipoCliente;
/
CREATE OR REPLACE
PROCEDURE modificaTipoInspeccion(
n_id		IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaTipoInspeccion
PROPSITO: gestiona la modificacin de un tipo de inspeccin
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado, rst
INPUT: n_id,n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaTipoInspeccion(1,'ANUAL',to_char(sysdate,'DD/MM/YYYY'),rst)
******************************************************************************/
n_des_ins             VARCHAR2(20);
n_fechaEstado_ins     VARCHAR2(11);
id_test			INTEGER;
des_test        		INTEGER;
estado_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			EXCEPTION;
dup_des    		        EXCEPTION;
dup_estado      		EXCEPTION;
dup_null  			EXCEPTION;

BEGIN
n_des_ins                     := SUBSTR (n_des, 1, 20);
n_fechaEstado_ins             := SUBSTR (n_fechaEstado, 1, 11);

--verificamos que los campos nulos no sean nulos
      IF    (n_id     IS NULL)
        OR  (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--verificamos si ya existe la ID 
SELECT COUNT (*)
INTO id_test
FROM TINSPECCION
WHERE tInspeccion.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_des;
END IF;


--verificamos si ya existe la descripcin 
SELECT COUNT (*)
INTO des_test
FROM TINSPECCION
WHERE tInspeccion.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos si existe el estao
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado; 
END IF;


-- modificamos el registro  de inspeccion
UPDATE  tinspeccion
SET
des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado_ins
WHERE
tinspeccion.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta Tipo Inspeccion  OK: '
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins); 
    rst:='OK, Alta Tipo Inspeccion  OK: ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el id tipo Inspeccin ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'Modifica Tipo Inspeccion: ' 
    	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
    	|| ' Estado: ' 
    	|| n_estado
    	||' fechaEstado: ' 
    	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya  existe la descripcion ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'Modifica Tipo Inspeccion: ' 
    || ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'Modifica Tipo Inspeccion: ' 
    	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: Hay campos NO nulos:  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica Tipo Inspeccion: ' 
	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
|| ' Estado: ' 
|| n_estado
||' fechaEstado: ' 
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica Tipo Inspeccion: '
	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
|| ' Estado: ' 
|| n_estado
||' fechaEstado: ' 
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

END modificaTipoInspeccion;
/
CREATE OR REPLACE
PROCEDURE modificaTipoLectura (
n_id    IN NUMBER,
n_des   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaTipoLectura 
PROPSITO: gestiona la modificacin  de un tipo de lecturas
PARAMETERS:  n_id, n_des, rst
INPUT:  n_id, n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaTipoLectura (1,'PRESENCIAL', rst);
******************************************************************************/
n_des_ins         VARCHAR2 ( 50 CHAR);

id_test           INTEGER;
des_test          INTEGER;

err_msg           VARCHAR2 (100);

dup_id            EXCEPTION;
dup_des           EXCEPTION;
dup_null          EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_des_ins       := SUBSTR (n_des, 1, 50);
--comprobamos campos no nulos que no esten vacios
IF (n_id  IS NULL)
OR (n_des IS NULL)
THEN
RAISE dup_null;
END IF;

--Verificamos que  exista el  codigo del tipo de  lectura 
SELECT COUNT (*)
INTO id_test
FROM tLectura
WHERE tLectura.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--verificamos que no exista la descripcion del tipo de lectura
SELECT COUNT (*)
INTO des_test
FROM TLECTURA
WHERE tLectura.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;


-- modificamos tipo de lectura
UPDATE tLectura
SET
id = n_id,
des = n_des
WHERE 
tlectura.id = n_id;

-- Fin de las operaciones
DBMS_OUTPUT.PUT_LINE('');  
DBMS_OUTPUT.PUT_LINE('n_id:' || n_id ||' des: '||n_des );  
DBMS_OUTPUT.PUT_LINE(rst);


rst := 'OK';

altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: ' 
|| n_id
||' n_des: '
|| n_des
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe  este id de tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_des: '
|| n_des
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta descripcion del tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_des
||' n_des: '
|| n_des
, 'rst', rst, rst);
ROLLBACK;



WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des

, 'rst', rst, rst);
ROLLBACK;
END modificaTipoLectura ;
/
CREATE OR REPLACE
PROCEDURE modificaUbicaciones (
n_id		    IN NUMBER,
n_via               IN NUMBER,
n_dir               IN VARCHAR2,
n_num               IN VARCHAR2,
n_pis               IN VARCHAR2,
n_pta               IN VARCHAR2,
n_codigoPostal      IN VARCHAR,
n_localidad         IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaUbicaciones 
PROPSITO: gestiona la modificacin  de una Ubicacion en la tabla ubicaciones
PARAMETERS: n_id, n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad, rst
INPUT: n_id,n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaUbicacion(1,1,'del pez','2','1r','2a','08330',1, rst);
******************************************************************************/
n_dir_ins           VARCHAR2 (50);
n_num_ins           VARCHAR2 (5);
n_pis_ins           VARCHAR2 (5);
n_pta_ins           VARCHAR2 (10);
n_codigoPostal_ins  VARCHAR  (10);

id_test		  INTEGER;
via_test          INTEGER;
localidad_test    INTEGER;
dup_id		  EXCEPTION;
dup_via           EXCEPTION;
dup_localidad     EXCEPTION;
err_msg           VARCHAR2 (100);
des_nulo          EXCEPTION;

BEGIN
-- controlar la longitud de las entradas
n_dir_ins               := SUBSTR (n_dir, 1, 50);
n_num_ins               := SUBSTR (n_num, 1, 5);
n_pis_ins               := SUBSTR (n_pis, 1, 5);
n_pta_ins               := SUBSTR (n_pta, 1, 10);
n_codigoPostal_ins      := SUBSTR (n_codigoPostal, 1, 10);


--verificamos que los campos no nulos no sean nulos
IF (n_id              IS NULL)
OR (n_via             IS NULL)
OR (n_dir             IS NULL)
OR (n_num             IS NULL)
OR (n_codigoPostal    IS NULL)
OR (n_localidad       IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista la ubicacin 
SELECT COUNT (*)
INTO id_test
FROM ubicaciones
WHERE ubicaciones.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--Verificamos que exista la via
SELECT COUNT (*)
INTO via_test
FROM via
WHERE via.id = n_via;
IF (via_test = 0)
THEN
RAISE dup_via;
END IF;


--verificamos que exista la localidad

SELECT COUNT (*)
INTO localidad_test
FROM localidad
WHERE localidad.id = n_localidad;
IF (localidad_test = 0)
THEN
RAISE dup_localidad;
END IF;

-- insertamos la nueva ubicacion
INSERT INTO ubicaciones(
via
,dir
,num
,pis
,pta
,codigoPostal
,localidad)
VALUES (n_via
,n_dir_ins
,n_num_ins
,n_pis_ins
,n_pta_ins
,n_codigoPostal_ins
,n_localidad);
-- Fin de las operaciones
rst := 'OK. Modificacin de ubicacin ';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');
        DBMS_OUTPUT.PUT_LINE(
        'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad);
        
        DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_via
THEN
      rst := 'ERROR: No existe este cdigo de via';
      DBMS_OUTPUT.ENABLE;    
      DBMS_OUTPUT.PUT_LINE('');  
      DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_localidad
THEN
    rst := 'ERROR: NO  existe localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
        rst := 'ERROR: hay campos nulos que no tienen datos';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');  
        DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc: altaUbicacion: ' 
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
END modificaUbicaciones ;
/
create or replace PROCEDURE modificaVia(
n_id    IN NUMBER,
n_des   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaVia
PROPSITO: gestiona la modificacin  de una via
PARAMETERS: n_id,n_des, rst
INPUT: n_id, n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaVia(1,'Rambla', rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test        INTEGER;
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_idVia       EXCEPTION;
desVia_nulo      EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos campos nulos
IF ( n_id  IS NULL)
OR (n_des_ins IS NULL) THEN
RAISE desVia_nulo;
END IF;
--verificamos si existe la via
SELECT COUNT (*)
INTO id_test
FROM VIA
WHERE via.id  = n_id;
IF (id_test = 0)
THEN
RAISE dup_idVia;
END IF;


-- modificamos la via
UPDATE via
SET
via.des = n_des_ins
where
via.id = n_id; 

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modificacin via: ' || n_id); 
    rst:='Ok, Modificacin Via ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_idVia
THEN
    rst := 'ERROR: No existe esta Via';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_id, 'rst', rst, rst);
ROLLBACK;
WHEN desVia_nulo
THEN
    rst := 'ERROR: el tipo de via  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaVia;
/* FIN_GESTOR_MODIFICA */