CREATE OR REPLACE FUNCTION getCentralEmax(n_id    NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getCentralEmax
PROPSITO:  para conocer la energia mxima que puede producir la central
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getCentralEmax (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         NUMBER;
BEGIN
SELECT      centrales.EMAX 
INTO ret
FROM centrales
WHERE
centrales.ID = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getCentralEmax', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getCentralEmax;
----------------------------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoCentral(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoCentral
PROPSITO:  para conocer el consumo la central -contadores conectados-, activa
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getConsumoCentral (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;
BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM estados, linea, lineas, contadores, centrales, consumos
WHERE
lineas.C1             = centrales.ID    -- conectadas
AND lineas.C2         = contadores.ID   -- con contadores
AND lineas.LINEA      = linea.ID      
AND consumos.CONTADOR = contadores.ID
AND centrales.ESTADO  =   1         -- activas
AND contadores.ESTADO =   1         -- activos
AND lineas.ESTADO     =   1         -- activas
AND Linea.ESTADO      =   1         -- activos
--AND centrales.CLASE   =   1         -- central de distribucion
GROUP BY centrales.ID
HAVING   SUM(consumos.CONSUMO)>-1 AND 
centrales.id = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoCentral;
----------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoCentralAnyo(n_id  NUMBER, n_anyo  NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoCentralAnyo
PROPSITO:  para conocer el consumo en un ao determinado de una la central de produccin
PARAMETERS: n_id, n_anyo
INPUT:      n_id, n_ayo
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getConsumoCentralAnyo (2,2011)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;
BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM estados, linea, lineas, contadores, centrales, consumos
WHERE
lineas.C1             = centrales.ID    -- central conectada
AND lineas.C2         = contadores.ID   --contadores conectados
AND lineas.LINEA      = linea.ID
AND consumos.CONTADOR = contadores.ID
AND centrales.ESTADO  =   1         -- activas
AND contadores.ESTADO =   1         -- activos
AND lineas.ESTADO     =   1         -- activas
AND Linea.ESTADO      =   1         -- activa
AND centrales.CLASE   =   2         -- produccion
AND consumos.ANYO     =   n_anyo
GROUP BY centrales.ID
HAVING   SUM(consumos.CONSUMO)>-1 AND 
centrales.id = n_id ;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoCentralAnyo', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:  ' || n_id 
||' n_anyo:  ' || n_anyo 
, 'rst', rst, rst);
ROLLBACK;
END getConsumoCentralAnyo;
-------------------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoCliente(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoMedioCliente
PROPSITO:  para conocer el consumo de un cliente en alta, contadores activos y conectados
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret 
RETORNA:    ret ( variable con el consumo medio del cliente )
EJEMPLO DE USO: getConsumoMedioCliente (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         	NUMBER;

BEGIN

SELECT  sum (consumos.consumo)
INTO ret
FROM CONSUMOS,   contadores, lineas, contratos, clientes
WHERE
contadores.ESTADO     = 1       -- en alta
and contratos.ESTADO  = 1       -- vigentes
and  clientes.ESTADO  = 1       -- en alta
and  lineas.ESTADO    = 1       -- en servicio
and  contadores.ID    = lineas.C2               -- conectados
and  contadores.ID    = contratos.CONTADOR      -- con contrato
and  clientes.ID      = contratos.CLIENTE       -- con el cliente    
and contadores.ID     = consumos.CONTADOR
and consumos.consumo >0
and clientes.ID = n_id;

RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoMedioCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoCliente;
--------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoContador(n_id  NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoContador
PROPSITO:  para conocer el consumo de un contador, activo y conectado
PARAMETERS: n_id
INPUT:      n_id
OUTPUT: -
RETORNA:    ret ( variable con el consumo total del contador )
EJEMPLO DE USO: getConsumoContador (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         	NUMBER;

BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM estados, linea, lineas, contadores,  consumos
WHERE
lineas.C2              	 = contadores.ID 	-- conectado
AND lineas.LINEA       	 = linea.ID	
AND consumos.CONTADOR  	 = contadores.ID
AND contadores.ESTADO   	=   1		-- en alta
AND lineas.ESTADO       	=   1		-- en alta	
AND Linea.ESTADO        	=   1		-- en alta
GROUP BY consumos.CONTADOR
HAVING   SUM(consumos.CONSUMO)>-1 AND 	        -- con consumo
consumos.CONTADOR = n_id;			
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoContador', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoContador;
-------------------------------------------
/
CREATE OR REPLACE
FUNCTION getConsumoContadorFecha(n_id  NUMBER,n_anyo NUMBER,n_mes NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoContadorFecha
PROPSITO:  para conocer el consumo del contador en un ao y mes determinado
PARAMETERS: n_id, n_anyo, n_mes
INPUT:      n_id, n_ayo, n_mes
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo   )
EJEMPLO DE USO: getConsumoContadorFecha (2,2011,1)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;

BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM    consumos
WHERE
 consumos.CONTADOR      = n_id
AND consumos.ANYO       = n_anyo
AND consumos.MES        = n_mes;

RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoContadorFecha', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:  ' || n_id 
||' n_anyo:  ' || n_anyo 
||' n_mes:  ' || n_mes
, 'rst', rst, rst);
END getConsumoContadorFecha;
------------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoLinea(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoCentral
PROPSITO:  para conocer el consumo la linea -contadores conectados-, activa
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getConsumoLinea (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         NUMBER;
BEGIN
select  sum (consumos.CONSUMO)
INTO ret
from linea, lineas, contadores, consumos, estados
where
linea.ID                  = lineas.LINEA
and lineas.C2             = contadores.ID
and contadores.id         = consumos.CONTADOR
and estados.ID            = contadores.ESTADO
--and contadores.ESTADO     = 1
--and linea.ESTADO          = 1
--and lineas.ESTADO         = 1
group by linea.id
HAVING   SUM(consumos.CONSUMO)>-1 AND 
linea.ID = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoLinea;
/
CREATE OR REPLACE
FUNCTION getConsumoLocalidadFecha(n_id NUMBER, n_anyo NUMBER, n_mes VARCHAR2)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoLocalidadFecha
PROPSITO:  para conocer el consumo en un ao determinado de una la central de produccin
PARAMETERS: n_id, n_anyo, n_mes
INPUT:      n_id, n_ayo, n_mes
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo   )
EJEMPLO DE USO: getConsumoLocalidadFecha (2,2011,1)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;
consumos_test   INTEGER;
BEGIN

SELECT sum(consumos.CONSUMO)
--SELECT   consumos.id, consumos.anyo, consumos.mes, consumos.CONSUMO, consumos.CONTADOR
INTO ret
FROM CONSUMOS, localidad, contadores, lineas, linea
WHERE
     contadores.ESTADO    =   1             -- vigentes
and linea.ESTADO          =   1             -- activa
and lineas.ESTADO         =   1             -- conexin activa
and linea.ID              = lineas.LINEA
and contadores.ID         = consumos.CONTADOR
and lineas.C2             = consumos.CONTADOR   -- que esten conectados
and localidad.ID           =  n_id    -- de la localidad que buscamos
and consumos.ANYO         = n_anyo    -- anyo de consumo
and consumos.MES          = n_mes     -- mes de consumo
and consumos.consumo >0;              -- con consumo
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoLocalidadFecha', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:  ' || n_id 
||' n_anyo:  ' || n_anyo 
||' n_mes:  ' || n_mes
, 'rst', rst, rst);
END getConsumoLocalidadFecha;
-------------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoMedioCliente(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoMedioCliente
PROPSITO:  para conocer el consumo medio de un cliente en alta, contadores activos y conectados
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret 
RETORNA:    ret ( variable con el consumo medio del cliente )
EJEMPLO DE USO: getConsumoMedioCliente (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         	NUMBER;

BEGIN

SELECT  avg (consumos.consumo)
INTO ret
FROM CONSUMOS,   contadores, lineas, contratos, clientes
WHERE
contadores.ESTADO     = 1       -- en alta
and contratos.ESTADO  = 1       -- vigentes
and  clientes.ESTADO  = 1       -- en alta
and  lineas.ESTADO    = 1       -- en servicio
and  contadores.ID    = lineas.C2               -- conectados
and  contadores.ID    = contratos.CONTADOR      -- con contrato
and  clientes.ID      = contratos.CLIENTE       -- con el cliente    
and contadores.ID     = consumos.CONTADOR
and consumos.consumo >0
and clientes.ID = n_id;

RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoMedioCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoMedioCliente;
--------------------------------
/
CREATE OR REPLACE
FUNCTION getConsumoMedioLocalidadFecha(n_id NUMBER, n_anyo NUMBER, n_mes VARCHAR2)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoMedioLocalidadFecha
PROPSITO:  para conocer el consumo en un ao determinado de una la central de produccin
PARAMETERS: n_id, n_anyo, n_mes
INPUT:      n_id, n_ayo, n_mes
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo   )
EJEMPLO DE USO: getConsumoMedioLocalidadFecha (2,2011,1)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER(9,2);
consumos_test   INTEGER;
BEGIN

SELECT avg(consumos.CONSUMO)
--SELECT   consumos.id, consumos.anyo, consumos.mes, consumos.CONSUMO, consumos.CONTADOR
INTO ret
FROM CONSUMOS, localidad, contadores, lineas, linea
WHERE
     contadores.ESTADO    =   1             -- vigentes
and linea.ESTADO          =   1             -- activa
and lineas.ESTADO         =   1             -- conexin activa
and linea.ID              = lineas.LINEA
and contadores.ID         = consumos.CONTADOR
and lineas.C2             = consumos.CONTADOR   -- que esten conectados
and localidad.ID           =  n_id    -- de la localidad que buscamos
and consumos.ANYO         = n_anyo    -- anyo de consumo
and consumos.MES          = n_mes     -- mes de consumo
and consumos.consumo >0;              -- con consumo
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoLocalidadFecha', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:  ' || n_id 
||' n_anyo:  ' || n_anyo 
||' n_mes:  ' || n_mes
, 'rst', rst, rst);
END getConsumoMedioLocalidadFecha;
-------------------------------------
/
CREATE OR REPLACE FUNCTION getLineaCmax(n_id    NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getLineaCmax
PROPSITO:  para conocer la energia mxima que tiene la linea 
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( variable con la capaciad  )
EJEMPLO DE USO: getLineaCmax (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         NUMBER;
BEGIN
SELECT      linea.CMAX 
INTO ret
FROM linea
WHERE
linea.ID = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getLineaCmax', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getLineaCmax;
----------------------------------------------------
/
CREATE OR REPLACE FUNCTION getLineaConsumo(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoCentral
PROPSITO:  para conocer el consumo la linea -contadores conectados-, activa
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getLineaConsumo (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         NUMBER;
BEGIN
 SELECT  sum (consumos.CONSUMO)
INTO ret
 FROM
 linea, lineas, contadores, consumos
 WHERE
 linea.id = lineas.LINEA
 and contadores.ID = lineas.C2
 and lineas.C2 = consumos.CONTADOR
 and linea.ID = 1
 group by linea.id
 having  sum (consumos.CONSUMO) > 0;

RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getLineaConsumo', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getLineaConsumo;
/
CREATE OR REPLACE FUNCTION getNomCliente(n_id NUMBER)
RETURN      VARCHAR2
IS
/******************************************************************************
NOMBRE:     getNomCliente
PROPSITO:  conocer los apellidos y nombre del cliente
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret 
RETORNA:    ret ( contiene los apellidos y nombre  del cliente )
EJEMPLO DE USO: getNomCliente (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             VARCHAR2 (150);

BEGIN

SELECT  (clientes.APE1 ||' ' || clientes.APE2 ||','|| clientes.NOM)
INTO ret
FROM  clientes
WHERE
clientes.ID = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getNomCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getNomCliente;
----------------------------------------
/
CREATE OR REPLACE FUNCTION getUbica(n_id IN NUMBER)
RETURN     Varchar2
IS
/******************************************************************************
NOMBRE:     getUbica
PROPSITO:  conocer los datos de la ubicacin
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( contiene los datos de la ubicacin: direccin, num, piso,
                  puerta, localidad, cdigo postal, provincia y pais )
EJEMPLO DE USO: getUbica (2)
******************************************************************************/
err_msg     VARCHAR2 (100);
rst 	    VARCHAR2 (100);
ret         VARCHAR2 (100);
BEGIN
SELECT  
via.DES
|| ubicaciones.DIR ||' '
|| ubicaciones.NUM ||' '
|| ubicaciones.PIS ||' '
|| ubicaciones.PTA ||' '
|| localidad.DES   ||' ('
|| ubicaciones.CODIGOPOSTAL   ||') '
|| provincia.DES   ||' '
|| pais.DES
INTO ret
FROM via, ubicaciones, localidad, provincia, pais
WHERE 
via.ID              =   ubicaciones.VIA
AND localidad.ID    =   ubicaciones.LOCALIDAD
AND provincia.ID    =   localidad.PROVINCIA
AND pais.ID         =   provincia.PAIS
AND ubicaciones.ID  =   n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getUbica', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getUbica;
/
CREATE OR REPLACE FUNCTION getIdCliente(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getIdCliente
PROPSITO:  conocer el codigo del cliente
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret 
RETORNA:    ret ( el codigo del cliente )
EJEMPLO DE USO: getIdCliente (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;

BEGIN

SELECT  clientes.id
INTO ret
FROM  clientes
WHERE
clientes.ID = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getNomCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getIdCliente;
----------------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoLineaAnyo(
n_id    NUMBER,
n_anyo  NUMBER
)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoLineaAnyo
PROPSITO:  para conocer el consumo de una linea en una ao concreto
PARAMETERS: n_id, n_anyo
INPUT:      n_id, n_anyo
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getConsumoLineaAnyo (2,2011);
******************************************************************************/
ret         NUMBER;
BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM estados, linea, lineas, contadores,  consumos
WHERE
lineas.C2         = contadores.ID -- contadores conectados
AND lineas.LINEA      = linea.ID
AND consumos.CONTADOR = contadores.ID
AND contadores.ESTADO  =   1
AND lineas.ESTADO     =   1
AND Linea.ESTADO      =   1
AND consumos.ANYO     =   n_anyo
GROUP BY linea.ID
HAVING   SUM(consumos.CONSUMO)>-1 AND 
linea.id = n_id ;
IF (ret = 0)
THEN ret :=1;
END IF;
RETURN ret;
END getConsumoLineaAnyo;
---------------------------
