/* GESTOR_ESTADISTICAS */
CREATE OR REPLACE
PROCEDURE altaE1(
n_central				IN NUMBER,
n_consumoContadores			IN NUMBER,
n_fecha                                 IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE1
PROPSITO: gestiona el alta en la tabla estadstica E1
Dada una central de produccin, el consumo de los contadores que dependen de la central.
PARAMETERS: n_central, n_consumoContadores, rst
INPUT: n_central, n_consumoContadores
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE1(1,300,to_char(sysdate,'DD/MM/YYYY'),rst)
******************************************************************************/
--definicion de variables
n_fecha_ins     VARCHAR2(11);
central_test	INTEGER;
clase_test      INTEGER;
err_msg       	VARCHAR2 (100);
des_nulo      	EXCEPTION;
dup_clase	EXCEPTION;
dup_central	EXCEPTION;

BEGIN
-- comprobar logitudes
n_fecha_ins  := SUBSTR (n_fecha ,1,11);

--verificamos si hay campos no nulos: nulos
IF 	   (n_central			IS NULL)
	OR (n_consumoContadores 	IS NULL)
        OR (n_fecha_ins          	IS NULL)
THEN
RAISE des_nulo;
END IF;

--obtener el codigo de la clase y verificar que es central de produccin 
--obtenemos el codigo de la clase

SELECT ccentral.ID
INTO clase_test
FROM ccentral
WHERE ccentral.DES = 'PRODUCCION' OR 
      ccentral.DES = 'PRODUCCIN';
IF (clase_test = 0)
THEN
RAISE dup_clase;
END IF;
--comprobar que la central existe
SELECT COUNT(*)
INTO central_test
FROM centrales
WHERE centrales.ID = n_central
and centrales.CLASE = clase_test;
IF (central_test=0)
THEN
RAISE dup_central;
END IF;

-- insertamos en E1
INSERT INTO E_1(central,consumoContadores,fecha)
VALUES (n_central, n_consumoContadores,n_fecha_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E1: '  || 'n_central: '  ||  n_central|| ' '||n_fecha_ins); 
    rst:='OK, Alta de E1  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
   , 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_clase
THEN
    rst := 'ERROR: NO existe clase de Central de Produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || clase_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central
THEN
    rst := 'ERROR: NO existe la central de produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_central: ' || n_central, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
    , 'rst', rst, rst);
ROLLBACK;
end altaE1;
/
CREATE OR REPLACE
PROCEDURE altaE2(
n_linea				IN NUMBER,
n_anyo  			IN NUMBER,
n_consumoEnergiaMedio           IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE2
PROPSITO: gestiona el alta en la tabla estadstica E_2
Dada una lnea de comunicacin y un ao en concreto, el valor medio de la energa consumida
si el contador hace servir dos lineas, computa en las dos
PARAMETERS: n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio, rst
INPUT:      n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE2(1,20112,50,rst);
******************************************************************************/
--definicion de variables
linea_test	INTEGER;
err_msg       	VARCHAR2 (100);
dup_linea	EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN
--verificamos si hay campos no nulos: nulos
IF 	   (n_linea			IS NULL)
--	OR (n_consumoContadores 	IS NULL)
      	OR (n_consumoEnergiaMedio 	IS NULL)
THEN
RAISE des_nulo;
END IF;
--comprobar que la linea existe
SELECT count(*)
INTO linea_test
FROM linea
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
--actualizamos la tabla E_2
INSERT INTO E_2(linea, anyo, consumoEnergiaMedio)
VALUES (n_linea,n_anyo, n_consumoEnergiaMedio);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E2: '  || 'n_linea: '  ||  n_linea || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio ); 
    
    rst:='OK, Alta de E2  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
   , 'rst', rst, rst);
COMMIT;
-- control de excepciones
EXCEPTION
WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_linea
THEN
    rst := 'ERROR: NO existe la linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;
END altaE2;
/
CREATE OR REPLACE
PROCEDURE altaE3(
n_linea				IN NUMBER,
n_consumoContadores             IN NUMBER,
n_fecha                         IN VARCHAR,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE3
PROPSITO: gestiona el alta en la tabla estadstica E_3
PARAMETERS: n_lina,n_anyo, n_consumoContadores, n_fecharst
INPUT:      n_lina,n_anyo, n_consumoContadores, n_fecha
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE3(1,200,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
--definicion de variables
n_fecha_ins     VARCHAR2(11);
linea_test	INTEGER;
err_msg       	VARCHAR2 (100);
dup_linea	EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN
-- comprobar logitudes
n_fecha_ins  := SUBSTR (n_fecha ,1,11);

--verificamos si hay campos no nulos: nulos
IF 	   (n_linea			IS NULL)
	OR (n_consumoContadores 	IS NULL)
        OR (n_fecha_ins          	IS NULL)
THEN
RAISE des_nulo;
END IF;



--comprobar que la linea existe
SELECT count(*)
INTO linea_test
FROM linea
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
-- insertamos en E3
INSERT INTO E_3(linea,consumoContadores,fecha)
VALUES (n_linea,n_consumoContadores,n_fecha_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E3: '  || 'n_linea: '  ||  n_linea); 
    DBMS_OUTPUT.PUT_LINE('Alta de E3: '  || 'n_consumoContadores: '  ||  n_consumoContadores); 
    DBMS_OUTPUT.PUT_LINE('Alta de E3: '  || 'n_fecha: '  ||  n_fecha_ins); 

    rst:='OK, Alta de E3  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_linea
THEN
    rst := 'ERROR: NO existe la linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
    , 'rst', rst, rst);
ROLLBACK;
END altaE3;
/
CREATE OR REPLACE
PROCEDURE altaE4(
n_anyo  		IN NUMBER,
n_perLineaMas50         IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE4
PROPSITO: gestiona el alta en la tabla estadstica 
            Dado un ao en concreto: porcentaje de lineas que superan 50% de energia consumida.
PARAMETERS: n_anyo, n_perLineaMas50, rst
INPUT:      n_anyo, n_perLineaMas50
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE4(2012,90,rst);
******************************************************************************/
--definicion de variables
--n_anyo_ins        VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;

BEGIN
--control de la longitud de cadenas
--n_anyo_ins := SUBSTR (n_anyo, 1, 4);

--verificamos si hay campos no nulos: nulos
IF 	   (n_anyo			IS NULL)
	OR (n_perLineaMas50 	        IS NULL)
THEN
RAISE des_nulo;
END IF;
-- insertamos en E4
INSERT INTO E_4(anyo,perLineaMas50) VALUES (n_anyo, n_perLineaMas50);

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E4: '  || 'n_anyo: '  ||  n_anyo); 
    DBMS_OUTPUT.PUT_LINE('Alta de E4: '  || 'n_perLineaMas50: '  ||  n_perLineaMas50); 
    rst:='OK, Alta de E4  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      ' n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
    , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      ' n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
    , 'rst', rst, rst);
ROLLBACK;
END altaE4;
/
CREATE OR REPLACE
PROCEDURE altaE5(
n_anyo  		        IN NUMBER,
n_cenProduccionMenos30          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE5
PROPSITO: gestiona el alta en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_anyo, cenProduccionMenos30, rst
INPUT:      n_anyo, cenProduccionMenos30 
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE5('2012',90,rst);
******************************************************************************/
--definicion de variables
--n_anyo_ins        VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;

BEGIN
--control de la longitud de cadenas
--n_anyo_ins := SUBSTR (n_anyo, 1, 4);

--verificamos si hay campos no nulos: nulos
IF 	   (n_anyo			        IS NULL)
	OR (n_cenProduccionMenos30 	        IS NULL)
THEN
RAISE des_nulo;
END IF;
-- insertamos en E4
INSERT INTO E_5(anyo,cenProduccionMenos30) VALUES (n_anyo, n_cenProduccionMenos30);

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E5: '  || 'n_anyo: '  ||  n_anyo); 
    DBMS_OUTPUT.PUT_LINE('Alta de E5: '  || 'n_cenProduccionMenos30: '  ||  n_cenProduccionMenos30); 
    rst:='OK, Alta de E5  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
    , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
    , 'rst', rst, rst);
ROLLBACK;
END altaE5;
/
CREATE OR REPLACE
PROCEDURE altaE6(
n_contador  	IN NUMBER,
n_consumo       IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE6
PROPSITO: gestiona el alta en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_contador,n_consumo, rst
INPUT:      n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE6('2012',90,rst);
******************************************************************************/
--definicion de variables
contador_test     VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
dup_contador      EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_contador        IS NULL)
	OR (n_consumo         IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

-- insertamos en E6
INSERT INTO E_6(contador,consumo) VALUES (n_contador, n_consumo);

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E6: '  || 'n_contador: '  ||  n_contador); 
    DBMS_OUTPUT.PUT_LINE('Alta de E6: '  || 'n_consumo: '  ||  n_consumo); 
    rst:='OK, Alta de E6  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
    , 'rst', rst, rst);
ROLLBACK;
END altaE6;
/
CREATE OR REPLACE
PROCEDURE altaE7(
n_cliente  	      IN NUMBER,
n_consumoMedio        IN NUMBER,
rst OUT VARCHAR2
)
IS

/******************************************************************************
NOMBRE: altaE7
PROPSITO: gestiona el alta en la tabla estadstica E_7
            Consumo medio de todos los clientes.
PARAMETERS: n_contador,n_consumo, rst
INPUT:      n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE7(2,90,rst);
******************************************************************************/
--definicion de variables
cliente_test      INTEGER;
err_msg       	  VARCHAR2 (100);
dup_cliente       EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_cliente           IS NULL)
	OR (n_consumoMedio      IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista el  cliente 
SELECT COUNT (*)
INTO cliente_test
FROM clientes
WHERE clientes.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

-- insertamos en E7
INSERT INTO E_7(cliente,consumoMedio) VALUES (n_cliente, n_consumoMedio);

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E_7: '  || 'n_cliente: '  ||  n_cliente); 
    DBMS_OUTPUT.PUT_LINE('Alta de E_7: '  || 'n_consumoMedio : '  ||  n_consumoMedio ); 
    rst:='OK, Alta de E_7  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_cliente
THEN
    rst := 'ERROR: NO existe el Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
    , 'rst', rst, rst);
ROLLBACK;
END altaE7;
/
CREATE OR REPLACE
PROCEDURE bajaE1(
n_id				IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE1
PROPSITO: gestiona el borrado del registro en la tabla estadstica E1
PARAMETERS: n_id, rst
INPUT: n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE1(1,rst)
******************************************************************************/
--definicion de variables
id_test		INTEGER;
err_msg       	VARCHAR2 (100);
des_nulo      	EXCEPTION;
dup_id		EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
IF 	   (n_id IS NULL)
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_1
WHERE E_1.id = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--borramos en E1
DELETE
FROM E_1
WHERE id=n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Baja/borrado en E1: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Borrado del registro en E1  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
   , 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;

END bajaE1;
/
CREATE OR REPLACE
PROCEDURE bajaE2(
n_id				IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE2
PROPSITO: baja del registro en la  la tabla estadstica E_2
Dada una lnea de comunicacin y un ao en concreto, el valor medio de la energa consumida
si el contador hace servir dos lineas, computa en las dos
PARAMETERS: n_id, rst
INPUT: n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE2(1,rst);
******************************************************************************/
--definicion de variables

id_test         INTEGER;
err_msg       	VARCHAR2 (100);
dup_id          EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
 	   
IF 	   (n_id  IS NULL)

THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_2
WHERE E_2.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--borramos registro de  E2
DELETE
FROM E_2
WHERE id=n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Baja del registro  E_2: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Baja del registro E_2:  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_id: '
    ||  n_id
     , 'rst', rst, rst);
ROLLBACK;
END bajaE2;
/
CREATE OR REPLACE
PROCEDURE bajaE3(

n_id 	IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE3
PROPSITO: gestiona la baja la tabla estadstica E_3
PARAMETERS: n_id,rst
INPUT:      n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE3(1,rst);
******************************************************************************/
--definicion de variables
id_test INTEGER;
err_msg       	VARCHAR2 (100);
dup_id EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
IF (n_id		IS NULL)

THEN
RAISE des_nulo;
END IF;



--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_3
WHERE E_3.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;


--borrar registro  E3
DELETE FROM E_3
WHERE id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Borrar registro  E3: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Borrar registro de E3  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
	'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;



WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
	'n_id: '
    ||  n_id
   , 'rst', rst, rst);
ROLLBACK;



WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. BajaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
	'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;
END bajaE3;
/
CREATE OR REPLACE
PROCEDURE bajaE4(
n_id		IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE4
PROPSITO: gestiona la baja del registro  de la  tabla estadstica 
            Dado un ao en concreto: porcentaje de lineas que superan 50% de energia consumida.
PARAMETERS: n_id,n_anyo, n_perLineaMas50, rst
INPUT:      n_id,n_anyo, n_perLineaMas50
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE4(1,rst);
******************************************************************************/
--definicion de variables
id_test       INTEGER;
err_msg       	  VARCHAR2 (100);
dup_id		EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_id              IS NULL)  
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_4
WHERE E_4.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

-- baja del registro en E4
DELETE FROM E_4
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Borrado registro de  E4: '  || 'n_id: '  ||  n_id);  
    rst:='OK, Borrado resgistro de   E4  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
    
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE4',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
   , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;
END bajaE4;
/
CREATE OR REPLACE
PROCEDURE bajaE5(
n_id				IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE5
PROPSITO: gestiona la baja del registro en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_id, rst
INPUT:      n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE5(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test		INTEGER;
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;
dup_id			EXCEPTION;
BEGIN

--verificamos si hay campos no nulos: nulos
IF 	  (n_id                   IS NULL)
THEN
RAISE des_nulo;
END IF;
--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_5
WHERE E_5.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--boramos el registro de  E5
DELETE FROM  E_5
WHERE id = n_id;
-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Borrado registro de   E_5: '  || 'n_id: '  ||  n_id);  
    rst:='OK, Borrado registro de   E_5  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
       , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE5',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
   , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
      , 'rst', rst, rst);
ROLLBACK;
END bajaE5;
/
CREATE OR REPLACE
PROCEDURE bajaE6(
n_id			IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE6
PROPSITO: gestiona el borrado del registro en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_id,n_contador,n_consumo, rst
INPUT:      n_id,n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE6(1,rst);
******************************************************************************/
--definicion de variables
id_test			INTEGER;
err_msg       	  VARCHAR2 (100);
dup_id            EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_id 			IS NULL)
	
THEN
RAISE des_nulo;
END IF;



--Verificamos exista el  registro 
SELECT COUNT (*)
INTO id_test
FROM E_6
WHERE E_6.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


--borramos el registro de E_6
DELETE FROM  E_6
WHERE id = n_id;

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Borrar el registro de  E6: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Modifica de E6  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
    , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el Registro';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 	'n_id: '
    ||  n_id
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;
END bajaE6;
/
CREATE OR REPLACE
PROCEDURE bajaE7(
n_id		      IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE7
PROPSITO: gestiona la baja del registro  en la tabla estadstica E_7
            Consumo medio de todos los clientes.
PARAMETERS: n_id,rst
INPUT:      n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE7(1,rst);
******************************************************************************/
--definicion de variables
id_test		  INTEGER;
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;
dup_id		  EXCEPTION;
BEGIN


--verificamos si hay campos no nulos: nulos
    IF 	   (n_id 	        IS NULL)
THEN
RAISE des_nulo;
END IF;


--Borrar registro de  E7
DELETE FROM E_7
WHERE id = n_id;

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Borrar registro de  E_7: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Borrar registro de E7 realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id : '
    ||  n_id
       , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_id: '
    ||  n_id
       , 'rst', rst, rst);
ROLLBACK;


WHEN dup_id
THEN
    rst := 'ERROR: NO existe el Registro';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;
END bajaE7;
/
CREATE OR REPLACE
PROCEDURE modificaE1(
n_id				IN NUMBER,
n_central			IN NUMBER,
n_consumoContadores		IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE1
PROPSITO: gestiona la modificacion en la tabla estadstica E1
PARAMETERS: n_id,n_central, n_consumoContadores, rst
INPUT: n_id,n_central, n_consumoContadores
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE1(1,1,300,rst)
******************************************************************************/
--definicion de variables
central_test	INTEGER;
clase_test      INTEGER;
id_test		INTEGER;
err_msg       	VARCHAR2 (100);
des_nulo      	EXCEPTION;
dup_clase	EXCEPTION;
dup_central	EXCEPTION;
dup_id		EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
IF 	   (n_id			IS NULL)
	OR (n_central			IS NULL)
	OR (n_consumoContadores 	IS NULL)
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM centrales
WHERE centrales.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;


--obtener el codigo de la clase y verificar que es central de produccin 
--obtenemos el codigo de la clase

SELECT ccentral.ID
INTO clase_test
FROM ccentral
WHERE ccentral.DES = 'PRODUCCION' OR 
      ccentral.DES = 'PRODUCCIN';
IF (clase_test = 0)
THEN
RAISE dup_clase;
END IF;
--comprobar que la central existe
SELECT COUNT(*)
INTO central_test
FROM centrales
WHERE centrales.ID = n_central
and centrales.CLASE = clase_test;
IF (central_test=0)
THEN
RAISE dup_central;
END IF;


--modificamos E1
UPDATE E_1
SET
central=n_central,
consumoContadores=n_consumoContadores
WHERE id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modificado  E1: '  || 'n_central: '  ||  n_central); 
    rst:='OK, Modificado de E1  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
   , 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_clase
THEN
    rst := 'ERROR: NO existe clase de Central de Produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || clase_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central
THEN
    rst := 'ERROR: NO existe la central de produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_central: ' || n_central, 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe la central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_central: ' || n_central, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    , 'rst', rst, rst);
ROLLBACK;

END modificaE1;
/
CREATE OR REPLACE
PROCEDURE modificaE2(
n_id				IN NUMBER,
n_linea				IN NUMBER,
n_anyo  			IN VARCHAR2,
n_consumoContadores             IN NUMBER,
n_consumoEnergiaMedio           IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE2
PROPSITO: modifica la tabla estadstica E_2
Dada una lnea de comunicacin y un ao en concreto, el valor medio de la energa consumida
si el contador hace servir dos lineas, computa en las dos
PARAMETERS: n_id,n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio, rst
INPUT: n_id,n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE2(1,1,'2012',90,50,rst);
******************************************************************************/
--definicion de variables
linea_test	INTEGER;
id_test         INTEGER;
err_msg       	VARCHAR2 (100);
dup_id          EXCEPTION;
dup_linea	EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
 	   
IF 	   (n_id			IS NULL)
	OR (n_linea			IS NULL)
	OR (n_consumoContadores 	IS NULL)
      	OR (n_consumoEnergiaMedio 	IS NULL)

THEN
RAISE des_nulo;
END IF;

--comprobar que la linea existe
SELECT count(*)
INTO linea_test
FROM linea
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_2
WHERE E_2.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--modificamos E2
UPDATE E_2
SET
linea= n_linea,
anyo = n_anyo, 
consumoContadores = n_consumoContadores,
consumoEnergiaMedio= n_consumoEnergiaMedio
WHERE id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modificacion de E_2: '  || 'n_linea: '  ||  n_linea); 
    rst:='OK, Modificacion de E_2:  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_linea
THEN
    rst := 'ERROR: NO existe la linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe la central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;
END modificaE2;
/
CREATE OR REPLACE
PROCEDURE modificaE3(

n_id 	IN NUMBER,
n_linea				IN NUMBER,
n_consumoContadores             IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE2
PROPSITO: gestiona el alta en la tabla estadstica E_3
PARAMETERS: n_lina,n_anyo, n_consumoContadores rst
INPUT:      n_lina,n_anyo, n_consumoContadores
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE3(1,200,rst);
******************************************************************************/
--definicion de variables
id_test INTEGER;
linea_test	INTEGER;
err_msg       	VARCHAR2 (100);
dup_id EXCEPTION;
dup_linea	EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
IF (n_id		IS NULL)
	 OR  (n_linea			IS NULL)
	OR (n_consumoContadores 	IS NULL)
THEN
RAISE des_nulo;
END IF;

--comprobar que la linea existe
SELECT count(*)
INTO linea_test
FROM linea
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;


--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_3
WHERE E_3.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;


--modificamos E3
UPDATE E_3
SET
linea= n_linea,
consumoContadores = n_consumoContadores
WHERE id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('modifica  E3: '  || 'n_linea: '  ||  n_linea); 
    DBMS_OUTPUT.PUT_LINE('modifica  E3: '  || 'n_consumoContadores: '  ||  n_consumoContadores); 
    rst:='OK, Alta de E3  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_linea
THEN
    rst := 'ERROR: NO existe la linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
   , 'rst', rst, rst);
ROLLBACK;



WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    , 'rst', rst, rst);
ROLLBACK;
END modificaE3;
/
CREATE OR REPLACE
PROCEDURE modificaE4(
n_id		IN NUMBER,
n_anyo  		IN VARCHAR2,
n_perLineaMas50         IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE4
PROPSITO: gestiona la modificacin de la  tabla estadstica 
            Dado un ao en concreto: porcentaje de lineas que superan 50% de energia consumida.
PARAMETERS: n_id,n_anyo, n_perLineaMas50, rst
INPUT:      n_id,n_anyo, n_perLineaMas50
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE4(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test       INTEGER;
n_anyo_ins        VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
dup_id		EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN
--control de la longitud de cadenas
n_anyo_ins := SUBSTR (n_anyo, 1, 4);

--verificamos si hay campos no nulos: nulos
IF 	   (n_id              IS NULL)  
       OR (n_anyo_ins	      IS NULL)
	OR (n_perLineaMas50   IS NULL)
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_4
WHERE E_4.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;



-- modificamos en E4
UPDATE E_4
SET
anyo = n_anyo,
perLineaMas50= n_perLineaMas50
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica E4: '  || 'n_anyo: '  ||  n_anyo); 
    DBMS_OUTPUT.PUT_LINE('Modifica E4: '  || 'n_perLineaMas50: '  ||  n_perLineaMas50); 
    rst:='OK, Modifica  E4  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE4',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
   , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
    , 'rst', rst, rst);
ROLLBACK;
END modificaE4;
/
CREATE OR REPLACE
PROCEDURE modificaE5(
n_id				IN NUMBER,
n_anyo  		        IN VARCHAR2,
n_cenProduccionMenos30          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE5
PROPSITO: gestiona la modificacin en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_id,n_anyo, cenProduccionMenos30, rst
INPUT:      n_id,n_anyo, cenProduccionMenos30 
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE5(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test		INTEGER;
n_anyo_ins        VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;
dup_id			EXCEPTION;
BEGIN
--control de la longitud de cadenas
n_anyo_ins := SUBSTR (n_anyo, 1, 4);

--verificamos si hay campos no nulos: nulos
IF 	  (n_id                   IS NULL)
      OR  (n_anyo_ins		  IS NULL)
      OR (n_cenProduccionMenos30  IS NULL)
THEN
RAISE des_nulo;
END IF;
--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_5
WHERE E_5.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--modificamos E5
UPDATE E_5
SET
anyo = n_anyo,
cenProduccionMenos30 = n_cenProduccionMenos30
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica  E_5: '  || 'n_anyo: '  ||  n_anyo); 
    DBMS_OUTPUT.PUT_LINE('Modifica  E_5: '  || 'n_cenProduccionMenos30: '  ||  n_cenProduccionMenos30); 
    rst:='OK, Modifica  E_5  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE5',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
   , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
    , 'rst', rst, rst);
ROLLBACK;
END modificaE5;
/
CREATE OR REPLACE
PROCEDURE modificaE6(
n_id			IN NUMBER,
n_contador  	IN NUMBER,
n_consumo       IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE6
PROPSITO: gestiona la modificacin en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_id,n_contador,n_consumo, rst
INPUT:      n_id,n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE6(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test			INTEGER;
contador_test     VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
dup_contador      EXCEPTION;
dup_id            EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_id 			IS NULL)
	OR (n_contador       IS NULL)
	OR (n_consumo        IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--Verificamos exista el  registro 
SELECT COUNT (*)
INTO id_test
FROM E_6
WHERE E_6.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


--modificamos E_6
UPDATE E_6
SET
contador= n_contador,
consumo= n_consumo
WHERE id = n_id;

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica E6: '  || 'n_contador: '  ||  n_contador); 
    DBMS_OUTPUT.PUT_LINE('Modifica E6: '  || 'n_consumo: '  ||  n_consumo); 
    rst:='OK, Modifica de E6  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el Registro';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
    , 'rst', rst, rst);
ROLLBACK;
END modificaE6;
/
CREATE OR REPLACE
PROCEDURE modificaE7(
n_id		      IN NUMBER,
n_cliente  	      IN NUMBER,
n_consumoMedio        IN NUMBER,
rst OUT VARCHAR2
)
IS

/******************************************************************************
NOMBRE: modificaE7
PROPSITO: gestiona el alta en la tabla estadstica E_7
            Consumo medio de todos los clientes.
PARAMETERS: n_id,n_contador,n_consumo, rst
INPUT:      n_id,n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE7(1,2,90,rst);
******************************************************************************/
--definicion de variables
id_test		  INTEGER;
cliente_test      INTEGER;
err_msg       	  VARCHAR2 (100);
dup_cliente       EXCEPTION;
des_nulo      	  EXCEPTION;
dup_id		  EXCEPTION;
BEGIN


--verificamos si hay campos no nulos: nulos
    IF 	   (n_id 	        IS NULL)
	OR (n_cliente           IS NULL)
	OR (n_consumoMedio      IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista el  cliente 
SELECT COUNT (*)
INTO cliente_test
FROM clientes
WHERE clientes.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

--modificamos E7
UPDATE E_7
SET
cliente= n_cliente,
consumoMedio= n_consumoMedio
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E_7: '  || 'n_cliente: '  ||  n_cliente); 
    DBMS_OUTPUT.PUT_LINE('Alta de E_7: '  || 'n_consumoMedio : '  ||  n_consumoMedio ); 
    rst:='OK, Alta de E_7  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_cliente
THEN
    rst := 'ERROR: NO existe el Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_id
THEN
    rst := 'ERROR: NO existe el Registro';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
    , 'rst', rst, rst);
ROLLBACK;
END modificaE7;
/
CREATE OR REPLACE
PROCEDURE altaEstadisticas(
n_anyo   IN  NUMBER,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEstadisticas
PROPSITO: gestiona la actualizacion de las estadisticas
PARAMETERS: n_anyo ,rst
INPUT:  n_anyo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaEstadisticas(2011,rst);

******************************************************************************/

-- variables para E_2 y E6
n_contador  NUMBER;
n_consumo   NUMBER;
n_anyo_ins  NUMBER; -- para E_2
e7_test                 INTEGER;
central_test            INTEGER;
lineas_test             INTEGER;
i                       INTEGER;
lMax                    INTEGER; 
iMax                    INTEGER;
porcentaje              NUMBER;
tipo_test               INTEGER;
err_msg                 VARCHAR2(100);

dup_central             EXCEPTION;
dup_lineas              EXCEPTION;
dup_null                EXCEPTION;

-- para actualizar E_2
CURSOR c2 IS
select distinct linea.id, consumos.ANYO, avg(consumos.CONTADOR)
from linea, lineas, consumos
where
linea.ID = lineas.LINEA
AND lineas.C2 = consumos.CONTADOR
AND consumos.ANYO = n_anyo
group by linea.id, consumos.ANYO
order by linea.id;

-- cursor para extraer los datos de Estadistica E6
CURSOR c1 IS
select consumos.CONTADOR,sum(consumos.consumo)
from consumos
group  by consumos.contador 
having sum(consumos.consumo) >0 
order by sum(consumos.consumo) desc;

---------
--proceso
---------
BEGIN
--inicializar variables
i :=1;

-------------------------------
-- actualizar estadisticas E_1
--------------------------------

-- obtenemos el numero de centrales de produccin activas
select  count (distinct centrales.id)
INTO central_test
FROM centrales, ccentral, lineas, linea, consumos, contadores
WHERE
    ccentral.ID     = centrales.CLASE
AND centrales.CLASE = 2                 --produccion
and linea.id = lineas.LINEA
and centrales.ID = lineas.C1            -- conectadas
and consumos.CONTADOR = lineas.C2       -- miro consumos
and contadores.id = lineas.c2           -- conectadas
and linea.ESTADO =1                     -- en alta
and lineas.ESTADO =1                    --en alta
and centrales.ESTADO =1                 --activas
and contadores.ESTADO =1                --en alta
and consumos.CONSUMO > 0;               -- con consumo

IF (central_test = 0)
THEN
RAISE dup_central;
END IF;

--actualizar registros
WHILE (i <= central_test)  LOOP  
--  altaE1(centrales.id,getConsumoCentral(centrales.id),to_char(sysdate,'DD/MM/YYYY'),rst);  -- actualizar el registro
  altaE1(i,getConsumoCentral(i),to_char(sysdate,'DD/MM/YYYY'),rst);  -- actualizar el registro
  --  DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('total_Centrales:' || central_test ||'central: '||central:  || i|| ' consumo:' ||getConsumoCentral(i)||' fecha: '|| to_char(sysdate,'DD/MM/YYYY') );
    i := i + 1;
END LOOP;
-- Fin de las operaciones
rst := 'OK: Actualizo E_1';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');
altaLog('Proc. altaEstadisticas_E1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_2
-------------------------------
--inicializar variables
--i :=0;
n_contador  :=0;  -- variable reutilizada para linea
n_consumo   :=0;  -- variable reutilizada para guardar el consumo medio de la linea
n_anyo_ins :=n_anyo;

 OPEN c2;
               FETCH c2 INTO n_contador ,n_anyo_ins ,n_consumo ;
               WHILE c2%FOUND  LOOP
                               
 --DBMS_OUTPUT.PUT_LINE('');
   DBMS_OUTPUT.PUT_LINE('   linea: ' || n_contador || '  n_anyo: ' || n_anyo || '  consumo_medio: ' || n_consumo );
              FETCH c2 INTO n_contador ,n_anyo_ins ,n_consumo ;
                altaE2(n_contador ,n_anyo_ins, n_consumo,rst);  -- actualizar  el registro
                end loop;
        CLOSE c2;
 -- Fin de las operaciones

rst := 'OK: Actualizo E_2';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
 ||'   n_contador'
 || n_contador
 || '  n_anyo: '
 || n_anyo
 || '  n_consumo: '
 || n_consumo
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_3
------------------------------
i     := 1;
lMax  := 0;
iMax  := 0;
-- obtener numero de lineas conectadas
select  count (distinct linea.ID)
INTO lineas_test
FROM lineas, linea
WHERE
    lineas.LINEA = linea.ID;
IF (lineas_test = 0)
THEN
RAISE dup_lineas;
END IF;
WHILE (i < lineas_test)  LOOP  
 IF (getConsumoLinea(i) > lMax)
    THEN    lMax := getConsumoLinea(i); -- buscar el consumo mximo
            iMax := i;                  -- id de la linea mxima
    END IF;
     i := i + 1;  --avanza
END LOOP;
  altaE3(i,getConsumoLinea(i),to_char(sysdate,'DD/MM/YYYY'),rst);  -- actualizar  el registro
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('Consumo Maximo : '||i ||', '|| lMax );
   -- DBMS_OUTPUT.PUT_LINE('Linea consumo Maximo : '||i ||', '|| getConsumoLinea(i) );
-- Fin de las operaciones

rst := 'OK: Actualizo E_3';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_4
-------------------------------

--lineas_test -> lineas conectadas
i    := 2;
lMax := 0;  --contador si linea supera el 50%
porcentaje := 0;  -- porcentaje final de lineas
    
WHILE (i < lineas_test)  LOOP  
 IF  (getConsumoLineaAnyo(i,n_anyo) > getLineaCMax(i)/2)
    THEN    lMax := lMax +1; -- incrementamos el contador de lina que supera el 50%
      -- DBMS_OUTPUT.PUT_LINE('lineas_test  : '|| lineas_test );
      -- DBMS_OUTPUT.PUT_LINE('lMax  : '|| lMax );
      -- DBMS_OUTPUT.PUT_LINE('i  : '|| i );

        END IF;
     i := i + 1;  --avanza
END LOOP;
 
 porcentaje :=  lMax*100/lineas_test;
 

 altaE4(n_anyo, iMax,rst);  -- actualizar  el registro
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('lineas_test  : '|| lineas_test );
   -- DBMS_OUTPUT.PUT_LINE('n_anyo  : '||i ||', '|| n_anyo );
   -- DBMS_OUTPUT.PUT_LINE('Porcentaje de lineas que superan el 50% : '||porcentaje ||'%'  );
-- Fin de las operaciones

rst := 'OK: Actualizo E_4';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

----------------------------------
-- actualizar estadstica E_5
-----------------------------------
i     := 1;
iMax  := 0;
WHILE (i < central_test)  LOOP  
 IF (getConsumoCentralAnyo(i ,n_anyo) < getCentralEmax(i) * 0.3)  -- produccion < del 30% de eMax de la central
    THEN    
            iMax := iMax+1;                  -- acumulo el numero de centrales
    END IF;
   i := i + 1;
END LOOP;
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('n_anyo : ' || n_anyo );
   -- DBMS_OUTPUT.PUT_LINE('iMax : ' || iMax );

altaE5(n_anyo,iMax,rst); -- actualizar el registro

-- Fin de las operaciones
rst := 'OK: Actualizo E_5';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_6
-------------------------------
--inicializar contador
i :=0;
--verificamos que los campos no nulos no sean nulos
 OPEN c1;
               FETCH c1 INTO n_contador,n_consumo ;
               WHILE (c1%FOUND and ( c1%ROWCOUNT <= 10)) LOOP
                               
 DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
 DBMS_OUTPUT.PUT_LINE('   n_contador: ' || n_contador  || '  n_consumo: ' || n_consumo );
               FETCH c1 INTO n_contador,n_consumo ;
                altaE6(n_contador, n_consumo,rst);  -- actualizar  el registro
                end loop;
        CLOSE c1;
 -- Fin de las operaciones

rst := 'OK: Actualizo E_6';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
 ||'   n_contador'
 || n_contador
 || '  n_consumo: '
 || n_consumo
, 'rst', rst, rst);
COMMIT;

---------------------------------
-- actualizar estadstica E_7
---------------------------------
i :=1;
--obterner el numero de clientes 
select count(distinct clientes.id)
into e7_test
from contratos, clientes, contadores, consumos
where clientes.ID   = contratos.CLIENTE
and  contadores.ID  = contratos.CONTADOR
and  contadores.ID  = consumos.CONTADOR;
WHILE (i < e7_test)  LOOP  
altaE7(getIdCliente(i), getConsumoMedioCliente(i),rst);  -- actualizar el registro
i := i + 1;
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('Cliente y consumo medio : '||getIdCliente(i) ||', '|| getConsumoMedioCliente(i) );
END LOOP;

-- Fin de las operaciones
rst := 'OK: Actualizo E_7';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;
---------------------------------------------


EXCEPTION
WHEN dup_central
THEN
    rst := 'ERROR: No hay centrales';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEstadistica E_1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_lineas
THEN
    rst := 'ERROR: No hay lineas conectadas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEstadistica_E_3 ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaEstadisticas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
 err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaEstadisticas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;
END altaEstadisticas;

/*
--- lanzar proceso
declare
    rst varchar2(250);
begin
altaEstadisticas(2011,rst);
END;
*/
/* FIN GESTOR_ESTADISTICAS */
 

