CREATE OR REPLACE FUNCTION getConsumoCentralAnyo(n_id  NUMBER, n_anyo  NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoCentralAnyo
PROPSITO:  para conocer el consumo en un ao determinado de una la central de produccin
PARAMETERS: n_id, n_anyo
INPUT:      n_id, n_ayo
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getConsumoCentralAnyo (2,2011)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;
BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM estados, linea, lineas, contadores, centrales, consumos
WHERE
lineas.C1             = centrales.ID    -- central conectada
AND lineas.C2         = contadores.ID   --contadores conectados
AND lineas.LINEA      = linea.ID
AND consumos.CONTADOR = contadores.ID
AND centrales.ESTADO  =   1         -- activas
AND contadores.ESTADO =   1         -- activos
AND lineas.ESTADO     =   1         -- activas
AND Linea.ESTADO      =   1         -- activa
AND centrales.CLASE   =   2         -- produccion
AND consumos.ANYO     =   n_anyo
GROUP BY centrales.ID
HAVING   SUM(consumos.CONSUMO)>-1 AND 
centrales.id = n_id ;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoCentralAnyo', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:  ' || n_id 
||' n_anyo:  ' || n_anyo 
, 'rst', rst, rst);
ROLLBACK;
END getConsumoCentralAnyo;
-------------------------------------------
/