CREATE OR REPLACE FUNCTION getConsumoMedioCliente(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoMedioCliente
PROPSITO:  para conocer el consumo medio de un cliente en alta, contadores activos y conectados
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret 
RETORNA:    ret ( variable con el consumo medio del cliente )
EJEMPLO DE USO: getConsumoMedioCliente (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         	NUMBER;

BEGIN

SELECT  avg (consumos.consumo)
INTO ret
FROM CONSUMOS,   contadores, lineas, contratos, clientes
WHERE
contadores.ESTADO     = 1       -- en alta
and contratos.ESTADO  = 1       -- vigentes
and  clientes.ESTADO  = 1       -- en alta
and  lineas.ESTADO    = 1       -- en servicio
and  contadores.ID    = lineas.C2               -- conectados
and  contadores.ID    = contratos.CONTADOR      -- con contrato
and  clientes.ID      = contratos.CLIENTE       -- con el cliente    
and contadores.ID     = consumos.CONTADOR
and consumos.consumo >0
and clientes.ID = n_id;

RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoMedioCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoMedioCliente;
--------------------------------
/