CREATE OR REPLACE
PROCEDURE altaCentralDistribucion(
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaCentralDistribucion
PROPSITO: gestiona el alta de una Central de DISTRIBUCION
PARAMETERS: n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT: n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaCentralDistribucion('BCN_D4',1,to_char(sysdate,'DD/MM/YYYY'),2,3,20,10,1,to_char(sysdate,'DD/MM/YYYY'),500,null,rst);
******************************************************************************/
n_des_ins             VARCHAR2(50);
n_obs_ins             VARCHAR2(50);
dist_test                       INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
ins_test                        INTEGER;
err_msg         		VARCHAR2 (100);
dup_dist                        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
des_nulo  			EXCEPTION;
dup_ins                         EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);
--verificamos que los campos nulos no sean nulos
IF   (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_clase IS NULL)
	OR (n_tipo IS NULL)
	OR (n_eMax IS NULL)
	OR (n_eMin IS NULL)
	OR (n_inspeccion IS NULL)
	OR (n_fIns IS NULL)
	OR (n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;
--verificamos si existe la descripcin de la  Central
SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_central;
END IF;
-- obtener el codigo de la central de Distribucion
SELECT id
INTO dist_test
FROM ccentral
WHERE
ccentral.des='DISTRIBUCION' OR 
ccentral.DES='DISTRIBUCIN';
IF (dist_test = 0)
THEN
RAISE dup_dist; 
END IF;

IF (n_clase <> dist_test)
THEN
RAISE dup_dist; -- no es central de Distribucion
END IF;

--verificamos exista la clase de central y que sea de Central de Distribucion

SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; 
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

--verificamos  que exista el tipo de inspeccion
SELECT COUNT (*)
INTO ins_test
FROM tInspeccion
WHERE tInspeccion.id = n_inspeccion;
IF (ins_test = 0)   
THEN
RAISE dup_ins; 
END IF;


-- insertamos la nueva central
INSERT INTO centrales
(des,estado,fechaEstado,clase,tipo,eMax,eMin,inspeccion,fIns,ubica,obs)
VALUES
(n_des_ins,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs_ins);

-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta CENTRAL OK: ' || n_des_ins); 
    rst:='OK, Alta CENTRAL  ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA CENTRAL: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION
WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta  Central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacion  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;

WHEN dup_dist
THEN
    rst := 'ERROR: No es CENTRAL DE DISTRIBUCION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || dist_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ins
THEN
    rst := 'ERROR: No existe el tipo de inspeccion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_inspeccion: ' || n_inspeccion, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. altaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaCentralDistribucion;
/


------------- inicializar
--------------------------

drop  SEQUENCE centrales_SEQ_GRAL;;
CREATE  SEQUENCE centrales_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER   centrales_TR_KEY
    BEFORE INSERT       ON  centrales         FOR EACH ROW
   BEGIN      SELECT        centrales_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
select * from centrales
declare
    rst varchar2(250);
begin


--	                 n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs
altaCentralDistribucion('BCN_D1',1,to_char(sysdate,'DD/MM/YYYY'),1,1,17000,100,1,to_char(sysdate,'DD/MM/YYYY'),4,null,rst);
altaCentralDistribucion('BCN_D2',1,to_char(sysdate,'DD/MM/YYYY'),1,2,18000,100,1,to_char(sysdate,'DD/MM/YYYY'),5,null,rst);
altaCentralDistribucion('BCN_D3',1,to_char(sysdate,'DD/MM/YYYY'),1,3,17000,100,1,to_char(sysdate,'DD/MM/YYYY'),6,null,rst);
altaCentralDistribucion('BCN_D4',1,to_char(sysdate,'DD/MM/YYYY'),1,3,17000,100,1,to_char(sysdate,'DD/MM/YYYY'),7,null,rst);
altaCentralDistribucion('BCN_D5',1,to_char(sysdate,'DD/MM/YYYY'),1,4,17000,100,1,to_char(sysdate,'DD/MM/YYYY'),8,null,rst);
altaCentralDistribucion('BCN_D6',1,to_char(sysdate,'DD/MM/YYYY'),1,4,17000,100,1,to_char(sysdate,'DD/MM/YYYY'),9,null,rst);
altaCentralDistribucion('BCN_D7',1,to_char(sysdate,'DD/MM/YYYY'),1,4,17000,100,1,to_char(sysdate,'DD/MM/YYYY'),9,null,rst);
altaCentralDistribucion('BCN_D8',1,to_char(sysdate,'DD/MM/YYYY'),1,5,17000,100,1,to_char(sysdate,'DD/MM/YYYY'),9,null,rst);
altaCentralDistribucion('BCN_D9',1,to_char(sysdate,'DD/MM/YYYY'),1,5,17000,100,1,to_char(sysdate,'DD/MM/YYYY'),9,null,rst);
altaCentralDistribucion('BCN_D10',1,to_char(sysdate,'DD/MM/YYYY'),1,5,17000,100,1,to_char(sysdate,'DD/MM/YYYY'),9,null,rst);
end;













