CREATE OR REPLACE
PROCEDURE altaClientes (
n_estado            IN NUMBER,
n_tipo              IN NUMBER,
n_nifCif            IN VARCHAR2,
n_nom               IN VARCHAR2,
n_ape1              IN VARCHAR2,
n_ape2              IN VARCHAR2,
n_email             IN VARCHAR2,
n_tMovil            IN VARCHAR2,
n_ubica             IN NUMBER,
n_fechaAlta         IN VARCHAR2,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaCliente
PROPSITO: gestiona el alta de un cliente en la tabla clientes
PARAMETERS: n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,
n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod, rst
INPUT: n_estado, n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,
n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaClientes(1,4,'43073208X', 'Alberto', 'Ramos', null, 'aramossa@uoc.edu','34671535222',1,'17/04/2012',null, rst);
******************************************************************************/

n_nifCif_ins          VARCHAR2(10 CHAR);
n_nom_ins             VARCHAR2(50 CHAR);
n_ape1_ins            VARCHAR2(50 CHAR);
n_ape2_ins            VARCHAR2(50 CHAR);
n_email_ins           VARCHAR2(50 CHAR);
n_tMovil_ins          VARCHAR2(11 CHAR);
n_ubica_ins           NUMBER;
n_fechaAlta_ins       VARCHAR2(11 CHAR);
n_fechaMod_ins        VARCHAR2(11 CHAR);

estado_test         INTEGER;
tipo_test           INTEGER;
nifCif_test         INTEGER;
ubica_test          INTEGER;

err_msg             VARCHAR2(100);

dup_estado          EXCEPTION;
dup_tipo            EXCEPTION;
dup_nifCif          EXCEPTION;
dup_ubica           EXCEPTION;

dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_nifCif_ins        := SUBSTR (n_nifCif, 1, 10);
n_nom_ins           := SUBSTR (n_nom, 1, 50);
n_ape1_ins          := SUBSTR (n_ape1, 1, 50);
n_ape2_ins          := SUBSTR (n_ape2, 1, 50);
n_email_ins         := SUBSTR (n_email, 1, 50);
n_tMovil_ins        := SUBSTR (n_tMovil, 1, 11);
n_fechaAlta_ins     := SUBSTR (n_fechaAlta, 1, 11);
n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_estado          IS NULL)
OR (n_tipo            IS NULL)
OR (n_nifCif_ins      IS NULL)
OR (n_nom_ins         IS NULL)
OR (n_ape1_ins        IS NULL)
OR (n_ubica           IS NULL)
OR (n_fechaAlta_ins   IS NULL)
THEN
RAISE dup_des;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--comprobar tipo cliente
SELECT COUNT (*)
INTO tipo_test
FROM TCLIENTE
WHERE tCliente.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;

--comprobar que la ubicacion exista 

SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.ID = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;

--verificamos que el nifCifel cliente  no exista
SELECT COUNT (*)
INTO nifCif_test
FROM CLIENTES
WHERE nifCif = n_nifCif_ins;
IF (nifCif_test > 0)
THEN
RAISE dup_nifCif;
END IF;


-- insertamos el nuevo cliente
INSERT INTO CLIENTES (estado,
tipo,
nifCif,
nom,
ape1,
ape2,
email,
tMovil,
ubica,
fechaAlta,
fechaMod)

VALUES (n_estado,
n_tipo,
n_nifCif_ins,
n_nom_ins, 
n_ape1_ins,
n_ape2_ins,
n_email_ins,
n_tMovil_ins,
n_ubica,
n_fechaAlta_ins,
n_fechaMod_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('cliente: ' || n_ape1_ins 
    ||','
    || n_ape2_ins
    ||','
    ||n_nom    
    ); 
    rst:='Ok, Alta cliente   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado: '
|| n_estado 
|| ', '
||'n_tipo  : ' 
|| n_tipo
|| ', ' 
||'n_nifCif  : ' 
|| n_nifCif 
|| ', ' 
||'n_nom: ' 
|| n_nom 
|| ', ' 
||'n_ape1: '
|| n_ape1 
|| ', '
||'n_ape2: '
|| n_ape2
|| ', '
||'n_email: '
|| n_email 
|| ', ' 
||'n_tMovil: '
|| n_tMovil 
|| ', ' 
||'n_ubica: '
|| n_ubica 
|| ', ' 
||'n_fechaAlta: '
|| n_fechaAlta 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION
WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tipo
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_tipo : ' || n_tipo  ); 
     rst := 'ERROR: NO existe TIPO CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el TIPO CLIENTE ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_tipo : ' || n_tipo 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_nifCif
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_nifCif : ' || n_nifCif_ins  ); 
     rst := 'ERROR:  ya existe este NIF / CIF';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: ya  existe el NIF - CIFT ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_nifCif : ' || n_nifCif 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe la UBICACION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la UBICACION ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica : ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado: '
|| n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_nifCif: '
|| n_nifCif 
, 'rst', rst, rst);
ROLLBACK;
END altaClientes;
/

--prueba de uso
declare rst varchar2(250);
begin
-- 		n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod, rst
altaClientes(1,1,'49213673K','AARON','DOUHET','MALAGRAVA','49213673K@.gmail.com','670123123',1,'23/11/2001','23/11/2001',rst);
altaClientes(1,1,'11259485L','ABDELKRIM','FONTOUA','DUCREUX','11259485L@.gmail.com','670123124',2,'23/11/2002','23/11/2002',rst);
altaClientes(1,1,'57248539K','ABAELKADER','FONZ','SALIP','57248539K@.gmail.com','670123125',3,'23/11/2003','23/11/2003',rst);
altaClientes(1,1,'74075914K','ABDERRAHMAN','CHAVARRIAS','PAXERAS','74075914K@.gmail.com','670123126',4,'23/11/2004','23/11/2004',rst);
altaClientes(1,1,'44331870Z','ABDELMALIK','HERETTE','MAIDEU','44331870Z@.gmail.com','670123127',5,'23/11/2005','23/11/2005',rst);
altaClientes(1,1,'33624203C','ABDELKADER','BANTULA','BARRACA','33624203C@.gmail.com','670123128',6,'23/11/2006','23/11/2006',rst);
altaClientes(1,1,'41929980Z','ABDEL','IBORRA','ALGORA','41929980Z@.gmail.com','670123129',7,'23/11/2007','23/11/2007',rst);
altaClientes(1,1,'39895167B','ABDELAH','BUTTICAZ','RECAMAN','39895167B@.gmail.com','670123130',8,'23/11/2008','23/11/2008',rst);
altaClientes(1,1,'39487303Y','ABDERRAMAN','NGOUNDO','ESPONADE','39487303Y@.gmail.com','670123131',9,'23/11/2009','23/11/2009',rst);
altaClientes(1,1,'77784282F','ABDERRAMAN','TAMERON','PLAZA','77784282F@.gmail.com','670123132',10,'23/11/2010','23/11/2010',rst);
altaClientes(1,1,'27323876Z','ABDESELAN','YSNARD','ESCUER','27323876Z@.gmail.com','670123133',11,'23/11/2011','23/11/2011',rst);
altaClientes(1,1,'71829137E','ABDESELAN','BLENNER','GURUPEGUI','71829137E@.gmail.com','670123134',12,'23/11/2012','23/11/2012',rst);
altaClientes(1,1,'22489285T','ABDULAI','PARDINAS','ARREGUS','22489285T@.gmail.com','670123135',13,'23/11/2013','23/11/2013',rst);
altaClientes(1,1,'95979492D','ABDERRAMAN','LAPIDO','ESTARRONA','95979492D@.gmail.com','670123136',14,'23/11/2014','23/11/2014',rst);
altaClientes(1,1,'24936715T','ABDESSELAM','LABAQUIOL','GARIDO','24936715T@.gmail.com','670123137',15,'23/11/2015','23/11/2015',rst);
altaClientes(1,1,'11434537H','ABDESSELAN','PUNYOLES','SALAGUREN','11434537H@.gmail.com','670123138',16,'23/11/2016','23/11/2016',rst);
altaClientes(1,1,'74101919J','ABDO','AHIJADO','BEIXACONILL','74101919J@.gmail.com','670123139',17,'23/11/2017','23/11/2017',rst);
altaClientes(1,1,'16682439X','ABDULIA','ARRAUT','SANTALUCIA','16682439X@.gmail.com','670123140',18,'23/11/2018','23/11/2018',rst);
altaClientes(1,1,'80687355C','ABDONA','CHADRADA','MARFAGON','80687355C@.gmail.com','670123141',19,'23/11/2019','23/11/2019',rst);
altaClientes(1,1,'10409647P','ABDESLAM','BELMEZ','RASHID','10409647P@.gmail.com','670123142',20,'23/11/2020','23/11/2020',rst);
altaClientes(1,1,'32019954K','ABDESSELAN','TRUNAS','WICHI','32019954K@.gmail.com','670123143',21,'23/11/2021','23/11/2021',rst);
altaClientes(1,1,'83443541R','ABELARD','GOYRI','GABA?AS','83443541R@.gmail.com','670123144',22,'23/11/2022','23/11/2022',rst);
altaClientes(1,1,'63766967L','ABELARD','ORTENSI','JENARO','63766967L@.gmail.com','670123145',23,'23/11/2023','23/11/2023',rst);
altaClientes(1,1,'19746097E','ABDULKADER','GAYANGO','BREMER','19746097E@.gmail.com','670123146',24,'23/11/2024','23/11/2024',rst);
altaClientes(1,1,'15604221D','ABELARDO','MONPEL','CARBELLIDO','15604221D@.gmail.com','670123147',25,'23/11/2025','23/11/2025',rst);
altaClientes(1,1,'11358801K','ABUNDIO','BARRERES','VELERDAS','11358801K@.gmail.com','670123148',26,'23/11/2026','23/11/2026',rst);
altaClientes(1,1,'29044777D','ABNER','TINAJERO','FERRONE','29044777D@.gmail.com','670123149',27,'23/11/2027','23/11/2027',rst);
altaClientes(1,1,'69058724M','ABELINO','PALMOU','HONTANGAS','69058724M@.gmail.com','670123150',28,'23/11/2028','23/11/2028',rst);
altaClientes(1,1,'66949376X','ABELIA','BONNIERE','FRANCO','66949376X@.gmail.com','670123151',29,'23/11/2029','23/11/2029',rst);
altaClientes(1,1,'92478964N','ABSELAM','VICASTILLO','PAREIX','92478964N@.gmail.com','670123152',30,'23/11/2030','23/11/2030',rst);
altaClientes(1,1,'32918632C','ABUNDIO','YELAMOS','SOIAN','32918632C@.gmail.com','670123153',31,'23/11/2031','23/11/2031',rst);
altaClientes(1,1,'48201179X','ACAN','QUERA','BIESENBENDER','48201179X@.gmail.com','670123154',32,'23/11/2032','23/11/2032',rst);
altaClientes(1,1,'60081776A','ACAN','ESTIVARIT','','60081776A@.gmail.com','670123155',33,'23/11/2033','23/11/2033',rst);
altaClientes(1,1,'56944545H','ACHI','FOURNIERS','BALDEVELL','56944545H@.gmail.com','670123156',34,'23/11/2034','23/11/2034',rst);
end;








