CREATE OR REPLACE
PROCEDURE altaConsumos(
n_contador          IN NUMBER,
n_anyo     	    IN NUMBER,
n_mes               IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaConsumos
PROPSITO: gestiona el alta en la tabla de consumos
PARAMETERS:  n_contador,n_anyo, n_mes,n_consumo, rst
INPUT:   n_contador, n_anyo,n_mes,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaConsumos(1,2011,1,12 rst)
******************************************************************************/

contador_test           INTEGER;
err_msg                 VARCHAR2 (100);
dup_contador            EXCEPTION;
dup_null                EXCEPTION;

BEGIN

--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_anyo              IS NULL)
OR (n_mes               IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;


--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;
-- insertamos el nuevo registro en consumos
INSERT INTO consumos(
contador,
anyo,
mes,
consumo
)
VALUES (
n_contador,
n_anyo,
n_mes,
n_consumo
);
-- Fin de las operaciones
rst := 'OK';
DBMS_OUTPUT.PUT_LINE('n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo);

DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes_ins: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END altaConsumos;
/


--inicializar
drop table consumos       cascade constraint purge;
CREATE TABLE consumos 
(
 ID             NUMBER          CONSTRAINT      PK_consumos               PRIMARY KEY,
 contador                       CONSTRAINT      FK_consumos_contador      REFERENCES contadores(ID) NOT NULL, 
 anyo     NUMBER  CONSTRAINT      NN_consumos_anyo          NOT NULL,
 mes      NUMBER  CONSTRAINT      NN_consumos_mes           NOT NULL,
-- anyo         VARCHAR2(4 CHAR)  CONSTRAINT      NN_consumos_anyo          NOT NULL,
-- mes          VARCHAR2(2 CHAR)  CONSTRAINT      NN_consumos_mes           NOT NULL,
 consumo       NUMBER(9,2) --CONSTRAINT NN_consumos_tConsumo  
);
DROP  SEQUENCE consumos_SEQ_GRAL;
CREATE  SEQUENCE consumos_SEQ_GRAL    START WITH 1    INCREMENT BY 1  NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER               consumos_TR_KEY
    BEFORE INSERT      ON               consumos
    FOR EACH ROW   BEGIN      SELECT    consumos_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;


declare
    rst varchar2(250);
begin
altaConsumos(1,to_char(sysdate,'YYYY'),to_char(sysdate,'MM'),12, rst);
end;
declare
    rst varchar2(250);
begin
altaConsumos(2,'2010','07',15, rst);
END;

-- con numero
declare
    rst varchar2(250);
begin
altaConsumos(2,2010,7,15, rst);
END;


select * from log
SELECT * from lecturas
select * from CONSUMOS