CREATE OR REPLACE
PROCEDURE altaContadores(
n_modelo         	IN NUMBER,
n_ubica         	IN NUMBER,
n_estado         	IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
n_numSerie         	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaContadores
PROPSITO: gestiona el alta de un contador en la tabla contadores
PARAMETERS: n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie,rst
INPUT: n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaContadores(1,1,1,to_char(sysdate,'DD/MM/YYYY'), 'n/s_1', rst);
******************************************************************************/
n_fechaEstado_ins       VARCHAR2(11 CHAR);
n_numSerie_ins          VARCHAR2(20);

modelo_test             NUMBER;
ubica_test              NUMBER;
estado_test             NUMBER;

err_msg                 VARCHAR2(100);
  dup_modelo            EXCEPTION;
dup_ubica               EXCEPTION;
dup_estado              EXCEPTION;
  dup_des               EXCEPTION;

BEGIN


n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 
n_numSerie_ins      := SUBSTR(n_numSerie, 1, 20);


--verificamos que los campos no nulos no sean nulos
IF (n_modelo          IS NULL)
OR (n_ubica           IS NULL)
OR (n_estado          IS NULL)
OR (n_fechaEstado_ins IS NULL)
OR (n_numSerie_ins    IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que existe el modelo
SELECT COUNT (*)
INTO modelo_test
FROM MODELOS
WHERE ID = n_modelo;
IF (modelo_test = 0)
THEN
RAISE dup_modelo;
END IF;
--comprobar que existe la  ubicacion
SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--insertamos el nuevo contador
INSERT INTO CONTADORES 
(modelo,
ubica,
estado,
fechaEstado,
numSerie)

VALUES 
(n_modelo,
n_ubica,
n_estado,
n_fechaEstado_ins,
n_numSerie_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_modelo : ' || n_modelo ); 
    rst:='Ok, Alta contador   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' 
|| n_modelo 
|| ', ' 
||'n_ubica  : '
|| n_ubica
|| ', ' 
||'n_estado  : '
|| n_estado
|| ', ' 
||'n_fechaEstado: '
|| n_fechaEstado_ins
|| ', ' 
||'n_numSerie: '
|| n_numSerie_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_modelo
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_modelo : ' || n_modelo  ); 
     rst := 'ERROR: No existe Modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' || n_modelo  
, 'rst', rst, rst);

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe ubicacin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica: ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: No existe Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado ' || n_estado
|| ', '
||'n_fechaEstado: ' || n_fechaEstado 
, 'rst', rst, rst);

ROLLBACK;
WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCcontador', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);
ROLLBACK;
END altaContadores;
/




DROP  SEQUENCE contadores_SEQ_GRAL;
CREATE  SEQUENCE contadores_SEQ_GRAL  START WITH 1    INCREMENT BY 1  NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER   contadores_TR_KEY
    BEFORE INSERT    ON     contadores
    FOR EACH ROW
   BEGIN      SELECT        contadores_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
declare rst varchar2(250);
begin
-- 		n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie
altaContadores(1,12,1,'01/01/2004','123456789',rst);
altaContadores(1,18,1,'01/01/2005','123456790',rst);
altaContadores(2,50,1,'01/01/2006','123456791',rst);
altaContadores(2,76,1,'01/01/2007','123456792',rst);
altaContadores(2,83,1,'01/01/2008','123456793',rst);
altaContadores(2,2,1,'01/01/2009','123456794',rst);
altaContadores(3,2,1,'01/01/2010','123456795',rst);
altaContadores(3,2,1,'01/01/2011','123456796',rst);
altaContadores(3,2,1,'01/01/2012','123456797',rst);
altaContadores(3,2,1,'01/01/1995','123456798',rst);
altaContadores(4,2,1,'01/01/1996','123456799',rst);
altaContadores(4,2,1,'01/01/1997','123456800',rst);
altaContadores(4,2,1,'01/01/1998','123456801',rst);
altaContadores(4,2,1,'01/01/1999','123456802',rst);
altaContadores(4,2,1,'01/01/2000','123456803',rst);
altaContadores(2,2,1,'01/01/2001','123456804',rst);
altaContadores(2,2,1,'01/01/2002','123456805',rst);
altaContadores(2,2,1,'01/01/2003','123456806',rst);
altaContadores(2,2,1,'01/01/2004','123456807',rst);
altaContadores(2,2,1,'01/01/2005','123456808',rst);
end;




