create or replace PROCEDURE altaContratos(
n_cliente           	IN NUMBER,
n_contador          	IN NUMBER,
n_estado            	IN NUMBER,
n_fechaEstado       	IN VARCHAR2,
n_pContrato         	IN NUMBER,
n_obs             	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaContratos
PROPSITO: gestiona el alta de un contraato en la tabla contratos
PARAMETERS: n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs, rst
INPUT:      n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs
PROCEDURE: altaLecturas(n_contador,n_fechaEstado_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaContratos(1,1,1,to_char(sysdate,'DD/MM/YYYY'),30,'obs_contrato', rst);
******************************************************************************/

n_fechaEstado_ins     VARCHAR2(11 CHAR);
n_obs_ins             VARCHAR2(50 CHAR);

cliente_test		INTEGER;
contador_test		INTEGER;
estado_test             INTEGER;
err_msg                 VARCHAR2(100);

n_anterior    NUMBER;
n_actual      NUMBER;
n_tipo        NUMBER;
n_consumo     NUMBER;
dup_cliente		EXCEPTION;
dup_contador	        EXCEPTION;
dup_estado		EXCEPTION;
dup_des                 EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  	:= SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins               := SUBSTR (n_obs, 1, 50);

-- inicializo contadores de lecturas y consumos 
n_anterior := 0;
n_actual   := 0; 
n_tipo     := 1;
n_consumo  := 0;
--verificamos que los campos no nulos no sean nulos

IF (n_cliente        		IS NULL)
OR (n_contador       		IS NULL)
OR (n_estado      		IS NULL)
OR (n_fechaEstado_ins           IS NULL)
OR (n_pContrato        	        IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que exista el  cliente
SELECT COUNT (*)
INTO cliente_test
FROM CLIENTES
WHERE CLIENTES.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

-- comprobar que exista el contador
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE contadores.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;


--comprobar que exista el estado 

SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;



-- insertamos el nuevo contrato
INSERT INTO CONTRATOS (
cliente,
contador,
estado,
fechaEstado,
pContrato,
obs
)
VALUES (
n_cliente,
n_contador,
n_estado,
n_fechaEstado_ins,
n_pContrato,
n_obs_ins
);
-- llamada procedure: actualiza lecturas y en lecturas llama procedure altaConsumo
altaLecturas(n_contador,n_fechaEstado_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
'n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
    ); 
    rst:='Ok, Alta contrato   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente: '
|| n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
COMMIT;

-- tratamiento de excepciones

EXCEPTION

WHEN dup_cliente
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_cliente : ' || n_cliente  ); 
     rst := 'ERROR: NO existe el CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el CLIENTE ';
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente  : ' || n_cliente
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_contador: ' || n_contador  ); 
     rst := 'ERROR:  NO  existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el CONTADOR';
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: ' || n_contador
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente: '
|| n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato 
||'n_obs: '
|| n_obs 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente: '
|| n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
ROLLBACK;
END altaContratos;
/

--inicializar
drop table contratos      cascade constraint purge;
CREATE TABLE contratos  
(
 ID             NUMBER        CONSTRAINT PK_contratos             PRIMARY KEY,
 cliente                      CONSTRAINT FK1_contratos_cliente    REFERENCES  clientes(ID)    NOT NULL,
 contador                     CONSTRAINT FK2_contratos_contador   REFERENCES  contadores(ID)  NOT NULL,
 estado                       CONSTRAINT FK3_contratos_estado     REFERENCES  estados(ID)     NOT NULL,
 fechaEstado    DATE          CONSTRAINT NN_contratos_fechaEstado                             NOT NULL,
 pContrato      NUMBER (9,2)  CONSTRAINT NN_contratos_pContrato                               NOT NULL,
 obs            VARCHAR(50 CHAR)         NULL
);
drop  SEQUENCE contratos_SEQ_GRAL;
CREATE  SEQUENCE contratos_SEQ_GRAL   START WITH 1    INCREMENT BY 1  NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER   contratos_TR_KEY
    BEFORE INSERT    ON     contratos
    FOR EACH ROW
   BEGIN      SELECT        contratos_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
declare
    rst varchar2(250);
begin
--		n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs, rst
altaContratos(1,1,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_1',rst);
altaContratos(2,2,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_2',rst);
altaContratos(3,3,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_3',rst);
altaContratos(4,4,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_4',rst);
altaContratos(5,5,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_5',rst);
altaContratos(6,6,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_6',rst);
altaContratos(7,7,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_7',rst);
altaContratos(8,8,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_8',rst);
altaContratos(9,9,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_9',rst);
altaContratos(10,10,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_10',rst);
altaContratos(11,11,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_11',rst);
altaContratos(12,12,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_12',rst);
altaContratos(13,13,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_13',rst);
altaContratos(14,14,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_14',rst);
altaContratos(15,15,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_15',rst);
altaContratos(16,16,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_16',rst);
altaContratos(17,17,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_17',rst);
altaContratos(18,18,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_18',rst);
altaContratos(19,19,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_19',rst);
altaContratos(20,20,1,to_char(sysdate,'DD/MM/YYYY'),100,'obs_cliente_20',rst);
end;


declare
    rst varchar2(250);
begin
altaContratos(1,1,1,'01/01/2011',100,'obs_cliente_1',rst);
altaContratos(2,2,1,'01/01/2011',100,'obs_cliente_2',rst);
altaContratos(3,3,1,'01/01/2011',100,'obs_cliente_3',rst);
altaContratos(4,4,1,'01/01/2011',100,'obs_cliente_4',rst);
altaContratos(5,5,1,'01/01/2011',100,'obs_cliente_5',rst);
altaContratos(6,6,1,'01/01/2011',100,'obs_cliente_6',rst);
altaContratos(7,7,1,'01/01/2011',100,'obs_cliente_7',rst);
altaContratos(8,8,1,'01/01/2011',100,'obs_cliente_8',rst);
altaContratos(9,9,1,'01/01/2011',100,'obs_cliente_9',rst);
altaContratos(10,10,1,'01/01/2011',100,'obs_cliente_10',rst);
end;

select * from consumos
select * from lecturas