create or replace PROCEDURE altaEmisionCentral(
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEmisionCentral
PROPSITO: gestiona el alta de un tipo de emisin o especificidad de la  Central
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaEmisionCentral('CO2', rst)
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_ecentral    		EXCEPTION;
desecentral_nulo  	        EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo ECentral.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desECentral_nulo;
END IF;
--verificamos si existe el tipo de emisin
SELECT COUNT (*)
INTO des_test
FROM ECentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_ECentral;
END IF;
-- insertamos el nuevo tipo de ECentral
INSERT INTO ECentral(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de ECentral: ' || n_des_ins); 
    rst:='Ok, Alta Tipo ECentral  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_ECentral
THEN
    rst := 'ERROR: Ya existe este tipo de  ECentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desECentral_nulo
THEN
    rst := 'ERROR: el tipo de ECentral  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaEmisionCentral;
/

drop ecentral_SEQ_GRAL;
CREATE  SEQUENCE ecentral_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER   ecentral_TR_KEY
    BEFORE INSERT       ON  ecentral
    FOR EACH ROW
   BEGIN            SELECT  ecentral_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;

declare
    rst varchar2(250);
begin
altaEmisionCentral('Kg.CO2',rst);
altaEmisionCentral('RESIDUO RADIOACTIVO',rst);
altaEmisionCentral('MOLINOS',rst);
altaEmisionCentral('PLACAS SOLARES ',rst);
end;