create or replace PROCEDURE altaEmpresa(
n_cif			IN VARCHAR2,
n_des 		IN VARCHAR2,
n_estado 		IN NUMBER,
n_fechaEstado	IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEmpresa
PROPSITO: gestiona el alta de una EMPRESA
PARAMETERS: n_cif,n_des,n_estado,n_fechaEstado, rst
INPUT: n_cif,n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaEmpresa('s121214','empresa3',5,'01/05/2012',rst);
******************************************************************************/
n_des_ins       		VARCHAR2 (50);

cif_test				INTEGER;
des_test        		INTEGER;
estado_test				INTEGER;

err_msg         	VARCHAR2 (100);

dup_cif			EXCEPTION;
dup_des    		EXCEPTION;
dup_estado			EXCEPTION;
des_nulo  			EXCEPTION;


BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);

--verificamos si el hay campos nulos
IF (n_cif IS NULL)
OR (n_des_ins IS NULL)
OR (n_estado IS NULL)
OR (n_fechaEstado IS NULL)
THEN
RAISE des_nulo;
END IF;

--verificamos si existe el cif de la empresa
SELECT COUNT (*)
INTO cif_test
FROM empresas
WHERE empresas.cif = n_cif;
IF (cif_test > 0)
THEN
RAISE dup_cif;
END IF;

--verificamos si existe la descripcin de la empresa
SELECT COUNT (*)
INTO des_test
FROM empresas
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos si existe el estado  de la empresa
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;



-- insertamos el nuevo tipo de empresa
INSERT INTO empresas
(cif,des,estado,fechaEstado)
VALUES
(n_cif,n_des_ins,n_estado,n_fechaEstado);


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de EMPRESA: ' || n_des_ins); 
    rst:='Ok, Alta EMPRESA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_cif
THEN
    rst := 'ERROR: Ya existe este CIF';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif

, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe este NOMBRE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif

, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO existe este ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
|| 'estado'
|| n_estado
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Empresa : ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaEmpresa;
/


declare
    rst varchar2(250);
begin
altaEmpresa('A08624203','ENDESA',1,'23/11/2001',rst);
altaEmpresa('A08624204','FECSA',1,'20/07/2008',rst);
altaEmpresa('A08624205','HIDROCARBUROS DEL NORTE',1,'07/11/2010',rst);
altaEmpresa('A08624206','CONTROL ENERGIA CC',1,'01/12/2001',rst);
altaEmpresa('A08624207','CATALANA ENERGETICA',1,'27/02/2007',rst);
altaEmpresa('A08624208','BBENERGY',1,'03/03/2005',rst);
altaEmpresa('A08624209','ENHER',1,'04/02/2008',rst);
altaEmpresa('A08624210','COMPANY ITT',1,'06/07/2005',rst);
altaEmpresa('A08624211','HIDOELECTRIC DEL EBRO',1,'14/06/2005',rst);
altaEmpresa('A08624212','SUNYER I ASSOCIATS',1,'15/03/2002',rst);
altaEmpresa('A08624213','FRANACE CONTROLLER',1,'22/03/2002',rst);
altaEmpresa('A08624214','HESSEN BBP  GERMANY',1,'23/06/2009',rst);
end;










