CREATE OR REPLACE
PROCEDURE altaLectura(
n_contador        IN NUMBER,
n_fechaLectura    IN VARCHAR2,
n_tipo            IN NUMBER,
n_lectura         IN NUMBER,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLectura
PROPSITO: gestiona el alta de una lectura de contador
PARAMETERS:   n_contador, n_fechaLectura,n_tipo,n_lectura,rst
INPUT:        n_contador, n_fechaLectura,n_tipo,n_lectura
PROCEDURE: altaLectura(n_contador,n_fechaLectura_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLectura(1, to_char(sysdate,'DD/MM/YYYY'),1,1212, rst);

******************************************************************************/
n_fechaLectura_ins      VARCHAR2 ( 11 CHAR);
contador_test           INTEGER;
cont_central      INTEGER;
i     integer;
tipo_test               INTEGER;
anterior_test           INTEGER;
n_anterior              NUMBER;
n_actual                NUMBER;
n_consumo               NUMBER;
err_msg                 VARCHAR2 (100);
dup_contador            EXCEPTION;
dup_tipo                EXCEPTION;
dup_null                EXCEPTION;

--proceso
BEGIN
-- comprobamos longitud de cadenas
n_fechaLectura_ins       := SUBSTR (n_fechaLectura, 1, 50);

--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_fechaLectura_ins  IS NULL)
OR (n_tipo              IS NULL)
OR (n_lectura           IS NULL)
THEN
RAISE dup_null;
END IF;

-- obtenemos el numero de centrales de produccin activas
select  count (*)
INTO cont_central
from centrales, ccentral
where
 ccentral.ID = centrales.CLASE
and centrales.CLASE = 2;
--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--verificamos que exista el tipo de  lectura
SELECT COUNT (*)
INTO tipo_test
FROM TLECTURA
WHERE tLectura.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;

-- obtener la lectura anterior del contador
        SELECT lecturas.ANTERIOR
        INTO n_anterior
        FROM lecturas
        WHERE lecturas.CONTADOR= n_contador
        AND  lecturas.FECHALECTURA <= n_fechaLectura_ins
        AND  ROWNUM=1;

-- obtener la lectura actual del contador
        SELECT lecturas.ACTUAL
        INTO n_actual
        FROM lecturas
        WHERE lecturas.CONTADOR= n_contador
        AND  lecturas.FECHALECTURA <= n_fechaLectura_ins
        AND  ROWNUM=1;

-- calcular los campos de lecturas
n_anterior := n_actual;
n_actual    := n_lectura;
n_consumo := (n_actual - n_anterior);

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_actual : ' || n_actual );
    DBMS_OUTPUT.PUT_LINE('n_lectura : ' || n_lectura ); 
    DBMS_OUTPUT.PUT_LINE('n_anterior : ' || n_anterior ); 
    DBMS_OUTPUT.PUT_LINE('n_consumo : ' || n_consumo ); 
    DBMS_OUTPUT.PUT_LINE('');  

-- insertamos la nueva lectura; llamada a procedimiento 

altaLecturas(n_contador,n_fechaLectura_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);
/*
-- actualizar estadisticas E_1
i  := 1;
while (i <= cont_central)  loop  
altaE1(i,getConsumoCentral(i),rst);
cont_central := cont_central + 1;
end loop;
*/

-- Fin de las operaciones
rst := 'OK: Lectura actualizada en Lecturas y Consumos';


altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_tipo
THEN
    rst := 'ERROR: Ya existe esta descripcion del tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
 err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END altaLectura;




select * from lecturas
select * from consumos

--EJEMPLO DE USO: altaLectura(1, to_char(sysdate,'DD/MM/YYYY'),1,1212, rst)

declare
    rst varchar2(250);
begin
-- n_contador, n_fechaLectura,n_tipo,n_lectura
altaLectura(1, to_char(sysdate,'DD/MM/YYYY'),1,1210, rst);
altaLectura(2, to_char(sysdate,'DD/MM/YYYY'),1,1211, rst);
altaLectura(3, to_char(sysdate,'DD/MM/YYYY'),1,1212, rst);
altaLectura(4, to_char(sysdate,'DD/MM/YYYY'),1,1213, rst);
altaLectura(5, to_char(sysdate,'DD/MM/YYYY'),1,1214, rst);
altaLectura(6, to_char(sysdate,'DD/MM/YYYY'),2,125, rst);
altaLectura(7, to_char(sysdate,'DD/MM/YYYY'),2,126, rst);
altaLectura(8, to_char(sysdate,'DD/MM/YYYY'),2,127, rst);
altaLectura(9, to_char(sysdate,'DD/MM/YYYY'),2,128, rst);
altaLectura(10, to_char(sysdate,'DD/MM/YYYY'),2,129, rst);
altaLectura(11, to_char(sysdate,'DD/MM/YYYY'),2,1220, rst);
end;


declare
    rst varchar2(250);
begin
altaLectura(1,'01/01/2011',1,10,rst);
altaLectura(1,'01/02/2011',1,20,rst);
altaLectura(1,'01/03/2011',1,30,rst);
altaLectura(1,'01/04/2011',1,40,rst);
altaLectura(1,'01/05/2011',1,50,rst);
altaLectura(1,'01/06/2011',1,60,rst);
altaLectura(1,'01/07/2011',1,70,rst);
altaLectura(1,'01/08/2011',1,80,rst);
altaLectura(1,'01/09/2011',1,90,rst);
altaLectura(1,'01/10/2011',1,100,rst);
altaLectura(1,'01/11/2011',1,110,rst);
altaLectura(1,'01/12/2011',1,120,rst);
altaLectura(2,'01/01/2011',1,10,rst);
altaLectura(2,'01/02/2011',1,20,rst);
altaLectura(2,'01/03/2011',1,30,rst);
altaLectura(2,'01/04/2011',1,40,rst);
altaLectura(2,'01/05/2011',1,50,rst);
altaLectura(2,'01/06/2011',1,60,rst);
altaLectura(2,'01/07/2011',1,70,rst);
altaLectura(2,'01/08/2011',1,80,rst);
altaLectura(2,'01/09/2011',1,90,rst);
altaLectura(2,'01/10/2011',1,100,rst);
altaLectura(2,'01/11/2011',1,110,rst);
altaLectura(2,'01/12/2011',1,120,rst);
altaLectura(3,'01/01/2011',1,10,rst);
altaLectura(3,'01/02/2011',1,20,rst);
altaLectura(3,'01/03/2011',1,30,rst);
altaLectura(3,'01/04/2011',1,40,rst);
altaLectura(3,'01/05/2011',1,50,rst);
altaLectura(3,'01/06/2011',1,60,rst);
altaLectura(3,'01/07/2011',1,70,rst);
altaLectura(3,'01/08/2011',1,80,rst);
altaLectura(3,'01/09/2011',1,90,rst);
altaLectura(3,'01/10/2011',1,100,rst);
altaLectura(3,'01/11/2011',1,110,rst);
altaLectura(3,'01/12/2011',1,120,rst);
altaLectura(4,'01/01/2011',1,10,rst);
altaLectura(4,'01/02/2011',1,20,rst);
altaLectura(4,'01/03/2011',1,30,rst);
altaLectura(4,'01/04/2011',1,40,rst);
altaLectura(4,'01/05/2011',1,50,rst);
altaLectura(4,'01/06/2011',1,60,rst);
altaLectura(4,'01/07/2011',1,70,rst);
altaLectura(4,'01/08/2011',1,80,rst);
altaLectura(4,'01/09/2011',1,90,rst);
altaLectura(4,'01/10/2011',1,100,rst);
altaLectura(4,'01/11/2011',1,110,rst);
altaLectura(4,'01/12/2011',1,120,rst);
altaLectura(5,'01/01/2011',1,10,rst);
altaLectura(5,'01/02/2011',1,20,rst);
altaLectura(5,'01/03/2011',1,30,rst);
altaLectura(5,'01/04/2011',1,40,rst);
altaLectura(5,'01/05/2011',1,50,rst);
altaLectura(5,'01/06/2011',1,60,rst);
altaLectura(5,'01/07/2011',1,70,rst);
altaLectura(5,'01/08/2011',1,80,rst);
altaLectura(5,'01/09/2011',1,90,rst);
altaLectura(5,'01/10/2011',1,100,rst);
altaLectura(5,'01/11/2011',1,110,rst);
altaLectura(5,'01/12/2011',1,120,rst);
altaLectura(6,'01/01/2011',1,10,rst);
altaLectura(6,'01/02/2011',1,20,rst);
altaLectura(6,'01/03/2011',1,30,rst);
altaLectura(6,'01/04/2011',1,40,rst);
altaLectura(6,'01/05/2011',1,50,rst);
altaLectura(6,'01/06/2011',1,60,rst);
altaLectura(6,'01/07/2011',1,70,rst);
altaLectura(6,'01/08/2011',1,80,rst);
altaLectura(6,'01/09/2011',1,90,rst);
altaLectura(6,'01/10/2011',1,100,rst);
altaLectura(6,'01/11/2011',1,110,rst);
altaLectura(6,'01/12/2011',1,120,rst);
altaLectura(7,'01/01/2011',1,10,rst);
altaLectura(7,'01/02/2011',1,20,rst);
altaLectura(7,'01/03/2011',1,30,rst);
altaLectura(7,'01/04/2011',1,40,rst);
altaLectura(7,'01/05/2011',1,50,rst);
altaLectura(7,'01/06/2011',1,60,rst);
altaLectura(7,'01/07/2011',1,70,rst);
altaLectura(7,'01/08/2011',1,80,rst);
altaLectura(7,'01/09/2011',1,90,rst);
altaLectura(7,'01/10/2011',1,100,rst);
altaLectura(7,'01/11/2011',1,110,rst);
altaLectura(7,'01/12/2011',1,120,rst);
altaLectura(8,'01/01/2011',1,10,rst);
altaLectura(8,'01/02/2011',1,20,rst);
altaLectura(8,'01/03/2011',1,30,rst);
altaLectura(8,'01/04/2011',1,40,rst);
altaLectura(8,'01/05/2011',1,50,rst);
altaLectura(8,'01/06/2011',1,60,rst);
altaLectura(8,'01/07/2011',1,70,rst);
altaLectura(8,'01/08/2011',1,80,rst);
altaLectura(8,'01/09/2011',1,90,rst);
altaLectura(8,'01/10/2011',1,100,rst);
altaLectura(8,'01/11/2011',1,110,rst);
altaLectura(8,'01/12/2011',1,120,rst);
altaLectura(9,'01/01/2011',1,10,rst);
altaLectura(9,'01/02/2011',1,20,rst);
altaLectura(9,'01/03/2011',1,30,rst);
altaLectura(9,'01/04/2011',1,40,rst);
altaLectura(9,'01/05/2011',1,50,rst);
altaLectura(9,'01/06/2011',1,60,rst);
altaLectura(9,'01/07/2011',1,70,rst);
altaLectura(9,'01/08/2011',1,80,rst);
altaLectura(9,'01/09/2011',1,90,rst);
altaLectura(9,'01/10/2011',1,100,rst);
altaLectura(9,'01/11/2011',1,110,rst);
altaLectura(9,'01/12/2011',1,120,rst);
altaLectura(10,'01/01/2011',1,10,rst);
altaLectura(10,'01/02/2011',1,20,rst);
altaLectura(10,'01/03/2011',1,30,rst);
altaLectura(10,'01/04/2011',1,40,rst);
altaLectura(10,'01/05/2011',1,50,rst);
altaLectura(10,'01/06/2011',1,60,rst);
altaLectura(10,'01/07/2011',1,70,rst);
altaLectura(10,'01/08/2011',1,80,rst);
altaLectura(10,'01/09/2011',1,90,rst);
altaLectura(10,'01/10/2011',1,100,rst);
altaLectura(10,'01/11/2011',1,110,rst);
altaLectura(10,'01/12/2011',1,120,rst);
end;



select * from consumos
select * from lecturas


select * from contratos
select * from log