CREATE OR REPLACE
PROCEDURE altaLecturas (
n_contador          IN NUMBER,
n_fechaLectura      IN VARCHAR2,
n_tipo              IN NUMBER,
n_anterior          IN NUMBER,
n_actual            IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLecturas
PROPSITO: gestiona el alta en la tabla de Lecturas
PARAMETERS:  n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo, rst
INPUT:   n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo
PROCEDURE EXTERNA:  altaConsumos(n_contador, n_anyo, n_mes, n_consumo,rst);
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLecturas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,1, rst)
******************************************************************************/
n_fechaLectura_ins      VARCHAR2 ( 11 CHAR);
n_anyo                  VARCHAR2(4 CHAR);
n_mes                   VARCHAR2(2 CHAR);
nn_anyo	          NUMBER;
nn_mes		  NUMBER;
contador_test           INTEGER;
tipo_test               INTEGER;
err_msg                 VARCHAR2 (100);
dup_contador            EXCEPTION;
dup_tipo                EXCEPTION;
dup_null                EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_fechaLectura_ins       := SUBSTR (n_fechaLectura, 1, 11);
n_anyo             := SUBSTR (n_fechaLectura_ins, 7, 4);
n_mes              := SUBSTR (n_fechaLectura_ins, 4, 2);
nn_anyo     := to_number(n_anyo,9999);
nn_mes      := to_number(n_mes,99);
--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_fechaLectura_ins  IS NULL)
OR (n_tipo              IS NULL)
OR (n_anterior          IS NULL)
OR (n_actual            IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;


--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--verificamos que  exista el tipo de lectura
SELECT COUNT (*)
INTO tipo_test
FROM TLECTURA
WHERE tLectura.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;


-- insertamos el nuevo registro en lecturas
INSERT INTO lecturas(
contador,
fechaLectura,
tipo,
anterior,
actual,
consumo
)
VALUES (
n_contador,
n_fechaLectura_ins,
n_tipo,
n_anterior,
n_actual,
n_consumo
);
-- Fin de las operaciones
rst := 'OK: lectura aceptada ';

altaConsumos(n_contador, nn_anyo, nn_mes, n_consumo,rst);



altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_tipo
THEN
    rst := 'ERROR: NO este  tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END altaLecturas;
/



-- LECTURAS
CREATE TABLE lecturas 
(
 ID               NUMBER            CONSTRAINT      PK_lecturas                   PRIMARY KEY,
 contador                           CONSTRAINT      FK1_lecturas_contador         REFERENCES  contadores(ID)  NOT NULL, 
 fechaLectura     DATE              CONSTRAINT      NN_lecturas_fechaLectura                                  NOT NULL,
 tipo                               CONSTRAINT      FK2_lecturas_tipo             REFERENCES  tLectura(ID)    NOT NULL, 
 anterior         NUMBER(9,2)       NULL,
 actual           NUMBER(9,2)       NULL,
 consumo          NUMBER(9,2)       CONSTRAINT      NN_lecturas_consumo           NOT NULL              
);
drop sequence lecturas_SEQ_GRAL;
CREATE  SEQUENCE lecturas_SEQ_GRAL    START WITH 1    INCREMENT BY 1  NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER lecturas_TR_KEY
    BEFORE INSERT      ON lecturas
    FOR EACH ROW
   BEGIN
      SELECT              lecturas_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;


