CREATE OR REPLACE
PROCEDURE altaLinea(

n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_cMax                  IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLinea
PROPSITO: gestiona el alta de una Linea
PARAMETERS: n_estado, n_fechaEstado, n_cMax, n_obs, rst
INPUT: n_estado, n_fechaEstado, n_cMax, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLinea(1,'10/05/2012',100,null,rst);
******************************************************************************/

n_obs_ins       VARCHAR2 (50);
err_msg         VARCHAR2 (100);
des_nulo      EXCEPTION;
BEGIN
n_obs_ins := SUBSTR (n_obs, 1, 50);
--verificamos si hay campos no nulos: nulos
IF 	    (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_cMax IS NULL)
THEN
RAISE des_nulo;
END IF;

-- insertamos el nuevo tipo de linea
INSERT INTO linea(estado,fechaEstado,cMax,obs)
VALUES (n_estado,n_fechaEstado,n_cMax,n_obs_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de linea: ' || n_estado
    || ' fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax)    ; 
    rst:='OK, Alta de linea  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'altaLinea:' || n_estado
    || 'fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax 
, 'rst', rst, rst);
COMMIT;
EXCEPTION


WHEN des_nulo
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' fecha  linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' fecha  de linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;
END altaLinea;
/


drop  SEQUENCE linea_SEQ_GRAL;
CREATE  SEQUENCE linea_SEQ_GRAL 	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER               linea_TR_KEY
    BEFORE INSERT       ON              linea
    FOR EACH ROW   BEGIN   SELECT       linea_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
-- prova de uso
declare
    rst varchar2(250);
begin
--	n_estado, n_fechaEstado, n_cMax, n_obs
altaLinea(1,to_char(sysdate,'DD/MM/YYYY'),1000,null,rst);
altaLinea(1,to_char(sysdate,'DD/MM/YYYY'),1000,null,rst);
altaLinea(1,to_char(sysdate,'DD/MM/YYYY'),1000,null,rst);
altaLinea(1,to_char(sysdate,'DD/MM/YYYY'),1000,null,rst);
altaLinea(1,to_char(sysdate,'DD/MM/YYYY'),1000,null,rst);
altaLinea(1,to_char(sysdate,'DD/MM/YYYY'),1000,null,rst);
altaLinea(1,to_char(sysdate,'DD/MM/YYYY'),1000,null,rst);
altaLinea(1,to_char(sysdate,'DD/MM/YYYY'),1000,null,rst);
altaLinea(1,to_char(sysdate,'DD/MM/YYYY'),1000,null,rst);
altaLinea(1,to_char(sysdate,'DD/MM/YYYY'),1000,null,rst);
end;


