CREATE OR REPLACE
PROCEDURE altaLineas(

n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_linea                 IN NUMBER,
n_c1                    IN NUMBER,
n_c2                    IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLineaS
PROPSITO: gestiona el alta de las lineas conectadas
PARAMETERS: n_estado, n_fechaEstado, n_linea,n_c1,n_c2, n_obs, rst
INPUT: n_estado, n_fechaEstado, n_linea, n_c1, n_c2, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,NULL,rst);
******************************************************************************/

n_obs_ins             VARCHAR2 (50);
n_fechaEstado_ins     VARCHAR2(11);
linea_test            INTEGER;
estado_test           INTEGER;
c1_test               INTEGER;  
c2_test               INTEGER;
err_msg               VARCHAR2 (100);

dup_estado            EXCEPTION;
dup_linea             EXCEPTION;
dup_c1                EXCEPTION;
dup_c2                EXCEPTION;
dup_c1_c2             EXCEPTION;
des_null              EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins := SUBSTR (n_obs, 1, 50);
--verificamos si hay campos no nulos: nulos
IF 	  (n_estado             IS NULL)
          OR (n_fechaEstado_ins IS NULL)
          OR (n_linea           IS NULL)
          OR (n_c1              IS NULL)
          OR (n_c2              IS NULL)
THEN
RAISE des_null;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
--comprobar existe la linea
SELECT COUNT (*)
INTO linea_test
FROM LINEA
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
--comprobar existe la central en c1
SELECT COUNT (*)
INTO c1_test
FROM CENTRALES
WHERE centrales.ID = n_c1;
IF (c1_test = 0)
THEN
RAISE dup_c1;
END IF;
--comprobar existe la central o contador en c2
SELECT COUNT (*)
INTO c2_test
FROM CENTRALES, CONTADORES
WHERE centrales.id = n_c2
or contadores.id = n_c2;
IF (c2_test = 0)
THEN
RAISE dup_c2;
END IF;
/*
-- comprobar que no conectamos dos iguales
IF ( n_c1 = n_c2 )
THEN
RAISE dup_c1_c2;
END IF;
*/
-- insertamos el alta de la linea de conexion
INSERT INTO lineas(
estado,
fechaEstado,
linea,
c1,
c2,
obs)
VALUES (
n_estado,
n_fechaEstado_ins,
n_linea,
n_c1,
n_c2,
n_obs_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Alta de linea: '
    ||' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins
    ); 
    rst:='OK, Alta de lineas  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN des_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_linea
THEN
    rst := 'ERROR: NO existe LINEA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1
THEN
    rst := 'ERROR: No es una Central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c2
THEN
    rst := 'ERROR: No es Central ni Contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1_c2
THEN
    rst := 'ERROR: No se pueden  conectar: conexiones iguales';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
END altaLineas;
/
-- prova de uso

drop  SEQUENCE lineas_SEQ_GRAL;
CREATE  SEQUENCE lineas_SEQ_GRAL 	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER               lineas_TR_KEY
    BEFORE INSERT     ON                lineas
    FOR EACH ROW   BEGIN      SELECT    lineas_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
declare
    rst varchar2(250);
begin
-- 	n_estado, n_fechaEstado, n_linea, n_c1, n_c2, n_obs
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,1,NULL,rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,NULL,rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),2,1,3,NULL,rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),2,1,4,NULL,rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),2,2,1,NULL,rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),2,2,2,NULL,rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),3,2,5,NULL,rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),3,2,6,NULL,rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),4,3,7,NULL,rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),4,3,8,NULL,rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),4,3,9,NULL,rst);
end;

declare
    rst varchar2(250);
begin
-- alta disponibilidad
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,'AD',rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),1,2,3,'AD',rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),2,2,4,'AD',rst);
altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),2,1,5,'AD',rst);
end;

select * from lineas