CREATE OR REPLACE
PROCEDURE altaLocalidad (
n_id  IN NUMBER,
n_des IN VARCHAR2,
n_provincia IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altalocalidad
PROPSITO: gestiona el alta de un localidad en la tabla localidad
PARAMETERS: n_id, n_des,n_provincia, rst
INPUT: n_id, n_des, n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altalocalidad(50,'Mataro',10, rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
des_test        INTEGER;
provincia_test  INTEGER;
err_msg         VARCHAR2 (100);
dup_des         EXCEPTION;
dup_id          EXCEPTION;
dup_provincia   EXCEPTION;
dup_null        EXCEPTION;

BEGIN
n_des_ins       := SUBSTR (n_des, 1, 50);
--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL) OR (n_des IS NULL) OR (n_provincia IS NULL)  THEN
RAISE dup_null;
END IF;
--Verificamos si el codigo de la localidad existe
SELECT COUNT (*)
INTO id_test
FROM localidad
WHERE ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;

--verificamos si existe la descripcion de la localidad
SELECT COUNT (*)
INTO des_test
FROM localidad
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;
provincia_test:=0;
--verificamos si existe el codigo de la provincia
SELECT COUNT (*)
INTO provincia_test
FROM provincia
WHERE provincia.ID = n_provincia;
IF (provincia_test = 0)
THEN
RAISE dup_provincia;
END IF;
DBMS_OUTPUT.ENABLE;
-- insertamos la nueva localidad
INSERT INTO localidad(ID,des,provincia) VALUES (n_id,n_des_ins,n_provincia);
-- Fin de las operaciones
rst := 'OK';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
        );  
        DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este cdigo localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_provincia
THEN
    rst := 'ERROR: NO  existe provincia';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos que NO tienen datos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' 
|| n_id
||' n_des:' 
||n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;
END altalocalidad;
/
--prueba de uso
--n_id, n_des,n_provincia, rst
declare rst varchar2(250);
begin
altaLocalidad(1,'BARCELONA',2,rst);
altaLocalidad(2,'TERRASSA',2,rst);
altaLocalidad(3,'SABADELL',2,rst);
altaLocalidad(4,'MANRESA',2,rst);
altaLocalidad(5,'BERGA',2,rst);
altaLocalidad(6,'SANTPEDOR',2,rst);
altaLocalidad(7,'RUBI',2,rst);
altaLocalidad(8,'MATADEPERA',2,rst);
altaLocalidad(10,'SANT FRUITOS DE BAGES',2,rst);
altaLocalidad(11,'CASTELLAR DEL VALLES',2,rst);
altaLocalidad(12,'VACARISES',2,rst);
altaLocalidad(13,'LES FONT DE TERRASSA',2,rst);
altaLocalidad(14,'SANT CUGAT DEL VALLES',2,rst);
altaLocalidad(15,'MOLLET DEL VALLES',2,rst);
altaLocalidad(16,'PREMI DE MAR',2,rst);
altaLocalidad(17,'MONTGAT',2,rst);
altaLocalidad(18,'IBI',3,rst);
altaLocalidad(19,'SANT QUIRZE DEL VALLS',2,rst);
altaLocalidad(20,'OLESA DE MONTSERRAT',2,rst);
altaLocalidad(21,'MONISTROL DE MONTSERRAT',2,rst);
altaLocalidad(22,'MONISTROL DE CALDERS',2,rst);
altaLocalidad(23,'SANT ANTONI DE CALONGE',5,rst);
altaLocalidad(24,'SANT JOAN DE VILATORRADA',2,rst);
altaLocalidad(25,'LLEIDA',6,rst);
altaLocalidad(26,'BALAGUER',6,rst);
altaLocalidad(27,'SANT FELIU DE GUIXOLS',5,rst);
altaLocalidad(28,'PALAMOS',5,rst);
altaLocalidad(29,'PALS',5,rst);
altaLocalidad(30,'GIRONA',5,rst);
altaLocalidad(31,'TARRAGONA',7,rst);
altaLocalidad(32,'REUS',7,rst);
altaLocalidad(33,'TORTOSA',7,rst);
altaLocalidad(34,'PUZOL',3,rst);
altaLocalidad(35,'VINAROZ',46,rst);
altaLocalidad(36,'PALMA DE MALLORCA',45,rst);
altaLocalidad(37,'ARNEDO',28,rst);
altaLocalidad(38,'ZARAGOZA',11,rst);
altaLocalidad(39,'ALCAIZ',9,rst);
altaLocalidad(40,'FUENSALIDA',30,rst);
altaLocalidad(41,'CEHEGIN',33,rst);
altaLocalidad(42,'NAVALCARNERO',8,rst);
altaLocalidad(43,'MADRID',8,rst);
altaLocalidad(44,'LAS PALMAS',44,rst);
altaLocalidad(45,'TELDE',44,rst);
altaLocalidad(46,'TENERIFE',43,rst);
altaLocalidad(47,'SANSEBASTIAN',20,rst);
altaLocalidad(48,'CADIZ',38,rst);
altaLocalidad(49,'MATARO',2,rst);
altaLocalidad(50,'BURGOS',27,rst);
altaLocalidad(51,'SEGOVIA',10,rst);
altaLocalidad(52,'SANT CELONI',2,rst);
altaLocalidad(53,'RIBAS DE FRESER',5,rst);
altaLocalidad(54,'PUIGCERDA',2,rst);
altaLocalidad(55,'LA SEU DURGELL',6,rst);
altaLocalidad(56,'CALASPARRAS',33,rst);
altaLocalidad(57,'CARTAGENA',33,rst);
altaLocalidad(59,'BURGO DE OSMA',48,rst);
altaLocalidad(60,'MORELLA',46,rst);
altaLocalidad(61,'CASABLANCA',49,rst);
altaLocalidad(62,'LISBOA',161,rst);
altaLocalidad(64,'OPORTO',154,rst);
altaLocalidad(66,'BOURG-EN-BRESSE',47,rst);
altaLocalidad(67,'LAON',50,rst);
altaLocalidad(68,'MOILINES (ALLIER)',51,rst);
altaLocalidad(69,'DIGNE-LES-BAINS',52,rst);
altaLocalidad(70,'GAP',53,rst);
altaLocalidad(71,'NIZA',54,rst);
altaLocalidad(72,'PRIVAS',55,rst);
altaLocalidad(73,'CHARLEVILLE-MZIRES',56,rst);
altaLocalidad(74,'FOIX',57,rst);
altaLocalidad(75,'TROYES',58,rst);
altaLocalidad(76,'CARCASONA',59,rst);
altaLocalidad(77,'RODEZ',60,rst);
altaLocalidad(78,'MARSELLA',61,rst);
altaLocalidad(79,'CAEN',62,rst);
altaLocalidad(80,'AURILLAC',63,rst);
altaLocalidad(81,'ANGULEMA',64,rst);
altaLocalidad(82,'LA ROCHELA',65,rst);
altaLocalidad(83,'BOURGES',66,rst);
altaLocalidad(84,'TULLE',67,rst);
altaLocalidad(85,'AJACCIO',68,rst);
altaLocalidad(86,'BASTIA',69,rst);
altaLocalidad(87,'DIJON',103,rst);
altaLocalidad(88,'GURET',104,rst);
altaLocalidad(89,'PRIGUEUX',106,rst);
altaLocalidad(90,'BESANON',107,rst);
altaLocalidad(91,'VALENCE',108,rst);
altaLocalidad(92,'VREUX',205,rst);
altaLocalidad(94,'CHARTRES',206,rst);
altaLocalidad(95,'QUIMPER',207,rst);
altaLocalidad(96,'NIMES',208,rst);
altaLocalidad(97,'TOULOSE',209,rst);
altaLocalidad(98,'AUCH',210,rst);
altaLocalidad(99,'BURDEOS',211,rst);
altaLocalidad(100,'MONTPELLIER',212,rst);
altaLocalidad(101,'RENNES',213,rst);
altaLocalidad(102,'CHTEAUROUX',214,rst);
altaLocalidad(103,'GRENOBLE',216,rst);
altaLocalidad(104,'LONS-LE-DAUNIER',217,rst);
altaLocalidad(105,'MONT-DE-MARSAN',218,rst);
altaLocalidad(106,'BLOIS',222,rst);
altaLocalidad(107,'SAINTE-TIENNE',220,rst);
altaLocalidad(108,'LE PUY-EN VELAY',221,rst);
altaLocalidad(109,'NANTES',219,rst);
altaLocalidad(110,'ORLEANS',271,rst);
altaLocalidad(112,'CAHORS',223,rst);
altaLocalidad(113,'AGEN',224,rst);
altaLocalidad(114,'MENDE',225,rst);
altaLocalidad(115,'ANGERS',226,rst);
altaLocalidad(116,'SAINT-L',227,rst);
altaLocalidad(117,'CHLONS-EN-CHAMPAGNE',228,rst);
altaLocalidad(118,'CHAUMONT',229,rst);
altaLocalidad(119,'LAVAL',230,rst);
altaLocalidad(120,'NANCY',231,rst);
altaLocalidad(121,'BAR-LE-DUC',232,rst);
altaLocalidad(122,'VANNES',233,rst);
altaLocalidad(123,'METZ',234,rst);
altaLocalidad(124,'NEVERS',235,rst);
altaLocalidad(125,'LILLE',236,rst);
altaLocalidad(126,'BEAUVAIS',237,rst);
altaLocalidad(127,'ALENON',238,rst);
altaLocalidad(128,'ARRAS',239,rst);
altaLocalidad(129,'CLERMONT-FERRAND',240,rst);
altaLocalidad(130,'PAU',241,rst);
altaLocalidad(131,'TARBES',242,rst);
altaLocalidad(132,'PERPIAN',243,rst);
altaLocalidad(133,'ESTRASBURGO',244,rst);
altaLocalidad(134,'COLMAR',245,rst);
altaLocalidad(135,'LYON',246,rst);
altaLocalidad(136,'VESOUL',247,rst);
altaLocalidad(137,'MCON',248,rst);
altaLocalidad(138,'LE MANS',249,rst);
altaLocalidad(139,'CHAMBRY',272,rst);
altaLocalidad(140,'ANNECY',247,rst);
altaLocalidad(141,'PARS',250,rst);
altaLocalidad(142,'RUAN',251,rst);
altaLocalidad(143,'MELUN',252,rst);
altaLocalidad(144,'VERSALLES',253,rst);
altaLocalidad(145,'NIORT',254,rst);
altaLocalidad(146,'AMIENS',255,rst);
altaLocalidad(147,'ALBI',95,rst);
altaLocalidad(148,'MONTAUBAN',257,rst);
altaLocalidad(149,'TOULON',258,rst);
altaLocalidad(150,'AVIGNON',259,rst);
altaLocalidad(151,'LA RCHE-SUR-YON',260,rst);
altaLocalidad(152,'POITIERS',261,rst);
altaLocalidad(153,'LIMOGES',273,rst);
altaLocalidad(154,'PINAL',263,rst);
altaLocalidad(155,'AUXERRE',264,rst);
altaLocalidad(156,'BELFORT',265,rst);
altaLocalidad(157,'VRY',266,rst);
altaLocalidad(158,'NANTERRE',267,rst);
altaLocalidad(159,'BOBIGNY',268,rst);
altaLocalidad(160,'CRTEIL',269,rst);
altaLocalidad(161,'PONTOISE',270,rst);
altaLocalidad(164,'PESCARA',86,rst);
altaLocalidad(165,'CHIETI',96,rst);
altaLocalidad(166,'TERAMO',87,rst);
altaLocalidad(167,'LAQUILA',364,rst);
altaLocalidad(168,'AVEZZANO',86,rst);
altaLocalidad(169,'SULMONA',86,rst);
altaLocalidad(170,'BITONTO',84,rst);
altaLocalidad(171,'ALTAMURA',84,rst);
altaLocalidad(172,'MONOPOLI',84,rst);
altaLocalidad(173,'NOCI',84,rst);
altaLocalidad(174,'TURI',84,rst);
altaLocalidad(175,'VALENZANO',84,rst);
altaLocalidad(176,'PRATA',364,rst);
altaLocalidad(177,'MAGLIANO DE MARSI',364,rst);
altaLocalidad(178,'PACENTRO',364,rst);
altaLocalidad(179,'OFENA',364,rst);
altaLocalidad(180,'OCRE',364,rst);
altaLocalidad(182,'VILLA SANTANGELO',364,rst);
altaLocalidad(183,'VITTORIO',364,rst);
altaLocalidad(184,'FRANCA VILLA AL MARE',96,rst);
altaLocalidad(185,'BUCCHIANICO',96,rst);
altaLocalidad(186,'RIPA TATIANA',96,rst);
altaLocalidad(187,'BOLOGNANO',86,rst);
altaLocalidad(188,'ELICE',86,rst);
altaLocalidad(189,'SALLE',86,rst);
altaLocalidad(190,'VICOLI',86,rst);
altaLocalidad(191,'BRINDISI',94,rst);
altaLocalidad(192,'BARAGIANO',94,rst);
altaLocalidad(193,'FORENZA',94,rst);
altaLocalidad(194,'GINESTRA',94,rst);
altaLocalidad(195,'ATELLA',94,rst);
altaLocalidad(196,'BALVANO',94,rst);
altaLocalidad(197,'ABRIOLA',94,rst);
altaLocalidad(198,'ACERNZA',94,rst);
altaLocalidad(199,'ANZI',94,rst);
altaLocalidad(200,'MARATEA',94,rst);
altaLocalidad(201,'MISSANELLO',94,rst);
altaLocalidad(202,'MELFI',94,rst);
altaLocalidad(203,'POTENZA',94,rst);
altaLocalidad(204,'SENISE',94,rst);
altaLocalidad(205,'TITO',94,rst);
altaLocalidad(206,'VENOSA',94,rst);
altaLocalidad(208,'BOTRICELLO',95,rst);
altaLocalidad(210,'BORGIA',95,rst);
altaLocalidad(211,'DAVOLI',95,rst);
altaLocalidad(212,'MOTEPAONE',95,rst);
altaLocalidad(213,'PENTONE',95,rst);
altaLocalidad(214,'PLATANIA',95,rst);
altaLocalidad(215,'SAN FLORO',95,rst);
altaLocalidad(216,'TAVERNA',95,rst);
altaLocalidad(217,'TIRIOLO',95,rst);
altaLocalidad(218,'VALLEFIORITA',95,rst);
altaLocalidad(219,'ZAGARISE',95,rst);
altaLocalidad(220,'NPOLES',274,rst);
altaLocalidad(221,'TORRE DEL GRECO',274,rst);
altaLocalidad(222,'POZZUOLI',274,rst);
altaLocalidad(223,'CASORIA',274,rst);
altaLocalidad(224,'CASTELLAMMARE DI STABIA',274,rst);
altaLocalidad(225,'AFRAGOLA',274,rst);
altaLocalidad(226,'MARANO DI NAPOLI',274,rst);
altaLocalidad(227,'ACERRA',274,rst);
altaLocalidad(228,'PORTICI',274,rst);
altaLocalidad(229,'BOLONIA',284,rst);
altaLocalidad(230,'ANZOLA DELLEMILIA',284,rst);
altaLocalidad(231,'ARGELATO',284,rst);
altaLocalidad(232,'BUDRIO',284,rst);
altaLocalidad(233,'CASTEL GUELFO DI BOLONIA',284,rst);
altaLocalidad(234,'DOZZA',284,rst);
altaLocalidad(235,'MONTE SAN PRIETO',284,rst);
altaLocalidad(236,'VERGATO',284,rst);
altaLocalidad(237,'RAVENNA',290,rst);
altaLocalidad(238,'FERRARA',285,rst);
altaLocalidad(239,'MODENA',287,rst);
altaLocalidad(240,'PIACENZA',289,rst);
altaLocalidad(241,'PARMA',288,rst);
altaLocalidad(242,'RIMINI',292,rst);
altaLocalidad(243,'TRIESTE',295,rst);
altaLocalidad(244,'DUINO-AURISINA',295,rst);
altaLocalidad(245,'MONRUPINO',295,rst);
altaLocalidad(246,'FROSINONE',297,rst);
altaLocalidad(247,'LATINA',298,rst);
altaLocalidad(248,'RIETI',299,rst);
altaLocalidad(249,'ROMA',300,rst);
altaLocalidad(250,'GUIDONIA MONTECELIO',300,rst);
altaLocalidad(251,'TVOLI',300,rst);
altaLocalidad(252,'POMEZIA',300,rst);
altaLocalidad(253,'CIAMPINO',300,rst);
altaLocalidad(254,'MARINO',300,rst);
altaLocalidad(255,'FIUMICINO',300,rst);
altaLocalidad(256,'GENOVA',302,rst);
altaLocalidad(258,'ARENZANO',302,rst);
altaLocalidad(259,'BARGAGLI',302,rst);
altaLocalidad(260,'CAMOGLI',302,rst);
altaLocalidad(261,'DAVAGNA',302,rst);
altaLocalidad(262,'VERONA',362,rst);
altaLocalidad(263,'COMO',308,rst);
altaLocalidad(264,'BERGAMO',306,rst);
altaLocalidad(265,'MILN',313,rst);
altaLocalidad(266,'MONZA',314,rst);
altaLocalidad(267,'FERMO',320,rst);
altaLocalidad(268,'TURIN',330,rst);
altaLocalidad(269,'FLORENCIA',343,rst);
altaLocalidad(270,'LIVORNO',345,rst);
altaLocalidad(271,'MESSINA',337,rst);
altaLocalidad(272,'PALERMO',338,rst);
altaLocalidad(273,'PISA',348,rst);
altaLocalidad(274,'TRENTO',353,rst);
altaLocalidad(275,'PRATO',350,rst);
altaLocalidad(276,'VENECIA',361,rst);
altaLocalidad(278,'TREVISO',360,rst);
altaLocalidad(279,'VICENZA',363,rst);
altaLocalidad(280,'ELX',4,rst);
altaLocalidad(281,'CREVILLENTE',4,rst);
altaLocalidad(282,'BAERES DE MARIOLA',4,rst);
altaLocalidad(283,'ALBACETE',32,rst);
altaLocalidad(284,'MURCIA',33,rst);
altaLocalidad(285,'TOLEDO',30,rst);
altaLocalidad(286,'BADAJOZ',31,rst);
altaLocalidad(287,'TERUEL',9,rst);
altaLocalidad(288,'VALLADOLID',16,rst);
altaLocalidad(289,'SEVILLA',35,rst);
altaLocalidad(290,'HUELVA',37,rst);
altaLocalidad(292,'VALLS',7,rst);
altaLocalidad(294,'BLANES',5,rst);
altaLocalidad(295,'SANT ANONI DE COLONGE',5,rst);
altaLocalidad(296,'SANT ANDREU DE LA BARCA',2,rst);
altaLocalidad(297,'MARTORELL',2,rst);
altaLocalidad(298,'LHOSPITALE DE LLOBREGAT',2,rst);
altaLocalidad(299,'AVILA',29,rst);
altaLocalidad(300,'TARAZONA',11,rst);
altaLocalidad(301,'CALAHORRA',28,rst);
altaLocalidad(302,'SIMANCAS',16,rst);
altaLocalidad(303,'TORDESILLA',16,rst);
altaLocalidad(304,'SAGUNTO',3,rst);
altaLocalidad(305,'LUGO',24,rst);
altaLocalidad(306,'OURENSE',22,rst);
altaLocalidad(307,'LA CORUA',21,rst);
altaLocalidad(308,'SANT HILARI',2,rst);
altaLocalidad(309,'JEREZ DE LA FRONTERA',38,rst);
altaLocalidad(310,'ALGECIRAS',38,rst);
altaLocalidad(311,'ALCOBENDAS',8,rst);
altaLocalidad(314,'CUENCA',13,rst);
end;
select * from localidad
