create or replace PROCEDURE altaLog (
   n_procesoLog           IN    VARCHAR2, 
   n_fechaLog             IN    varchar2,
   n_entradaLog           IN    VARCHAR2, 
   n_salidaLog            IN    VARCHAR2,
   n_RSPLog               IN    VARCHAR2, 
   rst                    OUT   VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      altaLog
   PROP?ITO:    gestiona el alta de un log en la tabla log                
   PARAMETERS:  n_procesoLog, fechaLog, entradaLog, n_salidaLog, rst
   INPUT:       n_procesoLog, fechaLog, entradaLog, n_salidaLog
   OUTPUT:      rst
   RETORNA:     'Alta realizada con Exito' si la operacion ha tenido exito, 
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:    altaLog('AT', 'AUSTRIA', rst);
******************************************************************************/
   n_procesoLog_ins           VARCHAR2 (50);
   n_fechaLog_ins             varchar2 (50);
   n_entradaLog_ins           VARCHAR2 (500);
   n_salidaLog_ins            VARCHAR2 (500);
   n_RSPLog_ins               VARCHAR2 (500);
   err_msg                    VARCHAR2 (100);
   hayCamposNulos             EXCEPTION;
BEGIN
   n_procesoLog_ins       := SUBSTR (n_procesoLog, 1, 50);
   n_fechaLog_ins         := SUBSTR (n_fechaLog, 1, 50);
   n_entradaLog_ins       := SUBSTR (n_entradaLog, 1, 500);
   n_salidaLog_ins        := SUBSTR (n_salidaLog, 1, 500);
   n_RSPLog_ins           := SUBSTR (n_RSPLog, 1, 500);
 
 -- insertamos el nuevo log
   INSERT INTO LOG(procesoLog, fechaLog, entradaLog, salidaLog, RSPLog) 
          VALUES (n_procesoLog_ins, n_fechaLog_ins, n_entradaLog_ins, n_salidaLog_ins, n_RSPLog_ins);
   --verificamos que los campos no nulos no sean nulos
   IF (n_procesoLog_ins IS NULL) OR (n_fechaLog_ins IS NULL) OR (n_entradaLog_ins IS NULL) 
      OR (n_salidaLog_ins IS NULL) OR (n_RSPLog_ins IS NULL)
   THEN 
   RAISE hayCamposNulos;
   END IF; 
   
   -- Fin de las operaciones
   rst := 'Nuevo registro en la tabla LOG';   
   COMMIT;
EXCEPTION
WHEN hayCamposNulos
 THEN
      rst := 'ERROR: hay NO nulos :sin contenido';   
      ROLLBACK;  
WHEN OTHERS
   THEN
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rst := 'ERROR:' || err_msg;
      ROLLBACK;
END altaLog;
/









