CREATE OR REPLACE
PROCEDURE altaModelos(
n_des            	IN VARCHAR2,
n_anyoFabrica        	IN VARCHAR2,
n_empresa            	IN NUMBER,
n_estado             	IN NUMBER,
n_fechaEstado		IN VARCHAR2,
n_obs              	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaModelo
PROPSITO: gestiona el alta de un modelo en la tabla modelos
PARAMETERS: n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs,rst;
INPUT: n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaModelos('Modelo_1','2012',1,1,to_char(sysdate,'DD/MM/YYYY'),'obs_modelo_1', rst);
******************************************************************************/

n_des_ins             VARCHAR2(50 CHAR);
n_anyoFabrica_ins     VARCHAR2(4  CHAR);
n_fechaEstado_ins      VARCHAR2(11 CHAR);
n_obs_ins             VARCHAR2(50 CHAR);


empresa_test		INTEGER;
estado_test         INTEGER;

err_msg             VARCHAR2(100);

dup_empresa          EXCEPTION;
dup_estado            EXCEPTION;

dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_des_ins        		:= SUBSTR (n_des,1,10);
n_anyoFabrica_ins         	:= SUBSTR (n_anyoFabrica,1,4);
n_fechaEstado_ins     		:= SUBSTR (n_fechaEstado,1,11);
n_obs_ins      			:= SUBSTR (n_obs,1,50);


--verificamos que los campos no nulos no sean nulos

IF (n_des		      	IS NULL)
OR (n_anyoFabrica_ins      IS NULL)
OR (n_empresa         	IS NULL)
OR (n_estado          	IS NULL)
OR (n_fechaEstado_ins   	IS NULL)
THEN
RAISE dup_des;
END IF;



--comprobar que exista la empresa
SELECT COUNT (*)
INTO empresa_test
FROM EMPRESAS
WHERE empresas.id = n_empresa;
IF (empresa_test = 0)
THEN
RAISE dup_empresa;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- insertamos el nuevo modelo
INSERT INTO MODELOS (des,
anyoFabrica,
empresa,
estado,
fechaEstado,
obs)

VALUES (
n_des_ins,
n_anyoFabrica_ins,
n_empresa, 
n_estado,
n_fechaEstado_ins,
n_obs_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
          'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs    
    ); 
    rst:='Ok, Alta Modelo   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_des
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs  
        , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	' n_estado: '
        ||n_estado
	, 'rst', rst, rst);
ROLLBACK;


WHEN dup_empresa
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_empresa : ' || n_empresa  ); 
     rst := 'ERROR: NO existe la EMPRESA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la EMPRESA ';
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_empresa: '
        ||n_empresa
	, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
ROLLBACK;
END altaModelos;
/
CREATE  SEQUENCE modelos_SEQ_GRAL     START WITH 1    INCREMENT BY 1  NOMAXVALUE  NOCACHE;
/
CREATE OR REPLACE TRIGGER   modelos_TR_KEY
    BEFORE INSERT    ON     modelos
    FOR EACH ROW
   BEGIN      SELECT        modelos_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
--prueba de uso
declare rst varchar2(250);
begin
--           n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs,rst;
--n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs
altaModelos('TURINCORP','2004',1,1,'01/01/2004','con soporte',rst);
altaModelos('FURTHER','2005',2,1,'01/01/2005','con soporte',rst);
altaModelos('COLMAN','2006',3,1,'01/01/2006','con soporte',rst);
altaModelos('MACII','2007',4,1,'01/01/2007','con soporte',rst);
altaModelos('ROMY','2008',5,1,'01/01/2008','con soporte',rst);
altaModelos('RHONEE','2009',6,1,'01/01/2009','con soporte',rst);
altaModelos('POLENC','2010',7,1,'01/01/2010','con soporte',rst);
altaModelos('FIBACCIITALY','2011',8,1,'01/01/2011','con soporte',rst);
altaModelos('HONNERDUMPER','2012',9,1,'01/01/2012','con soporte',rst);
altaModelos('Esneider','1995',10,2,'01/01/1995','descatalogado',rst);
altaModelos('CKA','1996',11,2,'01/01/1996','descatalogado',rst);
altaModelos('TTTN','1997',12,2,'01/01/1997','descatalogado',rst);
altaModelos('FILERSENT','1998',13,2,'01/01/1998','descatalogado',rst);
altaModelos('IPORG','1999',14,2,'01/01/1999','descatalogado',rst);
altaModelos('GOLSTEN','2000',15,2,'01/01/2000','descatalogado',rst);
altaModelos('FIBRAL','2001',16,2,'01/01/2001','descatalogado',rst);
altaModelos('ENHER','2002',17,2,'01/01/2002','descatalogado',rst);
altaModelos('ENDESA','2003',18,2,'01/01/2003','descatalogado',rst);
end;



