CREATE OR REPLACE
PROCEDURE altaPais (
n_id    IN NUMBER,
n_des   IN VARCHAR2,
n_cod   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaPais
PROPSITO: gestiona el alta de un pais en la tabla pais
PARAMETERS:  n_id, n_des,,n_cod, rst
INPUT:  n_id, n_des, n_cod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaPais(1,'Espaa','ES', rst)
******************************************************************************/
n_des_ins         VARCHAR2 ( 50 CHAR);
n_cod_ins         VARCHAR2  ( 5 CHAR );
id_test           INTEGER;
des_test          INTEGER;
cod_test          INTEGER;
err_msg           VARCHAR2 (100);
dup_id            EXCEPTION;
dup_des           EXCEPTION;
dup_cod           EXCEPTION;
dup_null          EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_des_ins       := SUBSTR (n_des, 1, 50);
n_cod_ins       := SUBSTR (n_cod, 1, 5);
--comprobamos campos no nulos que no esten vacios
IF (n_id  IS NULL)
OR (n_des IS NULL)
OR (n_cod IS NULL)
THEN
RAISE dup_null;
END IF;

--Verificamos que no exista el  codigo del pais 
SELECT COUNT (*)
INTO id_test
FROM PAIS
WHERE pais.ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;

--verificamos que no exista la descripcion del PAIS
SELECT COUNT (*)
INTO des_test
FROM PAIS
WHERE pais.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos que no exista  el codigo corto  del PAIS
SELECT COUNT (*)
INTO cod_test
FROM PAIS
WHERE pais.COD = n_cod_ins;
--IF (cod_test > 0)  -- no lo implemento por no tener todos los codigos
--THEN
--RAISE dup_cod;
--END IF;

-- insertamos el nuevo PAIS
INSERT INTO PAIS(ID,des,cod) VALUES (n_id,n_des_ins,n_cod_ins);
-- Fin de las operaciones
--rst := 'OK';

    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Alta de Pais '
||' n_id: ' 
|| n_id
||' n_des: '
|| n_des
); 
    rst:='OK';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: ' 
|| n_id
||' n_des: '
|| n_des
||' n_cod: '
|| n_cod
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este id de PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe este PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_des: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_cod
THEN
    rst := 'ERROR: Ya existe el codigo  de Pais ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cod: ' || n_cod
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
||' n_cod'
||n_cod
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
||' n_cod'
||n_cod
, 'rst', rst, rst);
ROLLBACK;
END altaPais;
/
--prueba de uso
declare
rst varchar2(250);
begin
altaPais(1,'ESPAA','ES',rst);
altaPais(2,'FRANCIA','FR',rst);
altaPais(3,'MARRUECOS','MA',rst);
altaPais(4,'ALEMANIA','DE',rst);
altaPais(5,'DINAMARCA','DK',rst);
altaPais(6,'HOLANDA','NL',rst);
altaPais(7,'BELGICA','BE',rst);
altaPais(8,'ITALIA','IT',rst);
altaPais(9,'GRAN BRETAA','GB',rst);
altaPais(10,'IRLANDA','IE',rst);
altaPais(11,'ANDORRA','AD',rst);
end;



