CREATE OR REPLACE
PROCEDURE altaProvincia (
n_id      IN NUMBER,
n_des     IN VARCHAR2,
n_pais    IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaProvincia
PROPSITO: gestiona el alta de una provincia en la tabla provincia
PARAMETERS: n_id, n_des, n_pais rst
INPUT: n_id, n_des, n_pais
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaProvincia(2,'BARCELONA',1,rst); 
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
des_test        INTEGER;
pais_test       INTEGER;
err_msg         VARCHAR2 (100);
dup_id          EXCEPTION;
dup_des         EXCEPTION;
dup_pais        EXCEPTION;
dup_null        EXCEPTION;

BEGIN
n_des_ins       := SUBSTR (n_des, 1, 50);

--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL) OR (n_des IS NULL) OR (n_pais IS NULL)  THEN
RAISE dup_null;
END IF;
--Verificamos si el codigo de la provincia existe
SELECT COUNT (*)
INTO id_test
FROM PROVINCIA
WHERE provincia.ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;

--verificamos si existe la Provincia
SELECT COUNT (*)
INTO des_test
FROM PROVINCIA
WHERE provincia.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

pais_test:=0;
--verificamos si existe el PAIS
SELECT COUNT (*)
INTO pais_test
FROM PAIS
WHERE pais.ID = n_pais;
IF (pais_test = 0)
THEN
RAISE dup_pais;
END IF;

--DBMS_OUTPUT.ENABLE;
-- insertamos la nueva PROVINCIA

INSERT INTO PROVINCIA(ID,des,pais) VALUES (n_id,n_des_ins,n_pais);
-- Fin de las operaciones
rst := 'OK';
    DBMS_OUTPUT.PUT_LINE('Alta Provincia '
||'n_id:'
|| n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
);  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este cdigo PROVINCIA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta PROVINCIA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_des: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_pais
THEN
    rst := 'ERROR: NO  existe PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_pais: ' || n_pais
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos que NO tienen datos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;
END altaProvincia;

--prueba de uso
declare rst varchar2(250);
begin
altaProvincia(1,'LA MASSANA',11,rst); 
altaProvincia(2,'BARCELONA',1,rst); 
altaProvincia(3,'VALENCIA',1,rst); 
altaProvincia(4,'ALICANTE',1,rst); 
altaProvincia(5,'GIRONA',1,rst); 
altaProvincia(6,'LLEIDA',1,rst); 
altaProvincia(7,'TARRAGONA',1,rst); 
altaProvincia(8,'MADRID',1,rst); 
altaProvincia(9,'TERUEL',1,rst); 
altaProvincia(10,'SEGOVIA',1,rst); 
altaProvincia(11,'ZARAGOZA',1,rst); 
altaProvincia(12,'HUESCA',1,rst); 
altaProvincia(13,'CUENCA',1,rst); 
altaProvincia(14,'GUADALAJARA',1,rst); 
altaProvincia(15,'LEON',1,rst); 
altaProvincia(16,'VALLADOLID',1,rst); 
altaProvincia(17,'SALAMANCA',1,rst); 
altaProvincia(18,'PAMPLONA',1,rst); 
altaProvincia(19,'BILBAO',1,rst); 
altaProvincia(20,'SAN SEBASTIAN',1,rst); 
altaProvincia(21,'LA CORUA',1,rst); 
altaProvincia(22,'ORENSE',1,rst); 
altaProvincia(23,'PONTEVEDRA',1,rst); 
altaProvincia(24,'LUGO',1,rst); 
altaProvincia(25,'OVIEDO',1,rst); 
altaProvincia(26,'GUIPUZCOA',1,rst); 
altaProvincia(27,'BURGOS',1,rst); 
altaProvincia(28,'LA RIOJA',1,rst); 
altaProvincia(29,'AVILA',1,rst); 
altaProvincia(30,'TOLEDO',1,rst); 
altaProvincia(31,'BADAJOZ',1,rst); 
altaProvincia(32,'ALBACETE',1,rst); 
altaProvincia(33,'MURCIA',1,rst); 
altaProvincia(34,'CORDOBA',1,rst); 
altaProvincia(35,'SEVILLA',1,rst); 
altaProvincia(36,'JAEN',1,rst); 
altaProvincia(37,'HUELVA',1,rst); 
altaProvincia(38,'CADIZ',1,rst); 
altaProvincia(39,'DONOSTIA',1,rst); 
altaProvincia(40,'CEUTA',1,rst); 
altaProvincia(41,'MELILLA',1,rst); 
altaProvincia(42,'GRANADA',1,rst); 
altaProvincia(43,'SANTA CRUZ DE TENERIFE',1,rst); 
altaProvincia(44,'GRAN CANARIAS',1,rst); 
altaProvincia(45,'ISLAS BALEARES',1,rst); 
altaProvincia(46,'CASTELLN',1,rst); 
altaProvincia(47,'AIN',2,rst); 
altaProvincia(48,'SORIA',1,rst); 
altaProvincia(49,'GREATER CASABLANCA',3,rst); 
altaProvincia(50,'AISNE',2,rst); 
altaProvincia(51,'ALLIER',2,rst); 
altaProvincia(52,'ALPES DE HAUTE PROVENCE',2,rst); 
altaProvincia(53,'HAUTES ALPES',2,rst); 
altaProvincia(54,'ALPES MARITIMES',2,rst); 
altaProvincia(55,'ARDCHE',2,rst); 
altaProvincia(56,'ARDENNES',2,rst); 
altaProvincia(57,'ARIGE',2,rst); 
altaProvincia(58,'AUBE',2,rst); 
altaProvincia(59,'AUDE',2,rst); 
altaProvincia(60,'AVEYRON',2,rst); 
altaProvincia(61,'BOUCHES DU RHNE',2,rst); 
altaProvincia(62,'CALVADOS',2,rst); 
altaProvincia(63,'CANTAL',2,rst); 
altaProvincia(64,'CHARENTE',2,rst); 
altaProvincia(65,'CHARENTE MARITIME',2,rst); 
altaProvincia(66,'CHER',2,rst); 
altaProvincia(67,'CORRZE',2,rst); 
altaProvincia(68,'CORSE DU SUD',2,rst); 
altaProvincia(69,'HAUTE CORSE',2,rst); 
altaProvincia(70,'BAVARIA',4,rst); 
altaProvincia(71,'HESSE',4,rst); 
altaProvincia(72,'LOWER SAXONY',4,rst); 
altaProvincia(73,'WETSPHALIA',4,rst); 
altaProvincia(74,'PALATINATE',4,rst); 
altaProvincia(75,'BADEN WRTTEMBERG',4,rst); 
altaProvincia(76,'TURIGIAN',4,rst); 
altaProvincia(77,'SAXONY ANHALT',4,rst); 
altaProvincia(78,'SAXONY',4,rst); 
altaProvincia(79,'POMERANIA',4,rst); 
altaProvincia(80,'BRANDENGURG',4,rst); 
altaProvincia(81,'SAARLAND',4,rst); 
altaProvincia(82,'HOLSTEIN',4,rst); 
altaProvincia(83,'VESZEPREN',42,rst); 
altaProvincia(84,'BARI',8,rst); 
altaProvincia(85,'LES ESCALDES',11,rst); 
altaProvincia(86,'PESCARA',8,rst); 
altaProvincia(87,'TERAMO',8,rst); 
altaProvincia(88,'BARLETTA-ANDRIA-TRANI',8,rst); 
altaProvincia(89,'BRINDISI',8,rst); 
altaProvincia(90,'FOGGIA',8,rst); 
altaProvincia(91,'TARENTO',8,rst); 
altaProvincia(92,'MATERA',8,rst); 
altaProvincia(93,'LECCE',8,rst); 
altaProvincia(94,'POTENZA',8,rst); 
altaProvincia(95,'CATANZARO',8,rst); 
altaProvincia(96,'CHIETI',8,rst); 
altaProvincia(97,'COSENZA',8,rst); 
altaProvincia(98,'BENEVENTO',8,rst); 
altaProvincia(99,'VIBO VALENTIA',8,rst); 
altaProvincia(100,'AVELLINO',8,rst); 
end;