create or replace PROCEDURE altaTipoCentral(
n_des 		        IN VARCHAR2,
n_estado 		IN NUMBER,
n_fechaEstado	        IN VARCHAR2,
n_emision		IN NUMBER,
n_cantidad		IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaTipoCentral
PROPSITO: gestiona el alta de un TIPO  de Central
PARAMETERS: n_des,n_estado,n_fechaEstado,n_emision,n_cantidad,
n_obs	, rst
INPUT: n_des,n_estado,n_fechaEstado,n_emision,n_cantidad,
n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaTipoCentral('NUCLEAR',1,'01/05/2012',1,20,NULL,rst)
******************************************************************************/
n_des_ins       		VARCHAR2 (50);

des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_tcentral    		EXCEPTION;
desTCentral_nulo  	EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo tcentral.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desTCentral_nulo;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM tcentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_tcentral;
END IF;
-- insertamos el nuevo tipo de tcentral
INSERT INTO tcentral
(des,estado,fechaEstado,emision,cantidad,obs)
VALUES
(n_des_ins,n_estado,n_fechaEstado,n_emision,n_cantidad,n_obs);


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de tcentral: ' || n_des_ins); 
    rst:='Ok, Alta Tipo tcentral  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_tcentral
THEN
    rst := 'ERROR: Ya existe este tipo de  tcentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desTCentral_nulo
THEN
    rst := 'ERROR: el tipo de tcentral  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaTipoCentral;
/

drop tcentral_SEQ_GRAL;
CREATE  SEQUENCE tcentral_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER       tcentral_TR_KEY
    BEFORE INSERT         ON    tcentral
    FOR EACH ROW
   BEGIN                SELECT  tcentral_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END altaTipoCentral;
/


declare
    rst varchar2(250);
begin
-- 		n_des,n_estado,n_fechaEstado,n_emision,n_cantidad,n_obs,rst
altaTipoCentral('NUCLEAR',1,'01/05/2012',1,20,NULL,rst);
altaTipoCentral('TERMICA',1,'01/05/2012',1,20,NULL,rst);
altaTipoCentral('CARBON',1,'01/05/2012',1,20,NULL,rst);
altaTipoCentral('EOLICA',1,'01/05/2012',1,20,NULL,rst);
altaTipoCentral('SOLAR',1,'01/05/2012',1,20,NULL,rst);
end;




