CREATE OR REPLACE
PROCEDURE altaTipoInspeccion(
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaTipoInspeccion
PROPSITO: gestiona el alta de un tipo de inspeccin
PARAMETERS: n_des,n_estado,n_fechaEstado, rst
INPUT: n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaTipoInspeccion('ANUAL',to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
n_des_ins             VARCHAR2(20);
n_fechaEstado_ins     VARCHAR2(11);
des_test        		INTEGER;
estado_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_des    		        EXCEPTION;
dup_estado      		EXCEPTION;
dup_null  			EXCEPTION;

BEGIN
n_des_ins                     := SUBSTR (n_des, 1, 20);
n_fechaEstado_ins             := SUBSTR (n_fechaEstado, 1, 11);

--verificamos que los campos nulos no sean nulos
IF          (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;



--verificamos si ya existe la descripcin 
SELECT COUNT (*)
INTO des_test
FROM TINSPECCION
WHERE tInspeccion.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos si existe el estado
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado; 
END IF;

-- insertamos el nuevo tipo de inspeccion
INSERT INTO tinspeccion
(des,estado,fechaEstado)
VALUES
(n_des_ins,n_estado,n_fechaEstado_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta Tipo Inspeccion  OK: '
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins); 
    rst:='OK, Alta Tipo Inspeccion  OK: ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_des
THEN
    rst := 'ERROR: Ya  existe la descripcion ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: Hay campos NO nulos:  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA Tipo Inspeccion: ' 
|| n_des_ins
|| ' Estado: ' 
|| n_estado
||' fechaEstado: ' 
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA Tipo Inspeccion: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

END altaTipoInspeccion;
/




drop  SEQUENCE tInspeccion_SEQ_GRAL;
CREATE  SEQUENCE tInspeccion_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER   tInspeccion_TR_KEY
    BEFORE INSERT       ON  tInspeccion
    FOR EACH ROW
   BEGIN      SELECT        tInspeccion_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;


drop  SEQUENCE tInspeccion_SEQ_GRAL;
CREATE  SEQUENCE tInspeccion_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE OR REPLACE TRIGGER   tInspeccion_TR_KEY
    BEFORE INSERT       ON  tInspeccion
    FOR EACH ROW
   BEGIN      SELECT        tInspeccion_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;


declare
    rst varchar2(250);
begin
-- 			n_des,n_estado,n_fechaEstado, rst
altaTipoInspeccion('INICIAL',1,to_char(sysdate,'DD/MM/YYYY'),rst);
altaTipoInspeccion('ORDINARIA',1,to_char(sysdate,'DD/MM/YYYY'),rst);
altaTipoInspeccion('EXTRAORDINARIA',1,to_char(sysdate,'DD/MM/YYYY'),rst);
altaTipoInspeccion('ANUAL',1,to_char(sysdate,'DD/MM/YYYY'),rst);
end;






