create or replace PROCEDURE altaUbicaciones (
 
n_via               IN NUMBER,
n_dir               IN VARCHAR2,
n_num               IN VARCHAR2,
n_pis               IN VARCHAR2,
n_pta               IN VARCHAR2,
n_codigoPostal      IN VARCHAR,
n_localidad          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaUbicaciones
PROPSITO: gestiona el alta de una Ubicacion en la tabla ubicaciones
PARAMETERS: n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad, rst
INPUT: n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaUbicacion(1,'del pez','2','1r','2a','08330',1, rst);
******************************************************************************/
n_dir_ins           VARCHAR2 (50);
n_num_ins           VARCHAR2 (5);
n_pis_ins           VARCHAR2 (5);
n_pta_ins           VARCHAR2 (10);
n_codigoPostal_ins  VARCHAR  (10);

via_test          INTEGER;
localidad_test    INTEGER;
dup_via           EXCEPTION;
dup_localidad     EXCEPTION;
err_msg           VARCHAR2 (100);
des_nulo          EXCEPTION;

BEGIN
-- controlar la longitud de las entradas
n_dir_ins               := SUBSTR (n_dir, 1, 50);
n_num_ins               := SUBSTR (n_num, 1, 5);
n_pis_ins               := SUBSTR (n_pis, 1, 5);
n_pta_ins               := SUBSTR (n_pta, 1, 10);
n_codigoPostal_ins      := SUBSTR (n_codigoPostal, 1, 10);


--verificamos que los campos no nulos no sean nulos
IF (n_via             IS NULL)
OR (n_dir             IS NULL)
OR (n_num             IS NULL)
OR (n_codigoPostal    IS NULL)
OR (n_localidad       IS NULL)
THEN
RAISE des_nulo;
END IF;
--Verificamos que exista la via
SELECT COUNT (*)
INTO via_test
FROM via
WHERE via.id = n_via;
IF (via_test = 0)
THEN
RAISE dup_via;
END IF;


--verificamos que eixsta la localidad

SELECT COUNT (*)
INTO localidad_test
FROM localidad
WHERE localidad.id = n_localidad;
IF (localidad_test = 0)
THEN
RAISE dup_localidad;
END IF;

-- insertamos la nueva ubicacion
INSERT INTO ubicaciones(
via
,dir
,num
,pis
,pta
,codigoPostal
,localidad)
VALUES (n_via
,n_dir_ins
,n_num_ins
,n_pis_ins
,n_pta_ins
,n_codigoPostal_ins
,n_localidad);
-- Fin de las operaciones
rst := 'OK';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE(
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
);  
        DBMS_OUTPUT.PUT_LINE(rst); 
        
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_via
THEN
      rst := 'ERROR: No existe este cdigo de via';
      DBMS_OUTPUT.ENABLE;    
      DBMS_OUTPUT.PUT_LINE('');  
      DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_localidad
THEN
    rst := 'ERROR: NO  existe localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
        rst := 'ERROR: hay campos nulos que no tienen datos';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');  
        DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc: altaUbicacion: ' 
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
END altaUbicaciones;
/
--n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad, rst
declare rst varchar2(250);
begin
altaUbicaciones(2,'ABAT ODO  ','127','6','3','08037',2,rst);
altaUbicaciones(2,'ACACIES','72','6','4','08021',2,rst);
altaUbicaciones(2,'ACACIES','103','6','2','08027',2,rst);
altaUbicaciones(2,'ACACIES','133','2','1','08035',2,rst);
altaUbicaciones(2,'ACACIES','121','8','1','08017',2,rst);
altaUbicaciones(2,'ACACIES','19','9','3','08013',2,rst);
altaUbicaciones(2,'ACACIES','44','3','3','08024',2,rst);
altaUbicaciones(2,'ACACIES','146','8','4','08018',2,rst);
altaUbicaciones(2,'ACTRIU TUBAU ','83','7','1','08024',2,rst);
altaUbicaciones(2,'AGREGACIO','144','3','3','08013',2,rst);
altaUbicaciones(2,'AGRICULTURA','75','1','3','08024',2,rst);
altaUbicaciones(2,'AGRICULTURA','15','6','4','08020',2,rst);
altaUbicaciones(2,'AGRICULTURA','53','1','4','08027',2,rst);
altaUbicaciones(2,'AGRICULTURA','45','3','4','08021',2,rst);
altaUbicaciones(2,'AGRICULTURA','38','0','1','08018',2,rst);
altaUbicaciones(2,'AGRICULTURA','11','1','2','08019',2,rst);
altaUbicaciones(2,'AGRICULTURA','55','0','1','08013',2,rst);
altaUbicaciones(2,'AGRICULTURA','73','0','1','08020',2,rst);
altaUbicaciones(2,'AGRICULTURA','60','4','4','08025',2,rst);
altaUbicaciones(2,'AGRICULTURA','104','8','3','08032',2,rst);
altaUbicaciones(2,'AGRICULTURA','29','4','1','08031',2,rst);
altaUbicaciones(2,'AGUDELLS','115','9','1','08002',2,rst);
altaUbicaciones(2,'AGUDELLS','71','4','4','08003',2,rst);
altaUbicaciones(2,'AGUDELLS','119','8','1','08013',2,rst);
altaUbicaciones(2,'AGUDES','8','1','1','08034',2,rst);
altaUbicaciones(2,'AGUDES','146','5','1','08022',2,rst);
altaUbicaciones(2,'AGUDES','27','8','3','08030',2,rst);
altaUbicaciones(2,'AGUDES','40','6','4','08027',2,rst);
altaUbicaciones(2,'AGUDES','127','4','2','08025',2,rst);
altaUbicaciones(2,'AGUDES','7','0','1','08016',2,rst);
altaUbicaciones(2,'AGUILAR','59','7','3','08028',2,rst);
altaUbicaciones(2,'AGUILAR','111','10','4','08018',2,rst);
altaUbicaciones(2,'AGUSTI I MILA','115','6','3','08025',2,rst);
altaUbicaciones(2,'AGUSTINA SARAGOSSA','137','9','3','08015',2,rst);
altaUbicaciones(2,'AIGUABLAVA','69','0','1','08001',2,rst);
altaUbicaciones(2,'AIGUABLAVA','23','8','3','08037',2,rst);
altaUbicaciones(2,'AIGUABLAVA','144','7','4','08020',2,rst);
altaUbicaciones(2,'AIGUABLAVA','106','6','2','08024',2,rst);
altaUbicaciones(2,'AIGUABLAVA','87','5','2','08032',2,rst);
altaUbicaciones(2,'ALBA ','37','1','4','08025',2,rst);
altaUbicaciones(2,'ALBANIA ','105','5','3','08020',2,rst);
altaUbicaciones(2,'ALBARCA','155','8','1','08033',2,rst);
altaUbicaciones(2,'ALBERT LLANAS','43','0','2','08031',2,rst);
altaUbicaciones(2,'ALBERT LLANAS','146','0','3','08025',2,rst);
altaUbicaciones(2,'ALBERT LLANAS ','122','8','2','08033',2,rst);
altaUbicaciones(2,'ALCALA DE GUADAIRA ','35','2','3','08018',2,rst);
altaUbicaciones(2,'ALCALA DE GUADAIRA ','55','1','3','08033',2,rst);
altaUbicaciones(2,'ALCALA DE GUADAIRA ','17','8','4','08016',2,rst);
altaUbicaciones(2,'ALCALA DE GUADAIRA ','18','5','2','08019',2,rst);
altaUbicaciones(2,'ALCALDE DE MOSTOLES ','116','0','2','08017',2,rst);
altaUbicaciones(2,'ALCALDE DE MOSTOLES ','142','2','1','08032',2,rst);
altaUbicaciones(2,'ALCALDE DE MOSTOLES ','47','4','4','08030',2,rst);
altaUbicaciones(2,'ALCALDE DE MOSTOLES ','13','3','1','08024',2,rst);
altaUbicaciones(2,'ALCAMO ','77','3','2','08031',2,rst);
altaUbicaciones(2,'ALCAMO ','9','5','3','08028',2,rst);
altaUbicaciones(2,'ALCAMO ','121','1','3','08016',2,rst);
altaUbicaciones(2,'ALCANAR','95','4','2','08016',2,rst);
altaUbicaciones(2,'ALCANAR','76','4','2','08033',2,rst);
altaUbicaciones(2,'ALCANTARA','127','4','3','08024',2,rst);
altaUbicaciones(2,'ALCANTARA','123','10','2','08029',2,rst);
altaUbicaciones(2,'ALCOLEA','140','3','4','08024',2,rst);
altaUbicaciones(2,'ALCOLEA','118','6','2','08028',2,rst);
altaUbicaciones(2,'ALCOLEA','1','10','4','08001',2,rst);
altaUbicaciones(2,'ALCOLEA','30','4','1','08004',2,rst);
altaUbicaciones(2,'ALCOLEA','138','3','2','08026',2,rst);
altaUbicaciones(2,'ALCOLEA','65','8','2','08023',2,rst);
altaUbicaciones(2,'ALCOLEA','148','0','2','08021',2,rst);
altaUbicaciones(2,'ALCUDIA','120','6','3','08014',2,rst);
altaUbicaciones(2,'ALCUDIA','133','6','1','08036',2,rst);
altaUbicaciones(2,'ALCUDIA','4','6','1','08003',2,rst);
altaUbicaciones(2,'ALCUDIA','23','0','3','08016',2,rst);
altaUbicaciones(2,'ALCUDIA','13','0','3','08020',2,rst);
altaUbicaciones(2,'ALCUDIA','69','10','4','08004',2,rst);
altaUbicaciones(2,'ALCUDIA','84','9','2','08025',2,rst);
altaUbicaciones(2,'ALCUDIA','94','2','4','08004',2,rst);
altaUbicaciones(2,'ALDANA','91','5','2','08026',2,rst);
altaUbicaciones(2,'ALDANA','9','8','4','08019',2,rst);
altaUbicaciones(2,'ALDANA','104','9','4','08004',2,rst);
altaUbicaciones(2,'ALEGRE ','54','7','3','08037',2,rst);
altaUbicaciones(2,'ALEGRE ','74','0','2','08028',2,rst);
altaUbicaciones(2,'ALEGRE ','65','3','1','08026',2,rst);
altaUbicaciones(2,'ALEGRE DE DALT ','97','8','3','08004',2,rst);
altaUbicaciones(2,'ALEGRE DE DALT ','60','0','4','08020',2,rst);
altaUbicaciones(2,'ALEGRE DE DALT ','49','10','1','08035',2,rst);
altaUbicaciones(2,'ALEGRE DE DALT ','48','6','3','08024',2,rst);
altaUbicaciones(2,'ALEGRE DE DALT ','46','7','1','08034',2,rst);
altaUbicaciones(2,'ALEGRE DE DALT ','73','1','3','08029',2,rst);
altaUbicaciones(2,'ALELLA','10','7','2','08018',2,rst);
altaUbicaciones(2,'ALELLA','117','9','2','08004',2,rst);
altaUbicaciones(2,'ALELLA','63','9','3','08029',2,rst);
altaUbicaciones(2,'ALEXANDRE GALI','40','3','4','08025',2,rst);
altaUbicaciones(2,'ALEXANDRE GALI ','108','8','2','08027',2,rst);
altaUbicaciones(2,'ALFONS EL MAGNANIM','57','5','3','08013',2,rst);
altaUbicaciones(2,'ALFONS EL MAGNANIM','82','5','3','08028',2,rst);
altaUbicaciones(2,'ALFONS EL MAGNANIM ','143','1','4','08025',2,rst);
altaUbicaciones(1,'ALFONS EL SAVI ','103','1','4','08026',2,rst);
altaUbicaciones(1,'ALFONS XII ','90','4','4','08028',2,rst);
altaUbicaciones(1,'ALFONS XII ','18','4','2','08034',2,rst);
altaUbicaciones(1,'ALFONS XII ','152','3','4','08014',2,rst);
altaUbicaciones(2,'ALFONSO DANIEL RODRIGUEZ CASTE','3','7','2','08004',2,rst);
altaUbicaciones(2,'ALGARVES','72','9','1','08026',2,rst);
altaUbicaciones(2,'ALI BEI','140','8','4','08028',2,rst);
altaUbicaciones(2,'ALI BEI','2','4','3','08025',2,rst);
altaUbicaciones(2,'ALI BEI ','103','4','4','08014',2,rst);
altaUbicaciones(2,'ALIGA ','105','9','1','08013',2,rst);
altaUbicaciones(2,'ALIO','101','3','2','08006',2,rst);
altaUbicaciones(2,'ALMAGRO','90','0','4','08021',2,rst);
altaUbicaciones(2,'ALMAGRO','3','9','3','08032',2,rst);
altaUbicaciones(2,'ALMANSA','74','10','4','08027',2,rst);
altaUbicaciones(2,'ALMANSA','70','8','3','08038',2,rst);
altaUbicaciones(2,'ALMASSORA','25','7','3','08030',2,rst);
altaUbicaciones(2,'ALMIRALL CERVERA ','30','9','1','08016',2,rst);
altaUbicaciones(2,'ALMIRALL CERVERA ','127','2','1','08029',2,rst);
altaUbicaciones(2,'ALMIRALL CERVERA ','113','5','4','08024',2,rst);
altaUbicaciones(2,'ALMIRALL CHURRUCA ','96','4','2','08026',2,rst);
altaUbicaciones(2,'ALMIRALL PROIXIDA ','47','6','4','08007',2,rst);
altaUbicaciones(2,'ALMOGAVERS','109','5','3','08028',2,rst);
altaUbicaciones(2,'ALPENS','16','0','4','08031',2,rst);
altaUbicaciones(2,'ALPENS','4','10','1','08005',2,rst);
altaUbicaciones(2,'ALSACIA','64','9','1','08035',2,rst);
altaUbicaciones(2,'ALT DE GIRONELLA','84','4','4','08031',2,rst);
altaUbicaciones(2,'ALT DE GIRONELLA','56','1','1','08014',2,rst);
altaUbicaciones(2,'ALT DE PEDRELL','126','3','1','08009',2,rst);
altaUbicaciones(2,'ALT DE PEDRELL','111','10','2','08017',2,rst);
altaUbicaciones(2,'ALT DE PEDRELL','135','5','2','08015',2,rst);
altaUbicaciones(2,'ALT DE PEDRELL ','65','4','2','08034',2,rst);
altaUbicaciones(2,'ALTA','92','2','2','08028',2,rst);
altaUbicaciones(2,'ALTA','41','6','3','08033',2,rst);
altaUbicaciones(2,'ALTA','82','1','2','08003',2,rst);
altaUbicaciones(2,'ALTA','49','2','2','08023',2,rst);
altaUbicaciones(2,'ALTA','135','10','4','08035',2,rst);
altaUbicaciones(2,'ALTS FORNS','49','7','1','08008',2,rst);
altaUbicaciones(2,'ALTS FORNS','124','2','4','08014',2,rst);
altaUbicaciones(2,'ALTS FORNS','60','3','4','08028',2,rst);
altaUbicaciones(2,'ALTS FORNS','35','0','4','08030',2,rst);
altaUbicaciones(2,'ALTS FORNS','114','10','2','08027',2,rst);
altaUbicaciones(2,'ALTS FORNS','130','3','2','08017',2,rst);
altaUbicaciones(2,'ALTS FORNS','23','8','1','08023',2,rst);
altaUbicaciones(2,'ALTS FORNS','145','9','1','08035',2,rst);
altaUbicaciones(2,'ALTS FORNS','148','8','1','08032',2,rst);
altaUbicaciones(2,'ALTS FORNS','78','3','2','08013',2,rst);
altaUbicaciones(2,'ALTS FORNS','50','9','2','08033',2,rst);
altaUbicaciones(2,'ALTS FORNS','127','3','3','08001',2,rst);
altaUbicaciones(2,'ALUMINI','32','10','1','08004',2,rst);
altaUbicaciones(2,'ALZINA ','60','0','2','08021',2,rst);
altaUbicaciones(2,'ALZINA ','154','8','4','08030',2,rst);
altaUbicaciones(2,'AMARGOS','121','10','2','08004',2,rst);
altaUbicaciones(1,'AMERICA','81','2','2','08023',2,rst);
altaUbicaciones(1,'AMERICA','37','2','3','08006',2,rst);
altaUbicaciones(2,'AMIGO','56','1','1','08022',2,rst);
altaUbicaciones(2,'AMIGO','91','0','1','08025',2,rst);
altaUbicaciones(2,'AMIGO','98','0','2','08036',2,rst);
altaUbicaciones(2,'AMIGO','111','4','3','08030',2,rst);
altaUbicaciones(2,'AMILCAR','9','2','4','08016',2,rst);
altaUbicaciones(2,'AMILCAR','13','4','1','08020',2,rst);
altaUbicaciones(2,'AMILCAR','138','5','4','08016',2,rst);
altaUbicaciones(2,'AMILCAR','23','8','1','08030',2,rst);
altaUbicaciones(2,'AMILCAR','133','9','1','08014',2,rst);
altaUbicaciones(2,'AMILCAR','141','4','1','08015',2,rst);
altaUbicaciones(2,'AMILCAR','4','7','2','08029',2,rst);
altaUbicaciones(2,'AMPLE','8','5','4','08027',2,rst);
altaUbicaciones(2,'AMPLE','1','4','4','08032',2,rst);
altaUbicaciones(2,'AMPLE','103','8','3','08011',2,rst);
altaUbicaciones(2,'AMPOSTA','14','0','4','08028',2,rst);
altaUbicaciones(2,'AMPOSTA','84','5','2','08020',2,rst);
altaUbicaciones(2,'AMPOSTA','149','3','2','08001',2,rst);
altaUbicaciones(2,'AMPOSTA','109','6','4','08015',2,rst);
altaUbicaciones(2,'AMUNT','147','2','4','08030',2,rst);
altaUbicaciones(2,'AMUNT','101','7','3','08028',2,rst);
altaUbicaciones(2,'ANDALUSIA','139','1','3','08024',2,rst);
altaUbicaciones(2,'ANDRADE','75','9','4','08033',2,rst);
altaUbicaciones(2,'ANDRADE','144','6','1','08019',2,rst);
altaUbicaciones(2,'ANDRADE','24','0','1','08027',2,rst);
altaUbicaciones(2,'ANDRADE','71','2','3','08023',2,rst);
altaUbicaciones(2,'ANDRADE','126','8','2','08013',2,rst);
altaUbicaciones(2,'ANDRADE','150','6','4','08031',2,rst);
altaUbicaciones(2,'ANDREA DORIA','127','7','2','08016',2,rst);
altaUbicaciones(2,'ANDREA DORIA','76','1','4','08011',2,rst);
altaUbicaciones(2,'ANDREA DORIA','81','10','3','08013',2,rst);
altaUbicaciones(2,'ANDREA DORIA','59','3','1','08027',2,rst);
altaUbicaciones(2,'ANDREA DORIA','66','10','1','08015',2,rst);
altaUbicaciones(2,'ANDREA DORIA','112','7','2','08020',2,rst);
altaUbicaciones(2,'ANDREA DORIA','126','1','1','08029',2,rst);
altaUbicaciones(2,'ANETO','102','0','4','08037',2,rst);
altaUbicaciones(2,'ANETO','141','5','4','08026',2,rst);
altaUbicaciones(2,'ANETO','71','8','1','08020',2,rst);
altaUbicaciones(2,'ANETO','44','3','2','08002',2,rst);
altaUbicaciones(2,'ANGEL ','70','3','1','08013',2,rst);
altaUbicaciones(2,'ANGEL MARQUES','124','5','1','08003',2,rst);
altaUbicaciones(2,'ANGLI','131','7','1','08013',2,rst);
altaUbicaciones(2,'ANGLI','59','8','4','08004',2,rst);
altaUbicaciones(2,'ANGLI','69','5','1','08035',2,rst);
altaUbicaciones(2,'ANNA PIFERRER','145','9','3','08021',2,rst);
altaUbicaciones(2,'ANOIA','24','10','3','08020',2,rst);
altaUbicaciones(2,'ANOIA','135','8','1','08025',2,rst);
altaUbicaciones(2,'ANTIC DE SANT JOAN','52','10','1','08015',2,rst);
altaUbicaciones(1,'ANTONI DE CAMPMANY','60','2','3','08026',2,rst);
altaUbicaciones(1,'ANTONI DE CAMPMANY','20','0','1','08028',2,rst);
altaUbicaciones(2,'ANTONIO MACHADO','105','8','3','08022',2,rst);
altaUbicaciones(2,'ANTONIO MACHADO','144','3','2','08033',2,rst);
altaUbicaciones(2,'ANTONIO MACHADO','151','2','4','08016',2,rst);
altaUbicaciones(2,'ANTONIO MACHADO','8','3','1','08001',2,rst);
altaUbicaciones(2,'ANTONIO MACHADO','14','4','2','08027',2,rst);
altaUbicaciones(2,'ANTONIO MACHADO','46','8','2','08015',2,rst);
altaUbicaciones(2,'ANTONIO MACHADO','90','2','4','08038',2,rst);
altaUbicaciones(1,'ANTONIO RICARDOS','6','6','2','08031',2,rst);
altaUbicaciones(1,'ANTONIO RICARDOS','21','2','4','08001',2,rst);
altaUbicaciones(1,'ANTONIO RICARDOS','92','4','4','08013',2,rst);
altaUbicaciones(1,'ANTONIO RICARDOS','32','4','2','08032',2,rst);
altaUbicaciones(2,'ARAGO ','73','9','3','08007',2,rst);
altaUbicaciones(2,'ARAGO ','23','8','4','08013',2,rst);
altaUbicaciones(2,'ARAGO ','56','10','4','08018',2,rst);
altaUbicaciones(2,'ARAGO ','65','9','2','08004',2,rst);
altaUbicaciones(2,'ARAGO ','76','2','2','08037',2,rst);
altaUbicaciones(2,'ARAGO ','9','3','4','08003',2,rst);
altaUbicaciones(2,'ARAGO ','154','4','2','08002',2,rst);
altaUbicaciones(2,'ARAGO ','117','3','2','08028',2,rst);
altaUbicaciones(2,'ARAGO ','91','2','2','08003',2,rst);
altaUbicaciones(2,'ARAGO ','78','7','1','08036',2,rst);
altaUbicaciones(2,'ARAGO ','125','8','3','08014',2,rst);
altaUbicaciones(2,'ARAGO ','86','3','4','08031',2,rst);
altaUbicaciones(2,'ARAGO ','116','10','3','08029',2,rst);
altaUbicaciones(2,'ARAGO ','44','8','4','08022',2,rst);
altaUbicaciones(2,'ARAGO ','33','7','1','08010',2,rst);
altaUbicaciones(2,'ARAGO ','94','6','2','08032',2,rst);
altaUbicaciones(2,'ARAGO ','102','3','3','08030',2,rst);
altaUbicaciones(2,'ARAGO ','60','8','3','08042',2,rst);
altaUbicaciones(2,'ARAGO ','55','6','4','08033',2,rst);
altaUbicaciones(2,'ARAGO ','34','8','4','08031',2,rst);
altaUbicaciones(2,'ARAGO ','111','2','3','08016',2,rst);
altaUbicaciones(2,'ARAGO ','24','5','3','08024',2,rst);
altaUbicaciones(2,'ARAGO ','145','7','4','08028',2,rst);
altaUbicaciones(2,'ARAGO ','9','6','2','08029',2,rst);
altaUbicaciones(2,'ARAGO ','115','0','1','08013',2,rst);
altaUbicaciones(2,'ARAGO ','122','2','2','08036',2,rst);
altaUbicaciones(2,'ARAGO ','146','8','3','08036',2,rst);
altaUbicaciones(2,'ARAGO ','138','6','1','08005',2,rst);
altaUbicaciones(2,'ARAGO ','87','10','1','08031',2,rst);
altaUbicaciones(2,'ARAGO ','149','4','1','08012',2,rst);
altaUbicaciones(2,'ARAGO ','23','2','3','08013',2,rst);
altaUbicaciones(2,'ARAGO ','119','4','4','08026',2,rst);
altaUbicaciones(2,'ARAGO ','109','1','3','08002',2,rst);
altaUbicaciones(2,'ARAGO ','118','2','3','08013',2,rst);
altaUbicaciones(2,'ARAGO ','22','10','2','08004',2,rst);
altaUbicaciones(2,'ARAGO ','151','4','4','08024',2,rst);
altaUbicaciones(2,'ARAGO ','28','7','2','08027',2,rst);
altaUbicaciones(2,'ARAGO ','123','9','3','08003',2,rst);
altaUbicaciones(2,'ARAGO ','4','3','4','08024',2,rst);
altaUbicaciones(2,'ARAGO ','40','8','4','08003',2,rst);
altaUbicaciones(2,'ARAGO ','88','9','4','08035',2,rst);
altaUbicaciones(2,'ARAGO ','136','0','4','08029',2,rst);
altaUbicaciones(2,'ARAGO ','70','9','2','08015',2,rst);
altaUbicaciones(2,'ARAGO ','107','7','4','08003',2,rst);
altaUbicaciones(2,'ARAGO ','26','10','3','08025',2,rst);
altaUbicaciones(2,'ARAGO ','6','0','1','08004',2,rst);
altaUbicaciones(2,'ARAGO ','86','7','4','08017',2,rst);
altaUbicaciones(2,'ARAGO ','146','3','1','08015',2,rst);
altaUbicaciones(2,'ARAGO ','102','2','4','08031',2,rst);
altaUbicaciones(2,'ARAGO ','53','9','4','08029',2,rst);
altaUbicaciones(2,'ARAGO ','76','3','1','08026',2,rst);
altaUbicaciones(2,'ARAGO ','149','0','2','08036',2,rst);
altaUbicaciones(2,'ARAI','100','4','1','08032',2,rst);
altaUbicaciones(2,'ARC DE SANT MARTI (L)','91','9','3','08011',2,rst);
altaUbicaciones(2,'ARC DE SANT MARTI (L)','109','10','1','08031',2,rst);
altaUbicaciones(2,'ARC DE SANT MARTI (L)','49','10','4','08015',2,rst);
altaUbicaciones(2,'ARC DE SANT MARTI (L)','123','5','1','08003',2,rst);
altaUbicaciones(2,'ARC DE SANT MARTI (L)','78','3','1','08025',2,rst);
altaUbicaciones(2,'ARC DE SANT MARTI (L)','1','7','4','08024',2,rst);
altaUbicaciones(2,'ARC DEL TEATRE (L)','41','2','3','08001',2,rst);
altaUbicaciones(2,'ARDEVOL','104','4','1','08032',2,rst);
altaUbicaciones(2,'ARDEVOL S','31','9','1','08030',2,rst);
altaUbicaciones(2,'ARENYS','34','10','4','08016',2,rst);
altaUbicaciones(2,'ARGENSOLA','40','1','1','08013',2,rst);
altaUbicaciones(2,'ARGENSOLA','79','4','4','08014',2,rst);
altaUbicaciones(2,'ARGENTERIA ','84','0','4','08013',2,rst);
altaUbicaciones(2,'ARGULLOS','58','0','4','08025',2,rst);
altaUbicaciones(2,'ARGULLOS','78','10','2','08016',2,rst);
altaUbicaciones(2,'ARGULLOS','142','0','1','08035',2,rst);
altaUbicaciones(2,'ARGULLOS','59','1','3','08024',2,rst);
altaUbicaciones(2,'ARGULLOS','8','10','1','08006',2,rst);
altaUbicaciones(2,'ARIBAU','34','2','2','08031',2,rst);
altaUbicaciones(2,'ARIBAU','123','8','1','08018',2,rst);
altaUbicaciones(2,'ARIBAU','124','6','4','08015',2,rst);
altaUbicaciones(2,'ARIBAU','25','0','1','08028',2,rst);
altaUbicaciones(2,'ARIBAU','122','10','3','08031',2,rst);
altaUbicaciones(2,'ARIBAU','1','7','3','08024',2,rst);
altaUbicaciones(2,'ARIBAU','69','3','4','08001',2,rst);
altaUbicaciones(2,'ARIBAU','52','4','1','08028',2,rst);
altaUbicaciones(2,'ARIBAU','25','4','3','08024',2,rst);
altaUbicaciones(2,'ARIBAU','12','10','3','08033',2,rst);
altaUbicaciones(2,'ARIBAU','18','5','2','08018',2,rst);
altaUbicaciones(2,'ARIBAU','104','10','2','08014',2,rst);
altaUbicaciones(2,'ARIBAU','37','8','2','08026',2,rst);
altaUbicaciones(2,'ARIBAU','76','0','3','08028',2,rst);
altaUbicaciones(2,'ARIBAU','124','7','1','08009',2,rst);
altaUbicaciones(2,'ARIBAU','80','10','4','08015',2,rst);
altaUbicaciones(2,'ARIBAU','7','10','3','08005',2,rst);
altaUbicaciones(2,'ARIBAU','143','2','4','08015',2,rst);
altaUbicaciones(2,'ARIMON','144','2','1','08024',2,rst);
altaUbicaciones(2,'ARIMON','106','7','3','08016',2,rst);
altaUbicaciones(2,'ARISTIDES MAILLOL','135','7','2','08016',2,rst);
altaUbicaciones(2,'ARISTIDES MAILLOL','130','10','1','08025',2,rst);
altaUbicaciones(2,'ARISTIDES MAILLOL','146','6','3','08022',2,rst);
altaUbicaciones(2,'ARITJOLS','95','6','2','08028',2,rst);
altaUbicaciones(2,'ARITJOLS','55','9','1','08026',2,rst);
altaUbicaciones(2,'ARITJOLS','55','2','2','08005',2,rst);
altaUbicaciones(2,'ARITJOLS','119','10','2','08016',2,rst);
altaUbicaciones(2,'ARITJOLS','46','9','3','08011',2,rst);
altaUbicaciones(2,'ARIZALA','148','2','1','08035',2,rst);
altaUbicaciones(2,'ARIZALA ','138','4','2','08012',2,rst);
altaUbicaciones(2,'ARNAU DOMS','56','7','1','08029',2,rst);
altaUbicaciones(2,'ARNAU DOMS','23','2','3','08031',2,rst);
altaUbicaciones(2,'ARNAU DOMS','115','1','1','08026',2,rst);
altaUbicaciones(2,'AROLAS','111','5','4','08014',2,rst);
altaUbicaciones(2,'ARQUIMEDES','132','10','4','08001',2,rst);
altaUbicaciones(2,'ARQUIMEDES','7','1','3','08030',2,rst);
altaUbicaciones(2,'ARQUITECTURA','89','1','3','08014',2,rst);
altaUbicaciones(2,'ARRIASSA','7','1','4','08020',2,rst);
altaUbicaciones(2,'ARRIASSA','54','9','3','08019',2,rst);
altaUbicaciones(2,'ART (L)','146','10','4','08017',2,rst);
altaUbicaciones(2,'ART (L)','149','2','1','08014',2,rst);
altaUbicaciones(2,'ART (L)','84','0','4','08028',2,rst);
altaUbicaciones(2,'ART (L)','86','9','4','08002',2,rst);
altaUbicaciones(2,'ART (L)','130','9','1','08013',2,rst);
altaUbicaciones(2,'ARTESA DE SEGRE','27','2','4','08026',2,rst);
altaUbicaciones(2,'ARTESANIA (L)','37','5','4','08021',2,rst);
altaUbicaciones(2,'ARTESANIA (L)','58','9','1','08029',2,rst);
end;
