CREATE OR REPLACE
PROCEDURE bajaCentral(
n_id		IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaCentral
PROPSITO: gestiona la baja lgica de una  Central
PARAMETERS: n_id,n_estado,n_fechaEstado, rst
INPUT: n_id,n_estado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaCentral(1,to_char(sysdate,'DD/MM/YYYY'),  rst);
******************************************************************************/
n_estado				INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;

err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	EXCEPTION;



BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11);

--verificamos que los campos nulos no sean nulos
IF   		(n_id 		IS NULL)
	OR 	(n_fechaEstado	IS NULL)
THEN
RAISE dup_null;
END IF;

-- verificamos que la Central a modificar exista

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;

-- cambio a estado de baja
UPDATE centrales
SET
centrales.ESTADO = estado_test,
centrales.FECHAESTADO =n_fechaEstado_ins
WHERE
centrales.ID = n_id;

-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('BAJA Lgica de la Central OK: ' || n_id); 
    rst:='OK, BAJA LOGICA DE LA  CENTRAL ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_estado: '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: NO existe esta  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_estado: '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral: ' 
|| 'n_id: '
||  n_id
|| ' n_estad0: '
||  n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: No existe el estado BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral: ' 
|| 'n_id: '
||  n_id
|| ' n_estad0: '
||  n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral' 
||  n_id
|| ' n_estad0: '
||  n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins 
, 'rst', rst, rst);
ROLLBACK;

END bajaCentral;
/
