CREATE OR REPLACE
PROCEDURE bajaClientes(
n_id                IN NUMBER,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaClientes
PROPSITO: gestiona la baja lgica de  un cliente en la tabla clientes
PARAMETERS: n_id,n_fechaMod, rst
INPUT: n_id,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaClientes(3,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/

n_fechaMod_ins      VARCHAR2(11 CHAR);
n_estado			NUMBER;
id_test             INTEGER;
estado_test         INTEGER;
err_msg             VARCHAR2(100);
dup_id              EXCEPTION;
dup_estado          EXCEPTION;
dup_null             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas

n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_id              IS NULL)
OR (n_fechaMod		IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM CLIENTES
WHERE clientes.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;


-- modificamos el cliente ESTADO A BAJA
UPDATE CLIENTES
SET
estado      = n_estado,
fechaMod    = n_fechaMod_ins
WHERE
clientes.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id: ' || n_id ); 
    rst:='Ok, BAJA logica del cliente realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
|| ', '
||'n_estado: '
|| n_estado 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el CODIGO DEL CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  CODIGO DEL CLIENTE ';
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;
END bajaClientes;
/






