CREATE OR REPLACE
PROCEDURE bajaContadores(

n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:     bajaContadores
PROPSITO:  gestiona la baja lgica del contador ( cambio de estado en la tabla contadores
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT:      n_id,n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaContadores(1,to_char(sysdate,'DD/MM/YYYY'),  rst);
******************************************************************************/
n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;

err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	        EXCEPTION;

BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos no nulos no sean nulos
IF (n_id		      IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM contadores
WHERE contadores.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;



-- cambio a estado de baja
UPDATE CONTADORES 
SET
contadores.ESTADO = estado_test,
contadores.FECHAESTADO =n_fechaEstado_ins
WHERE
contadores.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id ); 
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || estado_test ); 
    rst:='Ok, cambio de estado a BAJA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
 , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: No existe el Contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id  
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  );
    rst := 'ERROR: No existe el Estado de BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado ' || n_estado
|| ', '
||'n_fechaEstado: ' || n_fechaEstado 
, 'rst', rst, rst);

ROLLBACK;
WHEN dup_null
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;
END bajaContadores;

/
declare rst varchar2(250);
begin
bajaContadores(2,to_char(sysdate,'DD/MM/YYYY'), rst);
end;
select * from contadores 

select * from log





