CREATE OR REPLACE
PROCEDURE bajaContratos(
n_id			IN NUMBER,
n_fechaEstado       	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaContratos
PROPSITO: gestiona la baja lgica de un contraato en la tabla contratos
PARAMETERS: n_id, n_fechaEstado, rst
INPUT: n_id, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaContratos(1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/

n_fechaEstado_ins     VARCHAR2(11 CHAR);
n_contador              NUMBER;
id_test			INTEGER;
n_estado		NUMBER;
estado_test         	INTEGER;
err_msg             	VARCHAR2(100);
dup_id              	EXCEPTION;
dup_estado          	EXCEPTION;
dup_null                EXCEPTION;

BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  	:= SUBSTR (n_fechaEstado, 1, 11);
--verificamos que los campos no nulos no sean nulos
IF (n_id        		IS NULL)
OR (n_fechaEstado_ins           IS NULL)
THEN
RAISE dup_null;
END IF;
--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM contratos
WHERE contratos.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;
-- modificamos el contrato  A BAJA
UPDATE contratos
SET
estado       = n_estado,
fechaEstado  = n_fechaEstado_ins
WHERE
contratos.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
 ); 
    rst:='Ok, Baja Lgica del contrato  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
COMMIT;

-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el CONTRATO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el CONTRATO ';
altaLog('Proc. bajaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_contador: ' || n_contador  ); 
     rst := 'ERROR:  NO  existe el Estado de BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el estado de BAJA';
altaLog('Proc. bajaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;



WHEN dup_null
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;
END bajaContratos;


declare
    rst varchar2(250);
begin
bajaContratos(1,'01/05/2012',rst);
end;
