CREATE OR REPLACE
PROCEDURE bajaLineas(
n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaLineas
PROPSITO: gestiona la baja lgica de lineas  conectadas
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT: n_id,n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaLineas(1,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
n_estado			NUMBER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null                 	EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);

--verificamos si hay campos no nulos: nulos
IF 	     (n_id     		IS NULL)
          OR (n_fechaEstado_ins	IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM lineas
WHERE lineas.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
select * from estados
--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO n_estado
FROM ESTADOS
WHERE estados.DES = 'BAJA';
IF (n_estado = 0)
THEN
RAISE dup_estado;
END IF;
-- cambio a estado de baja
UPDATE lineas
SET
lineas.ESTADO = n_estado,
lineas.FECHAESTADO = n_fechaEstado_ins
WHERE
lineas.ID = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Baja de linea: '
	||'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    ); 
    rst:='OK, Baja de lineas lgica  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe Lineas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	 
	 n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	 
	 n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	
        'n_id: ' 
	||n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

END bajaLineas;
/
select * from lineas

declare
    rst varchar2(250);
begin
bajaLineas(1,to_char(sysdate,'DD/MM/YYYY'),rst);
end;
select * from log
