CREATE OR REPLACE
PROCEDURE bajaModelos(
n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaModelos
PROPSITO: gestiona la baja lgica de un modelo en la tabla modelos
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT:      n_id,n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaModelos(1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/
n_estado				INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	EXCEPTION;


BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos no nulos no sean nulos
IF (n_id		      IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM modelos
WHERE modelos.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;



-- cambio a estado de baja
UPDATE modelos
SET
modelos.ESTADO = estado_test,
modelos.FECHAESTADO = n_fechaEstado_ins
WHERE
modelos.ID = n_id;

-- Fin de las operaciones    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins  
    ); 
    rst:='Ok, baja Modelo   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
		'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
        , 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        	'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
        , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
	, 'rst', rst, rst);
ROLLBACK;


WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
		'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins  ); 
     rst := 'ERROR: NO existe el modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la EMPRESA ';
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
	, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
		'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
        , 'rst', rst, rst);
ROLLBACK;
END bajaModelos;
/
--prueba de uso
declare rst varchar2(250);
begin


bajaModelos(1,to_char(sysdate,'DD/MM/YYYY'),rst);
end;

select * from modelos

  select * from empresas