CREATE OR REPLACE
PROCEDURE bajaTipoInspeccion(
n_id         	    IN NUMBER,
n_fechaEstado      IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaTipoInspeccion
PROPSITO: gestiona la baja lgica de un tipo de inspeccin
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT: n_id,n_estado, n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: bajaTipoInspeccion(1,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	        EXCEPTION;

BEGIN
n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos nulos no sean nulos
IF                 (n_id IS NULL)
		OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;



--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM tInspeccion
WHERE tInspeccion.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;


-- cambio a estado de baja
UPDATE tInspeccion
SET
tInspeccion.ESTADO = estado_test,
tInspeccion.FECHAESTADO =n_fechaEstado_ins
WHERE
tInspeccion.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Baja  Tipo Inspeccion  OK: '
	||'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins); 
    rst:='OK, Baja Tipo Inspeccion  OK: ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
    , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el tipo de inspeccin ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: Hay campos NO nulos:  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;
END bajaTipoInspeccion;

select * from tInspeccion
declare rst varchar2(250);
begin
bajaTipoInspeccion(1,to_char(sysdate,'DD/MM/YYYY'),rst);

end;
