CREATE OR REPLACE
PROCEDURE bajaCentral_e(
n_id		IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaCentral_e
PROPSITO: gestiona la modificacin  del estado de  Central a BAJA estados.id = 2
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT: n_id, n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: bajaCentral_e
( 1,'GAROA',2,'01/05/2012',1,1,20,10,1,'15/05/2012',1,'OBS_CENTRAL',rst)
******************************************************************************/

n_des_ins             	VARCHAR2(50);
n_obs_ins             	VARCHAR2(50);
--n_fechaEstado_ins     	VARCHAR2(50);

id_test				INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;

err_msg         		VARCHAR2 (100);

dup_central_id 		        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;

des_nulo  			EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);

--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR 	(n_des_ins IS NULL)
	OR 	(n_estado IS NULL)
	OR 	(n_fechaEstado IS NULL)
	OR 	(n_clase IS NULL)
	OR 	(n_tipo IS NULL)
	OR 	(n_eMax IS NULL)
	OR 	(n_eMin IS NULL)
	OR 	(n_inspeccion IS NULL)
	OR 	(n_fIns IS NULL)
	OR 	(n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;


-- verificamos que la Central a modificar exista

SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_central_id;
END IF;


-- verificamos que la descripcion  a modificar exista

SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_central;
END IF;

--verificamos que existe la clase de la  Central
SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; -- no existe la clase de central
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

-- modificamos la central cambio de estado
UPDATE centrales
SET
des 		= n_des_ins,
estado 		= 2,                         -- codigo estado de baja n_estado,
fechaEstado 	= n_fechaEstado,
clase 		= n_clase,
tipo		= n_tipo,
eMax 		= n_eMax,
eMin 		= n_eMin,
inspeccion 	= n_inspeccion,
fIns 		= n_fIns,
ubica 		= n_ubica,
obs 		= n_obs
WHERE
centrales.id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('BAJA CENTRAL OK: ' || n_des_ins); 
    rst:='OK, BAJA CENTRAL ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaCentral_e', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'BAJA CENTRAL: ' || n_id
||', ' || 'descripcin: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION
WHEN dup_central_id
THEN
    rst := 'ERROR: NO existe esta  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral_e', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'CDIGO CENTRAL: ' || n_id, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta descripcin de  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral_e', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral_e', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral_e', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;


WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacin  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral_e', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;


WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaCentral_e', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral_e: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaCentral_e', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END bajaCentral_e;
/

-- prueba de uso
declare
    rst varchar2(250);
begin
bajaCentral_e(7,'ZAMORA',2,'02/05/2012',1,3,20,10,1,'20/05/2012',1,'OBS_CENTRAL_1',rst);
end;

SELECT * FROM LOG
select * from Centrales






