CREATE OR REPLACE
PROCEDURE bajaCentral(
n_id			IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 		IN NUMBER,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaCentral
PROPSITO: gestiona la baja definitiva de  Central tiene que tener estados.id = 2
PARAMETERS: n_id,n_des,n_estado, rst
INPUT: n_id,n_des,n_estado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: bajaCentral( 1,'GAROA',2,rst)
******************************************************************************/
n_des_ins             VARCHAR2(50);
id_test				INTEGER;
des_test				INTEGER;
estado_test        		INTEGER;
err_msg         		VARCHAR2 (100);

dup_central_id 		       EXCEPTION;
dup_central_des			  EXCEPTION;
dup_central_est 		       EXCEPTION;
des_nulo  			EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);

--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR 	(n_des_ins IS NULL)
	OR 	(n_estado IS NULL)
THEN
RAISE des_nulo;
END IF;

-- verificamos que la Central a modificar exista

SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_central_id;
END IF;

-- verificamos que la descripcion  exista

SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_central_des;
END IF;

--verificamos que la central tenga estado de baja
SELECT COUNT (*)
INTO estado_test
FROM centrales
WHERE centrales.estado = 2; -- estado de baja
IF (estado_test = 0)
THEN
RAISE dup_central_est; -- la central no esta en estado 2
END IF;

-- borramos completamente  la central 

DELETE FROM 
centrales
WHERE
centrales.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('BAJA CENTRAL OK: ' || n_des_ins); 
    rst:='OK, BAJA CENTRAL ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'BAJA CENTRAL: ' || n_id
||', ' || 'descripcin: ' || n_des_ins
||', ' || 'Estado: ' || n_estado

, 'rst', rst, rst);

COMMIT;

EXCEPTION
WHEN dup_central_id
THEN
    rst := 'ERROR: NO existe esta  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'CDIGO CENTRAL: ' || n_id
|| ',' || 'descripcin: ' || n_des_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central_des
THEN
    rst := 'ERROR: Ya existe esta descripcin de  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central_est
THEN
    rst := 'ERROR: NO tiene estado 2 BAJA en ESTADOS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'BAJA de CENTRAL: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral: ' || n_id, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Cdigo de central: ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END bajaCentral;
/

-- prueba de uso
declare
    rst varchar2(250);
begin
bajaCentral(6,'ZAMORA',2,rst);
end;

SELECT * FROM LOG
select * from Centrales


select *  from estados



