CREATE OR REPLACE
PROCEDURE borraClientes(
n_id                IN NUMBER,
n_estado            IN NUMBER,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: borraClientes
PROPSITO: gestiona el borrado total de la tabla  de  un cliente en la tabla clientes
PARAMETERS: n_id,n_estado,n_fechaMod, rst
INPUT: n_id,n_estado,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: borraClientes(3,2,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/

n_fechaMod_ins      VARCHAR2(11 CHAR);

id_test             INTEGER;
estado_test         INTEGER;
estado_id           INTEGER;
err_msg             VARCHAR2(100);
dup_id              EXCEPTION;
dup_estado          EXCEPTION;
dup_estado_id       EXCEPTION;
dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas

n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_id              IS NULL)
OR (n_estado          IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM CLIENTES
WHERE clientes.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtener el id de la descripcion de BAJA en Estados
--obtenemos el codigo de la clase

SELECT estados.ID
INTO estado_id
FROM estados
WHERE estados.DES = 'BAJA';
IF (estado_id = 0)
THEN
RAISE dup_estado_id;
END IF;


-- comprobar que el cliente esta de BAJA
SELECT COUNT (*)
INTO estado_test
FROM CLIENTES
WHERE clientes.ESTADO = estado_id;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- borra el cliente el cliente

DELETE
FROM CLIENTES
WHERE
clientes.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id: ' || n_id ); 
    rst:='Ok, BORRADO del cliente realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. borraClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
|| ', '
||'n_estado: '
|| n_estado 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el CODIGO DEL CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  CODIGO DEL CLIENTE ';
altaLog('Proc. borraClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: El cliente NO tiene estado de BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: El cliente NO tiene estado de BAJA ';
altaLog('Proc. borraClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: El estado NO es de BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: El estado No es de BAJA ';
altaLog('Proc. borraClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. borraClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. borraClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;
END borraClientes;
/

--prueba de uso
declare rst varchar2(250);
begin
borraClientes(6,2,to_char(sysdate,'DD/MM/YYYY'), rst);
end;


declare rst varchar2(250);
begin
modificaClientesEstado(6,2,to_char(sysdate,'DD/MM/YYYY'), rst);
end;
select * from clientes
select * from log


