CREATE OR REPLACE
PROCEDURE altaC3(
n_linea               IN NUMBER,
n_cLinea              IN NUMBER,
n_eAmplia             IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  altaC3 
PROPSITO:  alta en la tabla C3
PARAMETERS: n_linea,n_cLinea,n_eAmplia,rst
INPUT:  n_linea,n_cLinea,n_eAmplia
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaC3(1,20,30, rst);
******************************************************************************/

err_msg             VARCHAR2(100);

linea_test		INTEGER;
max_test		INTEGER;

dup_linea       EXCEPTION;
dup_max		EXCEPTION;
dup_null        EXCEPTION;
            
BEGIN


--verificamos que los campos no nulos no sean nulos
IF (n_linea   			IS NULL)
OR (n_cLinea              IS NULL)
OR (n_eAmplia             IS NULL)

THEN RAISE dup_null;
END IF;

-- verificar linea y carga mxima de lnea

SELECT count(*)
INTO linea_test
FROM linea
WHERE 
linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;

SELECT count(*)
INTO max_test
FROM linea
WHERE 
linea.cMax <  n_cLinea;
IF (max_test = 1)
THEN
RAISE dup_max;
END IF;

/*-- solo en fase de desarrollo para comprobar la salida
 DBMS_OUTPUT.ENABLE;
 DBMS_OUTPUT.PUT_LINE('');
 DBMS_OUTPUT.PUT_LINE('consultarLineasMasCargadasCapacidadMaxima' 
||' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
) ;
 DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
 DBMS_OUTPUT.PUT_LINE('');
*/

--insertamos en la tabla de C3 
 
INSERT INTO C3 (
 linea,cLinea, eAmplia)  
VALUES(n_linea,n_cLinea,n_eAmplia);

-- Fin de las operaciones
 
    rst:='Ok, alta C3: AltaconsultarLineasMasCargadasCapacidadMaxima';
    DBMS_OUTPUT.PUT_LINE('--------------------------------------------');
    DBMS_OUTPUT.PUT_LINE(rst);  
    DBMS_OUTPUT.PUT_LINE('---------------------------------------------');
 
       
altaLog('Proc. altaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
, 'rst', rst, rst);

ROLLBACK;

WHEN dup_linea
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: No hay linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
, 'rst', rst, rst);

ROLLBACK;

WHEN dup_max
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: Sobrepasa la carga mxima de linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
, 'rst', rst, rst);
ROLLBACK;
END altaC3;
/