CREATE OR REPLACE
PROCEDURE altaC4(
n_dni		          IN VARCHAR2,
n_contrato            IN NUMBER,
n_modelo			IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  altaC4 
PROPSITO:  consultarClientesContadoresAltaDisponibiliad 
PARAMETERS: n_dni,n_contrato,n_modelo ,rst
INPUT:  n_dni,n_contrato,n_modelo
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaC4('48023076',1,1, rst);
******************************************************************************/
n_dni_ins      VARCHAR2(10);

err_msg             VARCHAR2(100);

dni_test	INTEGER;
contrato_test	INTEGER;
modelo_test	INTEGER;
dup_dni           EXCEPTION;
dup_contrato		EXCEPTION;
dup_modelo			EXCEPTION;
dup_null            EXCEPTION;
            
BEGIN

--comprobamos la longitud de las cadenas
n_dni_ins   := SUBSTR (n_dni, 1, 10);

--verificamos que los campos no nulos no sean nulos
IF (n_dni_ins   IS NULL)
OR (n_contrato   IS NULL)
OR (n_modelo   IS NULL)

THEN RAISE dup_null;
END IF;

-- verificar dni, contrato y modelo

SELECT count(*)
INTO dni_test
FROM clientes
WHERE 
clientes.NIFCIF = n_dni;
IF (dni_test = 0)
THEN
RAISE dup_dni;
END IF;

SELECT count(*)
INTO contrato_test
FROM contratos
WHERE 
contratos.id = n_contrato;
IF (contrato_test = 0)
THEN
RAISE dup_contrato;
END IF;

SELECT count(*)
INTO modelo_test
FROM modelos
WHERE 
modelos.id = n_modelo;
IF (modelo_test = 0)
THEN
RAISE dup_modelo;
END IF;


 DBMS_OUTPUT.ENABLE;
 DBMS_OUTPUT.PUT_LINE('');
 DBMS_OUTPUT.PUT_LINE('consultarClientesContadoresAltaDisponibiliad' 
||' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
) ;
 DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
 DBMS_OUTPUT.PUT_LINE('');
  

--insertamos en la tabla de C4 
 
INSERT INTO C4 (dni,contrato,modelo)
VALUES(n_dni_ins,n_contrato,n_modelo);

-- Fin de las operaciones
 
    rst:='Ok, Alta consultarClientesContadoresAltaDisponibiliad';
       
altaLog('Proc. altaC4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_contrato
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('consultarClientesContadoresAltaDisponibiliad' 
||' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
) ;
    rst := 'ERROR: No hay contrato';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaC4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
, 'rst', rst, rst);

ROLLBACK;


WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
, 'rst', rst, rst);

ROLLBACK;

WHEN dup_modelo
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: No hay modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
, 'rst', rst, rst);

ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaC4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
, 'rst', rst, rst);
ROLLBACK;
END altaC4;
/
/*
--PRUEBA DE USO
declare rst varchar2(250);
begin
altaC4('33624203C',1,1, rst);
end;
*/



