CREATE OR REPLACE
PROCEDURE consultaC5(
n_central        IN NUMBER,
n_ini            IN VARCHAR2,
n_fin            IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  consultaC5 
PROPSITO:  Dada una central de produccin y un intervalo de tiempo,
            consumo producido por los contadores que dependen de la central
            y la energia producida por la central en el periodo de tiempo.
PARAMETERS: n_central, n_pInicial, n_pFinal ,rst
INPUT:      n_central, n_pInicial, n_pFinal 
OUTPUT:     rst
RETORNA:    'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: consultaC5(1,'01/01/2010','01/07/2012', rst);
******************************************************************************/
n_ini_ins   VARCHAR2(11);
n_fin_ins   VARCHAR2(11);
n_aIni      Varchar2(4);
n_aFin      VARCHAR2(4);
n_mIni      VARCHAR2(2);
n_mFin      VARCHAR2(2);

nn_aIni number;
nn_aFin number;
nn_mIni number;
nn_mFin number;

prod_test           INTEGER;
central_test        INTEGER;
contador_test       INTEGER;
contador            INTEGER;
n_contador          NUMBER;
n_central_ins       NUMBER;
n_consumo           NUMBER(9,2);
eProd               NUMBER(9,2);
eProducida               NUMBER(9,2);
err_msg             VARCHAR2(100);

dup_contador        EXCEPTION;
dup_null            EXCEPTION;
 
CURSOR c1 IS 
SELECT  distinct (contadores.ID) ,sum(consumos.CONSUMO), centrales.EMAX ,n_ini,n_fin
FROM
centrales,  contadores , consumos, estados, linea, lineas, modelos
WHERE
    consumos.ANYO BETWEEN nn_aIni and nn_aFin
and consumos.MES  BETWEEN nn_mIni and nn_mFin
and centrales.ID  = lineas.C1
and contadores.ID = lineas.C2
and contadores.ID = consumos.CONTADOR
and linea.ID      = lineas.LINEA
and estados.ID    = centrales.ESTADO
and estados.ID    = contadores.ESTADO
and estados.ID    = lineas.ESTADO
and estados.ID    = linea.ESTADO
and centrales.ID =  n_central 
group by  contadores.ID,(consumos.CONSUMO),  centrales.EMAX
having sum(consumos.consumo) > 0
order by contadores.id asc;

         
BEGIN
-- inicializar varables
contador := 1;
--comprobamos la longitud de las cadenas
n_ini_ins   := SUBSTR (n_ini, 1, 11);
n_fin_ins   := SUBSTR (n_fin, 1, 11);

n_aIni    := SUBSTR(n_ini_ins, 7, 4);
n_aFin    := SUBSTR(n_fin_ins, 7, 4);
n_mIni    := SUBSTR(n_ini_ins, 5, 1);
n_mFin    := SUBSTR(n_fin_ins, 5, 1);
nn_mIni   := to_number(n_mIni,99);
nn_mFin   := to_number(n_mFin,99);

nn_aIni   := to_number(n_aIni,9999);
nn_aFin   := to_number(n_aFin,9999);

    
-- verificar que existe la central
SELECT count(*)
INTO contador_test
FROM
centrales, linea, lineas, contadores, consumos, estados
WHERE
  
   consumos.ANYO BETWEEN n_aIni and n_aFin
and consumos.MES  BETWEEN nn_mIni and nn_mFin
and centrales.ID  = lineas.C1
and contadores.ID = lineas.C2
and contadores.ID = consumos.CONTADOR
and linea.ID      = lineas.LINEA
and estados.ID    = centrales.ESTADO
and estados.ID    = contadores.ESTADO
and estados.ID    = lineas.ESTADO
and estados.ID    = linea.ESTADO
and  centrales.ID = n_central;

IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;


eProducida := 0;
  --abrir el cursor e insertar en la tabla correspondiente
        OPEN c1;
               FETCH c1 INTO n_contador, n_consumo, eProd, n_ini_ins, n_fin_ins ;
               WHILE c1%FOUND  LOOP
               FETCH c1 INTO n_contador, n_consumo, eProd, n_ini_ins, n_fin_ins ;
                      DBMS_OUTPUT.ENABLE(250);
                      DBMS_OUTPUT.PUT_LINE(' Central: ' ||n_central||' Contador: ' ||n_contador ||' Consumo contador:  ' ||n_consumo
                      ||' Energia Mxima : ' ||eProd ||' n_ini_ins:  ' ||n_ini_ins ||' n_fin_ins:  ' ||n_fin_ins   );
                     eProducida := eProducida + n_consumo;
                    -- alta registro en la tabla                                  
                     altaC5(n_central, n_contador, n_consumo,  eProducida , n_ini_ins,  n_fin_ins,  rst);
                     END LOOP;
       
       DBMS_OUTPUT.PUT_LINE('------------------------------------------------------------------------------------------------------------------------ '    );
       DBMS_OUTPUT.PUT_LINE('Energia Producida: Central : ' ||n_central ||' , '
       || ' periodo inicial :'
       || n_ini_ins
       || ' ,periodo final :'
       || n_fin_ins
       ||' ,energia producida: '
       || eProducida   );
       DBMS_OUTPUT.PUT_LINE('------------------------------------------------------------------------------------------------------------------------ '    );
       CLOSE c1;

rst :='OK, Proc. consultaC5';     
altaLog('Proc. consultaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central'
|| n_central
||'  n_contador: '
|| n_contador
||'  n_consumo  : '
|| n_consumo
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_contador
THEN
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_central : ' || n_central  ); 
    rst := 'ERROR: La central no tiene contadores conectados';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. consultaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central'
|| n_central
, 'rst', rst, rst);

ROLLBACK;


WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. consultaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central'
|| n_central
||'  n_contador: ' 
|| n_contador 
||'  n_consumo  : '
|| n_consumo
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. consultaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central'
|| n_central
||'  n_contador: ' 
|| n_contador 
||'  n_consumo  : '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END consultaC5;
/
--PRUEBA DE USO C5
declare rst varchar2(250);
begin
--Consulta consumo contadores de central y energia producida por esta
consultaC5(1,'01/01/2010','01/07/2012', rst);
end;
/