CREATE OR REPLACE
PROCEDURE consultaC6(
n_pInicial          IN VARCHAR2,
n_pFinal            IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  consultaC6 
PROPSITO:  Consulta para obtener porcentaje de  lecturas de contadores  efectuades de forma
            presencial y de forma telemtica en un perodo de tiempo
PARAMETERS: n_pInicial, n_pFinal ,rst
INPUT:  n_pInicial, n_pFinal
OUTPUT: tTelema,tPresent,n_pTelematica,n_pPresencial,n_total,n_pInicial_ins,n_pFinal_ins,rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: consultaC6('01/01/2012','01/06/2012', rst);
******************************************************************************/
n_pInicial_ins      VARCHAR2(11);
n_pFinal_ins        VARCHAR2(11);
n_total             NUMBER(9,2);
tPresent            INTEGER;
tTelema             INTEGER;
contador_test       INTEGER;
n_presencial        NUMBER(9,2);
n_telematica        NUMBER(9,2);
n_pPresencial       NUMBER(9,2);
n_pTelematica       NUMBER(9,2);
err_msg             VARCHAR2(100);

dup_total           EXCEPTION;
dup_null            EXCEPTION;
            
BEGIN

--comprobamos la longitud de las cadenas
n_pInicial_ins   := SUBSTR (n_pInicial, 1, 11);
n_pFinal_ins     := SUBSTR (n_pFinal, 1, 11);

--verificamos que los campos no nulos no sean nulos
IF (n_pInicial_ins   IS NULL)
OR (n_pFinal_ins   IS NULL)
THEN RAISE dup_null;
END IF;

-- obtener tipo lectura y el numero de lecturas

SELECT tLectura.id
INTO tPresent
FROM TLECTURA
WHERE 
tlectura.des = 'PRESENCIAL';


select COUNT(lecturas.TIPO) 
INTO n_presencial
FROM lecturas, tlectura
WHERE 
tLectura.id = lecturas.tipo
and tlectura.ID = tPresent
and lecturas.FECHALECTURA BETWEEN n_pInicial and n_pFinal;


SELECT tLectura.id
INTO tTelema
FROM TLECTURA
WHERE 
tlectura.des = 'TELEMATICA' OR tlectura.des = 'TELEMTICA';

SELECT COUNT(lecturas.TIPO) 
INTO n_telematica
FROM lecturas, tlectura
WHERE 
tLectura.id = tTelema;



SELECT count(*)
INTO contador_test
FROM
centrales, linea, lineas, contadores, consumos, estados
WHERE
   centrales.ID = 1
and consumos.ANYO BETWEEN '2010' and '2012'
and consumos.MES  BETWEEN 1 and 7
and centrales.ID  = lineas.C1
and contadores.ID = lineas.C2
and contadores.ID = consumos.CONTADOR
and linea.ID      = lineas.LINEA
and estados.ID    = centrales.ESTADO
and estados.ID    = contadores.ESTADO
and estados.ID    = lineas.ESTADO
and estados.ID    = linea.ESTADO;


SELECT COUNT(lecturas.TIPO) 
INTO  n_total
FROM lecturas, tlectura
WHERE 
tLectura.id = lecturas.tipo
--and tlectura.des = 'TELEMATICA' OR tlectura.des = 'TELEMTICA' OR tlectura.des = 'PRESENCIAL';
and tlectura.ID = tPresent OR tlectura.ID = tTelema;

n_pPresencial := n_presencial * 100 / n_total;         

n_pTelematica := n_telematica * 100 / n_total;   



 DBMS_OUTPUT.ENABLE;
 DBMS_OUTPUT.PUT_LINE('');
 DBMS_OUTPUT.PUT_LINE('Consulta para obtener porcentaje de  lecturas de contadores ' || n_total) ;
 DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
 DBMS_OUTPUT.PUT_LINE('');
 DBMS_OUTPUT.PUT_LINE('Total lecturas        : ' || n_total);
 DBMS_OUTPUT.PUT_LINE('Lecturas presenciales : ' || n_presencial);
 DBMS_OUTPUT.PUT_LINE('Lecturas telemticas  : ' || n_telematica);
  DBMS_OUTPUT.PUT_LINE('% lecturas telemticas  : ' || n_pPresencial);
  DBMS_OUTPUT.PUT_LINE('%lecturas telemticas   : ' || n_pTelematica);
 
 DBMS_OUTPUT.PUT_LINE('');

IF (n_total = 0)
THEN
RAISE dup_total;
END IF;

--insertamos en la tabla de C6 porcentaje de  lecturas de contadores
 
INSERT INTO C6 (telematica,presencial,pTelematica,pPresencial,total,pInicial,pFinal)
VALUES(tTelema,tPresent,n_pTelematica,n_pPresencial,n_total,n_pInicial_ins,n_pFinal_ins);

-- Fin de las operaciones
 
    rst:='Ok,alta C6 Alta porcentajes lecturas  realizada con exito';
     DBMS_OUTPUT.PUT_LINE('--------------------------------------------------------------------');
     DBMS_OUTPUT.PUT_LINE(rst);
     DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------------');  
altaLog('Proc. consultaC6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_total'
|| n_total
||'n_pTelematica: ' 
|| n_pTelematica 
||'n_pPresencial  : '
|| n_pPresencial
|| n_pInicial 
||'n_pInicial  : '
|| 'n_pFinal' 
|| n_pFinal
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_total
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_total : ' || n_total  ); 
    rst := 'ERROR: No hay lecturas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. consultaC6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_total'
|| n_total
||'n_pTelematica: ' 
|| n_pTelematica 
||'n_pPresencial  : '
|| n_pPresencial
|| n_pInicial 
||'n_pInicial  : '
|| 'n_pFinal' 
|| n_pFinal
, 'rst', rst, rst);

ROLLBACK;


WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. consultaC6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_total'
|| n_total
||'n_pTelematica: ' 
|| n_pTelematica 
||'n_pPresencial  : '
|| n_pPresencial
|| n_pInicial 
||'n_pInicial  : '
|| 'n_pFinal' 
|| n_pFinal
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. consultaC6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_total'
|| n_total
||'n_pTelematica: ' 
|| n_pTelematica 
||'n_pPresencial  : '
|| n_pPresencial
|| n_pInicial 
||'n_pInicial  : '
|| 'n_pFinal' 
|| n_pFinal 
, 'rst', rst, rst);
ROLLBACK;
END consultaC6;
/
--PRUEBA DE USO C6
declare rst varchar2(250);
begin
consultaC6('01/01/2012','01/07/2012', rst);
end;
/





