CREATE OR REPLACE
PROCEDURE altaE1(
n_central				IN NUMBER,
n_consumoContadores			IN NUMBER,
n_fecha                                 IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE1
PROPSITO: gestiona el alta en la tabla estadstica E1
Dada una central de produccin, el consumo de los contadores que dependen de la central.
PARAMETERS: n_central, n_consumoContadores, rst
INPUT: n_central, n_consumoContadores
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE1(1,300,to_char(sysdate,'DD/MM/YYYY'),rst)
******************************************************************************/
--definicion de variables
n_fecha_ins     VARCHAR2(11);
central_test	INTEGER;
clase_test      INTEGER;
err_msg       	VARCHAR2 (100);
des_nulo      	EXCEPTION;
dup_clase	EXCEPTION;
dup_central	EXCEPTION;

BEGIN
-- comprobar logitudes
n_fecha_ins  := SUBSTR (n_fecha ,1,11);

--verificamos si hay campos no nulos: nulos
IF 	   (n_central			IS NULL)
	OR (n_consumoContadores 	IS NULL)
        OR (n_fecha_ins          	IS NULL)
THEN
RAISE des_nulo;
END IF;

--obtener el codigo de la clase y verificar que es central de produccin 
--obtenemos el codigo de la clase

SELECT ccentral.ID
INTO clase_test
FROM ccentral
WHERE ccentral.DES = 'PRODUCCION' OR 
      ccentral.DES = 'PRODUCCIN';
IF (clase_test = 0)
THEN
RAISE dup_clase;
END IF;
--comprobar que la central existe
SELECT COUNT(*)
INTO central_test
FROM centrales
WHERE centrales.ID = n_central
and centrales.CLASE = clase_test;
IF (central_test=0)
THEN
RAISE dup_central;
END IF;

-- insertamos en E1
INSERT INTO E_1(central,consumoContadores,fecha)
VALUES (n_central, n_consumoContadores,n_fecha_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E1: '  || 'n_central: '  ||  n_central|| ' '||n_fecha_ins); 
    rst:='OK, Alta de E1  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
   , 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_clase
THEN
    rst := 'ERROR: NO existe clase de Central de Produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || clase_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central
THEN
    rst := 'ERROR: NO existe la central de produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_central: ' || n_central, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
    , 'rst', rst, rst);
ROLLBACK;
end altaE1;
/