CREATE OR REPLACE
PROCEDURE altaE2(
n_linea				IN NUMBER,
n_anyo  			IN NUMBER,
n_consumoEnergiaMedio           IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE2
PROPSITO: gestiona el alta en la tabla estadstica E_2
Dada una lnea de comunicacin y un ao en concreto, el valor medio de la energa consumida
si el contador hace servir dos lineas, computa en las dos
PARAMETERS: n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio, rst
INPUT:      n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE2(1,20112,50,rst);
******************************************************************************/
--definicion de variables
linea_test	INTEGER;
err_msg       	VARCHAR2 (100);
dup_linea	EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN
--verificamos si hay campos no nulos: nulos
IF 	   (n_linea			IS NULL)
--	OR (n_consumoContadores 	IS NULL)
      	OR (n_consumoEnergiaMedio 	IS NULL)
THEN
RAISE des_nulo;
END IF;
--comprobar que la linea existe
SELECT count(*)
INTO linea_test
FROM linea
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
--actualizamos la tabla E_2
INSERT INTO E_2(linea, anyo, consumoEnergiaMedio)
VALUES (n_linea,n_anyo, n_consumoEnergiaMedio);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E2: '  || 'n_linea: '  ||  n_linea || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio ); 
    
    rst:='OK, Alta de E2  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
   , 'rst', rst, rst);
COMMIT;
-- control de excepciones
EXCEPTION
WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_linea
THEN
    rst := 'ERROR: NO existe la linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;
END altaE2;
/