CREATE OR REPLACE
PROCEDURE altaEstadisticas(
n_anyo   IN  NUMBER,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEstadisticas
PROPSITO: gestiona la actualizacion de las estadisticas
PARAMETERS: n_anyo ,rst
INPUT:  n_anyo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaEstadisticas(2011,rst);

******************************************************************************/

-- variables para E_2 y E6
n_contador  NUMBER;
n_consumo   NUMBER;
n_anyo_ins  NUMBER; -- para E_2
e7_test                 INTEGER;
central_test            INTEGER;
lineas_test             INTEGER;
i                       INTEGER;
lMax                    INTEGER; 
iMax                    INTEGER;
porcentaje              NUMBER;
tipo_test               INTEGER;
err_msg                 VARCHAR2(100);

dup_central             EXCEPTION;
dup_lineas              EXCEPTION;
dup_null                EXCEPTION;

-- para actualizar E_2
CURSOR c2 IS
select distinct linea.id, consumos.ANYO, avg(consumos.CONTADOR)
from linea, lineas, consumos
where
linea.ID = lineas.LINEA
AND lineas.C2 = consumos.CONTADOR
AND consumos.ANYO = n_anyo
group by linea.id, consumos.ANYO
order by linea.id;

-- cursor para extraer los datos de Estadistica E6
CURSOR c1 IS
select consumos.CONTADOR,sum(consumos.consumo)
from consumos
group  by consumos.contador 
having sum(consumos.consumo) >0 
order by sum(consumos.consumo) desc;

---------
--proceso
---------
BEGIN
--inicializar variables
i :=1;

-------------------------------
-- actualizar estadisticas E_1
--------------------------------

-- obtenemos el numero de centrales de produccin activas
select  count (distinct centrales.id)
INTO central_test
FROM centrales, ccentral, lineas, linea, consumos, contadores
WHERE
    ccentral.ID     = centrales.CLASE
AND centrales.CLASE = 2                 --produccion
and linea.id = lineas.LINEA
and centrales.ID = lineas.C1            -- conectadas
and consumos.CONTADOR = lineas.C2       -- miro consumos
and contadores.id = lineas.c2           -- conectadas
and linea.ESTADO =1                     -- en alta
and lineas.ESTADO =1                    --en alta
and centrales.ESTADO =1                 --activas
and contadores.ESTADO =1                --en alta
and consumos.CONSUMO > 0;               -- con consumo

IF (central_test = 0)
THEN
RAISE dup_central;
END IF;

--actualizar registros
WHILE (i <= central_test)  LOOP  
--  altaE1(centrales.id,getConsumoCentral(centrales.id),to_char(sysdate,'DD/MM/YYYY'),rst);  -- actualizar el registro
  altaE1(i,getConsumoCentral(i),to_char(sysdate,'DD/MM/YYYY'),rst);  -- actualizar el registro
  --  DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('total_Centrales:' || central_test ||'central: '||central:  || i|| ' consumo:' ||getConsumoCentral(i)||' fecha: '|| to_char(sysdate,'DD/MM/YYYY') );
    i := i + 1;
END LOOP;
-- Fin de las operaciones
rst := 'OK: Actualizo E_1';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');
altaLog('Proc. altaEstadisticas_E1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_2
-------------------------------
--inicializar variables
--i :=0;
n_contador  :=0;  -- variable reutilizada para linea
n_consumo   :=0;  -- variable reutilizada para guardar el consumo medio de la linea
n_anyo_ins :=n_anyo;

 OPEN c2;
               FETCH c2 INTO n_contador ,n_anyo_ins ,n_consumo ;
               WHILE c2%FOUND  LOOP
                               
 --DBMS_OUTPUT.PUT_LINE('');
   DBMS_OUTPUT.PUT_LINE('   linea: ' || n_contador || '  n_anyo: ' || n_anyo || '  consumo_medio: ' || n_consumo );
              FETCH c2 INTO n_contador ,n_anyo_ins ,n_consumo ;
                altaE2(n_contador ,n_anyo_ins, n_consumo,rst);  -- actualizar  el registro
                end loop;
        CLOSE c2;
 -- Fin de las operaciones

rst := 'OK: Actualizo E_2';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
 ||'   n_contador'
 || n_contador
 || '  n_anyo: '
 || n_anyo
 || '  n_consumo: '
 || n_consumo
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_3
------------------------------
i     := 1;
lMax  := 0;
iMax  := 0;
-- obtener numero de lineas conectadas
select  count (distinct linea.ID)
INTO lineas_test
FROM lineas, linea
WHERE
    lineas.LINEA = linea.ID;
IF (lineas_test = 0)
THEN
RAISE dup_lineas;
END IF;
WHILE (i < lineas_test)  LOOP  
 IF (getConsumoLinea(i) > lMax)
    THEN    lMax := getConsumoLinea(i); -- buscar el consumo mximo
            iMax := i;                  -- id de la linea mxima
    END IF;
     i := i + 1;  --avanza
END LOOP;
  altaE3(i,getConsumoLinea(i),to_char(sysdate,'DD/MM/YYYY'),rst);  -- actualizar  el registro
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('Consumo Maximo : '||i ||', '|| lMax );
   -- DBMS_OUTPUT.PUT_LINE('Linea consumo Maximo : '||i ||', '|| getConsumoLinea(i) );
-- Fin de las operaciones

rst := 'OK: Actualizo E_3';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_4
-------------------------------

--lineas_test -> lineas conectadas
i    := 2;
lMax := 0;  --contador si linea supera el 50%
porcentaje := 0;  -- porcentaje final de lineas
    
WHILE (i < lineas_test)  LOOP  
 IF  (getConsumoLineaAnyo(i,n_anyo) > getLineaCMax(i)/2)
    THEN    lMax := lMax +1; -- incrementamos el contador de lina que supera el 50%
      -- DBMS_OUTPUT.PUT_LINE('lineas_test  : '|| lineas_test );
      -- DBMS_OUTPUT.PUT_LINE('lMax  : '|| lMax );
      -- DBMS_OUTPUT.PUT_LINE('i  : '|| i );

        END IF;
     i := i + 1;  --avanza
END LOOP;
 
 porcentaje :=  lMax*100/lineas_test;
 

 altaE4(n_anyo, iMax,rst);  -- actualizar  el registro
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('lineas_test  : '|| lineas_test );
   -- DBMS_OUTPUT.PUT_LINE('n_anyo  : '||i ||', '|| n_anyo );
   -- DBMS_OUTPUT.PUT_LINE('Porcentaje de lineas que superan el 50% : '||porcentaje ||'%'  );
-- Fin de las operaciones

rst := 'OK: Actualizo E_4';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

----------------------------------
-- actualizar estadstica E_5
-----------------------------------
i     := 1;
iMax  := 0;
WHILE (i < central_test)  LOOP  
 IF (getConsumoCentralAnyo(i ,n_anyo) < getCentralEmax(i) * 0.3)  -- produccion < del 30% de eMax de la central
    THEN    
            iMax := iMax+1;                  -- acumulo el numero de centrales
    END IF;
   i := i + 1;
END LOOP;
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('n_anyo : ' || n_anyo );
   -- DBMS_OUTPUT.PUT_LINE('iMax : ' || iMax );

altaE5(n_anyo,iMax,rst); -- actualizar el registro

-- Fin de las operaciones
rst := 'OK: Actualizo E_5';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_6
-------------------------------
--inicializar contador
i :=0;
--verificamos que los campos no nulos no sean nulos
 OPEN c1;
               FETCH c1 INTO n_contador,n_consumo ;
               WHILE (c1%FOUND and ( c1%ROWCOUNT <= 10)) LOOP
                               
 DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
 DBMS_OUTPUT.PUT_LINE('   n_contador: ' || n_contador  || '  n_consumo: ' || n_consumo );
               FETCH c1 INTO n_contador,n_consumo ;
                altaE6(n_contador, n_consumo,rst);  -- actualizar  el registro
                end loop;
        CLOSE c1;
 -- Fin de las operaciones

rst := 'OK: Actualizo E_6';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
 ||'   n_contador'
 || n_contador
 || '  n_consumo: '
 || n_consumo
, 'rst', rst, rst);
COMMIT;

---------------------------------
-- actualizar estadstica E_7
---------------------------------
i :=1;
--obterner el numero de clientes 
select count(distinct clientes.id)
into e7_test
from contratos, clientes, contadores, consumos
where clientes.ID   = contratos.CLIENTE
and  contadores.ID  = contratos.CONTADOR
and  contadores.ID  = consumos.CONTADOR;
WHILE (i < e7_test)  LOOP  
altaE7(getIdCliente(i), getConsumoMedioCliente(i),rst);  -- actualizar el registro
i := i + 1;
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('Cliente y consumo medio : '||getIdCliente(i) ||', '|| getConsumoMedioCliente(i) );
END LOOP;

-- Fin de las operaciones
rst := 'OK: Actualizo E_7';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;
---------------------------------------------


EXCEPTION
WHEN dup_central
THEN
    rst := 'ERROR: No hay centrales';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEstadistica E_1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_lineas
THEN
    rst := 'ERROR: No hay lineas conectadas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEstadistica_E_3 ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaEstadisticas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
 err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaEstadisticas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;
END altaEstadisticas;

--- lanzar proceso
declare
    rst varchar2(250);
begin
altaEstadisticas(2011,rst);
END;

   












