CREATE OR REPLACE
PROCEDURE bajaE1(
n_id				IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE1
PROPSITO: gestiona el borrado del registro en la tabla estadstica E1
PARAMETERS: n_id, rst
INPUT: n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE1(1,rst)
******************************************************************************/
--definicion de variables
id_test		INTEGER;
err_msg       	VARCHAR2 (100);
des_nulo      	EXCEPTION;
dup_id		EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
IF 	   (n_id IS NULL)
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_1
WHERE E_1.id = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--borramos en E1
DELETE
FROM E_1
WHERE id=n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Baja/borrado en E1: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Borrado del registro en E1  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
   , 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;

END bajaE1;
/