CREATE OR REPLACE
PROCEDURE modificaE1(
n_id				IN NUMBER,
n_central			IN NUMBER,
n_consumoContadores		IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE1
PROPSITO: gestiona la modificacion en la tabla estadstica E1
PARAMETERS: n_id,n_central, n_consumoContadores, rst
INPUT: n_id,n_central, n_consumoContadores
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE1(1,1,300,rst)
******************************************************************************/
--definicion de variables
central_test	INTEGER;
clase_test      INTEGER;
id_test		INTEGER;
err_msg       	VARCHAR2 (100);
des_nulo      	EXCEPTION;
dup_clase	EXCEPTION;
dup_central	EXCEPTION;
dup_id		EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
IF 	   (n_id			IS NULL)
	OR (n_central			IS NULL)
	OR (n_consumoContadores 	IS NULL)
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM centrales
WHERE centrales.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;


--obtener el codigo de la clase y verificar que es central de produccin 
--obtenemos el codigo de la clase

SELECT ccentral.ID
INTO clase_test
FROM ccentral
WHERE ccentral.DES = 'PRODUCCION' OR 
      ccentral.DES = 'PRODUCCIN';
IF (clase_test = 0)
THEN
RAISE dup_clase;
END IF;
--comprobar que la central existe
SELECT COUNT(*)
INTO central_test
FROM centrales
WHERE centrales.ID = n_central
and centrales.CLASE = clase_test;
IF (central_test=0)
THEN
RAISE dup_central;
END IF;


--modificamos E1
UPDATE E_1
SET
central=n_central,
consumoContadores=n_consumoContadores
WHERE id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modificado  E1: '  || 'n_central: '  ||  n_central); 
    rst:='OK, Modificado de E1  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
   , 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_clase
THEN
    rst := 'ERROR: NO existe clase de Central de Produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || clase_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central
THEN
    rst := 'ERROR: NO existe la central de produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_central: ' || n_central, 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe la central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_central: ' || n_central, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    , 'rst', rst, rst);
ROLLBACK;

END modificaE1;
/