CREATE OR REPLACE
PROCEDURE modificaE2(
n_id				IN NUMBER,
n_linea				IN NUMBER,
n_anyo  			IN VARCHAR2,
n_consumoContadores             IN NUMBER,
n_consumoEnergiaMedio           IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE2
PROPSITO: modifica la tabla estadstica E_2
Dada una lnea de comunicacin y un ao en concreto, el valor medio de la energa consumida
si el contador hace servir dos lineas, computa en las dos
PARAMETERS: n_id,n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio, rst
INPUT: n_id,n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE2(1,1,'2012',90,50,rst);
******************************************************************************/
--definicion de variables
linea_test	INTEGER;
id_test         INTEGER;
err_msg       	VARCHAR2 (100);
dup_id          EXCEPTION;
dup_linea	EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
 	   
IF 	   (n_id			IS NULL)
	OR (n_linea			IS NULL)
	OR (n_consumoContadores 	IS NULL)
      	OR (n_consumoEnergiaMedio 	IS NULL)

THEN
RAISE des_nulo;
END IF;

--comprobar que la linea existe
SELECT count(*)
INTO linea_test
FROM linea
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_2
WHERE E_2.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--modificamos E2
UPDATE E_2
SET
linea= n_linea,
anyo = n_anyo, 
consumoContadores = n_consumoContadores,
consumoEnergiaMedio= n_consumoEnergiaMedio
WHERE id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modificacion de E_2: '  || 'n_linea: '  ||  n_linea); 
    rst:='OK, Modificacion de E_2:  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_linea
THEN
    rst := 'ERROR: NO existe la linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe la central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;
END modificaE2;
/