CREATE OR REPLACE
PROCEDURE modificaE4(
n_id		IN NUMBER,
n_anyo  		IN VARCHAR2,
n_perLineaMas50         IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE4
PROPSITO: gestiona la modificacin de la  tabla estadstica 
            Dado un ao en concreto: porcentaje de lineas que superan 50% de energia consumida.
PARAMETERS: n_id,n_anyo, n_perLineaMas50, rst
INPUT:      n_id,n_anyo, n_perLineaMas50
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE4(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test       INTEGER;
n_anyo_ins        VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
dup_id		EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN
--control de la longitud de cadenas
n_anyo_ins := SUBSTR (n_anyo, 1, 4);

--verificamos si hay campos no nulos: nulos
IF 	   (n_id              IS NULL)  
       OR (n_anyo_ins	      IS NULL)
	OR (n_perLineaMas50   IS NULL)
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_4
WHERE E_4.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;



-- modificamos en E4
UPDATE E_4
SET
anyo = n_anyo,
perLineaMas50= n_perLineaMas50
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica E4: '  || 'n_anyo: '  ||  n_anyo); 
    DBMS_OUTPUT.PUT_LINE('Modifica E4: '  || 'n_perLineaMas50: '  ||  n_perLineaMas50); 
    rst:='OK, Modifica  E4  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE4',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
   , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
    , 'rst', rst, rst);
ROLLBACK;
END modificaE4;
/