CREATE OR REPLACE
PROCEDURE modificaE5(
n_id				IN NUMBER,
n_anyo  		        IN VARCHAR2,
n_cenProduccionMenos30          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE5
PROPSITO: gestiona la modificacin en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_id,n_anyo, cenProduccionMenos30, rst
INPUT:      n_id,n_anyo, cenProduccionMenos30 
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE5(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test		INTEGER;
n_anyo_ins        VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;
dup_id			EXCEPTION;
BEGIN
--control de la longitud de cadenas
n_anyo_ins := SUBSTR (n_anyo, 1, 4);

--verificamos si hay campos no nulos: nulos
IF 	  (n_id                   IS NULL)
      OR  (n_anyo_ins		  IS NULL)
      OR (n_cenProduccionMenos30  IS NULL)
THEN
RAISE des_nulo;
END IF;
--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_5
WHERE E_5.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--modificamos E5
UPDATE E_5
SET
anyo = n_anyo,
cenProduccionMenos30 = n_cenProduccionMenos30
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica  E_5: '  || 'n_anyo: '  ||  n_anyo); 
    DBMS_OUTPUT.PUT_LINE('Modifica  E_5: '  || 'n_cenProduccionMenos30: '  ||  n_cenProduccionMenos30); 
    rst:='OK, Modifica  E_5  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE5',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
   , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
    , 'rst', rst, rst);
ROLLBACK;
END modificaE5;
/