CREATE OR REPLACE
PROCEDURE modificaE6(
n_id			IN NUMBER,
n_contador  	IN NUMBER,
n_consumo       IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE6
PROPSITO: gestiona la modificacin en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_id,n_contador,n_consumo, rst
INPUT:      n_id,n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE6(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test			INTEGER;
contador_test     VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
dup_contador      EXCEPTION;
dup_id            EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_id 			IS NULL)
	OR (n_contador       IS NULL)
	OR (n_consumo        IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--Verificamos exista el  registro 
SELECT COUNT (*)
INTO id_test
FROM E_6
WHERE E_6.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


--modificamos E_6
UPDATE E_6
SET
contador= n_contador,
consumo= n_consumo
WHERE id = n_id;

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica E6: '  || 'n_contador: '  ||  n_contador); 
    DBMS_OUTPUT.PUT_LINE('Modifica E6: '  || 'n_consumo: '  ||  n_consumo); 
    rst:='OK, Modifica de E6  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el Registro';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
    , 'rst', rst, rst);
ROLLBACK;
END modificaE6;
/