CREATE OR REPLACE
PROCEDURE modificaE7(
n_id		      IN NUMBER,
n_cliente  	      IN NUMBER,
n_consumoMedio        IN NUMBER,
rst OUT VARCHAR2
)
IS

/******************************************************************************
NOMBRE: modificaE7
PROPSITO: gestiona el alta en la tabla estadstica E_7
            Consumo medio de todos los clientes.
PARAMETERS: n_id,n_contador,n_consumo, rst
INPUT:      n_id,n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE7(1,2,90,rst);
******************************************************************************/
--definicion de variables
id_test		  INTEGER;
cliente_test      INTEGER;
err_msg       	  VARCHAR2 (100);
dup_cliente       EXCEPTION;
des_nulo      	  EXCEPTION;
dup_id		  EXCEPTION;
BEGIN


--verificamos si hay campos no nulos: nulos
    IF 	   (n_id 	        IS NULL)
	OR (n_cliente           IS NULL)
	OR (n_consumoMedio      IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista el  cliente 
SELECT COUNT (*)
INTO cliente_test
FROM clientes
WHERE clientes.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

--modificamos E7
UPDATE E_7
SET
cliente= n_cliente,
consumoMedio= n_consumoMedio
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E_7: '  || 'n_cliente: '  ||  n_cliente); 
    DBMS_OUTPUT.PUT_LINE('Alta de E_7: '  || 'n_consumoMedio : '  ||  n_consumoMedio ); 
    rst:='OK, Alta de E_7  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_cliente
THEN
    rst := 'ERROR: NO existe el Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_id
THEN
    rst := 'ERROR: NO existe el Registro';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
    , 'rst', rst, rst);
ROLLBACK;
END modificaE7;
/