CREATE OR REPLACE
PROCEDURE modificaCentralProduccion(
n_id			IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaCentralProduccion
PROPSITO: gestiona la modificacin de una  Central de Produccin
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT:n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaCentralProduccion(1,'BCN_P4',1,to_char(sysdate,'DD/MM/YYYY'),2,3,20,10,1,to_char(sysdate,'DD/MM/YYYY'),500,null,rst);
******************************************************************************/
n_des_ins             VARCHAR2(50);
n_obs_ins             VARCHAR2(50);
id_test			INTEGER;
dist_test                       INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
ins_test                        INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			EXCEPTION;
dup_dist                        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
des_nulo  			EXCEPTION;
dup_ins                         EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);
--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_clase IS NULL)
	OR (n_tipo IS NULL)
	OR (n_eMax IS NULL)
	OR (n_eMin IS NULL)
	OR (n_inspeccion IS NULL)
	OR (n_fIns IS NULL)
	OR (n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;
/*
--verificamos si existe la descripcin de la  Central
SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_central;
END IF;
*/
-- obtener el codigo de la central de Produccion
SELECT id
INTO dist_test
FROM ccentral
WHERE
ccentral.des='PRODUCCION' OR 
ccentral.DES='PRODUCCIN';
IF (dist_test = 0)
THEN
RAISE dup_dist; 
END IF;

IF (n_clase <> dist_test)
THEN
RAISE dup_dist; -- no es central de Produccin
END IF;
--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


--verificamos exista la clase de central y que sea de Central de Distribucion

SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; 
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

--verificamos  que exista el tipo de inspeccion
SELECT COUNT (*)
INTO ins_test
FROM tInspeccion
WHERE tInspeccion.id = n_inspeccion;
IF (ins_test = 0)   
THEN
RAISE dup_ins; 
END IF;

--modificamos la Central de Produccin

UPDATE centrales
SET
des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado
,clase =n_clase
,tipo= n_tipo
,eMax= n_eMax
,eMin = n_eMin
,inspeccion = n_inspeccion
,fIns = n_fIns
,ubica = n_ubica
,obs =n_obs_ins
WHERE
centrales.id = n_id;


-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica Central ProduccinOK: ' || n_id); 
    rst:='OK, Modificacin Central Produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica CENTRAL: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el cdigo de la central de Produccin'||n_id;
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el cdigo de la Central de Distribucin ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta descripcin de  Central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacion  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;

WHEN dup_dist
THEN
    rst := 'ERROR: No es CENTRAL DE PRODUCCION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || dist_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ins
THEN
    rst := 'ERROR: No existe el tipo de inspeccion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_inspeccion: ' || n_inspeccion, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. altaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaCentralProduccion;
/

declare
    rst varchar2(250);
begin
--	n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, 
modificaCentralProduccion(1,'BCN_PROD_1',1,to_char(sysdate,'DD/MM/YYYY'),2,1,12000,100,1,to_char(sysdate,'DD/MM/YYYY'),1,null,rst);
end;

select * from centrales