CREATE OR REPLACE
PROCEDURE modificaClientesEstado(
n_id                IN NUMBER,
n_estado            IN NUMBER,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaClientesEstado
PROPSITO: gestiona la modificacion  del estado de  un cliente en la tabla clientes
PARAMETERS: n_id,n_estado,n_fechaMod, rst
INPUT: n_id,n_estado,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaClientesEstado(3,1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/

n_fechaMod_ins      VARCHAR2(11 CHAR);

id_test             INTEGER;
estado_test         INTEGER;
err_msg             VARCHAR2(100);
dup_id              EXCEPTION;
dup_estado          EXCEPTION;
dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas

n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_id              IS NULL)
OR (n_estado          IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM CLIENTES
WHERE clientes.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- modificamos el cliente
UPDATE CLIENTES
SET
estado      = n_estado,
fechaMod    = n_fechaMod_ins
WHERE
clientes.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id: ' || n_id ); 
    rst:='Ok, Modificacion de estado de cliente realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
|| ', '
||'n_estado: '
|| n_estado 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el CODIGO DEL CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  CODIGO DEL CLIENTE ';
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;
END modificaClientesEstado;
/

--prueba de uso
declare rst varchar2(250);
begin
modificaClientesEstado(3,2,to_char(sysdate,'DD/MM/YYYY'), rst);
end;
/



