CREATE OR REPLACE
PROCEDURE modificaContadores(
n_id			IN NUMBER,
n_modelo         	IN NUMBER,
n_ubica         	IN NUMBER,
n_estado         	IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
n_numSerie         	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaContadores
PROPSITO: gestiona la modificacin  de un contador en la tabla contadores
PARAMETERS: n_id,n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie,rst
INPUT: n_id,n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaContadores(1,1,1,1,to_char(sysdate,'DD/MM/YYYY'), 'n/s_1', rst);
******************************************************************************/
n_fechaEstado_ins       VARCHAR2(11 CHAR);
n_numSerie_ins          VARCHAR2(20);
id_test                 INTEGER;
modelo_test             INTEGER;
ubica_test              INTEGER;
estado_test             INTEGER;
err_msg                 VARCHAR2(100);
dup_id                  EXCEPTION;
dup_modelo            EXCEPTION;
dup_ubica               EXCEPTION;
dup_estado              EXCEPTION;
dup_des               EXCEPTION;

BEGIN


n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 
n_numSerie_ins      := SUBSTR(n_numSerie, 1, 20);


--verificamos que los campos no nulos no sean nulos
IF (n_id 			IS NULL)
OR (n_modelo          IS NULL)
OR (n_ubica           IS NULL)
OR (n_estado          IS NULL)
OR (n_fechaEstado_ins IS NULL)
OR (n_numSerie_ins    IS NULL)
THEN
RAISE dup_des;
END IF;



--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM contadores
WHERE contadores.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--comprobar que existe el modelo
SELECT COUNT (*)
INTO modelo_test
FROM MODELOS
WHERE ID = n_modelo;
IF (modelo_test = 0)
THEN
RAISE dup_modelo;
END IF;
--comprobar que existe la  ubicacion
SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--modificamos el contador
UPDATE contadores
SET
modelo = n_modelo
,ubica = n_ubica
,estado = n_estado
,fechaEstado = n_fechaEstado_ins
,numSerie= n_numSerie_ins
WHERE
contadores.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'n_modelo: ' 
|| n_modelo 
|| ', ' 
||'n_ubica  : '
|| n_ubica
|| ', ' 
||'n_estado  : '
|| n_estado
|| ', ' 
||'n_fechaEstado: '
|| n_fechaEstado_ins
|| ', ' 
||'n_numSerie: '
|| n_numSerie_ins); 
    rst:='Ok, Modifica contador   realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' 
|| n_modelo 
|| ', ' 
||'n_ubica  : '
|| n_ubica
|| ', ' 
||'n_estado  : '
|| n_estado
|| ', ' 
||'n_fechaEstado: '
|| n_fechaEstado_ins
|| ', ' 
||'n_numSerie: '
|| n_numSerie_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el Cdigo del contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  Cdigo del contador ';
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_modelo
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_modelo : ' || n_modelo  ); 
     rst := 'ERROR: No existe Modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' || n_modelo  
, 'rst', rst, rst);

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe ubicacin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica: ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: No existe Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado ' || n_estado
|| ', '
||'n_fechaEstado: ' || n_fechaEstado 
, 'rst', rst, rst);

ROLLBACK;
WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);
ROLLBACK;
END modificaContadores;
/






