CREATE OR REPLACE
PROCEDURE modificaContratos(
n_id				IN NUMBER,
n_cliente           	IN NUMBER,
n_contador          	IN NUMBER,
n_estado            	IN NUMBER,
n_fechaEstado       	IN VARCHAR2,
n_pContrato         	IN NUMBER,
n_obs             	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaContratos
PROPSITO: gestiona la modificacin de un contraato en la tabla contratos
PARAMETERS: n_id,n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs, rst
INPUT: n_id,n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaContratos(1,1,1,1,to_char(sysdate,'DD/MM/YYYY'),30,'obs_contrato', rst);
******************************************************************************/

n_fechaEstado_ins     	VARCHAR2(11 CHAR);
n_obs_ins             	VARCHAR2(50 CHAR);
id_test				INTEGER;
cliente_test			INTEGER;
contador_test			INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);

n_anterior    NUMBER;
n_actual      NUMBER;
n_tipo        NUMBER;
n_consumo     NUMBER;
dup_cliente			EXCEPTION;
dup_contador	        	EXCEPTION;
dup_estado				EXCEPTION;
dup_des                 	EXCEPTION;
dup_id				EXCEPTION;

BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  		:= SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins               	:= SUBSTR (n_obs, 1, 50);

-- inicializo contadores de lecturas y consumos 
n_anterior := 0;
n_actual   := 0; 
n_tipo     := 1;
n_consumo  := 0;
--verificamos que los campos no nulos no sean nulos

IF (n_id	        		IS NULL)
OR (n_cliente        		IS NULL)
OR (n_contador       		IS NULL)
OR (n_estado      		IS NULL)
OR (n_fechaEstado_ins       IS NULL)
OR (n_pContrato        	IS NULL)
THEN
RAISE dup_des;
END IF;

--Verificamos que que exista el id del contrato 
SELECT COUNT (*)
INTO id_test
FROM contratos
WHERE contratos.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--comprobar que exista el  cliente
SELECT COUNT (*)
INTO cliente_test
FROM CLIENTES
WHERE CLIENTES.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

-- comprobar que exista el contador
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE contadores.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;


--comprobar que exista el estado 

SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;



-- modificamos el contrato
UPDATE contratos
SET
cliente 		= n_cliente
,contador 		= n_contador
,estado 		= n_estado
,fechaEstado 	= n_fechaEstado_ins
,pContrato 	= n_pContrato
,obs 			= n_fechaEstado_ins
WHERE
contratos.id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
    ); 
    rst:='Ok, Modifica contrato con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
COMMIT;

-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el id del Contrato';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaContrato', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_cliente
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_cliente : ' || n_cliente  ); 
     rst := 'ERROR: NO existe el CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el CLIENTE ';
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente  : ' || n_cliente
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_contador: ' || n_contador  ); 
     rst := 'ERROR:  NO  existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el CONTADOR';
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: ' || n_contador
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato 
||'n_obs: '
|| n_obs 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
ROLLBACK;
END modificaContratos;
/


