CREATE OR REPLACE
PROCEDURE modificaEmpresa(
n_id		IN VARCHAR2,
n_cif		IN VARCHAR2,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaEmpresa
PROPSITO: gestiona la modificacin de una EMPRESA
PARAMETERS: n_id,n_cif,n_des,n_estado,n_fechaEstado, rst
INPUT: n_cif,n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaEmpresa(1's121214','empresa3',5,'01/05/2012',rst);
******************************************************************************/
n_des_ins       	VARCHAR2 (50);
n_fechaEstado_ins    	VARCHAR2 (11);
id_test			INTEGER;
estado_test		INTEGER;
err_msg         	VARCHAR2 (100);
dup_id			EXCEPTION;
dup_estado		EXCEPTION;
des_nulo  		EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);
--verificamos si el hay campos nulos
IF (n_id	IS NULL)
OR (n_cif       IS NULL)
OR (n_des_ins   IS NULL)
OR (n_estado    IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE des_nulo;
END IF;
--verificamos si existe el estado  de la empresa
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- modificamos la  empresa
UPDATE empresas
SET
cif = n_cif
,des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado_ins
WHERE
empresas.id = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Modifica EMPRESA :'
|| n_des
|| 'cif: '
|| n_cif); 
    rst:='Ok, Modificacin  EMPRESA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica EMPRESA :'
|| n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe el id de Empesa';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO existe este ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica EMPRESA :' || n_des
|| 'cif: '
|| n_cif
|| 'estado'
|| n_estado
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Empresa : ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaEmpresa;
/
