CREATE OR REPLACE
PROCEDURE modificaLecturas(
n_id		    IN NUMBER,
n_contador          IN NUMBER,
n_fechaLectura      IN VARCHAR2,
n_tipo              IN NUMBER,
n_anterior          IN NUMBER,
n_actual            IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaLecturas
PROPSITO: gestiona el alta en la tabla de Lecturas
PARAMETERS:  n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo, rst
INPUT:   n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaLecturas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,1, rst)
******************************************************************************/
n_fechaLectura_ins      VARCHAR2 ( 11 CHAR);

id_test		        INTEGER;
contador_test           INTEGER;
tipo_test               INTEGER;
err_msg                 VARCHAR2 (100);
dup_id		        EXCEPTION;
dup_contador            EXCEPTION;
dup_tipo                EXCEPTION;
dup_null                EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_fechaLectura_ins       := SUBSTR (n_fechaLectura, 1, 50);
--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_fechaLectura_ins  IS NULL)
OR (n_tipo              IS NULL)
OR (n_anterior          IS NULL)
OR (n_actual            IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;


--Verificamos exista la lectura 
SELECT COUNT (*)
INTO id_test
FROM LECTURAS
WHERE lecturas.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--verificamos que  exista el tipo de lectura
SELECT COUNT (*)
INTO tipo_test
FROM TLECTURA
WHERE tLectura.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;



-- modificamos la tupla de lecturas
UPDATE lecturas
SET
lecturas.CONTADOR 	= n_contador,
lecturas.FECHALECTURA 	= n_fechaLectura_ins,
lecturas.TIPO		= n_tipo,
lecturas.ANTERIOR	= n_anterior,
lecturas.ACTUAL		= n_actual,
lecturas.CONSUMO	= n_consumo
WHERE
lecturas.ID = n_id;

-- Fin de las operaciones
rst := 'OK';

altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;



WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_tipo
THEN
    rst := 'ERROR: NO este  tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END modificaLecturas;
/
