CREATE OR REPLACE
PROCEDURE modificaLinea(
n_id			IN NUMBER,
n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_cMax                  IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaLinea
PROPSITO: gestiona la modificin de una linea
PARAMETERS: n_id,n_estado, n_fechaEstado, n_cMax, n_obs, rst
INPUT: n_id,n_estado, n_fechaEstado, n_cMax, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaLinea(1,1,'10/05/2012',10000,null,rst);
******************************************************************************/

id_test		INTEGER;
n_obs_ins       VARCHAR2 (50);
err_msg         VARCHAR2 (100);
dup_id		EXCEPTION;
des_nulo        EXCEPTION;

BEGIN
-- compobar longitud de cadenas
n_obs_ins := SUBSTR (n_obs, 1, 50);

--verificamos si hay campos no nulos: nulos
        IF   (n_id          IS NULL)
        OR   (n_estado      IS NULL)
        OR   (n_fechaEstado IS NULL)
        OR   (n_cMax        IS NULL)
        THEN
        RAISE des_nulo;
        END IF;

--Verificamos que que exista el id de la linea 
SELECT COUNT (*)
INTO id_test
FROM linea
WHERE linea.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
-- hacemos la modificacin de la lnea
UPDATE linea
SET
 estado =  n_estado
,fechaEstado = n_fechaEstado
,cMax =n_cMax
,obs = n_obs_ins
WHERE  linea.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica linea: ' 
    || n_id
    ||' n_estado'
    || n_estado
    || 'fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax)    ; 
    rst:='OK, Modifica linea  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'modificaLinea:' 
    || n_id
    ||' n_estado'
    || n_estado
    || ' fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax 
, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe la lnea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'fecha  linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'fecha  de linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;
END modificaLinea;
/

declare
    rst varchar2(250);
begin
--            n_id,n_estado, n_fechaEstado, n_cMax, n_obs,
modificaLinea(5,1,'10/05/2012',6500,null,rst);
modificaLinea(6,1,'10/05/2012',6600,null,rst);
modificaLinea(7,1,'10/05/2012',6700,null,rst);
modificaLinea(8,1,'10/05/2012',6800,null,rst);
modificaLinea(9,1,'10/05/2012',69000,null,rst);
modificaLinea(10,1,'10/05/2012',6800,null,rst);
modificaLinea(11,1,'10/05/2012',69000,null,rst);

END;