CREATE OR REPLACE
PROCEDURE modificaLineas(

n_id			IN NUMBER,
n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_linea                 IN NUMBER,
n_c1                    IN NUMBER,
n_c2                    IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaLineas
PROPSITO: gestiona la modificacin   de las lineas conectadas
PARAMETERS: n_id,n_estado, n_fechaEstado,n_linea, n_c1,n_c2, n_obs, rst
INPUT: n_id,n_estado, n_fechaEstado, n_linea, n_c1, n_c2, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaLineas(1,1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,NULL,rst);
******************************************************************************/
id_test		      INTEGER;
n_obs_ins             VARCHAR2 (50);
n_fechaEstado_ins     VARCHAR2(11);
linea_test            INTEGER;
estado_test           INTEGER;
c1_test               INTEGER;  
c2_test               INTEGER;
err_msg               VARCHAR2 (100);
dup_id		      EXCEPTION;
dup_estado            EXCEPTION;
dup_linea             EXCEPTION;
dup_c1                EXCEPTION;
dup_c2                EXCEPTION;
dup_c1_c2             EXCEPTION;
des_null              EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins := SUBSTR (n_obs, 1, 50);
--verificamos si hay campos no nulos: nulos
IF 	     (n_id              IS NULL)
	  OR (n_estado          IS NULL)
          OR (n_fechaEstado_ins IS NULL)
          OR (n_linea           IS NULL)
          OR (n_c1              IS NULL)
          OR (n_c2              IS NULL)
THEN
RAISE des_null;
END IF;

--Verificamos que no exista el  codigo del pais 
SELECT COUNT (*)
INTO id_test
FROM lineas
WHERE lineas.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
--comprobar existe la linea
SELECT COUNT (*)
INTO linea_test
FROM LINEA
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
--comprobar existe la central en c1
SELECT COUNT (*)
INTO c1_test
FROM CENTRALES
WHERE centrales.ID = n_c1;
IF (c1_test = 0)
THEN
RAISE dup_c1;
END IF;
--comprobar existe la central o contador en c2
SELECT COUNT (*)
INTO c2_test
FROM CENTRALES, CONTADORES
WHERE centrales.id = n_c2
or contadores.id = n_c2;
IF (c2_test = 0)
THEN
RAISE dup_c2;
END IF;
-- comprobar que no conectamos dos iguales
IF ( n_c1 = n_c2 )
THEN
RAISE dup_c1_c2;
END IF;
-- insertamos el alta de la linea de conexion
UPDATE  lineas
SET
estado        = n_estado
,fechaEstado  = n_fechaEstado_ins
,linea        = n_linea
,c1           = n_c1
,c2           = n_c2
,obs          = n_obs_ins
WHERE 
lineas.id = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Modifica  lineas: '
    || ' n_id'
    || n_id
    ||' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins
    ); 
    rst:='OK, Modificacin  de lneas  realizada con xito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_id: '
    || n_id
    || ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe el id de Lneas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
, 'rst', rst, rst);
ROLLBACK;
WHEN des_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_linea
THEN
    rst := 'ERROR: NO existe LINEA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1
THEN
    rst := 'ERROR: No es una Central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c2
THEN
    rst := 'ERROR: No es Central ni Contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1_c2
THEN
    rst := 'ERROR: No se pueden  conectar: conexiones iguales';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
END modificaLineas;
/
