CREATE OR REPLACE
PROCEDURE modificaLocalidad(
n_id  IN NUMBER,
n_des IN VARCHAR2,
n_provincia IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaLocalidad
PROPSITO: gestiona la modifcacin de un localidad en la tabla localidad
PARAMETERS: n_id, n_des,n_provincia, rst
INPUT: n_id, n_des, n_provincia
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaLocalidad(50,'Mataro',10, rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
des_test        INTEGER;
provincia_test  INTEGER;
err_msg         VARCHAR2 (100);
dup_id          EXCEPTION;
dup_provincia   EXCEPTION;
dup_null        EXCEPTION;

BEGIN
n_des_ins       := SUBSTR (n_des, 1, 50);
--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL) OR (n_des IS NULL) OR (n_provincia IS NULL)  THEN
RAISE dup_null;
END IF;
--Verificamos si el codigo de la localidad existe
SELECT COUNT (*)
INTO id_test
FROM localidad
WHERE ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


provincia_test:=0;
--verificamos si existe el codigo de la provincia
SELECT COUNT (*)
INTO provincia_test
FROM provincia
WHERE provincia.ID = n_provincia;
IF (provincia_test = 0)
THEN
RAISE dup_provincia;
END IF;
DBMS_OUTPUT.ENABLE;
-- Modificamos la localidad localidad
UPDATE localidad
SET
des = n_des_ins,
provincia = n_provincia
WHERE
localidad.id = n_id;

-- Fin de las operaciones
rst := 'OK';
    DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');  
	DBMS_OUTPUT.PUT_LINE('Modificacin de la localidad :'||n_id);  

    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe este cdigo localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_provincia
THEN
    rst := 'ERROR: NO  existe provincia';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos que NO tienen datos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' 
|| n_id
||' n_des:' 
||n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaLocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;
END modificaLocalidad;
/
--prueba de uso
--n_id, n_des,n_provincia, rst
declare rst varchar2(250);
begin
modificaLocalidad(1,'BARCELONA',2,rst);
modificaLocalidad(2,'TERRASSA',2,rst);
modificaLocalidad(3,'SABADELL',2,rst);
modificaLocalidad(4,'MANRESA',2,rst);
modificaLocalidad(5,'BERGA',2,rst);
modificaLocalidad(6,'SANTPEDOR',2,rst);
modificaLocalidad(7,'RUBI',2,rst);
modificaLocalidad(8,'MATADEPERA',2,rst);
modificaLocalidad(10,'SANT FRUITOS DE BAGES',2,rst);
modificaLocalidad(11,'CASTELLAR DEL VALLES',2,rst);
modificaLocalidad(12,'VACARISES',2,rst);
modificaLocalidad(13,'LES FONT DE TERRASSA',2,rst);
modificaLocalidad(14,'SANT CUGAT DEL VALLES',2,rst);
modificaLocalidad(15,'MOLLET DEL VALLES',2,rst);
modificaLocalidad(16,'PREMI DE MAR',2,rst);
modificaLocalidad(17,'MONTGAT',2,rst);
modificaLocalidad(18,'IBI',3,rst);
modificaLocalidad(19,'SANT QUIRZE DEL VALLS',2,rst);
modificaLocalidad(20,'OLESA DE MONTSERRAT',2,rst);
modificaLocalidad(21,'MONISTROL DE MONTSERRAT',2,rst);
modificaLocalidad(22,'MONISTROL DE CALDERS',2,rst);
modificaLocalidad(23,'SANT ANTONI DE CALONGE',5,rst);
modificaLocalidad(24,'SANT JOAN DE VILATORRADA',2,rst);
modificaLocalidad(25,'LLEIDA',6,rst);
modificaLocalidad(26,'BALAGUER',6,rst);
modificaLocalidad(27,'SANT FELIU DE GUIXOLS',5,rst);
modificaLocalidad(28,'PALAMOS',5,rst);
modificaLocalidad(29,'PALS',5,rst);
modificaLocalidad(30,'GIRONA',5,rst);
modificaLocalidad(31,'TARRAGONA',7,rst);
modificaLocalidad(32,'REUS',7,rst);
modificaLocalidad(33,'TORTOSA',7,rst);
modificaLocalidad(34,'PUZOL',3,rst);
modificaLocalidad(35,'VINAROZ',46,rst);
modificaLocalidad(36,'PALMA DE MALLORCA',45,rst);
modificaLocalidad(37,'ARNEDO',28,rst);
modificaLocalidad(38,'ZARAGOZA',11,rst);
modificaLocalidad(39,'ALCAIZ',9,rst);
modificaLocalidad(40,'FUENSALIDA',30,rst);
modificaLocalidad(41,'CEHEGIN',33,rst);
modificaLocalidad(42,'NAVALCARNERO',8,rst);
modificaLocalidad(43,'MADRID',8,rst);
modificaLocalidad(44,'LAS PALMAS',44,rst);
modificaLocalidad(45,'TELDE',44,rst);
modificaLocalidad(46,'TENERIFE',43,rst);
modificaLocalidad(47,'SANSEBASTIAN',20,rst);
modificaLocalidad(48,'CADIZ',38,rst);
modificaLocalidad(49,'MATARO',2,rst);
modificaLocalidad(50,'BURGOS',27,rst);
modificaLocalidad(51,'SEGOVIA',10,rst);
modificaLocalidad(52,'SANT CELONI',2,rst);
modificaLocalidad(53,'RIBAS DE FRESER',5,rst);
modificaLocalidad(54,'PUIGCERDA',2,rst);
modificaLocalidad(55,'LA SEU DURGELL',6,rst);
modificaLocalidad(56,'CALASPARRAS',33,rst);
modificaLocalidad(57,'CARTAGENA',33,rst);
modificaLocalidad(59,'BURGO DE OSMA',48,rst);
modificaLocalidad(60,'MORELLA',46,rst);
modificaLocalidad(61,'CASABLANCA',49,rst);
modificaLocalidad(62,'LISBOA',161,rst);
modificaLocalidad(64,'OPORTO',154,rst);
modificaLocalidad(66,'BOURG-EN-BRESSE',47,rst);
modificaLocalidad(67,'LAON',50,rst);
modificaLocalidad(68,'MOILINES (ALLIER)',51,rst);
modificaLocalidad(69,'DIGNE-LES-BAINS',52,rst);
modificaLocalidad(70,'GAP',53,rst);
modificaLocalidad(71,'NIZA',54,rst);
modificaLocalidad(72,'PRIVAS',55,rst);
modificaLocalidad(73,'CHARLEVILLE-MZIRES',56,rst);
modificaLocalidad(74,'FOIX',57,rst);
modificaLocalidad(75,'TROYES',58,rst);
modificaLocalidad(76,'CARCASONA',59,rst);
modificaLocalidad(77,'RODEZ',60,rst);
modificaLocalidad(78,'MARSELLA',61,rst);
modificaLocalidad(79,'CAEN',62,rst);
modificaLocalidad(80,'AURILLAC',63,rst);
modificaLocalidad(81,'ANGULEMA',64,rst);
modificaLocalidad(82,'LA ROCHELA',65,rst);
modificaLocalidad(83,'BOURGES',66,rst);
modificaLocalidad(84,'TULLE',67,rst);
modificaLocalidad(85,'AJACCIO',68,rst);
modificaLocalidad(86,'BASTIA',69,rst);
modificaLocalidad(87,'DIJON',103,rst);
modificaLocalidad(88,'GURET',104,rst);
modificaLocalidad(89,'PRIGUEUX',106,rst);
modificaLocalidad(90,'BESANON',107,rst);
modificaLocalidad(91,'VALENCE',108,rst);
modificaLocalidad(92,'VREUX',205,rst);
modificaLocalidad(94,'CHARTRES',206,rst);
modificaLocalidad(95,'QUIMPER',207,rst);
modificaLocalidad(96,'NIMES',208,rst);
modificaLocalidad(97,'TOULOSE',209,rst);
modificaLocalidad(98,'AUCH',210,rst);
modificaLocalidad(99,'BURDEOS',211,rst);
modificaLocalidad(100,'MONTPELLIER',212,rst);
modificaLocalidad(101,'RENNES',213,rst);
modificaLocalidad(102,'CHTEAUROUX',214,rst);
modificaLocalidad(103,'GRENOBLE',216,rst);
modificaLocalidad(104,'LONS-LE-DAUNIER',217,rst);
modificaLocalidad(105,'MONT-DE-MARSAN',218,rst);
modificaLocalidad(106,'BLOIS',222,rst);
modificaLocalidad(107,'SAINTE-TIENNE',220,rst);
modificaLocalidad(108,'LE PUY-EN VELAY',221,rst);
modificaLocalidad(109,'NANTES',219,rst);
modificaLocalidad(110,'ORLEANS',271,rst);
modificaLocalidad(112,'CAHORS',223,rst);
modificaLocalidad(113,'AGEN',224,rst);
modificaLocalidad(114,'MENDE',225,rst);
modificaLocalidad(115,'ANGERS',226,rst);
modificaLocalidad(116,'SAINT-L',227,rst);
modificaLocalidad(117,'CHLONS-EN-CHAMPAGNE',228,rst);
modificaLocalidad(118,'CHAUMONT',229,rst);
modificaLocalidad(119,'LAVAL',230,rst);
modificaLocalidad(120,'NANCY',231,rst);
modificaLocalidad(121,'BAR-LE-DUC',232,rst);
modificaLocalidad(122,'VANNES',233,rst);
modificaLocalidad(123,'METZ',234,rst);
modificaLocalidad(124,'NEVERS',235,rst);
modificaLocalidad(125,'LILLE',236,rst);
modificaLocalidad(126,'BEAUVAIS',237,rst);
modificaLocalidad(127,'ALENON',238,rst);
modificaLocalidad(128,'ARRAS',239,rst);
modificaLocalidad(129,'CLERMONT-FERRAND',240,rst);
modificaLocalidad(130,'PAU',241,rst);
modificaLocalidad(131,'TARBES',242,rst);
modificaLocalidad(132,'PERPIAN',243,rst);
modificaLocalidad(133,'ESTRASBURGO',244,rst);
modificaLocalidad(134,'COLMAR',245,rst);
modificaLocalidad(135,'LYON',246,rst);
modificaLocalidad(136,'VESOUL',247,rst);
modificaLocalidad(137,'MCON',248,rst);
modificaLocalidad(138,'LE MANS',249,rst);
modificaLocalidad(139,'CHAMBRY',272,rst);
modificaLocalidad(140,'ANNECY',247,rst);
modificaLocalidad(141,'PARS',250,rst);
modificaLocalidad(142,'RUAN',251,rst);
modificaLocalidad(143,'MELUN',252,rst);
modificaLocalidad(144,'VERSALLES',253,rst);
modificaLocalidad(145,'NIORT',254,rst);
modificaLocalidad(146,'AMIENS',255,rst);
modificaLocalidad(147,'ALBI',95,rst);
modificaLocalidad(148,'MONTAUBAN',257,rst);
modificaLocalidad(149,'TOULON',258,rst);
modificaLocalidad(150,'AVIGNON',259,rst);
modificaLocalidad(151,'LA RCHE-SUR-YON',260,rst);
modificaLocalidad(152,'POITIERS',261,rst);
modificaLocalidad(153,'LIMOGES',273,rst);
modificaLocalidad(154,'PINAL',263,rst);
modificaLocalidad(155,'AUXERRE',264,rst);
modificaLocalidad(156,'BELFORT',265,rst);
modificaLocalidad(157,'VRY',266,rst);
modificaLocalidad(158,'NANTERRE',267,rst);
modificaLocalidad(159,'BOBIGNY',268,rst);
modificaLocalidad(160,'CRTEIL',269,rst);
modificaLocalidad(161,'PONTOISE',270,rst);
modificaLocalidad(164,'PESCARA',86,rst);
modificaLocalidad(165,'CHIETI',96,rst);
modificaLocalidad(166,'TERAMO',87,rst);
modificaLocalidad(167,'LAQUILA',364,rst);
modificaLocalidad(168,'AVEZZANO',86,rst);
modificaLocalidad(169,'SULMONA',86,rst);
modificaLocalidad(170,'BITONTO',84,rst);
modificaLocalidad(171,'ALTAMURA',84,rst);
modificaLocalidad(172,'MONOPOLI',84,rst);
modificaLocalidad(173,'NOCI',84,rst);
modificaLocalidad(174,'TURI',84,rst);
modificaLocalidad(175,'VALENZANO',84,rst);
modificaLocalidad(176,'PRATA',364,rst);
modificaLocalidad(177,'MAGLIANO DE MARSI',364,rst);
modificaLocalidad(178,'PACENTRO',364,rst);
modificaLocalidad(179,'OFENA',364,rst);
modificaLocalidad(180,'OCRE',364,rst);
modificaLocalidad(182,'VILLA SANTANGELO',364,rst);
modificaLocalidad(183,'VITTORIO',364,rst);
modificaLocalidad(184,'FRANCA VILLA AL MARE',96,rst);
modificaLocalidad(185,'BUCCHIANICO',96,rst);
modificaLocalidad(186,'RIPA TATIANA',96,rst);
modificaLocalidad(187,'BOLOGNANO',86,rst);
modificaLocalidad(188,'ELICE',86,rst);
modificaLocalidad(189,'SALLE',86,rst);
modificaLocalidad(190,'VICOLI',86,rst);
modificaLocalidad(191,'BRINDISI',94,rst);
modificaLocalidad(192,'BARAGIANO',94,rst);
modificaLocalidad(193,'FORENZA',94,rst);
modificaLocalidad(194,'GINESTRA',94,rst);
modificaLocalidad(195,'ATELLA',94,rst);
modificaLocalidad(196,'BALVANO',94,rst);
modificaLocalidad(197,'ABRIOLA',94,rst);
modificaLocalidad(198,'ACERNZA',94,rst);
modificaLocalidad(199,'ANZI',94,rst);
modificaLocalidad(200,'MARATEA',94,rst);
modificaLocalidad(201,'MISSANELLO',94,rst);
modificaLocalidad(202,'MELFI',94,rst);
modificaLocalidad(203,'POTENZA',94,rst);
modificaLocalidad(204,'SENISE',94,rst);
modificaLocalidad(205,'TITO',94,rst);
modificaLocalidad(206,'VENOSA',94,rst);
modificaLocalidad(208,'BOTRICELLO',95,rst);
modificaLocalidad(210,'BORGIA',95,rst);
modificaLocalidad(211,'DAVOLI',95,rst);
modificaLocalidad(212,'MOTEPAONE',95,rst);
modificaLocalidad(213,'PENTONE',95,rst);
modificaLocalidad(214,'PLATANIA',95,rst);
modificaLocalidad(215,'SAN FLORO',95,rst);
modificaLocalidad(216,'TAVERNA',95,rst);
modificaLocalidad(217,'TIRIOLO',95,rst);
modificaLocalidad(218,'VALLEFIORITA',95,rst);
modificaLocalidad(219,'ZAGARISE',95,rst);
modificaLocalidad(220,'NPOLES',274,rst);
modificaLocalidad(221,'TORRE DEL GRECO',274,rst);
modificaLocalidad(222,'POZZUOLI',274,rst);
modificaLocalidad(223,'CASORIA',274,rst);
modificaLocalidad(224,'CASTELLAMMARE DI STABIA',274,rst);
modificaLocalidad(225,'AFRAGOLA',274,rst);
modificaLocalidad(226,'MARANO DI NAPOLI',274,rst);
modificaLocalidad(227,'ACERRA',274,rst);
modificaLocalidad(228,'PORTICI',274,rst);
modificaLocalidad(229,'BOLONIA',284,rst);
modificaLocalidad(230,'ANZOLA DELLEMILIA',284,rst);
modificaLocalidad(231,'ARGELATO',284,rst);
modificaLocalidad(232,'BUDRIO',284,rst);
modificaLocalidad(233,'CASTEL GUELFO DI BOLONIA',284,rst);
modificaLocalidad(234,'DOZZA',284,rst);
modificaLocalidad(235,'MONTE SAN PRIETO',284,rst);
modificaLocalidad(236,'VERGATO',284,rst);
modificaLocalidad(237,'RAVENNA',290,rst);
modificaLocalidad(238,'FERRARA',285,rst);
modificaLocalidad(239,'MODENA',287,rst);
modificaLocalidad(240,'PIACENZA',289,rst);
modificaLocalidad(241,'PARMA',288,rst);
modificaLocalidad(242,'RIMINI',292,rst);
modificaLocalidad(243,'TRIESTE',295,rst);
modificaLocalidad(244,'DUINO-AURISINA',295,rst);
modificaLocalidad(245,'MONRUPINO',295,rst);
modificaLocalidad(246,'FROSINONE',297,rst);
modificaLocalidad(247,'LATINA',298,rst);
modificaLocalidad(248,'RIETI',299,rst);
modificaLocalidad(249,'ROMA',300,rst);
modificaLocalidad(250,'GUIDONIA MONTECELIO',300,rst);
modificaLocalidad(251,'TVOLI',300,rst);
modificaLocalidad(252,'POMEZIA',300,rst);
modificaLocalidad(253,'CIAMPINO',300,rst);
modificaLocalidad(254,'MARINO',300,rst);
modificaLocalidad(255,'FIUMICINO',300,rst);
modificaLocalidad(256,'GENOVA',302,rst);
modificaLocalidad(258,'ARENZANO',302,rst);
modificaLocalidad(259,'BARGAGLI',302,rst);
modificaLocalidad(260,'CAMOGLI',302,rst);
modificaLocalidad(261,'DAVAGNA',302,rst);
modificaLocalidad(262,'VERONA',362,rst);
modificaLocalidad(263,'COMO',308,rst);
modificaLocalidad(264,'BERGAMO',306,rst);
modificaLocalidad(265,'MILN',313,rst);
modificaLocalidad(266,'MONZA',314,rst);
modificaLocalidad(267,'FERMO',320,rst);
modificaLocalidad(268,'TURIN',330,rst);
modificaLocalidad(269,'FLORENCIA',343,rst);
modificaLocalidad(270,'LIVORNO',345,rst);
modificaLocalidad(271,'MESSINA',337,rst);
modificaLocalidad(272,'PALERMO',338,rst);
modificaLocalidad(273,'PISA',348,rst);
modificaLocalidad(274,'TRENTO',353,rst);
modificaLocalidad(275,'PRATO',350,rst);
modificaLocalidad(276,'VENECIA',361,rst);
modificaLocalidad(278,'TREVISO',360,rst);
modificaLocalidad(279,'VICENZA',363,rst);
modificaLocalidad(280,'ELX',4,rst);
modificaLocalidad(281,'CREVILLENTE',4,rst);
modificaLocalidad(282,'BAERES DE MARIOLA',4,rst);
modificaLocalidad(283,'ALBACETE',32,rst);
modificaLocalidad(284,'MURCIA',33,rst);
modificaLocalidad(285,'TOLEDO',30,rst);
modificaLocalidad(286,'BADAJOZ',31,rst);
modificaLocalidad(287,'TERUEL',9,rst);
modificaLocalidad(288,'VALLADOLID',16,rst);
modificaLocalidad(289,'SEVILLA',35,rst);
modificaLocalidad(290,'HUELVA',37,rst);
modificaLocalidad(292,'VALLS',7,rst);
modificaLocalidad(294,'BLANES',5,rst);
modificaLocalidad(295,'SANT ANONI DE COLONGE',5,rst);
modificaLocalidad(296,'SANT ANDREU DE LA BARCA',2,rst);
modificaLocalidad(297,'MARTORELL',2,rst);
modificaLocalidad(298,'LHOSPITALE DE LLOBREGAT',2,rst);
modificaLocalidad(299,'AVILA',29,rst);
modificaLocalidad(300,'TARAZONA',11,rst);
modificaLocalidad(301,'CALAHORRA',28,rst);
modificaLocalidad(302,'SIMANCAS',16,rst);
modificaLocalidad(303,'TORDESILLA',16,rst);
modificaLocalidad(304,'SAGUNTO',3,rst);
modificaLocalidad(305,'LUGO',24,rst);
modificaLocalidad(306,'OURENSE',22,rst);
modificaLocalidad(307,'LA CORUA',21,rst);
modificaLocalidad(308,'SANT HILARI',2,rst);
modificaLocalidad(309,'JEREZ DE LA FRONTERA',38,rst);
modificaLocalidad(310,'ALGECIRAS',38,rst);
modificaLocalidad(311,'ALCOBENDAS',8,rst);
modificaLocalidad(314,'CUENCA',13,rst);
end;
select * from localidad
