CREATE OR REPLACE
PROCEDURE modificaModelos(
n_id                    IN NUMBER,
n_des            	IN VARCHAR2,
n_anyoFabrica        	IN VARCHAR2,
n_empresa            	IN NUMBER,
n_estado             	IN NUMBER,
n_fechaEstado		IN VARCHAR2,
n_obs              	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaModelos
PROPSITO: gestiona la modificacin de un modelo en la tabla modelos
PARAMETERS: n_id,n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs,rst;
INPUT: n_id,n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaModelos(1,'Modelo_1','2012',1,1,to_char(sysdate,'DD/MM/YYYY'),'obs_modelo_1', rst);
******************************************************************************/

n_des_ins             VARCHAR2(50 CHAR);
n_anyoFabrica_ins     VARCHAR2(4  CHAR);
n_fechaEstado_ins      VARCHAR2(11 CHAR);
n_obs_ins             VARCHAR2(50 CHAR);
id_test			INTEGER;
empresa_test		INTEGER;
estado_test         INTEGER;
err_msg             VARCHAR2(100);
dup_id			EXCEPTION;
dup_empresa          EXCEPTION;
dup_estado            EXCEPTION;
dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_des_ins        		:= SUBSTR (n_des,1,10);
n_anyoFabrica_ins         	:= SUBSTR (n_anyoFabrica,1,4);
n_fechaEstado_ins     		:= SUBSTR (n_fechaEstado,1,11);
n_obs_ins      			:= SUBSTR (n_obs,1,50);


--verificamos que los campos no nulos no sean nulos
IF (n_id		      	IS NULL)
OR (n_des		      	IS NULL)
OR (n_anyoFabrica_ins      IS NULL)
OR (n_empresa         	IS NULL)
OR (n_estado          	IS NULL)
OR (n_fechaEstado_ins   	IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que exista la empresa
SELECT COUNT (*)
INTO empresa_test
FROM EMPRESAS
WHERE empresas.id = n_empresa;
IF (empresa_test = 0)
THEN
RAISE dup_empresa;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- modificamos el modelo
UPDATE modelos
SET
des 			= n_des_ins,
anyoFabrica 	= n_anyoFabrica_ins,
empresa 		= n_empresa,
estado 		= n_Estado,
fechaEstado 	= n_fechaEstado_ins,
obs 			= n_obs_ins
WHERE 
modelos.id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
          'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs    
    ); 
    rst:='Ok, Modifica Modelo   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_des
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs  
        , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	' n_estado: '
        ||n_estado
	, 'rst', rst, rst);
ROLLBACK;


WHEN dup_empresa
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_empresa : ' || n_empresa  ); 
     rst := 'ERROR: NO existe la EMPRESA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la EMPRESA ';
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_empresa: '
        ||n_empresa
	, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
ROLLBACK;
END modificaModelos;
/
