CREATE OR REPLACE
PROCEDURE modificaProvincia(
n_id      IN NUMBER,
n_des     IN VARCHAR2,
n_pais    IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaProvincia
PROPSITO: gestiona la modificacin de una provincia en la tabla provincia
PARAMETERS: n_id, n_des, n_pais rst
INPUT: n_id, n_des, n_pais
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaProvincia(2,'BARCELONA',1,rst); 
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
pais_test       INTEGER;

err_msg         VARCHAR2 (100);
dup_id          EXCEPTION;
dup_des         EXCEPTION;
dup_pais        EXCEPTION;

dup_null        EXCEPTION;

BEGIN
n_des_ins       := SUBSTR (n_des, 1, 50);

--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL) OR (n_des IS NULL) OR (n_pais IS NULL)  THEN
RAISE dup_null;
END IF;
--Verificamos si el codigo de la provincia existe
SELECT COUNT (*)
INTO id_test
FROM PROVINCIA
WHERE provincia.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;



pais_test:=0;
--verificamos si existe el PAIS
SELECT COUNT (*)
INTO pais_test
FROM PAIS
WHERE pais.ID = n_pais;
IF (pais_test = 0)
THEN
RAISE dup_pais;
END IF;

--modificamos la provincia

UPDATE provincia
SET
des = n_des_ins,
pais = n_pais
WHERE
id = n_id;

rst := 'OK';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE('Modificacin de la provincia '|| n_id); 
DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este cdigo PROVINCIA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_pais
THEN
    rst := 'ERROR: NO  existe PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_pais: ' || n_pais
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos que NO tienen datos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;
END modificaProvincia;
/