CREATE OR REPLACE
PROCEDURE modificaTipoInspeccion(
n_id		IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaTipoInspeccion
PROPSITO: gestiona la modificacin de un tipo de inspeccin
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado, rst
INPUT: n_id,n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaTipoInspeccion(1,'ANUAL',to_char(sysdate,'DD/MM/YYYY'),rst)
******************************************************************************/
n_des_ins             VARCHAR2(20);
n_fechaEstado_ins     VARCHAR2(11);
id_test			INTEGER;
des_test        		INTEGER;
estado_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			EXCEPTION;
dup_des    		        EXCEPTION;
dup_estado      		EXCEPTION;
dup_null  			EXCEPTION;

BEGIN
n_des_ins                     := SUBSTR (n_des, 1, 20);
n_fechaEstado_ins             := SUBSTR (n_fechaEstado, 1, 11);

--verificamos que los campos nulos no sean nulos
      IF    (n_id     IS NULL)
        OR  (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--verificamos si ya existe la ID 
SELECT COUNT (*)
INTO id_test
FROM TINSPECCION
WHERE tInspeccion.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_des;
END IF;


--verificamos si ya existe la descripcin 
SELECT COUNT (*)
INTO des_test
FROM TINSPECCION
WHERE tInspeccion.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos si existe el estao
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado; 
END IF;


-- modificamos el registro  de inspeccion
UPDATE  tinspeccion
SET
des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado_ins
WHERE
tinspeccion.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta Tipo Inspeccion  OK: '
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins); 
    rst:='OK, Alta Tipo Inspeccion  OK: ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el id tipo Inspeccin ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'Modifica Tipo Inspeccion: ' 
    	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
    	|| ' Estado: ' 
    	|| n_estado
    	||' fechaEstado: ' 
    	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya  existe la descripcion ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'Modifica Tipo Inspeccion: ' 
    || ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'Modifica Tipo Inspeccion: ' 
    	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: Hay campos NO nulos:  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica Tipo Inspeccion: ' 
	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
|| ' Estado: ' 
|| n_estado
||' fechaEstado: ' 
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica Tipo Inspeccion: '
	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
|| ' Estado: ' 
|| n_estado
||' fechaEstado: ' 
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

END modificaTipoInspeccion;
/


declare
    rst varchar2(250);
begin
-- 			n_des,n_estado,n_fechaEstado, rst
modificaTipoInspeccion(1,'INICIALMENTE',1,to_char(sysdate,'DD/MM/YYYY'),rst);
end;

SELECT * FROM TINSPECCION




