CREATE OR REPLACE
PROCEDURE modificaTipoLectura (
n_id    IN NUMBER,
n_des   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaTipoLectura 
PROPSITO: gestiona la modificacin  de un tipo de lecturas
PARAMETERS:  n_id, n_des, rst
INPUT:  n_id, n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaTipoLectura (1,'PRESENCIAL', rst);
******************************************************************************/
n_des_ins         VARCHAR2 ( 50 CHAR);

id_test           INTEGER;
des_test          INTEGER;

err_msg           VARCHAR2 (100);

dup_id            EXCEPTION;
dup_des           EXCEPTION;
dup_null          EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_des_ins       := SUBSTR (n_des, 1, 50);
--comprobamos campos no nulos que no esten vacios
IF (n_id  IS NULL)
OR (n_des IS NULL)
THEN
RAISE dup_null;
END IF;

--Verificamos que  exista el  codigo del tipo de  lectura 
SELECT COUNT (*)
INTO id_test
FROM tLectura
WHERE tLectura.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--verificamos que no exista la descripcion del tipo de lectura
SELECT COUNT (*)
INTO des_test
FROM TLECTURA
WHERE tLectura.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;


-- modificamos tipo de lectura
UPDATE tLectura
SET
id = n_id,
des = n_des
WHERE 
tlectura.id = n_id;

-- Fin de las operaciones
DBMS_OUTPUT.PUT_LINE('');  
DBMS_OUTPUT.PUT_LINE('n_id:' || n_id ||' des: '||n_des );  
DBMS_OUTPUT.PUT_LINE(rst);


rst := 'OK';

altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: ' 
|| n_id
||' n_des: '
|| n_des
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe  este id de tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_des: '
|| n_des
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta descripcion del tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_des
||' n_des: '
|| n_des
, 'rst', rst, rst);
ROLLBACK;



WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des

, 'rst', rst, rst);
ROLLBACK;
END modificaTipoLectura ;
/

