CREATE OR REPLACE
PROCEDURE modificaUbicaciones (
n_id		    IN NUMBER,
n_via               IN NUMBER,
n_dir               IN VARCHAR2,
n_num               IN VARCHAR2,
n_pis               IN VARCHAR2,
n_pta               IN VARCHAR2,
n_codigoPostal      IN VARCHAR,
n_localidad         IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaUbicaciones 
PROPSITO: gestiona la modificacin  de una Ubicacion en la tabla ubicaciones
PARAMETERS: n_id, n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad, rst
INPUT: n_id,n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaUbicacion(1,1,'del pez','2','1r','2a','08330',1, rst);
******************************************************************************/
n_dir_ins           VARCHAR2 (50);
n_num_ins           VARCHAR2 (5);
n_pis_ins           VARCHAR2 (5);
n_pta_ins           VARCHAR2 (10);
n_codigoPostal_ins  VARCHAR  (10);

id_test		  INTEGER;
via_test          INTEGER;
localidad_test    INTEGER;
dup_id		  EXCEPTION;
dup_via           EXCEPTION;
dup_localidad     EXCEPTION;
err_msg           VARCHAR2 (100);
des_nulo          EXCEPTION;

BEGIN
-- controlar la longitud de las entradas
n_dir_ins               := SUBSTR (n_dir, 1, 50);
n_num_ins               := SUBSTR (n_num, 1, 5);
n_pis_ins               := SUBSTR (n_pis, 1, 5);
n_pta_ins               := SUBSTR (n_pta, 1, 10);
n_codigoPostal_ins      := SUBSTR (n_codigoPostal, 1, 10);


--verificamos que los campos no nulos no sean nulos
IF (n_id              IS NULL)
OR (n_via             IS NULL)
OR (n_dir             IS NULL)
OR (n_num             IS NULL)
OR (n_codigoPostal    IS NULL)
OR (n_localidad       IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista la ubicacin 
SELECT COUNT (*)
INTO id_test
FROM ubicaciones
WHERE ubicaciones.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--Verificamos que exista la via
SELECT COUNT (*)
INTO via_test
FROM via
WHERE via.id = n_via;
IF (via_test = 0)
THEN
RAISE dup_via;
END IF;


--verificamos que exista la localidad

SELECT COUNT (*)
INTO localidad_test
FROM localidad
WHERE localidad.id = n_localidad;
IF (localidad_test = 0)
THEN
RAISE dup_localidad;
END IF;

-- insertamos la nueva ubicacion
INSERT INTO ubicaciones(
via
,dir
,num
,pis
,pta
,codigoPostal
,localidad)
VALUES (n_via
,n_dir_ins
,n_num_ins
,n_pis_ins
,n_pta_ins
,n_codigoPostal_ins
,n_localidad);
-- Fin de las operaciones
rst := 'OK. Modificacin de ubicacin ';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');
        DBMS_OUTPUT.PUT_LINE(
        'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad);
        
        DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_via
THEN
      rst := 'ERROR: No existe este cdigo de via';
      DBMS_OUTPUT.ENABLE;    
      DBMS_OUTPUT.PUT_LINE('');  
      DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_localidad
THEN
    rst := 'ERROR: NO  existe localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
        rst := 'ERROR: hay campos nulos que no tienen datos';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');  
        DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc: altaUbicacion: ' 
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
END modificaUbicaciones ;
/
--n_id,n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad, rst
declare rst varchar2(250);
begin
modificaUbicaciones (1,2,'ABAT ODO  ','128','6','4','08037',2,rst);
end;
