/*---  TABLAS---- */
--------------------
CREATE TABLE estados  
(
 ID   NUMBER PRIMARY KEY,
 des  CHAR(20) NOT NULL   
 CONSTRAINT CH_estado_des CHECK (des=UPPER(des)) --restricci majuscules per l'atribut desEstado
);
-------- PAIS -------------
CREATE TABLE pais  
(
  ID        NUMBER                  CONSTRAINT PK_pais      PRIMARY KEY ,    -- pk	
  des       VARCHAR2  (50 CHAR)     CONSTRAINT NN_pais_des  NOT NULL,        -- nn
  cod       VARCHAR   (5  CHAR)     CONSTRAINT NN_pais_cod  NOT NULL        --nn
);
-------- PROVINCIA -- 
CREATE TABLE PROVINCIA (
  ID            NUMBER              CONSTRAINT  PK_provincia          PRIMARY KEY, 	
  des           VARCHAR2(50 CHAR)   CONSTRAINT  NN_provincia_des      NOT NULL,
  pais                              CONSTRAINT  FK_provincia_pais   REFERENCES pais(ID) NOT NULL
);
----------- LOCALIDAD -- 
CREATE TABLE LOCALIDAD 
(
  ID            NUMBER            CONSTRAINT    PK_localidad              PRIMARY KEY, 	
  des           VARCHAR2(50 CHAR) CONSTRAINT    NN_localidad__des         NOT NULL,
  provincia                       CONSTRAINT    FK_localidad_provincia    REFERENCES provincia(ID) NOT NULL
); 
------------ VIA ---------
CREATE TABLE VIA 
(
  ID    NUMBER              CONSTRAINT PK_via       PRIMARY KEY, 	
  des   VARCHAR2(50 BYTE)   CONSTRAINT NN_via__des  NOT NULL
);
------- UBICACIONES  ----------
CREATE TABLE UBICACIONES  
(
 ID                 NUMBER                  CONSTRAINT PK_ubicaciones             PRIMARY KEY, 
 via                                        CONSTRAINT FK1_ubicaciones_via        REFERENCES VIA(ID)         NOT NULL,
 dir                VARCHAR2  (50 CHAR)     CONSTRAINT NN_ubicaciones_dir                                    NOT NULL,
 num                VARCHAR2  (5 CHAR)      CONSTRAINT NN_ubicaciones_num                                    NOT NULL,
 pis                VARCHAR2  (5 CHAR)      NULL, --CONSTRAINT NN_ubicaciones_piso                                   NOT NULL,
 pta                VARCHAR2  (10 CHAR)     NULL, --CONSTRAINT NN_ubicaciones_puerta                                 NOT NULL,
 codigoPostal       VARCHAR2  (10 CHAR)     CONSTRAINT NN_ubicaciones_codigoPostal                           NOT NULL,
 localidad                                  CONSTRAINT FK2_ubicaciones_localidad  REFERENCES LOCALIDAD(ID)   NOT NULL
); 
-- tCliente -- tipos de cliente
CREATE TABLE tCliente  
(
  ID        NUMBER                CONSTRAINT PK_tCliente       PRIMARY KEY,
  des       VARCHAR2(20 CHAR)     CONSTRAINT NN_tCliente_des   NOT NULL
);
-- CLIENTES 
CREATE TABLE clientes 
 (
 ID           NUMBER                    CONSTRAINT PK_clientes            PRIMARY KEY,
 estado                                 CONSTRAINT FK1_clientes_estado    REFERENCES estados(ID)  NOT NULL,   --fk,nn
 tipo 	   		                CONSTRAINT FK2_clientes_tipo      REFERENCES tCliente(ID) NOT NULL,   --fk,nn
 nifCif       VARCHAR2(10 CHAR)         CONSTRAINT AK_clientes_nifCif     UNIQUE NOT NULL,                    --ak,nn                      
 nom          VARCHAR2(50 CHAR)         CONSTRAINT NN_clientes_nom        NOT NULL ,         --nn
 ape1         VARCHAR2(50 CHAR)         CONSTRAINT NN_clientes_ape1       NOT NULL ,         --nn
 ape2         VARCHAR2(50 CHAR)         NULL,           
 email        VARCHAR2(50 CHAR)         NULL,
 tMovil       VARCHAR (11 CHAR)         NULL,
 ubica                                  CONSTRAINT FK3_clientes_ubica     REFERENCES UBICACIONES(ID) NOT NULL,    --fk
 fechaAlta    DATE                      CONSTRAINT NN_clientes_fechaAlta  NOT NULL,                               --nn
-- fechaAlta    DATE    DEFAULT(sysdate)  CONSTRAINT NN_clientes_fechaAlta  NOT NULL,                               --nn
 fechaMod     DATE    NULL          
);
------- EMPRESAS  ----------
CREATE TABLE empresas  
(
 ID               NUMBER CONSTRAINT                   PK_empresas                                     PRIMARY KEY,       --pk
 cif              VARCHAR2(10 CHAR)       CONSTRAINT  AK_empresas_Cif                               UNIQUE NOT NULL,   --ak,nn   
 des              VARCHAR(50 CHAR)        CONSTRAINT  NN_empresas_des                               NOT NULL,          --nn
 estado                                   CONSTRAINT  FK_empresas_estado  REFERENCES estados(ID)    NOT NULL,     --fk
 fechaEstado      DATE                    CONSTRAINT  NN_empresas_fechaEstado                       NOT NULL
);
------- MODELOS  ----------
CREATE TABLE modelos 
(
 ID             NUMBER              CONSTRAINT  PK_modelos            PRIMARY KEY,
 des            VARCHAR(50 CHAR)                                                              NOT NULL,
 anyoFabrica    VARCHAR(4 CHAR)     CONSTRAINT  NN_modelos_anyoFabrica                        NOT NULL, 
 empresa                            CONSTRAINT  FK_modelos_empresa    REFERENCES empresas(ID) NOT NULL,
 estado                             CONSTRAINT  FK_modelos_idEstado   REFERENCES estados(ID)  NOT NULL,
 fechaEstado    DATE                NULL,
 obs            VARCHAR(50 CHAR)    NULL
);
------- CONTADORES  ----------
CREATE TABLE contadores  
(
 ID             NUMBER            CONSTRAINT PK_contadores                PRIMARY KEY,
 modelo                           CONSTRAINT FK1_contadores_modelo        REFERENCES  modelos(ID)         NOT NULL,
 ubica                            CONSTRAINT FK2_contadores_ubica         REFERENCES  ubicaciones(ID)     NOT NULL,
 estado                           CONSTRAINT FK3_contadores_estado        REFERENCES  estados(ID)         NOT NULL,
 fechaEstado    DATE              CONSTRAINT NN_contadores_fechaEstado                                    NOT NULL, 
 numSerie       VARCHAR(20 CHAR)  CONSTRAINT NN_contadores_numSerie                                       NOT NULL
);
------- CONTRATOS  ----------
CREATE TABLE contratos  
(
 ID             NUMBER        CONSTRAINT PK_contratos             PRIMARY KEY,
 cliente                      CONSTRAINT FK1_contratos_cliente    REFERENCES  clientes(ID)    NOT NULL,
 contador                     CONSTRAINT FK2_contratos_contador   REFERENCES  contadores(ID)  NOT NULL,
 estado                       CONSTRAINT FK3_contratos_estado     REFERENCES  estados(ID)     NOT NULL,
 fechaEstado    DATE          CONSTRAINT NN_contratos_fechaEstado                             NOT NULL,
 pContrato      NUMBER (9,2)  CONSTRAINT NN_contratos_pContrato                               NOT NULL,
 obs            VARCHAR(50 CHAR)         NULL
);
-- TABLA ECENTRAL   -Emisiones Central-
CREATE TABLE eCentral
(
 ID               NUMBER              CONSTRAINT    PK_eCentral               PRIMARY KEY,
 des              VARCHAR(20 CHAR)    CONSTRAINT    NN_eCentral_des                                   NOT NULL
);
-- TABLA CCENTRAL  -CLASE DE CENTRAL- --ns
CREATE TABLE cCentral
(
 ID               NUMBER              CONSTRAINT    PK_cCentral               PRIMARY KEY,
 des              VARCHAR(20 CHAR)    CONSTRAINT    NN_cCentral_des                                   NOT NULL
);
-- TIPO CENTRALES 
CREATE TABLE tCentral 
(
 ID               NUMBER              CONSTRAINT    PK_tCentral                 PRIMARY KEY,
 des              VARCHAR(20 CHAR)    CONSTRAINT    NN_tCentral_des                                       NOT NULL,
 estado                               CONSTRAINT    FK1_tCentral_estado         REFERENCES estados(ID)    NOT NULL,
 fechaEstado      DATE                CONSTRAINT    NN_tCentral_fechaEstado                               NOT NULL,
 emision                              CONSTRAINT    FK2_tCentral_emision        REFERENCES eCentral(ID)   NOT NULL,
 cantidad         NUMBER(9,2)         CONSTRAINT    NN_tCentral_cantidad                                  NOT NULL,
 obs              VARCHAR(50 CHAR)    NULL
);
-- TABLA tInspeccion   -tipo de inspeccion
CREATE TABLE tInspeccion
(
 ID               NUMBER              CONSTRAINT    PK_tInspeccion              PRIMARY KEY,
 des              VARCHAR(20 CHAR)    CONSTRAINT    NN_tInspeccion_des                                       NOT NULL,
 estado                               CONSTRAINT    FK_tInspeccion_estado        REFERENCES estados(ID)      NOT NULL,
 fechaEstado      DATE                CONSTRAINT    NN_tInspeccion_fechaEstado                               NOT NULL
);
-- CENTRALES
CREATE TABLE centrales 
(
 ID               NUMBER              CONSTRAINT    PK_centrales                PRIMARY KEY,
 des              VARCHAR(50 CHAR)    CONSTRAINT    NN_centrales_des                                        NOT NULL,
 estado                               CONSTRAINT    FK1_centrales_estado        REFERENCES estados(ID)      NOT NULL,
 fechaEstado      DATE                CONSTRAINT    NN_centrales_fechaEstado                                NOT NULL,
 clase                                CONSTRAINT    FK2_centrales_clase         REFERENCES cCentral(ID)     NOT NULL,
 tipo                                 CONSTRAINT    FK3_centrales_tipo          REFERENCES tCentral(ID)     NOT NULL,
 eMax             NUMBER(9,2)         CONSTRAINT    NN_centrales_eMax                                       NOT NULL,
 eMin             NUMBER(9,2)         CONSTRAINT    NN_centrales_eMin                                       NOT NULL,
 inspeccion                           CONSTRAINT    FK4_centrales_inspeccion    REFERENCES tInspeccion(ID)  NOT NULL,
 fIns             DATE                CONSTRAINT    NN_centrales_fIns                                       NOT NULL,
 ubica                                CONSTRAINT    FK5_centrales_ubica         REFERENCES ubicaciones(ID)  NOT NULL,
 obs              VARCHAR(50 CHAR)                  NULL
);
--LINEA
CREATE TABLE linea 
(
 ID             NUMBER        CONSTRAINT PK_linea             PRIMARY KEY,
 estado                       CONSTRAINT FK_linea_estado      REFERENCES estados(ID) NOT NULL,
 fechaEstado    DATE          CONSTRAINT NN_linea_fechaEstado NOT NULL,
 cMax           NUMERIC(9,2)  CONSTRAINT NN_linea_cMax        NOT NULL,
 obs            VARCHAR(50 CHAR)                              NULL
);
-- LINEAS
CREATE TABLE lineas 
(
 ID             NUMBER    CONSTRAINT      PK_lineas             PRIMARY KEY,
 estado                   CONSTRAINT      FK1_lineas_estado     REFERENCES estados(ID)      NOT NULL,
 fechaEstado  DATE        CONSTRAINT      NN_lineas_fechaEstado                             NOT NULL,
 linea                    CONSTRAINT      FK2_lineas_linea      REFERENCES linea(ID)        NOT NULL,
 c1                       CONSTRAINT      FK3_lineas_c1         REFERENCES centrales(ID)    NOT NULL,
 c2              NUMBER   CONSTRAINT      NN_lineas_c2                                      NOT NULL,
 obs                      VARCHAR(50 CHAR)   NULL
--dual            INTEGER  CONSTRAINT CH_lineas_dual CHECK (dual = 0 OR dual =1)              NULL  
);
--  TABLA tLectura  -tipo de lecturas---
CREATE TABLE tLectura 
(
 ID           NUMBER    CONSTRAINT PK_tLectura            PRIMARY KEY,
 des          VARCHAR2(20 CHAR)                           NOT NULL 
);
-- LECTURAS
CREATE TABLE lecturas 
(
 ID               NUMBER            CONSTRAINT      PK_lecturas                   PRIMARY KEY,
 contador                           CONSTRAINT      FK1_lecturas_contador         REFERENCES  contadores(ID)  NOT NULL, 
 fechaLectura     DATE              CONSTRAINT      NN_lecturas_fechaLectura                                  NOT NULL,
 tipo                               CONSTRAINT      FK2_lecturas_tipo             REFERENCES  tLectura(ID)    NOT NULL, 
 anterior         NUMBER(9,2)       NULL,
 actual           NUMBER(9,2)       NULL,
 consumo          NUMBER(9,2)       CONSTRAINT      NN_lecturas_consumo           NOT NULL              
);
-- CONSUMOS
CREATE TABLE consumos 
(
 ID             NUMBER          CONSTRAINT      PK_consumos               PRIMARY KEY,
 contador                       CONSTRAINT      FK_consumos_contador      REFERENCES contadores(ID) NOT NULL, 
 anyo     NUMBER  CONSTRAINT      NN_consumos_anyo          NOT NULL,
 mes      NUMBER  CONSTRAINT      NN_consumos_mes           NOT NULL,
 consumo       NUMBER(9,2)       -- CONSTRAINT NN_consumos_consumo  
);
--- LOG --
CREATE TABLE Log(
  idLog         NUMBER              CONSTRAINT PK_log               PRIMARY KEY, 
  procesoLog    VARCHAR2(50 BYTE)   CONSTRAINT NN_procesoLog_Log    NOT NULL, 
  fechaLog      VARCHAR2(50 BYTE)   CONSTRAINT NN_fechaHoraLog_Log  NOT NULL, 
  entradaLog    VARCHAR2(500 BYTE)  CONSTRAINT NN_entradaLog_Log    NOT NULL, 
  salidaLog     VARCHAR2(500 BYTE)  CONSTRAINT NN_salidaLog_Log     NOT NULL, 
  RSPLog        VARCHAR2(500 BYTE)  CONSTRAINT NN_RSPLog_log        NOT NULL
  );

--ESTADISTICAS
----------------
               
CREATE TABLE E_1 --Donada una central de producci, el consum dels comptadors que depenen de la central.
(
 ID                   NUMBER          CONSTRAINT        PK_e_1                                             PRIMARY KEY,
 central                              CONSTRAINT        FK_e_1_central           REFERENCES centrales(ID)  NOT NULL,
 consumoContadores    NUMBER(9,2)     CONSTRAINT        NN_e_1_consumoContadores                           NOT NULL,
  fecha                VARCHAR2(11 CHAR)   CONSTRAINT   NN_e_1_fecha                                       NOT NULL
);
-- Donada una lnia de comunicaci i un any concret, el valor mitj de lenergia consumida, tenint en compte que aquest
-- consum depn dels comptadors que salimenten mitjanant  aquesta lnia.
-- Si un comptador pot fer servir dues lnies, suposeu que les dues lnies computen el consum per
-- garantir que les lnies estan ben dimensionades en cas de caiguda dalguna delles.

CREATE TABLE E_2                     
(
 ID                   NUMBER             CONSTRAINT      PK_e_2                                PRIMARY KEY,
 linea                                   CONSTRAINT      FK_e_2_linea     REFERENCES  linea(ID) NOT NULL,
 anyo                 NUMBER             CONSTRAINT      NN_e_2_anyo                           NOT NULL, 
 consumoEnergiaMedio  NUMBER(9,2)        CONSTRAINT      NN_e_2_consumoEnergiaMedio            NOT NULL
);
CREATE TABLE E_3   -- E3_Lnia que ha estat ms carregada a nivell denergia consumida. 
(
 ID                   NUMBER             CONSTRAINT      PK_e_3                                PRIMARY KEY,
 linea                                   CONSTRAINT      FK_e_3_linea    REFERENCES  linea(ID) NOT NULL,
 consumoContadores    NUMBER(9,2)        CONSTRAINT      NN_e_3_consumoContadores              NOT NULL,
 fecha                VARCHAR2(11 CHAR)   CONSTRAINT     NN_e_3_fecha                          NOT NULL
);
CREATE TABLE E_4    -- E4 Donat un any concret: percentatge de lnies que superen el 50% denergia consumida.
(
 ID                   NUMBER             CONSTRAINT      PK_e_4                                PRIMARY KEY,
 anyo                 NUMBER             CONSTRAINT      NN_e_4_anyo                           NOT NULL, 
 perLineaMas50        NUMBER(9,2)        CONSTRAINT      NN_e_4_perLineaMas50                  NOT NULL
);
CREATE TABLE E_5    -- E5 Donat un any concret: el nombre de centrals de producci que generen menys del 30% de producci.
(
 ID                       NUMBER             CONSTRAINT      PK_e_5                                    PRIMARY KEY,
 anyo                     NUMBER             CONSTRAINT      NN_e_5_anyo                               NOT NULL, 
 cenProduccionMenos30     NUMBER(9,2)        CONSTRAINT      NN_e_5_cenProduccionMenos30               NOT NULL
);
CREATE TABLE E_6    -- E6 Top-10 de comptadors que histricament han tingut ms consum.
(
 ID                     NUMBER             CONSTRAINT      PK_e_6                                         PRIMARY KEY,
 contador                                  CONSTRAINT      FK_e_6_contador   REFERENCES  contadores(ID)   NOT NULL,
 consumo                NUMBER(9,2)        CONSTRAINT      NN_e_6_consumo                                 NOT NULL
);
CREATE TABLE E_7    -- E7 Consum mig de tots dels clients.
(
 ID                     NUMBER              CONSTRAINT      PK_e_7                                          PRIMARY KEY,
 cliente                                    CONSTRAINT      FK_e_7_cliente       REFERENCES  clientes(ID)   NOT NULL,
 consumoMedio           NUMBER(9,2)         CONSTRAINT      NN_e7_consumoMedio                              NOT NULL
);
-------------
--CONSULTAS
------------
--CONSULTA 1  a
CREATE TABLE C1     --consultarCiudadFecha 
(
 ID                   NUMBER             CONSTRAINT      PK_C1                                           PRIMARY KEY,
 contrato             NUMBER             CONSTRAINT      FK_C1_contrato    REFERENCES   contratos(ID)     NOT NULL, 
 pContratada          NUMBER(9,2)        CONSTRAINT      NN_C1_pContratada                                NOT NULL, 
 tpConsumo            NUMBER(9,2)        CONSTRAINT      NN_C1_tpConsumo                                  NOT NULL,
 mConsumo             NUMBER(9,2)        CONSTRAINT      NN_C1_mConsumo                                   NOT NULL,
 anyo                 NUMBER             CONSTRAINT      NN_C1_anyo          NOT NULL,
 mes                  NUMBER             CONSTRAINT      NN_C1_mes           NOT NULL
 --fecha                VARCHAR2(11 CHAR)   CONSTRAINT     NN_C1_pInicial                                   NOT NULL
);

--CONSULTA 2   b
CREATE TABLE C2     --consultarCentralesDistribucionMasEnergia 
(
 ID                   NUMBER             CONSTRAINT      PK_C2                                            PRIMARY KEY,
 central              NUMBER             CONSTRAINT      FK_C2_central     REFERENCES   centrales(ID)     NOT NULL, 
 ubica                NUMBER             CONSTRAINT      NN_C2_ubica                                      NOT NULL, 
 eEmitida             NUMBER(9,2)        CONSTRAINT      NN_C2_eEmitida                                   NOT NULL,
 eMax                 NUMBER(9,2)        CONSTRAINT      NN_C2_eMax                                       NOT NULL
);

--CONSULTA 3    c
CREATE TABLE C3     --consultarLineasMasCargadasCapacidadMaxima 
(
 ID                   NUMBER             CONSTRAINT      PK_C3                                            PRIMARY KEY,
 linea                NUMBER             CONSTRAINT      FK_C3_linea     REFERENCES   lineas(ID)          NOT NULL, 
 cLinea               NUMBER(9,2)        CONSTRAINT      NN_C3_cLinea                                     NOT NULL, 
 eAmplia              NUMBER(9,2)        CONSTRAINT      NN_C3_eAmplia                                    NOT NULL
);
--CONSULTA 4   d
CREATE TABLE C4     --consultarClientesContadoresAltaDisponibiliad 
(
 ID                   NUMBER             CONSTRAINT      PK_C4                                            PRIMARY KEY,
 dni                  VARCHAR2(10 CHAR)  CONSTRAINT      NN_C4_dni                                        NOT NULL, 
 contrato             NUMBER             CONSTRAINT      FK1_C4_contrato    REFERENCES   contratos(ID)    NOT NULL, 
 modelo               NUMBER             CONSTRAINT      FK2_C4_modelo      REFERENCES   modelos(ID)      NOT NULL
);
--CONSULTA 5 e
CREATE TABLE C5     --consultarConsumoContadoresCentralIntervaloTiempo 
(
 ID                   NUMBER             CONSTRAINT      PK_C5                                               PRIMARY KEY,
 central              NUMBER             CONSTRAINT      FK_C5_central      REFERENCES    centrales(ID)       NOT NULL, 
 contador             NUMBER              CONSTRAINT      NN_C5_contador     REFERENCES    contadores(ID)      NOT NULL, 
 consumo              NUMBER(9,2)        CONSTRAINT      NN_C5_consumo                                        NOT NULL,
 eProd                NUMBER(9,2)        CONSTRAINT      NN_C5_eProd                                          NOT NULL,
 pInicial             VARCHAR2(11 CHAR)   CONSTRAINT     NN_C5_pInicial                                      NOT NULL,
 pFinal               VARCHAR2(11 CHAR)   CONSTRAINT     NN_C5_pFinal                                        NOT NULL
);

--CONSULTA 6 f
CREATE TABLE C6     --consultarPercentLecturasPresencialTelematica 
(
 ID                   NUMBER             CONSTRAINT       PK_C6                                               PRIMARY KEY,
 telematica           NUMBER             CONSTRAINT       FK1_C6_telematica     REFERENCES    tLectura(ID)    NOT NULL, 
 presencial           NUMBER             CONSTRAINT       FK2_C6_presencial     REFERENCES    tLectura(ID)    NOT NULL, 
 pTelematica          NUMBER(9,2)        CONSTRAINT       NN_C6_pTelematica                                   NOT NULL,
 pPresencial          NUMBER(9,2)        CONSTRAINT       NN_C6_pPresencial                                   NOT NULL,
 total                NUMBER(9,2)        CONSTRAINT       NN_C6_total                                         NOT NULL,
 pInicial             VARCHAR2(11 CHAR)   CONSTRAINT      NN_C6_pInicial                                      NOT NULL,
 pFinal               VARCHAR2(11 CHAR)   CONSTRAINT      NN_C6_pFinal                                        NOT NULL
);

--CONSULTA 7 g
CREATE TABLE C7     --consultarContadoresAntiguedad 
(
 ID                   NUMBER             CONSTRAINT      PK_C7                                               PRIMARY KEY,
 contador             NUMBER             CONSTRAINT      FK1_C7_contador    REFERENCES    contadores(ID)     NOT NULL, 
 anyos                NUMBER             CONSTRAINT      NN_C7_anyos                                         NOT NULL,
 fabrica              VARCHAR2(4 CHAR)   CONSTRAINT      NN_C7_fabrica                                       NOT NULL,
 fechaConsulta        DATE  
);

/*-- FIN CREACIN TABLES  --*/
------------------------------------------------------------------------------------------------------------
/* CREACION DE SECUENCIAS */
-----------------------------

CREATE  SEQUENCE estados_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE via_SEQ_GRAL   	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE ccentral_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE ecentral_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE tcentral_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE tInspeccion_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE centrales_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE linea_SEQ_GRAL 	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE lineas_SEQ_GRAL 	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE empresas_SEQ_GRAL	START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE tCliente_SEQ_GRAL      START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE clientes_SEQ_GRAL      START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE modelos_SEQ_GRAL       START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE contadores_SEQ_GRAL    START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE contratos_SEQ_GRAL     START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE ubicaciones_SEQ_GRAL   START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE lecturas_SEQ_GRAL      START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE consumos_SEQ_GRAL      START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
CREATE  SEQUENCE  Log_SEQ_GRAL          START WITH 1  INCREMENT BY 1 NOMAXVALUE  NOCACHE;
--------------------------------------------------
---------------------- ESTADISTICAS --------------
--------------------------------------------------
CREATE SEQUENCE e_1_SEQ_GRAL   	START WITH 1  INCREMENT BY 1  	NOMAXVALUE  	NOCACHE;
CREATE SEQUENCE e_2_SEQ_GRAL 	START WITH 1  INCREMENT BY 1  	NOMAXVALUE  	NOCACHE;
CREATE SEQUENCE e_3_SEQ_GRAL   	START WITH 1  INCREMENT BY 1  	NOMAXVALUE  	NOCACHE;
CREATE SEQUENCE e_4_SEQ_GRAL 	START WITH 1  INCREMENT BY 1  	NOMAXVALUE  	NOCACHE;
CREATE SEQUENCE e_5_SEQ_GRAL   	START WITH 1  INCREMENT BY 1  	NOMAXVALUE  	NOCACHE;
CREATE SEQUENCE e_6_SEQ_GRAL 	START WITH 1  INCREMENT BY 1  	NOMAXVALUE  	NOCACHE;
CREATE SEQUENCE e_7_SEQ_GRAL 	START WITH 1  INCREMENT BY 1  	NOMAXVALUE  	NOCACHE;
--------------------------
--CONSULTAS----------------
--------------------------
CREATE SEQUENCE C1_SEQ_GRAL     START WITH 1  INCREMENT BY 1  NOMAXVALUE  NOCACHE;
CREATE SEQUENCE C2_SEQ_GRAL     START WITH 1  INCREMENT BY 1  NOMAXVALUE  NOCACHE;
CREATE SEQUENCE C3_SEQ_GRAL     START WITH 1  INCREMENT BY 1  NOMAXVALUE  NOCACHE;
CREATE SEQUENCE C4_SEQ_GRAL     START WITH 1  INCREMENT BY 1  NOMAXVALUE  NOCACHE;
CREATE SEQUENCE C5_SEQ_GRAL     START WITH 1  INCREMENT BY 1  NOMAXVALUE  NOCACHE;
CREATE SEQUENCE C6_SEQ_GRAL     START WITH 1  INCREMENT BY 1  NOMAXVALUE  NOCACHE;
CREATE SEQUENCE C7_SEQ_GRAL     START WITH 1  INCREMENT BY 1  NOMAXVALUE  NOCACHE;
-----------------
--CREATE TRIGGERS
-----------------
--ESTADOS
CREATE OR REPLACE TRIGGER   estados_TR_KEY
    BEFORE INSERT       ON  estados    FOR EACH ROW
   BEGIN      SELECT        estados_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--UBICACIONES
CREATE OR REPLACE TRIGGER ubicaciones_TR_KEY
    BEFORE INSERT      ON ubicaciones
    FOR EACH ROW
   BEGIN
      SELECT              ubicaciones_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--VIA
CREATE OR REPLACE TRIGGER   via_TR_KEY
    BEFORE INSERT       ON  via    FOR EACH ROW
   BEGIN             SELECT via_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--cCentral
CREATE OR REPLACE TRIGGER   ccentral_TR_KEY
    BEFORE INSERT       ON  ccentral
    FOR EACH ROW
    BEGIN            SELECT ccentral_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--eCentral
CREATE OR REPLACE TRIGGER   ecentral_TR_KEY
    BEFORE INSERT       ON  ecentral
    FOR EACH ROW
   BEGIN            SELECT  ecentral_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--tCentral
CREATE OR REPLACE TRIGGER       tcentral_TR_KEY
    BEFORE INSERT         ON    tcentral
    FOR EACH ROW
   BEGIN                SELECT  tcentral_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--tInspeccion
CREATE OR REPLACE TRIGGER   tInspeccion_TR_KEY
    BEFORE INSERT       ON  tInspeccion
    FOR EACH ROW
   BEGIN      SELECT        tInspeccion_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--Centrales
CREATE OR REPLACE TRIGGER   centrales_TR_KEY
    BEFORE INSERT       ON  centrales         FOR EACH ROW
   BEGIN      SELECT        centrales_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--linea
CREATE OR REPLACE TRIGGER               linea_TR_KEY
    BEFORE INSERT       ON              linea
    FOR EACH ROW   BEGIN   SELECT       linea_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--lineas
CREATE OR REPLACE TRIGGER               lineas_TR_KEY
    BEFORE INSERT     ON                lineas
    FOR EACH ROW   BEGIN      SELECT    lineas_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
CREATE OR REPLACE TRIGGER               empresas_TR_KEY
    BEFORE INSERT       ON              empresas
    FOR EACH ROW   BEGIN      SELECT    empresas_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--tCliente
CREATE OR REPLACE TRIGGER   tCliente_TR_KEY
    BEFORE INSERT       ON  tCliente
    FOR EACH ROW   BEGIN
      SELECT                tCliente_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--CLIENTES
CREATE OR REPLACE TRIGGER   clientes_TR_KEY
    BEFORE INSERT       ON  clientes
    FOR EACH ROW
   BEGIN      SELECT        clientes_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--MODELOS
CREATE OR REPLACE TRIGGER   modelos_TR_KEY
    BEFORE INSERT    ON     modelos
    FOR EACH ROW
   BEGIN      SELECT        modelos_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--EMPRESAS
CREATE OR REPLACE TRIGGER   empresas_TR_KEY
    BEFORE INSERT    ON     empresas
    FOR EACH ROW
   BEGIN      SELECT        empresas_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--CONTADORES
CREATE OR REPLACE TRIGGER   contadores_TR_KEY
    BEFORE INSERT    ON     contadores
    FOR EACH ROW
   BEGIN      SELECT        contadores_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--CONTRATOS
CREATE OR REPLACE TRIGGER   contratos_TR_KEY
    BEFORE INSERT    ON     contratos
    FOR EACH ROW
   BEGIN      SELECT        contratos_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--LECTURAS
CREATE OR REPLACE TRIGGER lecturas_TR_KEY
    BEFORE INSERT      ON lecturas
    FOR EACH ROW
   BEGIN
      SELECT              lecturas_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--CONSUMOS
CREATE OR REPLACE TRIGGER               consumos_TR_KEY
    BEFORE INSERT      ON               consumos
    FOR EACH ROW   BEGIN      SELECT    consumos_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
END;
/
--LOG
CREATE OR REPLACE TRIGGER  Log_TR_KEY
    BEFORE INSERT       ON Log
    FOR EACH ROW
   BEGIN
      SELECT              Log_SEQ_GRAL.NEXTVAL INTO :NEW.idLog FROM dual;
END;
/
---------------ESTADISTICAS-------
----------------------------------
CREATE OR REPLACE TRIGGER           e_1_TR_KEY
        BEFORE INSERT        ON     e_1   FOR EACH ROW
    BEGIN                   SELECT  e_1_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER           e_2_TR_KEY
        BEFORE INSERT        ON     e_2   FOR EACH ROW
    BEGIN                   SELECT  e_2_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER           e_3_TR_KEY
        BEFORE INSERT        ON     e_3   FOR EACH ROW
    BEGIN                   SELECT  e_3_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER           e_4_TR_KEY
        BEFORE INSERT        ON     e_4   FOR EACH ROW
    BEGIN                   SELECT  e_4_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER           e_5_TR_KEY
        BEFORE INSERT        ON     e_5   FOR EACH ROW
    BEGIN                   SELECT  e_5_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER           e_6_TR_KEY
        BEFORE INSERT        ON     e_6   FOR EACH ROW
    BEGIN                   SELECT  e_6_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER           e_7_TR_KEY
        BEFORE INSERT        ON     e_7   FOR EACH ROW
    BEGIN                   SELECT  e_7_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
----------CONSULTAS
-------------------
CREATE OR REPLACE TRIGGER  C1_TR_KEY  BEFORE INSERT  ON  C1   FOR EACH ROW
    BEGIN          SELECT  C1_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER  C2_TR_KEY  BEFORE INSERT  ON  C2   FOR EACH ROW
    BEGIN          SELECT  C2_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER  C3_TR_KEY  BEFORE INSERT  ON  C3   FOR EACH ROW
    BEGIN          SELECT  C3_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER  C4_TR_KEY  BEFORE INSERT  ON  C4   FOR EACH ROW
    BEGIN          SELECT  C4_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER  C5_TR_KEY  BEFORE INSERT  ON  C5   FOR EACH ROW
    BEGIN          SELECT  C5_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER  C6_TR_KEY  BEFORE INSERT  ON  C6   FOR EACH ROW
    BEGIN          SELECT  C6_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
/
CREATE OR REPLACE TRIGGER  C7_TR_KEY  BEFORE INSERT  ON  C7   FOR EACH ROW
    BEGIN          SELECT  C7_SEQ_GRAL.NEXTVAL INTO :NEW.id FROM dual;
    END;
----end triggers
----------------
/* FIN CREACION DE SECUENCIAS */

/* GESTOR_ALTAS */
CREATE OR REPLACE
PROCEDURE altaCentralDistribucion(
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaCentralDistribucion
PROPSITO: gestiona el alta de una Central de DISTRIBUCION
PARAMETERS: n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT: n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaCentralDistribucion('BCN_D4',1,to_char(sysdate,'DD/MM/YYYY'),2,3,20,10,1,to_char(sysdate,'DD/MM/YYYY'),500,null,rst);
******************************************************************************/
n_des_ins             VARCHAR2(50);
n_obs_ins             VARCHAR2(50);
dist_test                       INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
ins_test                        INTEGER;
err_msg         		VARCHAR2 (100);
dup_dist                        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
des_nulo  			EXCEPTION;
dup_ins                         EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);
--verificamos que los campos nulos no sean nulos
IF   (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_clase IS NULL)
	OR (n_tipo IS NULL)
	OR (n_eMax IS NULL)
	OR (n_eMin IS NULL)
	OR (n_inspeccion IS NULL)
	OR (n_fIns IS NULL)
	OR (n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;
--verificamos si existe la descripcin de la  Central
SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_central;
END IF;
-- obtener el codigo de la central de Distribucion
SELECT id
INTO dist_test
FROM ccentral
WHERE
ccentral.des='DISTRIBUCION' OR 
ccentral.DES='DISTRIBUCIN';
IF (dist_test = 0)
THEN
RAISE dup_dist; 
END IF;

IF (n_clase <> dist_test)
THEN
RAISE dup_dist; -- no es central de Distribucion
END IF;

--verificamos exista la clase de central y que sea de Central de Distribucion

SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; 
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

--verificamos  que exista el tipo de inspeccion
SELECT COUNT (*)
INTO ins_test
FROM tInspeccion
WHERE tInspeccion.id = n_inspeccion;
IF (ins_test = 0)   
THEN
RAISE dup_ins; 
END IF;


-- insertamos la nueva central
INSERT INTO centrales
(des,estado,fechaEstado,clase,tipo,eMax,eMin,inspeccion,fIns,ubica,obs)
VALUES
(n_des_ins,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs_ins);

-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta CENTRAL OK: ' || n_des_ins); 
    rst:='OK, Alta CENTRAL  ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA CENTRAL: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION
WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta  Central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacion  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;

WHEN dup_dist
THEN
    rst := 'ERROR: No es CENTRAL DE DISTRIBUCION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || dist_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ins
THEN
    rst := 'ERROR: No existe el tipo de inspeccion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_inspeccion: ' || n_inspeccion, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. altaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaCentralDistribucion;
/
CREATE OR REPLACE
PROCEDURE altaCentralProduccion(
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaCentral
PROPSITO: gestiona el alta de una Central de PRODUCCION
PARAMETERS: n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT: n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaCentralProduccion('BARCELONA_2',1,to_char(sysdate,'DD/MM/YYYY'),1,3,20,10,1,'15/05/2012',1,null,rst);
******************************************************************************/
n_des_ins             VARCHAR2(50);
n_obs_ins             VARCHAR2(50);


prod_test                       INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
ins_test                        INTEGER;

err_msg         		VARCHAR2 (100);
dup_prod                        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
dup_ins                         EXCEPTION;
des_nulo  			EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);

--verificamos que los campos nulos no sean nulos
IF   (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_clase IS NULL)
	OR (n_tipo IS NULL)
	OR (n_eMax IS NULL)
	OR (n_eMin IS NULL)
	OR (n_inspeccion IS NULL)
	OR (n_fIns IS NULL)
	OR (n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;



--verificamos si existe la descripcin de la  Central
SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_central;
END IF;

-- obtener el codigo de la central de produccion
SELECT id
INTO prod_test
FROM ccentral
WHERE
ccentral.des='PRODUCCION' OR 
ccentral.DES='PRODUCCIN';
IF (prod_test = 0)
THEN
RAISE dup_prod; 
END IF;

IF (n_clase <> prod_test)
THEN
RAISE dup_prod; -- no es central de produccion
END IF;

--verificamos exista la clase de central y que sea de Central de Produccion

SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; 
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

--verificamos  que exista el tipo de inspeccion
SELECT COUNT (*)
INTO ins_test
FROM tInspeccion
WHERE tInspeccion.id = n_inspeccion;
IF (ins_test = 0)   
THEN
RAISE dup_ins; 
END IF;


-- insertamos la nueva central
INSERT INTO centrales
(des,estado,fechaEstado,clase,tipo,eMax,eMin,inspeccion,fIns,ubica,obs)
VALUES
(n_des_ins,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs_ins);


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta CENTRAL OK: ' || n_des_ins); 
    rst:='OK, Alta Central de Produccin  ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA CENTRAL: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION
WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta  Central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;


WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacion  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;


WHEN dup_prod
THEN
    rst := 'ERROR: No es CENTRAL DE PRODUCCION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || prod_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ins
THEN
    rst := 'ERROR: No existe el tipo de inspeccion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_inspeccion: ' || n_inspeccion, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. altaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaCentralProduccion;
/
create or replace PROCEDURE altaClaseCentral(
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaClaseCentral
PROPSITO: gestiona el alta de un Clase de Central
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido sxito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaClaseCentral('DISTRIBUCIN', rst);
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_ccentral    		EXCEPTION;
desCCentral_nulo  	EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo CCENTRAL.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desCCentral_nulo;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM ccentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_ccentral;
END IF;
-- insertamos el nuevo tipo de ccentral
INSERT INTO ccentral(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de CCENTRAL: ' || n_des_ins); 
    rst:='Ok, Alta Tipo CCENTRAL  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_ccentral
THEN
    rst := 'ERROR: Ya existe este tipo de  CCENTRAL';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desCCentral_nulo
THEN
    rst := 'ERROR: el tipo de CCENTRAL  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaClaseCentral;
/
CREATE OR REPLACE
PROCEDURE altaClientes (
n_estado            IN NUMBER,
n_tipo              IN NUMBER,
n_nifCif            IN VARCHAR2,
n_nom               IN VARCHAR2,
n_ape1              IN VARCHAR2,
n_ape2              IN VARCHAR2,
n_email             IN VARCHAR2,
n_tMovil            IN VARCHAR2,
n_ubica             IN NUMBER,
n_fechaAlta         IN VARCHAR2,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaCliente
PROPSITO: gestiona el alta de un cliente en la tabla clientes
PARAMETERS: n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,
n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod, rst
INPUT: n_estado, n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,
n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaClientes(1,4,'43073208X', 'Alberto', 'Ramos', null, 'aramossa@uoc.edu','34671535222',1,'17/04/2012',null, rst);
******************************************************************************/

n_nifCif_ins          VARCHAR2(10 CHAR);
n_nom_ins             VARCHAR2(50 CHAR);
n_ape1_ins            VARCHAR2(50 CHAR);
n_ape2_ins            VARCHAR2(50 CHAR);
n_email_ins           VARCHAR2(50 CHAR);
n_tMovil_ins          VARCHAR2(11 CHAR);
n_ubica_ins           NUMBER;
n_fechaAlta_ins       VARCHAR2(11 CHAR);
n_fechaMod_ins        VARCHAR2(11 CHAR);

estado_test         INTEGER;
tipo_test           INTEGER;
nifCif_test         INTEGER;
ubica_test          INTEGER;

err_msg             VARCHAR2(100);

dup_estado          EXCEPTION;
dup_tipo            EXCEPTION;
dup_nifCif          EXCEPTION;
dup_ubica           EXCEPTION;

dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_nifCif_ins        := SUBSTR (n_nifCif, 1, 10);
n_nom_ins           := SUBSTR (n_nom, 1, 50);
n_ape1_ins          := SUBSTR (n_ape1, 1, 50);
n_ape2_ins          := SUBSTR (n_ape2, 1, 50);
n_email_ins         := SUBSTR (n_email, 1, 50);
n_tMovil_ins        := SUBSTR (n_tMovil, 1, 11);
n_fechaAlta_ins     := SUBSTR (n_fechaAlta, 1, 11);
n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_estado          IS NULL)
OR (n_tipo            IS NULL)
OR (n_nifCif_ins      IS NULL)
OR (n_nom_ins         IS NULL)
OR (n_ape1_ins        IS NULL)
OR (n_ubica           IS NULL)
OR (n_fechaAlta_ins   IS NULL)
THEN
RAISE dup_des;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--comprobar tipo cliente
SELECT COUNT (*)
INTO tipo_test
FROM TCLIENTE
WHERE tCliente.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;

--comprobar que la ubicacion exista 

SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.ID = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;

--verificamos que el nifCifel cliente  no exista
SELECT COUNT (*)
INTO nifCif_test
FROM CLIENTES
WHERE nifCif = n_nifCif_ins;
IF (nifCif_test > 0)
THEN
RAISE dup_nifCif;
END IF;


-- insertamos el nuevo cliente
INSERT INTO CLIENTES (estado,
tipo,
nifCif,
nom,
ape1,
ape2,
email,
tMovil,
ubica,
fechaAlta,
fechaMod)

VALUES (n_estado,
n_tipo,
n_nifCif_ins,
n_nom_ins, 
n_ape1_ins,
n_ape2_ins,
n_email_ins,
n_tMovil_ins,
n_ubica,
n_fechaAlta_ins,
n_fechaMod_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('cliente: ' || n_ape1_ins 
    ||','
    || n_ape2_ins
    ||','
    ||n_nom    
    ); 
    rst:='Ok, Alta cliente   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado: '
|| n_estado 
|| ', '
||'n_tipo  : ' 
|| n_tipo
|| ', ' 
||'n_nifCif  : ' 
|| n_nifCif 
|| ', ' 
||'n_nom: ' 
|| n_nom 
|| ', ' 
||'n_ape1: '
|| n_ape1 
|| ', '
||'n_ape2: '
|| n_ape2
|| ', '
||'n_email: '
|| n_email 
|| ', ' 
||'n_tMovil: '
|| n_tMovil 
|| ', ' 
||'n_ubica: '
|| n_ubica 
|| ', ' 
||'n_fechaAlta: '
|| n_fechaAlta 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION
WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tipo
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_tipo : ' || n_tipo  ); 
     rst := 'ERROR: NO existe TIPO CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el TIPO CLIENTE ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_tipo : ' || n_tipo 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_nifCif
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_nifCif : ' || n_nifCif_ins  ); 
     rst := 'ERROR:  ya existe este NIF / CIF';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: ya  existe el NIF - CIFT ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_nifCif : ' || n_nifCif 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe la UBICACION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la UBICACION ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica : ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado: '
|| n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_nifCif: '
|| n_nifCif 
, 'rst', rst, rst);
ROLLBACK;
END altaClientes;
/
CREATE OR REPLACE
PROCEDURE altaConsumos(
n_contador          IN NUMBER,
n_anyo     	    IN NUMBER,
n_mes               IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaConsumos
PROPSITO: gestiona el alta en la tabla de consumos
PARAMETERS:  n_contador,n_anyo, n_mes,n_consumo, rst
INPUT:   n_contador, n_anyo,n_mes,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaConsumos(1,2011,1,12 rst)
******************************************************************************/

contador_test           INTEGER;
err_msg                 VARCHAR2 (100);
dup_contador            EXCEPTION;
dup_null                EXCEPTION;

BEGIN

--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_anyo              IS NULL)
OR (n_mes               IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;


--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;
-- insertamos el nuevo registro en consumos
INSERT INTO consumos(
contador,
anyo,
mes,
consumo
)
VALUES (
n_contador,
n_anyo,
n_mes,
n_consumo
);
-- Fin de las operaciones
rst := 'OK';
DBMS_OUTPUT.PUT_LINE('n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo);

DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes_ins: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END altaConsumos;
/
CREATE OR REPLACE
PROCEDURE altaContadores(
n_modelo         	IN NUMBER,
n_ubica         	IN NUMBER,
n_estado         	IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
n_numSerie         	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaContadores
PROPSITO: gestiona el alta de un contador en la tabla contadores
PARAMETERS: n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie,rst
INPUT: n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaContadores(1,1,1,to_char(sysdate,'DD/MM/YYYY'), 'n/s_1', rst);
******************************************************************************/
n_fechaEstado_ins       VARCHAR2(11 CHAR);
n_numSerie_ins          VARCHAR2(20);

modelo_test             NUMBER;
ubica_test              NUMBER;
estado_test             NUMBER;

err_msg                 VARCHAR2(100);
  dup_modelo            EXCEPTION;
dup_ubica               EXCEPTION;
dup_estado              EXCEPTION;
  dup_des               EXCEPTION;

BEGIN


n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 
n_numSerie_ins      := SUBSTR(n_numSerie, 1, 20);


--verificamos que los campos no nulos no sean nulos
IF (n_modelo          IS NULL)
OR (n_ubica           IS NULL)
OR (n_estado          IS NULL)
OR (n_fechaEstado_ins IS NULL)
OR (n_numSerie_ins    IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que existe el modelo
SELECT COUNT (*)
INTO modelo_test
FROM MODELOS
WHERE ID = n_modelo;
IF (modelo_test = 0)
THEN
RAISE dup_modelo;
END IF;
--comprobar que existe la  ubicacion
SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--insertamos el nuevo contador
INSERT INTO CONTADORES 
(modelo,
ubica,
estado,
fechaEstado,
numSerie)

VALUES 
(n_modelo,
n_ubica,
n_estado,
n_fechaEstado_ins,
n_numSerie_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_modelo : ' || n_modelo ); 
    rst:='Ok, Alta contador   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' 
|| n_modelo 
|| ', ' 
||'n_ubica  : '
|| n_ubica
|| ', ' 
||'n_estado  : '
|| n_estado
|| ', ' 
||'n_fechaEstado: '
|| n_fechaEstado_ins
|| ', ' 
||'n_numSerie: '
|| n_numSerie_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_modelo
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_modelo : ' || n_modelo  ); 
     rst := 'ERROR: No existe Modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' || n_modelo  
, 'rst', rst, rst);

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe ubicacin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica: ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: No existe Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado ' || n_estado
|| ', '
||'n_fechaEstado: ' || n_fechaEstado 
, 'rst', rst, rst);

ROLLBACK;
WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaCcontadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaCcontador', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);
ROLLBACK;
END altaContadores;
/
create or replace PROCEDURE altaContratos(
n_cliente           	IN NUMBER,
n_contador          	IN NUMBER,
n_estado            	IN NUMBER,
n_fechaEstado       	IN VARCHAR2,
n_pContrato         	IN NUMBER,
n_obs             	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaContratos
PROPSITO: gestiona el alta de un contraato en la tabla contratos
PARAMETERS: n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs, rst
INPUT:      n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs
PROCEDURE: altaLecturas(n_contador,n_fechaEstado_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaContratos(1,1,1,to_char(sysdate,'DD/MM/YYYY'),30,'obs_contrato', rst);
******************************************************************************/

n_fechaEstado_ins     VARCHAR2(11 CHAR);
n_obs_ins             VARCHAR2(50 CHAR);

cliente_test		INTEGER;
contador_test		INTEGER;
estado_test             INTEGER;
err_msg                 VARCHAR2(100);

n_anterior    NUMBER;
n_actual      NUMBER;
n_tipo        NUMBER;
n_consumo     NUMBER;
dup_cliente		EXCEPTION;
dup_contador	        EXCEPTION;
dup_estado		EXCEPTION;
dup_des                 EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  	:= SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins               := SUBSTR (n_obs, 1, 50);

-- inicializo contadores de lecturas y consumos 
n_anterior := 0;
n_actual   := 0; 
n_tipo     := 1;
n_consumo  := 0;
--verificamos que los campos no nulos no sean nulos

IF (n_cliente        		IS NULL)
OR (n_contador       		IS NULL)
OR (n_estado      		IS NULL)
OR (n_fechaEstado_ins           IS NULL)
OR (n_pContrato        	        IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que exista el  cliente
SELECT COUNT (*)
INTO cliente_test
FROM CLIENTES
WHERE CLIENTES.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

-- comprobar que exista el contador
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE contadores.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;
--comprobar que exista el estado 
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
-- insertamos el nuevo contrato
INSERT INTO CONTRATOS (
cliente,
contador,
estado,
fechaEstado,
pContrato,
obs
)
VALUES (
n_cliente,
n_contador,
n_estado,
n_fechaEstado_ins,
n_pContrato,
n_obs_ins
);
-- llamada procedure: actualiza lecturas y en lecturas llama procedure altaConsumo
altaLecturas(n_contador,n_fechaEstado_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
'n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
    ); 
    rst:='Ok, Alta contrato   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente: '
|| n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
COMMIT;

-- tratamiento de excepciones

EXCEPTION

WHEN dup_cliente
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_cliente : ' || n_cliente  ); 
     rst := 'ERROR: NO existe el CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el CLIENTE ';
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente  : ' || n_cliente
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_contador: ' || n_contador  ); 
     rst := 'ERROR:  NO  existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el CONTADOR';
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: ' || n_contador
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente: '
|| n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato 
||'n_obs: '
|| n_obs 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente: '
|| n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
ROLLBACK;
END altaContratos;
/
create or replace PROCEDURE altaEmisionCentral(
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEmisionCentral
PROPSITO: gestiona el alta de un tipo de emisin o especificidad de la  Central
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaEmisionCentral('CO2', rst)
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_ecentral    		EXCEPTION;
desecentral_nulo  	        EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo ECentral.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desECentral_nulo;
END IF;
--verificamos si existe el tipo de emisin
SELECT COUNT (*)
INTO des_test
FROM ECentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_ECentral;
END IF;
-- insertamos el nuevo tipo de ECentral
INSERT INTO ECentral(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de ECentral: ' || n_des_ins); 
    rst:='Ok, Alta Tipo ECentral  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_ECentral
THEN
    rst := 'ERROR: Ya existe este tipo de  ECentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desECentral_nulo
THEN
    rst := 'ERROR: el tipo de ECentral  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ECentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaEmisionCentral;
/
create or replace PROCEDURE altaEmpresa(
n_cif			IN VARCHAR2,
n_des 		IN VARCHAR2,
n_estado 		IN NUMBER,
n_fechaEstado	IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEmpresa
PROPSITO: gestiona el alta de una EMPRESA
PARAMETERS: n_cif,n_des,n_estado,n_fechaEstado, rst
INPUT: n_cif,n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaEmpresa('s121214','empresa3',5,'01/05/2012',rst);
******************************************************************************/
n_des_ins       		VARCHAR2 (50);

cif_test				INTEGER;
des_test        		INTEGER;
estado_test				INTEGER;

err_msg         	VARCHAR2 (100);

dup_cif			EXCEPTION;
dup_des    		EXCEPTION;
dup_estado			EXCEPTION;
des_nulo  			EXCEPTION;


BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);

--verificamos si el hay campos nulos
IF (n_cif IS NULL)
OR (n_des_ins IS NULL)
OR (n_estado IS NULL)
OR (n_fechaEstado IS NULL)
THEN
RAISE des_nulo;
END IF;

--verificamos si existe el cif de la empresa
SELECT COUNT (*)
INTO cif_test
FROM empresas
WHERE empresas.cif = n_cif;
IF (cif_test > 0)
THEN
RAISE dup_cif;
END IF;

--verificamos si existe la descripcin de la empresa
SELECT COUNT (*)
INTO des_test
FROM empresas
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos si existe el estado  de la empresa
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;



-- insertamos el nuevo tipo de empresa
INSERT INTO empresas
(cif,des,estado,fechaEstado)
VALUES
(n_cif,n_des_ins,n_estado,n_fechaEstado);


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de EMPRESA: ' || n_des_ins); 
    rst:='Ok, Alta EMPRESA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_cif
THEN
    rst := 'ERROR: Ya existe este CIF';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif

, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe este NOMBRE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif

, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO existe este ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
|| 'estado'
|| n_estado
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Empresa : ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaEmpresa;
/
create or replace PROCEDURE altaEstados(
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEstados
PROPSITO: gestiona el alta de un estado
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido scito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaEstado('ALTA', rst)
******************************************************************************/
n_des_ins       VARCHAR2 (50);
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_estados      EXCEPTION;
desEstado_nulo      EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo estados.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desEstado_nulo;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM ESTADOS
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_estados;
END IF;
-- insertamos el nuevo tipo de ESTADOS
INSERT INTO ESTADOS(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de ESTADOS: ' || n_des_ins); 
    rst:='Ok, Alta Tipo ESTADOS  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaESTADOS', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_estados
THEN
    rst := 'ERROR: Ya existe este tipo de  ESTADOS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaESTADOS', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desEstado_nulo
THEN
    rst := 'ERROR: el tipo de ESTADOS  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaESTADOS', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaESTADOS', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaEstados;
/
CREATE OR REPLACE
PROCEDURE altaLectura(
n_contador        IN NUMBER,
n_fechaLectura    IN VARCHAR2,
n_tipo            IN NUMBER,
n_lectura         IN NUMBER,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLectura
PROPSITO: gestiona el alta de una lectura de contador
PARAMETERS:   n_contador, n_fechaLectura,n_tipo,n_lectura,rst
INPUT:        n_contador, n_fechaLectura,n_tipo,n_lectura
PROCEDURE: altaLectura(n_contador,n_fechaLectura_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLectura(1, to_char(sysdate,'DD/MM/YYYY'),1,1212, rst);

******************************************************************************/
n_fechaLectura_ins      VARCHAR2 ( 11 CHAR);
contador_test           INTEGER;
cont_central      INTEGER;
i     integer;
tipo_test               INTEGER;
anterior_test           INTEGER;
n_anterior              NUMBER;
n_actual                NUMBER;
n_consumo               NUMBER;
err_msg                 VARCHAR2 (100);
dup_contador            EXCEPTION;
dup_tipo                EXCEPTION;
dup_null                EXCEPTION;

--proceso
BEGIN
-- comprobamos longitud de cadenas
n_fechaLectura_ins       := SUBSTR (n_fechaLectura, 1, 50);

--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_fechaLectura_ins  IS NULL)
OR (n_tipo              IS NULL)
OR (n_lectura           IS NULL)
THEN
RAISE dup_null;
END IF;

-- obtenemos el numero de centrales de produccin activas
select  count (*)
INTO cont_central
from centrales, ccentral
where
 ccentral.ID = centrales.CLASE
and centrales.CLASE = 2;
--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--verificamos que exista el tipo de  lectura
SELECT COUNT (*)
INTO tipo_test
FROM TLECTURA
WHERE tLectura.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;

-- obtener la lectura anterior del contador
        SELECT lecturas.ANTERIOR
        INTO n_anterior
        FROM lecturas
        WHERE lecturas.CONTADOR= n_contador
        AND  lecturas.FECHALECTURA <= n_fechaLectura_ins
        AND  ROWNUM=1;

-- obtener la lectura actual del contador
        SELECT lecturas.ACTUAL
        INTO n_actual
        FROM lecturas
        WHERE lecturas.CONTADOR= n_contador
        AND  lecturas.FECHALECTURA <= n_fechaLectura_ins
        AND  ROWNUM=1;

-- calcular los campos de lecturas
n_anterior := n_actual;
n_actual    := n_lectura;
n_consumo := (n_actual - n_anterior);

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_actual : ' || n_actual );
    DBMS_OUTPUT.PUT_LINE('n_lectura : ' || n_lectura ); 
    DBMS_OUTPUT.PUT_LINE('n_anterior : ' || n_anterior ); 
    DBMS_OUTPUT.PUT_LINE('n_consumo : ' || n_consumo ); 
    DBMS_OUTPUT.PUT_LINE('');  

-- insertamos la nueva lectura; llamada a procedimiento 

altaLecturas(n_contador,n_fechaLectura_ins,n_tipo,n_anterior,n_actual,n_consumo,rst);
/*
-- actualizar estadisticas E_1
i  := 1;
while (i <= cont_central)  loop  
altaE1(i,getConsumoCentral(i),rst);
cont_central := cont_central + 1;
end loop;
*/

-- Fin de las operaciones
rst := 'OK: Lectura actualizada en Lecturas y Consumos';


altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_tipo
THEN
    rst := 'ERROR: Ya existe esta descripcion del tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
 err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END altaLectura;
/
CREATE OR REPLACE
PROCEDURE altaLecturas (
n_contador          IN NUMBER,
n_fechaLectura      IN VARCHAR2,
n_tipo              IN NUMBER,
n_anterior          IN NUMBER,
n_actual            IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLecturas
PROPSITO: gestiona el alta en la tabla de Lecturas
PARAMETERS:  n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo, rst
INPUT:   n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo
PROCEDURE EXTERNA:  altaConsumos(n_contador, n_anyo, n_mes, n_consumo,rst);
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLecturas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,1, rst)
******************************************************************************/
n_fechaLectura_ins      VARCHAR2 ( 11 CHAR);
n_anyo                  VARCHAR2(4 CHAR);
n_mes                   VARCHAR2(2 CHAR);
nn_anyo	          NUMBER;
nn_mes		  NUMBER;
contador_test           INTEGER;
tipo_test               INTEGER;
err_msg                 VARCHAR2 (100);
dup_contador            EXCEPTION;
dup_tipo                EXCEPTION;
dup_null                EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_fechaLectura_ins       := SUBSTR (n_fechaLectura, 1, 11);
n_anyo             := SUBSTR (n_fechaLectura_ins, 7, 4);
n_mes              := SUBSTR (n_fechaLectura_ins, 4, 2);
nn_anyo     := to_number(n_anyo,9999);
nn_mes      := to_number(n_mes,99);
--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_fechaLectura_ins  IS NULL)
OR (n_tipo              IS NULL)
OR (n_anterior          IS NULL)
OR (n_actual            IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;
--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;
--verificamos que  exista el tipo de lectura
SELECT COUNT (*)
INTO tipo_test
FROM TLECTURA
WHERE tLectura.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;
-- insertamos el nuevo registro en lecturas
INSERT INTO lecturas(
contador,
fechaLectura,
tipo,
anterior,
actual,
consumo
)
VALUES (
n_contador,
n_fechaLectura_ins,
n_tipo,
n_anterior,
n_actual,
n_consumo
);
-- Fin de las operaciones
rst := 'OK: lectura aceptada ';

altaConsumos(n_contador, nn_anyo, nn_mes, n_consumo,rst);

altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_tipo
THEN
    rst := 'ERROR: NO este  tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END altaLecturas;
/
CREATE OR REPLACE
PROCEDURE altaLinea(

n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_cMax                  IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLinea
PROPSITO: gestiona el alta de una Linea
PARAMETERS: n_estado, n_fechaEstado, n_cMax, n_obs, rst
INPUT: n_estado, n_fechaEstado, n_cMax, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLinea(1,'10/05/2012',100,null,rst);
******************************************************************************/

n_obs_ins       VARCHAR2 (50);
err_msg         VARCHAR2 (100);
des_nulo      EXCEPTION;
BEGIN
n_obs_ins := SUBSTR (n_obs, 1, 50);
--verificamos si hay campos no nulos: nulos
IF 	    (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_cMax IS NULL)
THEN
RAISE des_nulo;
END IF;

-- insertamos el nuevo tipo de linea
INSERT INTO linea(estado,fechaEstado,cMax,obs)
VALUES (n_estado,n_fechaEstado,n_cMax,n_obs_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de linea: ' || n_estado
    || ' fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax)    ; 
    rst:='OK, Alta de linea  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'altaLinea:' || n_estado
    || 'fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax 
, 'rst', rst, rst);
COMMIT;
EXCEPTION


WHEN des_nulo
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' fecha  linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' fecha  de linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;
END altaLinea;
/
CREATE OR REPLACE
PROCEDURE altaLineas(

n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_linea                 IN NUMBER,
n_c1                    IN NUMBER,
n_c2                    IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaLineaS
PROPSITO: gestiona el alta de las lineas conectadas
PARAMETERS: n_estado, n_fechaEstado, n_linea,n_c1,n_c2, n_obs, rst
INPUT: n_estado, n_fechaEstado, n_linea, n_c1, n_c2, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaLineas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,NULL,rst);
******************************************************************************/

n_obs_ins             VARCHAR2 (50);
n_fechaEstado_ins     VARCHAR2(11);
linea_test            INTEGER;
estado_test           INTEGER;
c1_test               INTEGER;  
c2_test               INTEGER;
err_msg               VARCHAR2 (100);

dup_estado            EXCEPTION;
dup_linea             EXCEPTION;
dup_c1                EXCEPTION;
dup_c2                EXCEPTION;
dup_c1_c2             EXCEPTION;
des_null              EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins := SUBSTR (n_obs, 1, 50);
--verificamos si hay campos no nulos: nulos
IF 	  (n_estado             IS NULL)
          OR (n_fechaEstado_ins IS NULL)
          OR (n_linea           IS NULL)
          OR (n_c1              IS NULL)
          OR (n_c2              IS NULL)
THEN
RAISE des_null;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
--comprobar existe la linea
SELECT COUNT (*)
INTO linea_test
FROM LINEA
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
--comprobar existe la central en c1
SELECT COUNT (*)
INTO c1_test
FROM CENTRALES
WHERE centrales.ID = n_c1;
IF (c1_test = 0)
THEN
RAISE dup_c1;
END IF;
--comprobar existe la central o contador en c2
SELECT COUNT (*)
INTO c2_test
FROM CENTRALES, CONTADORES
WHERE centrales.id = n_c2
or contadores.id = n_c2;
IF (c2_test = 0)
THEN
RAISE dup_c2;
END IF;
/*
-- comprobar que no conectamos dos iguales
IF ( n_c1 = n_c2 )
THEN
RAISE dup_c1_c2;
END IF;
*/
-- insertamos el alta de la linea de conexion
INSERT INTO lineas(
estado,
fechaEstado,
linea,
c1,
c2,
obs)
VALUES (
n_estado,
n_fechaEstado_ins,
n_linea,
n_c1,
n_c2,
n_obs_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Alta de linea: '
    ||' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins
    ); 
    rst:='OK, Alta de lineas  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN des_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_linea
THEN
    rst := 'ERROR: NO existe LINEA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1
THEN
    rst := 'ERROR: No es una Central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c2
THEN
    rst := 'ERROR: No es Central ni Contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1_c2
THEN
    rst := 'ERROR: No se pueden  conectar: conexiones iguales';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
END altaLineas;
/
CREATE OR REPLACE
PROCEDURE altaLocalidad (
n_id  IN NUMBER,
n_des IN VARCHAR2,
n_provincia IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altalocalidad
PROPSITO: gestiona el alta de un localidad en la tabla localidad
PARAMETERS: n_id, n_des,n_provincia, rst
INPUT: n_id, n_des, n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altalocalidad(50,'Mataro',10, rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
des_test        INTEGER;
provincia_test  INTEGER;
err_msg         VARCHAR2 (100);
dup_des         EXCEPTION;
dup_id          EXCEPTION;
dup_provincia   EXCEPTION;
dup_null        EXCEPTION;

BEGIN
n_des_ins       := SUBSTR (n_des, 1, 50);
--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL) OR (n_des IS NULL) OR (n_provincia IS NULL)  THEN
RAISE dup_null;
END IF;
--Verificamos si el codigo de la localidad existe
SELECT COUNT (*)
INTO id_test
FROM localidad
WHERE ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;

--verificamos si existe la descripcion de la localidad
SELECT COUNT (*)
INTO des_test
FROM localidad
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;
provincia_test:=0;
--verificamos si existe el codigo de la provincia
SELECT COUNT (*)
INTO provincia_test
FROM provincia
WHERE provincia.ID = n_provincia;
IF (provincia_test = 0)
THEN
RAISE dup_provincia;
END IF;
DBMS_OUTPUT.ENABLE;
-- insertamos la nueva localidad
INSERT INTO localidad(ID,des,provincia) VALUES (n_id,n_des_ins,n_provincia);
-- Fin de las operaciones
rst := 'OK';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
        );  
        DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este cdigo localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_provincia
THEN
    rst := 'ERROR: NO  existe provincia';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos que NO tienen datos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' 
|| n_id
||' n_des:' 
||n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altalocalidad', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
||n_id
||' n_des:' 
|| n_des_ins
||' n_provincia:' 
|| n_provincia
, 'rst', rst, rst);
ROLLBACK;
END altalocalidad;
/
create or replace PROCEDURE altaLog (
   n_procesoLog           IN    VARCHAR2, 
   n_fechaLog             IN    varchar2,
   n_entradaLog           IN    VARCHAR2, 
   n_salidaLog            IN    VARCHAR2,
   n_RSPLog               IN    VARCHAR2, 
   rst                    OUT   VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      altaLog
   PROP?ITO:    gestiona el alta de un log en la tabla log                
   PARAMETERS:  n_procesoLog, fechaLog, entradaLog, n_salidaLog, rst
   INPUT:       n_procesoLog, fechaLog, entradaLog, n_salidaLog
   OUTPUT:      rst
   RETORNA:     'Alta realizada con Exito' si la operacion ha tenido exito, 
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:    altaLog('AT', 'AUSTRIA', rst);
******************************************************************************/
   n_procesoLog_ins           VARCHAR2 (50);
   n_fechaLog_ins             varchar2 (50);
   n_entradaLog_ins           VARCHAR2 (500);
   n_salidaLog_ins            VARCHAR2 (500);
   n_RSPLog_ins               VARCHAR2 (500);
   err_msg                    VARCHAR2 (100);
   hayCamposNulos             EXCEPTION;
BEGIN
   n_procesoLog_ins       := SUBSTR (n_procesoLog, 1, 50);
   n_fechaLog_ins         := SUBSTR (n_fechaLog, 1, 50);
   n_entradaLog_ins       := SUBSTR (n_entradaLog, 1, 500);
   n_salidaLog_ins        := SUBSTR (n_salidaLog, 1, 500);
   n_RSPLog_ins           := SUBSTR (n_RSPLog, 1, 500);
 
 -- insertamos el nuevo log
   INSERT INTO LOG(procesoLog, fechaLog, entradaLog, salidaLog, RSPLog) 
          VALUES (n_procesoLog_ins, n_fechaLog_ins, n_entradaLog_ins, n_salidaLog_ins, n_RSPLog_ins);
   --verificamos que los campos no nulos no sean nulos
   IF (n_procesoLog_ins IS NULL) OR (n_fechaLog_ins IS NULL) OR (n_entradaLog_ins IS NULL) 
      OR (n_salidaLog_ins IS NULL) OR (n_RSPLog_ins IS NULL)
   THEN 
   RAISE hayCamposNulos;
   END IF; 
   
   -- Fin de las operaciones
   rst := 'Nuevo registro en la tabla LOG';   
   COMMIT;
EXCEPTION
WHEN hayCamposNulos
 THEN
      rst := 'ERROR: hay NO nulos :sin contenido';   
      ROLLBACK;  
WHEN OTHERS
   THEN
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rst := 'ERROR:' || err_msg;
      ROLLBACK;
END altaLog;
/
CREATE OR REPLACE
PROCEDURE altaModelos(
n_des            	IN VARCHAR2,
n_anyoFabrica        	IN VARCHAR2,
n_empresa            	IN NUMBER,
n_estado             	IN NUMBER,
n_fechaEstado		IN VARCHAR2,
n_obs              	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaModelo
PROPSITO: gestiona el alta de un modelo en la tabla modelos
PARAMETERS: n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs,rst;
INPUT: n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaModelos('Modelo_1','2012',1,1,to_char(sysdate,'DD/MM/YYYY'),'obs_modelo_1', rst);
******************************************************************************/

n_des_ins             VARCHAR2(50 CHAR);
n_anyoFabrica_ins     VARCHAR2(4  CHAR);
n_fechaEstado_ins      VARCHAR2(11 CHAR);
n_obs_ins             VARCHAR2(50 CHAR);


empresa_test		INTEGER;
estado_test         INTEGER;

err_msg             VARCHAR2(100);

dup_empresa          EXCEPTION;
dup_estado            EXCEPTION;

dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_des_ins        		:= SUBSTR (n_des,1,10);
n_anyoFabrica_ins         	:= SUBSTR (n_anyoFabrica,1,4);
n_fechaEstado_ins     		:= SUBSTR (n_fechaEstado,1,11);
n_obs_ins      			:= SUBSTR (n_obs,1,50);


--verificamos que los campos no nulos no sean nulos

IF (n_des		      	IS NULL)
OR (n_anyoFabrica_ins      IS NULL)
OR (n_empresa         	IS NULL)
OR (n_estado          	IS NULL)
OR (n_fechaEstado_ins   	IS NULL)
THEN
RAISE dup_des;
END IF;



--comprobar que exista la empresa
SELECT COUNT (*)
INTO empresa_test
FROM EMPRESAS
WHERE empresas.id = n_empresa;
IF (empresa_test = 0)
THEN
RAISE dup_empresa;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- insertamos el nuevo modelo
INSERT INTO MODELOS (des,
anyoFabrica,
empresa,
estado,
fechaEstado,
obs)

VALUES (
n_des_ins,
n_anyoFabrica_ins,
n_empresa, 
n_estado,
n_fechaEstado_ins,
n_obs_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
          'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs    
    ); 
    rst:='Ok, Alta Modelo   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_des
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs  
        , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	' n_estado: '
        ||n_estado
	, 'rst', rst, rst);
ROLLBACK;


WHEN dup_empresa
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_empresa : ' || n_empresa  ); 
     rst := 'ERROR: NO existe la EMPRESA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la EMPRESA ';
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_empresa: '
        ||n_empresa
	, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
ROLLBACK;
END altaModelos;
/
CREATE OR REPLACE
PROCEDURE altaPais (
n_id    IN NUMBER,
n_des   IN VARCHAR2,
n_cod   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaPais
PROPSITO: gestiona el alta de un pais en la tabla pais
PARAMETERS:  n_id, n_des,,n_cod, rst
INPUT:  n_id, n_des, n_cod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaPais(1,'Espaa','ES', rst)
******************************************************************************/
n_des_ins         VARCHAR2 ( 50 CHAR);
n_cod_ins         VARCHAR2  ( 5 CHAR );
id_test           INTEGER;
des_test          INTEGER;
cod_test          INTEGER;
err_msg           VARCHAR2 (100);
dup_id            EXCEPTION;
dup_des           EXCEPTION;
dup_cod           EXCEPTION;
dup_null          EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_des_ins       := SUBSTR (n_des, 1, 50);
n_cod_ins       := SUBSTR (n_cod, 1, 5);
--comprobamos campos no nulos que no esten vacios
IF (n_id  IS NULL)
OR (n_des IS NULL)
OR (n_cod IS NULL)
THEN
RAISE dup_null;
END IF;

--Verificamos que no exista el  codigo del pais 
SELECT COUNT (*)
INTO id_test
FROM PAIS
WHERE pais.ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;

--verificamos que no exista la descripcion del PAIS
SELECT COUNT (*)
INTO des_test
FROM PAIS
WHERE pais.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos que no exista  el codigo corto  del PAIS
SELECT COUNT (*)
INTO cod_test
FROM PAIS
WHERE pais.COD = n_cod_ins;
--IF (cod_test > 0)  -- no lo implemento por no tener todos los codigos
--THEN
--RAISE dup_cod;
--END IF;

-- insertamos el nuevo PAIS
INSERT INTO PAIS(ID,des,cod) VALUES (n_id,n_des_ins,n_cod_ins);
-- Fin de las operaciones
--rst := 'OK';

    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Alta de Pais '
||' n_id: ' 
|| n_id
||' n_des: '
|| n_des
); 
    rst:='OK';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: ' 
|| n_id
||' n_des: '
|| n_des
||' n_cod: '
|| n_cod
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este id de PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe este PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_des: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_cod
THEN
    rst := 'ERROR: Ya existe el codigo  de Pais ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cod: ' || n_cod
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
||' n_cod'
||n_cod
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
||' n_cod'
||n_cod
, 'rst', rst, rst);
ROLLBACK;
END altaPais;
/
CREATE OR REPLACE
PROCEDURE altaProvincia (
n_id      IN NUMBER,
n_des     IN VARCHAR2,
n_pais    IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaProvincia
PROPSITO: gestiona el alta de una provincia en la tabla provincia
PARAMETERS: n_id, n_des, n_pais rst
INPUT: n_id, n_des, n_pais
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaProvincia(2,'BARCELONA',1,rst); 
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
des_test        INTEGER;
pais_test       INTEGER;
err_msg         VARCHAR2 (100);
dup_id          EXCEPTION;
dup_des         EXCEPTION;
dup_pais        EXCEPTION;
dup_null        EXCEPTION;

BEGIN
n_des_ins       := SUBSTR (n_des, 1, 50);

--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL) OR (n_des IS NULL) OR (n_pais IS NULL)  THEN
RAISE dup_null;
END IF;
--Verificamos si el codigo de la provincia existe
SELECT COUNT (*)
INTO id_test
FROM PROVINCIA
WHERE provincia.ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;

--verificamos si existe la Provincia
SELECT COUNT (*)
INTO des_test
FROM PROVINCIA
WHERE provincia.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

pais_test:=0;
--verificamos si existe el PAIS
SELECT COUNT (*)
INTO pais_test
FROM PAIS
WHERE pais.ID = n_pais;
IF (pais_test = 0)
THEN
RAISE dup_pais;
END IF;

--DBMS_OUTPUT.ENABLE;
-- insertamos la nueva PROVINCIA

INSERT INTO PROVINCIA(ID,des,pais) VALUES (n_id,n_des_ins,n_pais);
-- Fin de las operaciones
rst := 'OK';
    DBMS_OUTPUT.PUT_LINE('Alta Provincia '
||'n_id:'
|| n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
);  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este cdigo PROVINCIA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta PROVINCIA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_des: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_pais
THEN
    rst := 'ERROR: NO  existe PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_pais: ' || n_pais
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos que NO tienen datos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;
END altaProvincia;
/
create or replace PROCEDURE altaTipoCentral(
n_des 		        IN VARCHAR2,
n_estado 		IN NUMBER,
n_fechaEstado	        IN VARCHAR2,
n_emision		IN NUMBER,
n_cantidad		IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaTipoCentral
PROPSITO: gestiona el alta de un TIPO  de Central
PARAMETERS: n_des,n_estado,n_fechaEstado,n_emision,n_cantidad,
n_obs	, rst
INPUT: n_des,n_estado,n_fechaEstado,n_emision,n_cantidad,
n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaTipoCentral('NUCLEAR',1,'01/05/2012',1,20,NULL,rst)
******************************************************************************/
n_des_ins       		VARCHAR2 (50);

des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_tcentral    		EXCEPTION;
desTCentral_nulo  	EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo tcentral.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desTCentral_nulo;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM tcentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_tcentral;
END IF;
-- insertamos el nuevo tipo de tcentral
INSERT INTO tcentral
(des,estado,fechaEstado,emision,cantidad,obs)
VALUES
(n_des_ins,n_estado,n_fechaEstado,n_emision,n_cantidad,n_obs);


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de tcentral: ' || n_des_ins); 
    rst:='Ok, Alta Tipo tcentral  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_tcentral
THEN
    rst := 'ERROR: Ya existe este tipo de  tcentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desTCentral_nulo
THEN
    rst := 'ERROR: el tipo de tcentral  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaTipoCentral;
/
create or replace PROCEDURE altaTipoCliente(
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaTipoCliente
PROPSITO: gestiona el alta de un tipo decliente
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaTipoCliente('PARTICULAR', rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_des      EXCEPTION;
des_nulo      EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo tCliente.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE des_nulo;
END IF;
--verificamos si existe el tipo de Cliente
SELECT COUNT (*)
INTO des_test
FROM tCliente
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;
-- insertamos el nuevo tipo de Cliente
INSERT INTO tCliente(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de Cliente: ' || n_des_ins); 
    rst:='Ok, Alta Tipo Cliente  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_des
THEN
    rst := 'ERROR: Ya existe este tipo de  Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN des_nulo
THEN
    rst := 'ERROR: el tipo de Cliente  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaTipoCliente;
/
CREATE OR REPLACE
PROCEDURE altaTipoInspeccion(
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaTipoInspeccion
PROPSITO: gestiona el alta de un tipo de inspeccin
PARAMETERS: n_des,n_estado,n_fechaEstado, rst
INPUT: n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaTipoInspeccion('ANUAL',to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
n_des_ins             VARCHAR2(20);
n_fechaEstado_ins     VARCHAR2(11);
des_test        		INTEGER;
estado_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_des    		        EXCEPTION;
dup_estado      		EXCEPTION;
dup_null  			EXCEPTION;

BEGIN
n_des_ins                     := SUBSTR (n_des, 1, 20);
n_fechaEstado_ins             := SUBSTR (n_fechaEstado, 1, 11);
--verificamos que los campos nulos no sean nulos
IF          (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;
--verificamos si ya existe la descripcin 
SELECT COUNT (*)
INTO des_test
FROM TINSPECCION
WHERE tInspeccion.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos si existe el estado
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado; 
END IF;

-- insertamos el nuevo tipo de inspeccion
INSERT INTO tinspeccion
(des,estado,fechaEstado)
VALUES
(n_des_ins,n_estado,n_fechaEstado_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta Tipo Inspeccion  OK: '
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins); 
    rst:='OK, Alta Tipo Inspeccion  OK: ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_des
THEN
    rst := 'ERROR: Ya  existe la descripcion ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_null
THEN
    rst := 'ERROR: Hay campos NO nulos:  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA Tipo Inspeccion: ' 
|| n_des_ins
|| ' Estado: ' 
|| n_estado
||' fechaEstado: ' 
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA Tipo Inspeccion: ' || n_des
, 'rst', rst, rst);
ROLLBACK;
END altaTipoInspeccion;
/
CREATE OR REPLACE
PROCEDURE altaTipoLectura (
n_id    IN NUMBER,
n_des   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaTipoLectura
PROPSITO: gestiona el alta de un tipo de lecturas
PARAMETERS:  n_id, n_des, rst
INPUT:  n_id, n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaTipoLectura(1,'PRESENCIAL', rst)
******************************************************************************/
n_des_ins         VARCHAR2 ( 50 CHAR);
id_test           INTEGER;
des_test          INTEGER;
err_msg           VARCHAR2 (100);
dup_id            EXCEPTION;
dup_des           EXCEPTION;
dup_null          EXCEPTION;
BEGIN
-- comprobamos longitud de cadenas
n_des_ins       := SUBSTR (n_des, 1, 50);
--comprobamos campos no nulos que no esten vacios
IF (n_id  IS NULL)
OR (n_des IS NULL)
THEN
RAISE dup_null;
END IF;
--Verificamos que no exista el  codigo del tipo de  lectura 
SELECT COUNT (*)
INTO id_test
FROM tLectura
WHERE tLectura.ID = n_id;
IF (id_test > 0)
THEN
RAISE dup_id;
END IF;
--verificamos que no exista la descripcion del tipo de lectura
SELECT COUNT (*)
INTO des_test
FROM TLECTURA
WHERE tLectura.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;
-- insertamos el nuevo tipo de lectura
INSERT INTO tLectura(ID,des) VALUES (n_id,n_des_ins);
-- Fin de las operaciones
rst := 'OK';
altaLog('Proc. altaTipoLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: ' 
|| n_id
||' n_des: '
|| n_des
, 'rst', rst, rst);
COMMIT;
---------------
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este id de tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_des: '
|| n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta descripcion del tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaTipoLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_des
||' n_des: '
|| n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaTipoLectura', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
, 'rst', rst, rst);
ROLLBACK;
END altaTipoLectura;
/
create or replace PROCEDURE altaUbicaciones (
n_via               IN NUMBER,
n_dir               IN VARCHAR2,
n_num               IN VARCHAR2,
n_pis               IN VARCHAR2,
n_pta               IN VARCHAR2,
n_codigoPostal      IN VARCHAR,
n_localidad          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaUbicaciones
PROPSITO: gestiona el alta de una Ubicacion en la tabla ubicaciones
PARAMETERS: n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad, rst
INPUT: n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaUbicacion(1,'del pez','2','1r','2a','08330',1, rst);
******************************************************************************/
n_dir_ins           VARCHAR2 (50);
n_num_ins           VARCHAR2 (5);
n_pis_ins           VARCHAR2 (5);
n_pta_ins           VARCHAR2 (10);
n_codigoPostal_ins  VARCHAR  (10);

via_test          INTEGER;
localidad_test    INTEGER;
dup_via           EXCEPTION;
dup_localidad     EXCEPTION;
err_msg           VARCHAR2 (100);
des_nulo          EXCEPTION;
BEGIN
-- controlar la longitud de las entradas
n_dir_ins               := SUBSTR (n_dir, 1, 50);
n_num_ins               := SUBSTR (n_num, 1, 5);
n_pis_ins               := SUBSTR (n_pis, 1, 5);
n_pta_ins               := SUBSTR (n_pta, 1, 10);
n_codigoPostal_ins      := SUBSTR (n_codigoPostal, 1, 10);
--verificamos que los campos no nulos no sean nulos
IF (n_via             IS NULL)
OR (n_dir             IS NULL)
OR (n_num             IS NULL)
OR (n_codigoPostal    IS NULL)
OR (n_localidad       IS NULL)
THEN
RAISE des_nulo;
END IF;
--Verificamos que exista la via
SELECT COUNT (*)
INTO via_test
FROM via
WHERE via.id = n_via;
IF (via_test = 0)
THEN
RAISE dup_via;
END IF;
--verificamos que eixsta la localidad
SELECT COUNT (*)
INTO localidad_test
FROM localidad
WHERE localidad.id = n_localidad;
IF (localidad_test = 0)
THEN
RAISE dup_localidad;
END IF;

-- insertamos la nueva ubicacion
INSERT INTO ubicaciones(
via
,dir
,num
,pis
,pta
,codigoPostal
,localidad)
VALUES (n_via
,n_dir_ins
,n_num_ins
,n_pis_ins
,n_pta_ins
,n_codigoPostal_ins
,n_localidad);
-- Fin de las operaciones
rst := 'OK';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE(
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
);  
        DBMS_OUTPUT.PUT_LINE(rst); 
        
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_via
THEN
      rst := 'ERROR: No existe este cdigo de via';
      DBMS_OUTPUT.ENABLE;    
      DBMS_OUTPUT.PUT_LINE('');  
      DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_localidad
THEN
    rst := 'ERROR: NO  existe localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
        rst := 'ERROR: hay campos nulos que no tienen datos';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');  
        DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc: altaUbicacion: ' 
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
END altaUbicaciones;
/
create or replace PROCEDURE altaVia (
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaVia
PROPSITO: gestiona el alta de una via
PARAMETERS: n_des, rst
INPUT: n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaVia('Rambla', rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_desVia      EXCEPTION;
desVia_nulo      EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo Via.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desVia_nulo;
END IF;
--verificamos si existe el tipo de via
SELECT COUNT (*)
INTO des_test
FROM VIA
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_desVia;
END IF;
-- insertamos el nuevo tipo de via
INSERT INTO VIA(des) VALUES (n_des_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de tipo de via: ' || n_des_ins); 
    rst:='Ok, Alta Tipo Via  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_desVia
THEN
    rst := 'ERROR: Ya existe este tipo de  Via';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desVia_nulo
THEN
    rst := 'ERROR: el tipo de via  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END altaVia;
/* FIN GESTOR_ALTAS */
/
/* GESTOR_MODIFICA */
CREATE OR REPLACE
PROCEDURE modificaCentral(
n_id			IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 		IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaCentral
PROPSITO: gestiona la modificacin  de una Central
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT: n_id, n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaCentral
( 1,'GAROA',1,'01/05/2012',1,1,20,10,1,'15/05/2012',1,'OBS_CENTRAL',rst)
******************************************************************************/

n_des_ins             	VARCHAR2(50);
n_obs_ins             	VARCHAR2(50);

id_test				INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
err_msg         		VARCHAR2 (100);

dup_central_id 		        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
des_nulo  			EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);

--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR 	(n_des_ins IS NULL)
	OR 	(n_estado IS NULL)
	OR 	(n_fechaEstado IS NULL)
	OR 	(n_clase IS NULL)
	OR 	(n_tipo IS NULL)
	OR 	(n_eMax IS NULL)
	OR 	(n_eMin IS NULL)
	OR 	(n_inspeccion IS NULL)
	OR 	(n_fIns IS NULL)
	OR 	(n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;

-- verificamos que la Central a modificar exista

SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_central_id;
END IF;

-- verificamos que la descripcion  a modificar exista

SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_central;
END IF;

--verificamos que existe la clase de la  Central
SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; -- no existe la clase de central
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

-- modificamos la central
UPDATE centrales
SET
des 		= n_des_ins,
estado 		= n_estado,
fechaEstado 	= n_fechaEstado,
clase 		= n_clase,
tipo		= n_tipo,
eMax 		= n_eMax,
eMin 		= n_eMin,
inspeccion 	= n_inspeccion,
fIns 		= n_fIns,
ubica 		= n_ubica,
obs 		= n_obs
WHERE
centrales.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica CENTRAL OK: ' || n_des_ins); 
    rst:='OK, Modifica CENTRAL ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'MODIFICA CENTRAL: ' || n_id
||', ' || 'descripcin: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION
WHEN dup_central_id
THEN
    rst := 'ERROR: NO existe esta  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'CDIGO CENTRAL: ' || n_id, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta descripcin de  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;


WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacin  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;


WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. modificaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaCentral;
/
CREATE OR REPLACE
PROCEDURE modificaCentralDistribucion(
n_id			IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaCentralDistribucion
PROPSITO: gestiona la modificacin de una  Central de DISTRIBUCION
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT:n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaCentralDistribucion(1,'BCN_D4',1,to_char(sysdate,'DD/MM/YYYY'),2,3,20,10,1,to_char(sysdate,'DD/MM/YYYY'),500,null,rst);
******************************************************************************/
n_des_ins             VARCHAR2(50);
n_obs_ins             VARCHAR2(50);
id_test			INTEGER;
dist_test                       INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
ins_test                        INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			EXCEPTION;
dup_dist                        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
des_nulo  			EXCEPTION;
dup_ins                         EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);
--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_clase IS NULL)
	OR (n_tipo IS NULL)
	OR (n_eMax IS NULL)
	OR (n_eMin IS NULL)
	OR (n_inspeccion IS NULL)
	OR (n_fIns IS NULL)
	OR (n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;
/*
--verificamos si existe la descripcin de la  Central
SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_central;
END IF;
*/
-- obtener el codigo de la central de Distribucion
SELECT id
INTO dist_test
FROM ccentral
WHERE
ccentral.des='DISTRIBUCION' OR 
ccentral.DES='DISTRIBUCIN';
IF (dist_test = 0)
THEN
RAISE dup_dist; 
END IF;

IF (n_clase <> dist_test)
THEN
RAISE dup_dist; -- no es central de Distribucion
END IF;
--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


--verificamos exista la clase de central y que sea de Central de Distribucion

SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; 
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

--verificamos  que exista el tipo de inspeccion
SELECT COUNT (*)
INTO ins_test
FROM tInspeccion
WHERE tInspeccion.id = n_inspeccion;
IF (ins_test = 0)   
THEN
RAISE dup_ins; 
END IF;

--modificamos la Central de Distribucin

UPDATE centrales
SET
des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado
,clase =n_clase
,tipo= n_tipo
,eMax= n_eMax
,eMin = n_eMin
,inspeccion = n_inspeccion
,fIns = n_fIns
,ubica = n_ubica
,obs =n_obs_ins
WHERE
centrales.id = n_id;


-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica Central Distribucin OK: ' || n_id); 
    rst:='OK, Modificacin Central Distribucin  ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'ALTA CENTRAL: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el cdigo de la central de Distribucin '||n_id;
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el cdigo de la Central de Distribucin ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta descripcin de  Central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacion  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;

WHEN dup_dist
THEN
    rst := 'ERROR: No es CENTRAL DE DISTRIBUCION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || dist_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ins
THEN
    rst := 'ERROR: No existe el tipo de inspeccion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_inspeccion: ' || n_inspeccion, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. altaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaCentralDistribucion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaCentralDistribucion;
/
CREATE OR REPLACE
PROCEDURE modificaCentralProduccion(
n_id			IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_clase		IN NUMBER,
n_tipo		IN NUMBER,
n_eMax		IN NUMBER,
n_eMin		IN NUMBER,
n_inspeccion	IN NUMBER,
n_fIns		IN VARCHAR2,
n_ubica		IN NUMBER,
n_obs 		IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaCentralProduccion
PROPSITO: gestiona la modificacin de una  Central de Produccin
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs, rst
INPUT:n_id,n_des,n_estado,n_fechaEstado,n_clase,n_tipo,n_eMax,n_eMin,n_inspeccion,n_fIns,n_ubica,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaCentralProduccion(1,'BCN_P4',1,to_char(sysdate,'DD/MM/YYYY'),2,3,20,10,1,to_char(sysdate,'DD/MM/YYYY'),500,null,rst);
******************************************************************************/
n_des_ins             VARCHAR2(50);
n_obs_ins             VARCHAR2(50);
id_test			INTEGER;
dist_test                       INTEGER;
des_test        		INTEGER;
clas_test        		INTEGER;
tipo_test        		INTEGER;
ubica_test        		INTEGER;
ins_test                        INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			EXCEPTION;
dup_dist                        EXCEPTION;
dup_central    		        EXCEPTION;
dup_ccentral    		EXCEPTION;
dup_tcentral    		EXCEPTION;
dup_ucentral    		EXCEPTION;
des_nulo  			EXCEPTION;
dup_ins                         EXCEPTION;

BEGIN
n_des_ins             := SUBSTR (n_des, 1, 50);
n_obs_ins             := SUBSTR (n_obs, 1, 50);
--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado IS NULL)
	OR (n_clase IS NULL)
	OR (n_tipo IS NULL)
	OR (n_eMax IS NULL)
	OR (n_eMin IS NULL)
	OR (n_inspeccion IS NULL)
	OR (n_fIns IS NULL)
	OR (n_ubica IS NULL)
THEN
RAISE des_nulo;
END IF;
/*
--verificamos si existe la descripcin de la  Central
SELECT COUNT (*)
INTO des_test
FROM centrales
WHERE centrales.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_central;
END IF;
*/
-- obtener el codigo de la central de Distribucion
SELECT id
INTO dist_test
FROM ccentral
WHERE
ccentral.des='PRODUCCION' OR 
ccentral.DES='PRODUCCIN';
IF (dist_test = 0)
THEN
RAISE dup_dist; 
END IF;

IF (n_clase <> dist_test)
THEN
RAISE dup_dist; -- no es central de Produccin
END IF;
--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


--verificamos exista la clase de central y que sea de Central de Distribucion

SELECT COUNT (*)
INTO clas_test
FROM ccentral
WHERE ccentral.id = n_clase;
IF (clas_test = 0)
THEN
RAISE dup_ccentral; 
END IF;

--verificamos si existe el tipo  de  Central
SELECT COUNT (*)
INTO tipo_test
FROM tcentral
WHERE tcentral.id = n_tipo;
IF (tipo_test = 0)  
THEN
RAISE dup_tcentral;  -- no existe el tipo de central
END IF;

--verificamos si existe la ubicacin de la  Central
SELECT COUNT (*)
INTO ubica_test
FROM ubicaciones
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)   
THEN
RAISE dup_ucentral; -- no existe la ubicacion
END IF;

--verificamos  que exista el tipo de inspeccion
SELECT COUNT (*)
INTO ins_test
FROM tInspeccion
WHERE tInspeccion.id = n_inspeccion;
IF (ins_test = 0)   
THEN
RAISE dup_ins; 
END IF;

--modificamos la Central de Produccin

UPDATE centrales
SET
des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado
,clase =n_clase
,tipo= n_tipo
,eMax= n_eMax
,eMin = n_eMin
,inspeccion = n_inspeccion
,fIns = n_fIns
,ubica = n_ubica
,obs =n_obs_ins
WHERE
centrales.id = n_id;


-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica Central ProduccinOK: ' || n_id); 
    rst:='OK, Modificacin Central Produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica CENTRAL: ' || n_des_ins
||', ' || 'Estado: ' || n_estado
||', ' || 'fechaEstado: ' || n_fechaEstado
||', ' || 'tipo: ' || n_tipo
||', ' || 'eMax: ' || n_eMax
||', ' || 'eMin: ' || n_eMin
||', ' || 'inspeccion: ' || n_inspeccion
||', ' || 'fecha inspeccin: ' || n_fIns
||', ' || 'ubicacin: ' || n_ubica
||', ' || 'observaciones: ' || n_obs_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el cdigo de la central de Produccin'||n_id;
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el cdigo de la Central de Distribucin ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_central
THEN
    rst := 'ERROR: Ya existe esta descripcin de  Central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: No existe la clase de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de central: ' || n_clase, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: No existe el tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de central: ' || n_tipo, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ucentral
THEN
    rst := 'ERROR: No existe la ubicacion  de la central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Ubicacin de central: ' || n_ubica, 'rst', rst, rst);
ROLLBACK;

WHEN dup_dist
THEN
    rst := 'ERROR: No es CENTRAL DE PRODUCCION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || dist_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ins
THEN
    rst := 'ERROR: No existe el tipo de inspeccion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_inspeccion: ' || n_inspeccion, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. altaCentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaCentralProduccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Descripcin de central: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaCentralProduccion;
/
create or replace PROCEDURE modificaClaseCentral(
n_id 	 IN NUMBER,
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaClaseCentral
PROPSITO: gestiona la modificacin de una Clase de Central
PARAMETERS: n_id,n_des, rst
INPUT: n_id,n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaClaseCentral(1,'DISTRIBUCIN', rst);
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
id_test        		        INTEGER;
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			        EXCEPTION;
dup_ccentral    		EXCEPTION;
desCCentral_nulo  	        EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--Verificamos si el codigo de la clase de central existe
SELECT COUNT (*)
INTO id_test
FROM ccentral
WHERE ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--verificamos si el campo CCENTRAL.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desCCentral_nulo;
END IF;
--verificamos si existe la descripcion de la central
/*
SELECT COUNT (*)
INTO des_test
FROM ccentral
WHERE des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_ccentral;
END IF;
*/
-- modificamos la  clase de central
UPDATE ccentral
SET
des = n_des_ins
WHERE
ccentral.id = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modificado  tipo de CCENTRAL: ' || n_id); 
    rst:='Ok, Modifica Tipo CCENTRAL  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe este cdigo localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ccentral
THEN
    rst := 'ERROR: Ya existe este nombre de   CCENTRAL';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desCCentral_nulo
THEN
    rst := 'ERROR: el tipo de CCENTRAL  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaClaseCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaClaseCentral;
/
CREATE OR REPLACE
PROCEDURE modificaClientes(
n_id                IN NUMBER,
n_estado            IN NUMBER,
n_tipo              IN NUMBER,
n_nifCif            IN VARCHAR2,
n_nom               IN VARCHAR2,
n_ape1              IN VARCHAR2,
n_ape2              IN VARCHAR2,
n_email             IN VARCHAR2,
n_tMovil            IN VARCHAR2,
n_ubica             IN NUMBER,
n_fechaAlta         IN VARCHAR2,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaClientes
PROPSITO: gestiona la modificacin  del estado de un cliente en la tabla clientes
PARAMETERS: n_id,n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,
n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod, rst
INPUT: n_id, n_estado, n_estado, n_tipo, n_nifCif, n_nombre, n_apellido1, n_apellido2,n_email, n_tMovil,n_ubica,n_fechaAlta,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaClientes(1,1,4,'43073208X', 'Alberto', 'Ramos', null, 'aramossa@uoc.edu','34671535222',1,'17/04/2012',null, rst);
******************************************************************************/

n_nifCif_ins          VARCHAR2(10 CHAR);
n_nom_ins             VARCHAR2(50 CHAR);
n_ape1_ins            VARCHAR2(50 CHAR);
n_ape2_ins            VARCHAR2(50 CHAR);
n_email_ins           VARCHAR2(50 CHAR);
n_tMovil_ins          VARCHAR2(11 CHAR);
n_ubica_ins           NUMBER;
n_fechaAlta_ins       VARCHAR2(11 CHAR);
n_fechaMod_ins        VARCHAR2(11 CHAR);
id_test			INTEGER;
estado_test         INTEGER;
tipo_test           INTEGER;
nifCif_test         INTEGER;
ubica_test          INTEGER;

err_msg             VARCHAR2(100);
dup_id		    EXCEPTION;
dup_estado          EXCEPTION;
dup_tipo            EXCEPTION;
dup_nifCif          EXCEPTION;
dup_ubica           EXCEPTION;

dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_nifCif_ins        := SUBSTR (n_nifCif, 1, 10);
n_nom_ins           := SUBSTR (n_nom, 1, 50);
n_ape1_ins          := SUBSTR (n_ape1, 1, 50);
n_ape2_ins          := SUBSTR (n_ape2, 1, 50);
n_email_ins         := SUBSTR (n_email, 1, 50);
n_tMovil_ins        := SUBSTR (n_tMovil, 1, 11);
n_fechaAlta_ins     := SUBSTR (n_fechaAlta, 1, 11);
n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos
IF (n_id			IS NULL)
OR (n_estado          IS NULL)
OR (n_tipo            IS NULL)
OR (n_nifCif_ins      IS NULL)
OR (n_nom_ins         IS NULL)
OR (n_ape1_ins        IS NULL)
OR (n_ubica           IS NULL)
OR (n_fechaAlta_ins   IS NULL)
THEN
RAISE dup_des;
END IF;

--Verificamos que  exista el ID del cliente 
SELECT COUNT (*)
INTO id_test
FROM clientes
WHERE clientes.ID = n_id;
IF (id_test =0 )
THEN
RAISE dup_id;
END IF;
-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--comprobar tipo cliente
SELECT COUNT (*)
INTO tipo_test
FROM TCLIENTE
WHERE tCliente.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;

--comprobar que la ubicacion exista 

SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.ID = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;

--verificamos que el nifCifel cliente  exista
SELECT COUNT (*)
INTO nifCif_test
FROM CLIENTES
WHERE nifCif = n_nifCif_ins;
IF (nifCif_test = 0)
THEN
RAISE dup_nifCif;
END IF;

-- insertamos el nuevo cliente
UPDATE  CLIENTES
SET
estado           = n_estado
,tipo           =  n_tipo
,nifCif  	=	n_nifCif
,nom		=	n_nom_ins 
,ape1		=	n_ape1_ins
,ape2		=	n_ape2_ins
,email	        =	  n_email_ins
,tMovil	        =	n_tMovil_ins
,ubica	        =	n_ubica
,fechaAlta	=	n_fechaAlta_ins
,fechaMod 	= 	n_fechaMod_ins
where 
clientes.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('cliente: ' || n_ape1_ins 
    ||','
    || n_ape2_ins
    ||','
    ||n_nom    
    ); 
    rst:='Ok, Modifica cliente  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado: '
|| n_estado 
|| ', '
||'n_tipo  : ' 
|| n_tipo
|| ', ' 
||'n_nifCif  : ' 
|| n_nifCif 
|| ', ' 
||'n_nom: ' 
|| n_nom 
|| ', ' 
||'n_ape1: '
|| n_ape1 
|| ', '
||'n_ape2: '
|| n_ape2
|| ', '
||'n_email: '
|| n_email 
|| ', ' 
||'n_tMovil: '
|| n_tMovil 
|| ', ' 
||'n_ubica: '
|| n_ubica 
|| ', ' 
||'n_fechaAlta: '
|| n_fechaAlta 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe  este id de clientes';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tipo
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_tipo : ' || n_tipo  ); 
     rst := 'ERROR: NO existe TIPO CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el TIPO CLIENTE ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_tipo : ' || n_tipo 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_nifCif
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_nifCif : ' || n_nifCif_ins  ); 
     rst := 'ERROR:  ya existe este NIF / CIF';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: ya  existe el NIF - CIFT ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_nifCif : ' || n_nifCif 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe la UBICACION';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la UBICACION ';
altaLog('Proc. altaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica : ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado: '
|| n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modifcaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_nifCif: '
|| n_nifCif 
, 'rst', rst, rst);
ROLLBACK;
END modificaClientes;
/
CREATE OR REPLACE
PROCEDURE modificaClientesEstado(
n_id                IN NUMBER,
n_estado            IN NUMBER,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaClientesEstado
PROPSITO: gestiona la modificacion  del estado de  un cliente en la tabla clientes
PARAMETERS: n_id,n_estado,n_fechaMod, rst
INPUT: n_id,n_estado,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaClientesEstado(3,1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/

n_fechaMod_ins      VARCHAR2(11 CHAR);

id_test             INTEGER;
estado_test         INTEGER;
err_msg             VARCHAR2(100);
dup_id              EXCEPTION;
dup_estado          EXCEPTION;
dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas

n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_id              IS NULL)
OR (n_estado          IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM CLIENTES
WHERE clientes.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- modificamos el cliente
UPDATE CLIENTES
SET
estado      = n_estado,
fechaMod    = n_fechaMod_ins
WHERE
clientes.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id: ' || n_id ); 
    rst:='Ok, Modificacion de estado de cliente realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
|| ', '
||'n_estado: '
|| n_estado 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el CODIGO DEL CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  CODIGO DEL CLIENTE ';
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaClientesEstado', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;
END modificaClientesEstado;
/
CREATE OR REPLACE
PROCEDURE modificaConsumos(
n_id		    IN NUMBER,	
n_contador          IN NUMBER,
n_anyo     	    IN NUMBER,
n_mes               IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaConsumos
PROPSITO: gestiona el alta en la tabla de consumos
PARAMETERS:  n_id,n_contador,n_anyo, n_mes,n_consumo, rst
INPUT:   n_id,n_contador, n_anyo,n_mes,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaConsumos(1,1,2012,2,12 rst);
******************************************************************************/
id_test			INTEGER;
contador_test           INTEGER;
err_msg                 VARCHAR2 (100);
dup_id			EXCEPTION;
dup_contador            EXCEPTION;
dup_null                EXCEPTION;

BEGIN

--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_anyo              IS NULL)
OR (n_mes               IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;
--Verificamos exista el  el id de consumos 
SELECT COUNT (*)
INTO id_test
FROM consumos
WHERE consumos.ID = n_id;
IF (contador_test = 0)
THEN
RAISE dup_id;
END IF;

--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;


-- modificamos el registro de consumos
UPDATE  consumos
SET
contador  	= n_contador
,anyo 	        = n_anyo
,mes 		= n_mes
,consumo 	= n_consumo
Where
consumos.id = n_id;
-- Fin de las operaciones
--rst := 'OK';
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Consumo modificado: ' || n_contador 
    ||','|| n_anyo 
    ||','||n_mes  
    ||','||n_consumo
    ); 
    rst:='Ok, modificaConsumos   realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

altaLog('Proc. modificaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el id de Consumos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
|| n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
|| n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
|| n_id
||' n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaConsumos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id'
|| n_id
||' n_contador: '
||n_contador
||' n_anyo: '
|| n_anyo
||' n_mes: '
||n_mes
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END modificaConsumos;
/
CREATE OR REPLACE
PROCEDURE modificaContadores(
n_id			IN NUMBER,
n_modelo         	IN NUMBER,
n_ubica         	IN NUMBER,
n_estado         	IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
n_numSerie         	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaContadores
PROPSITO: gestiona la modificacin  de un contador en la tabla contadores
PARAMETERS: n_id,n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie,rst
INPUT: n_id,n_modelo, n_ubica, n_estado, n_fechaEstado, n_numSerie
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaContadores(1,1,1,1,to_char(sysdate,'DD/MM/YYYY'), 'n/s_1', rst);
******************************************************************************/
n_fechaEstado_ins       VARCHAR2(11 CHAR);
n_numSerie_ins          VARCHAR2(20);
id_test                 INTEGER;
modelo_test             INTEGER;
ubica_test              INTEGER;
estado_test             INTEGER;
err_msg                 VARCHAR2(100);
dup_id                  EXCEPTION;
dup_modelo            EXCEPTION;
dup_ubica               EXCEPTION;
dup_estado              EXCEPTION;
dup_des               EXCEPTION;

BEGIN


n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 
n_numSerie_ins      := SUBSTR(n_numSerie, 1, 20);


--verificamos que los campos no nulos no sean nulos
IF (n_id 			IS NULL)
OR (n_modelo          IS NULL)
OR (n_ubica           IS NULL)
OR (n_estado          IS NULL)
OR (n_fechaEstado_ins IS NULL)
OR (n_numSerie_ins    IS NULL)
THEN
RAISE dup_des;
END IF;



--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM contadores
WHERE contadores.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--comprobar que existe el modelo
SELECT COUNT (*)
INTO modelo_test
FROM MODELOS
WHERE ID = n_modelo;
IF (modelo_test = 0)
THEN
RAISE dup_modelo;
END IF;
--comprobar que existe la  ubicacion
SELECT COUNT (*)
INTO ubica_test
FROM UBICACIONES
WHERE ubicaciones.id = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

--modificamos el contador
UPDATE contadores
SET
modelo = n_modelo
,ubica = n_ubica
,estado = n_estado
,fechaEstado = n_fechaEstado_ins
,numSerie= n_numSerie_ins
WHERE
contadores.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'n_modelo: ' 
|| n_modelo 
|| ', ' 
||'n_ubica  : '
|| n_ubica
|| ', ' 
||'n_estado  : '
|| n_estado
|| ', ' 
||'n_fechaEstado: '
|| n_fechaEstado_ins
|| ', ' 
||'n_numSerie: '
|| n_numSerie_ins); 
    rst:='Ok, Modifica contador   realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' 
|| n_modelo 
|| ', ' 
||'n_ubica  : '
|| n_ubica
|| ', ' 
||'n_estado  : '
|| n_estado
|| ', ' 
||'n_fechaEstado: '
|| n_fechaEstado_ins
|| ', ' 
||'n_numSerie: '
|| n_numSerie_ins
, 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el Cdigo del contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  Cdigo del contador ';
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_modelo
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_modelo : ' || n_modelo  ); 
     rst := 'ERROR: No existe Modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo: ' || n_modelo  
, 'rst', rst, rst);

WHEN dup_ubica
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_ubica : ' || n_ubica  ); 
     rst := 'ERROR: NO existe ubicacin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_ubica: ' || n_ubica 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: No existe Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado ' || n_estado
|| ', '
||'n_fechaEstado: ' || n_fechaEstado 
, 'rst', rst, rst);

ROLLBACK;
WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_modelo ' || n_modelo || ', '
||'n_ubica  : ' || n_ubica || ', ' 
|| 'n_estado  : ' || n_estado || ', '
||'n_fechaEstado: ' || n_fechaEstado|| ', '
||'n_numSerie: ' || n_numSerie
, 'rst', rst, rst);
ROLLBACK;
END modificaContadores;
/
CREATE OR REPLACE
PROCEDURE modificaContratos(
n_id				IN NUMBER,
n_cliente           	IN NUMBER,
n_contador          	IN NUMBER,
n_estado            	IN NUMBER,
n_fechaEstado       	IN VARCHAR2,
n_pContrato         	IN NUMBER,
n_obs             	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaContratos
PROPSITO: gestiona la modificacin de un contraato en la tabla contratos
PARAMETERS: n_id,n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs, rst
INPUT: n_id,n_cliente, n_contador, n_estado, n_fechaEstado, n_pContrato, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaContratos(1,1,1,1,to_char(sysdate,'DD/MM/YYYY'),30,'obs_contrato', rst);
******************************************************************************/

n_fechaEstado_ins     	VARCHAR2(11 CHAR);
n_obs_ins             	VARCHAR2(50 CHAR);
id_test				INTEGER;
cliente_test			INTEGER;
contador_test			INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);

n_anterior    NUMBER;
n_actual      NUMBER;
n_tipo        NUMBER;
n_consumo     NUMBER;
dup_cliente			EXCEPTION;
dup_contador	        	EXCEPTION;
dup_estado				EXCEPTION;
dup_des                 	EXCEPTION;
dup_id				EXCEPTION;

BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  		:= SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins               	:= SUBSTR (n_obs, 1, 50);

-- inicializo contadores de lecturas y consumos 
n_anterior := 0;
n_actual   := 0; 
n_tipo     := 1;
n_consumo  := 0;
--verificamos que los campos no nulos no sean nulos

IF (n_id	        		IS NULL)
OR (n_cliente        		IS NULL)
OR (n_contador       		IS NULL)
OR (n_estado      		IS NULL)
OR (n_fechaEstado_ins       IS NULL)
OR (n_pContrato        	IS NULL)
THEN
RAISE dup_des;
END IF;

--Verificamos que que exista el id del contrato 
SELECT COUNT (*)
INTO id_test
FROM contratos
WHERE contratos.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--comprobar que exista el  cliente
SELECT COUNT (*)
INTO cliente_test
FROM CLIENTES
WHERE CLIENTES.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

-- comprobar que exista el contador
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE contadores.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;


--comprobar que exista el estado 

SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;



-- modificamos el contrato
UPDATE contratos
SET
cliente 		= n_cliente
,contador 		= n_contador
,estado 		= n_estado
,fechaEstado 	= n_fechaEstado_ins
,pContrato 	= n_pContrato
,obs 			= n_fechaEstado_ins
WHERE
contratos.id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
    ); 
    rst:='Ok, Modifica contrato  con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
COMMIT;

-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el id del Contrato';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaContrato', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_cliente
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_cliente : ' || n_cliente  ); 
     rst := 'ERROR: NO existe el CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el CLIENTE ';
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_cliente  : ' || n_cliente
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_contador: ' || n_contador  ); 
     rst := 'ERROR:  NO  existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el CONTADOR';
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: ' || n_contador
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato 
||'n_obs: '
|| n_obs 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
||' n_cliente: ' || n_cliente
|| ', '
||'n_contador  : ' 
|| n_contador  
|| ', ' 
||'n_estado  : ' 
|| n_estado  
|| ', ' 
||'n_fechaEstado: ' 
|| n_fechaEstado
|| ', ' 
||'n_pContrato: '
|| n_pContrato
||'n_obs: '
|| n_obs
, 'rst', rst, rst);
ROLLBACK;
END modificaContratos;
/
CREATE OR REPLACE
PROCEDURE modificaEmisionCentral(
n_id  IN NUMBER,
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaEmisionCentral
PROPSITO: gestiona la modificacin  de un tipo de emisin o especificidad de la  Central
PARAMETERS: n_id,n_des, rst
INPUT: n_id,n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido sxito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaEmisionCentral(1,'CO2', rst)
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
id_test			        INTEGER;
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_id                          EXCEPTION;
dup_ecentral    		EXCEPTION;
desecentral_nulo  	        EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo ECentral.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE desECentral_nulo;
END IF;
--verificamos que exista el id de estado
SELECT COUNT (*)
INTO id_test
FROM ECentral
WHERE des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_id;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM ECentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_ECentral;
END IF;
--modificamos la emisin de la eCentral
UPDATE ecentral
SET
des =	n_des_ins	
WHERE
eCentral.id = n_id;

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('Modifica ECentral:' 
||' n_id'
||n_id
||' n_des'
|| n_des_ins);
    rst:='Ok, Modifica Tipo ECentral  realizado con xito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ECentral:'
 ||' n_id'
||n_id
||' n_des'
|| n_des
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe este  id de  ECentral';
    DBMS_OUTPUT.PUT_LINE('n_id'||n_id||' n_des'||n_des);  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ECentral: '
||' n_id'
||n_id
||' n_des'
|| n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN desECentral_nulo
THEN
    rst := 'ERROR: el tipo de ECentral  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('Modifica ECentral:' 
||' n_id'
||n_id
||' n_des'
|| n_des);  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ECentral:'
||' n_id'
||n_id
||' n_des'
|| n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_ECentral
THEN
    rst := 'ERROR: Ya existe este tipo de  ECentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ECentral:'
||' n_id'
||n_id
||' n_des'
|| n_des
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaEmisionCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ECentral:'
||' n_id'
||n_id
||' n_des'
|| n_des
, 'rst', rst, rst);
ROLLBACK;
END modificaEmisionCentral;
/
CREATE OR REPLACE
PROCEDURE modificaEmpresa(
n_id		IN VARCHAR2,
n_cif		IN VARCHAR2,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaEmpresa
PROPSITO: gestiona la modificacin de una EMPRESA
PARAMETERS: n_id,n_cif,n_des,n_estado,n_fechaEstado, rst
INPUT: n_cif,n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaEmpresa(1's121214','empresa3',5,'01/05/2012',rst);
******************************************************************************/
n_des_ins       	VARCHAR2 (50);
n_fechaEstado_ins    	VARCHAR2 (11);
id_test			INTEGER;
estado_test		INTEGER;
err_msg         	VARCHAR2 (100);
dup_id			EXCEPTION;
dup_estado		EXCEPTION;
des_nulo  		EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);
--verificamos si el hay campos nulos
IF (n_id	IS NULL)
OR (n_cif       IS NULL)
OR (n_des_ins   IS NULL)
OR (n_estado    IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE des_nulo;
END IF;
--verificamos si existe el estado  de la empresa
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- modificamos la  empresa
UPDATE empresas
SET
cif = n_cif
,des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado_ins
WHERE
empresas.id = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Modifica EMPRESA :'
|| n_des
|| 'cif: '
|| n_cif); 
    rst:='Ok, Modificacin  EMPRESA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica EMPRESA :'
|| n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe el id de Empesa';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO existe este ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica EMPRESA :' || n_des
|| 'cif: '
|| n_cif
|| 'estado'
|| n_estado
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta EMPRESA :' || n_des
|| 'cif: '
|| n_cif
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Empresa : ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaEmpresa;
/
CREATE OR REPLACE
PROCEDURE modificaEstadoCentral(
n_id		IN NUMBER,
n_estado 		IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaEstadoCentral
PROPSITO: gestiona la modificacin  del estado de  Central
PARAMETERS: n_id,n_estado, rst
INPUT: n_id,n_estado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaEstadoCentral(1,2,rst);
******************************************************************************/

id_test				INTEGER;
err_msg 	        		VARCHAR2 (100);
dup_central_id 	           EXCEPTION;
des_nulo  			EXCEPTION;

BEGIN

--verificamos que los campos nulos no sean nulos
IF   		(n_id IS NULL)
	OR 	(n_estado IS NULL)
THEN
RAISE des_nulo;
END IF;


-- verificamos que la Central a modificar exista

SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_central_id;
END IF;


-- modificamos la central cambio de estado
UPDATE centrales
SET
estado 	= n_estado                       
WHERE
centrales.id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('CAMBIO DE ESTADO OK: ' || n_estado); 
    rst:='OK, CAMBIO DE ESTADO CENTRAL ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaEstadoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_estado: '
|| n_estado
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_central_id
THEN
    rst := 'ERROR: NO existe esta  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEstadoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_estado: '
|| n_estado
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaEstadoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. modificaEstadoCentral: ' 
|| 'n_id: '
||  n_id
|| ' n_estad0: '
||  n_estado
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaEstadoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. modificaEstadoCentral ' || n_id, 'rst', rst, rst);
ROLLBACK;
END modificaEstadoCentral;
/
CREATE OR REPLACE
PROCEDURE modificaEstados(
n_id  IN NUMBER,
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaEstados
PROPSITO: gestiona la modificacin de un estado
PARAMETERS: n_id,n_des, rst
INPUT: n_id,n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaEstados('ALTA', rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_estados     EXCEPTION;
dup_id          EXCEPTION;
desEstado_nulo  EXCEPTION;

BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo estados.des es nulo
IF (n_id		 IS NULL)
OR (n_des_ins 	IS NULL)
 THEN
RAISE desEstado_nulo;
END IF;
SELECT COUNT(*)
INTO id_test
FROM estados
WHERE estados.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM ESTADOS
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_estados;
END IF;

-- modificamos la tabla de  ESTADOS
UPDATE estados
SET
id	= n_id,
des  = n_des
WHERE 
estados.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica el  tipo de ESTADOS: ' || n_des_ins); 
    rst:='Ok, Modifica Tipo ESTADOS  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaEstados', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe el id del Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEstados', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estados
THEN
    rst := 'ERROR: Ya existe este tipo de  ESTADOS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaEstados', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desEstado_nulo
THEN
    rst := 'ERROR: el tipo de ESTADOS  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaEstados', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaEstados', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de ESTADOS: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaEstados;
/
CREATE OR REPLACE
PROCEDURE modificaLecturas(
n_id		    IN NUMBER,
n_contador          IN NUMBER,
n_fechaLectura      IN VARCHAR2,
n_tipo              IN NUMBER,
n_anterior          IN NUMBER,
n_actual            IN NUMBER,
n_consumo           IN NUMBER,
rst                 OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaLecturas
PROPSITO: gestiona el alta en la tabla de Lecturas
PARAMETERS:  n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo, rst
INPUT:   n_contador, n_fechaLectura,n_tipo,n_anterior,n_actual,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaLecturas(1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,1, rst)
******************************************************************************/
n_fechaLectura_ins      VARCHAR2 ( 11 CHAR);

id_test		        INTEGER;
contador_test           INTEGER;
tipo_test               INTEGER;
err_msg                 VARCHAR2 (100);
dup_id		        EXCEPTION;
dup_contador            EXCEPTION;
dup_tipo                EXCEPTION;
dup_null                EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_fechaLectura_ins       := SUBSTR (n_fechaLectura, 1, 50);
--comprobamos campos no nulos que no esten vacios
IF (n_contador          IS NULL)
OR (n_fechaLectura_ins  IS NULL)
OR (n_tipo              IS NULL)
OR (n_anterior          IS NULL)
OR (n_actual            IS NULL)
OR (n_consumo           IS NULL)
THEN
RAISE dup_null;
END IF;


--Verificamos exista la lectura 
SELECT COUNT (*)
INTO id_test
FROM LECTURAS
WHERE lecturas.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--verificamos que  exista el tipo de lectura
SELECT COUNT (*)
INTO tipo_test
FROM TLECTURA
WHERE tLectura.ID = n_tipo;
IF (tipo_test = 0)
THEN
RAISE dup_tipo;
END IF;



-- modificamos la tupla de lecturas
UPDATE lecturas
SET
lecturas.CONTADOR 	= n_contador,
lecturas.FECHALECTURA 	= n_fechaLectura_ins,
lecturas.TIPO		= n_tipo,
lecturas.ANTERIOR	= n_anterior,
lecturas.ACTUAL		= n_actual,
lecturas.CONSUMO	= n_consumo
WHERE
lecturas.ID = n_id;

-- Fin de las operaciones
rst := 'OK';

altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;



WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_tipo
THEN
    rst := 'ERROR: NO este  tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaLecturas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
||n_id
||' n_contador: '
||n_contador
||' n_fechaLectura: '
|| n_fechaLectura
||' n_tipo: '
||n_tipo
||' n_anterior: '
|| n_anterior
||' n_actual: '
||n_actual
||' n_consumo: '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END modificaLecturas;
/
CREATE OR REPLACE
PROCEDURE modificaLinea(
n_id			IN NUMBER,
n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_cMax                  IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaLinea
PROPSITO: gestiona la modificin de una linea
PARAMETERS: n_id,n_estado, n_fechaEstado, n_cMax, n_obs, rst
INPUT: n_id,n_estado, n_fechaEstado, n_cMax, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: modificaLinea(1,1,'10/05/2012',10000,null,rst);
******************************************************************************/

id_test		INTEGER;
n_obs_ins       VARCHAR2 (50);
err_msg         VARCHAR2 (100);
dup_id		EXCEPTION;
des_nulo        EXCEPTION;

BEGIN
-- compobar longitud de cadenas
n_obs_ins := SUBSTR (n_obs, 1, 50);

--verificamos si hay campos no nulos: nulos
        IF   (n_id          IS NULL)
        OR   (n_estado      IS NULL)
        OR   (n_fechaEstado IS NULL)
        OR   (n_cMax        IS NULL)
        THEN
        RAISE des_nulo;
        END IF;

--Verificamos que que exista el id de la linea 
SELECT COUNT (*)
INTO id_test
FROM linea
WHERE linea.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
-- hacemos la modificacin de la lnea
UPDATE linea
SET
 estado =  n_estado
,fechaEstado = n_fechaEstado
,cMax =n_cMax
,obs = n_obs_ins
WHERE  linea.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica linea: ' 
    || n_id
    ||' n_estado'
    || n_estado
    || 'fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax)    ; 
    rst:='OK, Modifica linea  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'modificaLinea:' 
    || n_id
    ||' n_estado'
    || n_estado
    || ' fecha: '
    || n_fechaEstado
    || ' capacidad mxima: '
    || n_cMax 
, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe la lnea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'fecha  linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'fecha  de linea: ' || n_fechaEstado, 'rst', rst, rst);
ROLLBACK;
END modificaLinea;
/
CREATE OR REPLACE
PROCEDURE modificaLineas(

n_id			IN NUMBER,
n_estado		IN NUMBER,
n_fechaEstado           IN VARCHAR2,
n_linea                 IN NUMBER,
n_c1                    IN NUMBER,
n_c2                    IN NUMBER,
n_obs			IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaLineas
PROPSITO: gestiona la modificacin   de las lineas conectadas
PARAMETERS: n_id,n_estado, n_fechaEstado,n_linea, n_c1,n_c2, n_obs, rst
INPUT: n_id,n_estado, n_fechaEstado, n_linea, n_c1, n_c2, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaLineas(1,1,to_char(sysdate,'DD/MM/YYYY'),1,1,2,NULL,rst);
******************************************************************************/
id_test		      INTEGER;
n_obs_ins             VARCHAR2 (50);
n_fechaEstado_ins     VARCHAR2(11);
linea_test            INTEGER;
estado_test           INTEGER;
c1_test               INTEGER;  
c2_test               INTEGER;
err_msg               VARCHAR2 (100);
dup_id		      EXCEPTION;
dup_estado            EXCEPTION;
dup_linea             EXCEPTION;
dup_c1                EXCEPTION;
dup_c2                EXCEPTION;
dup_c1_c2             EXCEPTION;
des_null              EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);
n_obs_ins := SUBSTR (n_obs, 1, 50);
--verificamos si hay campos no nulos: nulos
IF 	     (n_id              IS NULL)
	  OR (n_estado          IS NULL)
          OR (n_fechaEstado_ins IS NULL)
          OR (n_linea           IS NULL)
          OR (n_c1              IS NULL)
          OR (n_c2              IS NULL)
THEN
RAISE des_null;
END IF;

--Verificamos que no exista el  codigo del pais 
SELECT COUNT (*)
INTO id_test
FROM lineas
WHERE lineas.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--comprobar existe el estado
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
--comprobar existe la linea
SELECT COUNT (*)
INTO linea_test
FROM LINEA
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
--comprobar existe la central en c1
SELECT COUNT (*)
INTO c1_test
FROM CENTRALES
WHERE centrales.ID = n_c1;
IF (c1_test = 0)
THEN
RAISE dup_c1;
END IF;
--comprobar existe la central o contador en c2
SELECT COUNT (*)
INTO c2_test
FROM CENTRALES, CONTADORES
WHERE centrales.id = n_c2
or contadores.id = n_c2;
IF (c2_test = 0)
THEN
RAISE dup_c2;
END IF;
-- comprobar que no conectamos dos iguales
IF ( n_c1 = n_c2 )
THEN
RAISE dup_c1_c2;
END IF;
-- insertamos el alta de la linea de conexion
UPDATE  lineas
SET
estado        = n_estado
,fechaEstado  = n_fechaEstado_ins
,linea        = n_linea
,c1           = n_c1
,c2           = n_c2
,obs          = n_obs_ins
WHERE 
lineas.id = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Modifica  lineas: '
    || ' n_id'
    || n_id
    ||' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins
    ); 
    rst:='OK, Modificacin  de lneas  realizada con xito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_id: '
    || n_id
    || ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe el id de Lneas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
, 'rst', rst, rst);
ROLLBACK;
WHEN des_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_linea
THEN
    rst := 'ERROR: NO existe LINEA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1
THEN
    rst := 'ERROR: No es una Central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c2
THEN
    rst := 'ERROR: No es Central ni Contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_c1_c2
THEN
    rst := 'ERROR: No se pueden  conectar: conexiones iguales';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     ' n_estado: '
    || n_estado
    ||' n_fechaEsatado: '
    || n_fechaEstado_ins
    ||' n_linea: '
    ||n_linea
    ||' n_c1: '
    ||n_c1
    ||' n_c2'
    || n_c2
     ||' n_obs '
    ||n_obs_ins 
    , 'rst', rst, rst);
ROLLBACK;
END modificaLineas;
/
create or replace PROCEDURE altaUbicaciones (
 
n_via               IN NUMBER,
n_dir               IN VARCHAR2,
n_num               IN VARCHAR2,
n_pis               IN VARCHAR2,
n_pta               IN VARCHAR2,
n_codigoPostal      IN VARCHAR,
n_localidad          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaUbicaciones
PROPSITO: gestiona el alta de una Ubicacion en la tabla ubicaciones
PARAMETERS: n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad, rst
INPUT: n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaUbicacion(1,'del pez','2','1r','2a','08330',1, rst);
******************************************************************************/
n_dir_ins           VARCHAR2 (50);
n_num_ins           VARCHAR2 (5);
n_pis_ins           VARCHAR2 (5);
n_pta_ins           VARCHAR2 (10);
n_codigoPostal_ins  VARCHAR  (10);

via_test          INTEGER;
localidad_test    INTEGER;
dup_via           EXCEPTION;
dup_localidad     EXCEPTION;
err_msg           VARCHAR2 (100);
des_nulo          EXCEPTION;

BEGIN
-- controlar la longitud de las entradas
n_dir_ins               := SUBSTR (n_dir, 1, 50);
n_num_ins               := SUBSTR (n_num, 1, 5);
n_pis_ins               := SUBSTR (n_pis, 1, 5);
n_pta_ins               := SUBSTR (n_pta, 1, 10);
n_codigoPostal_ins      := SUBSTR (n_codigoPostal, 1, 10);


--verificamos que los campos no nulos no sean nulos
IF (n_via             IS NULL)
OR (n_dir             IS NULL)
OR (n_num             IS NULL)
OR (n_codigoPostal    IS NULL)
OR (n_localidad       IS NULL)
THEN
RAISE des_nulo;
END IF;
--Verificamos que exista la via
SELECT COUNT (*)
INTO via_test
FROM via
WHERE via.id = n_via;
IF (via_test = 0)
THEN
RAISE dup_via;
END IF;


--verificamos que eixsta la localidad

SELECT COUNT (*)
INTO localidad_test
FROM localidad
WHERE localidad.id = n_localidad;
IF (localidad_test = 0)
THEN
RAISE dup_localidad;
END IF;

-- insertamos la nueva ubicacion
INSERT INTO ubicaciones(
via
,dir
,num
,pis
,pta
,codigoPostal
,localidad)
VALUES (n_via
,n_dir_ins
,n_num_ins
,n_pis_ins
,n_pta_ins
,n_codigoPostal_ins
,n_localidad);
-- Fin de las operaciones
rst := 'OK';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE(
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
);  
        DBMS_OUTPUT.PUT_LINE(rst); 
        
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_via
THEN
      rst := 'ERROR: No existe este cdigo de via';
      DBMS_OUTPUT.ENABLE;    
      DBMS_OUTPUT.PUT_LINE('');  
      DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_localidad
THEN
    rst := 'ERROR: NO  existe localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
        rst := 'ERROR: hay campos nulos que no tienen datos';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');  
        DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Alta ubicacin:'
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc: altaUbicacion: ' 
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
END altaUbicaciones;
/
CREATE OR REPLACE
PROCEDURE modificaModelos(
n_id                    IN NUMBER,
n_des            	IN VARCHAR2,
n_anyoFabrica        	IN VARCHAR2,
n_empresa            	IN NUMBER,
n_estado             	IN NUMBER,
n_fechaEstado		IN VARCHAR2,
n_obs              	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaModelos
PROPSITO: gestiona la modificacin de un modelo en la tabla modelos
PARAMETERS: n_id,n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs,rst;
INPUT: n_id,n_des, n_anyoFabrica, n_empresa, n_estado, n_fechaEstado, n_obs
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaModelos(1,'Modelo_1','2012',1,1,to_char(sysdate,'DD/MM/YYYY'),'obs_modelo_1', rst);
******************************************************************************/

n_des_ins             VARCHAR2(50 CHAR);
n_anyoFabrica_ins     VARCHAR2(4  CHAR);
n_fechaEstado_ins      VARCHAR2(11 CHAR);
n_obs_ins             VARCHAR2(50 CHAR);
id_test			INTEGER;
empresa_test		INTEGER;
estado_test         INTEGER;
err_msg             VARCHAR2(100);
dup_id			EXCEPTION;
dup_empresa          EXCEPTION;
dup_estado            EXCEPTION;
dup_des             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_des_ins        		:= SUBSTR (n_des,1,10);
n_anyoFabrica_ins         	:= SUBSTR (n_anyoFabrica,1,4);
n_fechaEstado_ins     		:= SUBSTR (n_fechaEstado,1,11);
n_obs_ins      			:= SUBSTR (n_obs,1,50);


--verificamos que los campos no nulos no sean nulos
IF (n_id		      	IS NULL)
OR (n_des		      	IS NULL)
OR (n_anyoFabrica_ins      IS NULL)
OR (n_empresa         	IS NULL)
OR (n_estado          	IS NULL)
OR (n_fechaEstado_ins   	IS NULL)
THEN
RAISE dup_des;
END IF;

--comprobar que exista la empresa
SELECT COUNT (*)
INTO empresa_test
FROM EMPRESAS
WHERE empresas.id = n_empresa;
IF (empresa_test = 0)
THEN
RAISE dup_empresa;
END IF;

-- comprobar estado cliente
SELECT COUNT (*)
INTO estado_test
FROM ESTADOS
WHERE estados.ID = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;

-- modificamos el modelo
UPDATE modelos
SET
des 			= n_des_ins,
anyoFabrica 	= n_anyoFabrica_ins,
empresa 		= n_empresa,
estado 		= n_Estado,
fechaEstado 	= n_fechaEstado_ins,
obs 			= n_obs_ins
WHERE 
modelos.id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
          'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs    
    ); 
    rst:='Ok, Modifica Modelo   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_des
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs  
        , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	' n_estado: '
        ||n_estado
	, 'rst', rst, rst);
ROLLBACK;


WHEN dup_empresa
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_empresa : ' || n_empresa  ); 
     rst := 'ERROR: NO existe la EMPRESA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la EMPRESA ';
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_empresa: '
        ||n_empresa
	, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        'n_des: ' 
	||n_des_ins 
        ||' n_anyoFabrica: '
        ||n_anyoFabrica_ins
        ||' n_empresa: '
        ||n_empresa
	||' n_estado: '
        ||n_estado
	||' n_fechaEstado: '
        ||n_fechaEstado_ins
	||' n_obs: '
        ||n_obs 
        , 'rst', rst, rst);
ROLLBACK;
END modificaModelos;
/
CREATE OR REPLACE
PROCEDURE modificaPais(
n_id    IN NUMBER,
n_des   IN VARCHAR2,
n_cod   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaPais
PROPSITO: gestiona la modificacin de un pais en la tabla pais
PARAMETERS:  n_id, n_des,,n_cod, rst
INPUT:  n_id, n_des, n_cod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaPais(1,'Espaa','ES', rst);
******************************************************************************/
n_des_ins         VARCHAR2 ( 50 CHAR);
n_cod_ins         VARCHAR2  ( 5 CHAR );
id_test           INTEGER;
des_test          INTEGER;
cod_test          INTEGER;
err_msg           VARCHAR2 (100);
dup_id            EXCEPTION;
dup_des           EXCEPTION;
dup_cod           EXCEPTION;
dup_null          EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_des_ins       := SUBSTR (n_des, 1, 50);
n_cod_ins       := SUBSTR (n_cod, 1, 5);
--comprobamos campos no nulos que no esten vacios
IF (n_id  IS NULL)
OR (n_des IS NULL)
OR (n_cod IS NULL)
THEN
RAISE dup_null;
END IF;
--Verificamos que no exista el  codigo del pais 
SELECT COUNT (*)
INTO id_test
FROM PAIS
WHERE pais.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--verificamos que no exista la descripcion del PAIS
SELECT COUNT (*)
INTO des_test
FROM PAIS
WHERE pais.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;
-- modificamos el  PAIS
UPDATE PAIS
SET
des = n_des_ins,
cod = n_cod_ins
Where 
id = n_id;

--rst := 'OK';
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica Pais ' || n_des_ins); 
    rst:='Ok, Modifica Pais con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

altaLog('Proc. modificaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: ' 
|| n_id
||' n_des: '
|| n_des
||' n_cod: '
|| n_cod
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: NO existe este id de PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe este PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_des: ' || n_des
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
||' n_cod'
||n_cod
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
||' n_cod'
||n_cod
, 'rst', rst, rst);
ROLLBACK;
END modificaPais;
/
CREATE OR REPLACE
PROCEDURE modificaProvincia(
n_id      IN NUMBER,
n_des     IN VARCHAR2,
n_pais    IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaProvincia
PROPSITO: gestiona la modificacin de una provincia en la tabla provincia
PARAMETERS: n_id, n_des, n_pais rst
INPUT: n_id, n_des, n_pais
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaProvincia(2,'BARCELONA',1,rst); 
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test         INTEGER;
pais_test       INTEGER;

err_msg         VARCHAR2 (100);
dup_id          EXCEPTION;
dup_des         EXCEPTION;
dup_pais        EXCEPTION;

dup_null        EXCEPTION;

BEGIN
n_des_ins       := SUBSTR (n_des, 1, 50);

--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL) OR (n_des IS NULL) OR (n_pais IS NULL)  THEN
RAISE dup_null;
END IF;
--Verificamos si el codigo de la provincia existe
SELECT COUNT (*)
INTO id_test
FROM PROVINCIA
WHERE provincia.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;



pais_test:=0;
--verificamos si existe el PAIS
SELECT COUNT (*)
INTO pais_test
FROM PAIS
WHERE pais.ID = n_pais;
IF (pais_test = 0)
THEN
RAISE dup_pais;
END IF;

--modificamos la provincia

UPDATE provincia
SET
des = n_des_ins,
pais = n_pais
WHERE
id = n_id;

rst := 'OK';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE('Modificacin de la provincia '|| n_id); 
DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: Ya existe este cdigo PROVINCIA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_pais
THEN
    rst := 'ERROR: NO  existe PAIS';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_pais: ' || n_pais
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos que NO tienen datos';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaProvincia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:' || n_id
|| 'n_des'
|| n_des_ins
|| 'n_pais'
|| n_pais
, 'rst', rst, rst);
ROLLBACK;
END modificaProvincia;
/
create or replace PROCEDURE modificaTipoCentral(
n_id			IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 		IN NUMBER,
n_fechaEstado	IN VARCHAR2,
n_emision		IN NUMBER,
n_cantidad		IN NUMBER,
n_obs			IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaTipoCentral
PROPSITO: gestiona la modificacin de un tipo   de Central
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado,n_emision,n_cantidad, n_obs, rst
INPUT: n_id,n_des,n_estado,n_fechaEstado,n_emision,n_cantidad,n_obs	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaTipoCentral('NUCLEAR',1,'01/05/2012',1,20,NULL,rst);
******************************************************************************/
n_des_ins       		VARCHAR2 (50);
id_test			INTEGER;
des_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			EXCEPTION;
dup_tcentral    		EXCEPTION;
desTCentral_nulo  	EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo tcentral.des es nulo
IF ( n_id IS NULL)
OR  (n_des_ins IS NULL) THEN
RAISE desTCentral_nulo;
END IF;

--Verificamos si el codigo del tipo  de central existe
SELECT COUNT (*)
INTO id_test
FROM tcentral
WHERE ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--verificamos si existe el tipo de estado
SELECT COUNT (*)
INTO des_test
FROM tcentral
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_tcentral;
END IF;
-- insertamos el nuevo tipo de tcentral
INSERT INTO tcentral
(des,estado,fechaEstado,emision,cantidad,obs)
VALUES
(n_des_ins,n_estado,n_fechaEstado,n_emision,n_cantidad,n_obs);


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica  de tipo de tcentral: ' || n_des_ins); 
    rst:='Ok, Modifica  Tipo tcentral  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe este cdigo de tipo de central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de CCENTRAL: ' || n_des
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_tcentral
THEN
    rst := 'ERROR: Ya existe este tipo de  tcentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN desTCentral_nulo
THEN
    rst := 'ERROR: el tipo de tcentral  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaTipoCentral;
/
create or replace PROCEDURE modificaTipoCliente(
n_id  IN VARCHAR2,
n_des IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaTipoCliente
PROPSITO: gestiona la modificacin de un tipo de cliente
PARAMETERS: n_id,n_des, rst
INPUT: n_id,n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaTipoCliente('PARTICULAR', rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test		INTEGER;
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_id		EXCEPTION;
dup_des      EXCEPTION;
des_nulo      EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos si el campo tCliente.des es nulo
IF (n_des_ins IS NULL) THEN
RAISE des_nulo;
END IF;


--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM tcliente
WHERE tcliente.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--verificamos si existe el tipo de Cliente
SELECT COUNT (*)
INTO des_test
FROM tCliente
WHERE des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;


-- modificacmos el tipo de Cliente
UPDATE tcliente
SET
des = n_des_ins
WHERE
tcliente.id = n_id;
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica  de tipo de Cliente: ' || n_id); 
    rst:='Ok, Modifica Tipo Cliente  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
--rst := 'OK';
altaLog('Proc. modificaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el tipo de Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  CODIGO DEL tipo de cliente ';
altaLog('Proc. modificaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta descripcin del  tipo de  Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN des_nulo
THEN
    rst := 'ERROR: el tipo de Cliente  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaTipoCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Cliente: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaTipoCliente;
/
CREATE OR REPLACE
PROCEDURE modificaTipoInspeccion(
n_id		IN NUMBER,
n_des 		IN VARCHAR2,
n_estado 	IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaTipoInspeccion
PROPSITO: gestiona la modificacin de un tipo de inspeccin
PARAMETERS: n_id,n_des,n_estado,n_fechaEstado, rst
INPUT: n_id,n_des,n_estado,n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaTipoInspeccion(1,'ANUAL',to_char(sysdate,'DD/MM/YYYY'),rst)
******************************************************************************/
n_des_ins             VARCHAR2(20);
n_fechaEstado_ins     VARCHAR2(11);
id_test			INTEGER;
des_test        		INTEGER;
estado_test        		INTEGER;
err_msg         		VARCHAR2 (100);
dup_id			EXCEPTION;
dup_des    		        EXCEPTION;
dup_estado      		EXCEPTION;
dup_null  			EXCEPTION;

BEGIN
n_des_ins                     := SUBSTR (n_des, 1, 20);
n_fechaEstado_ins             := SUBSTR (n_fechaEstado, 1, 11);

--verificamos que los campos nulos no sean nulos
      IF    (n_id     IS NULL)
        OR  (n_des_ins IS NULL)
	OR (n_estado IS NULL)
	OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--verificamos si ya existe la ID 
SELECT COUNT (*)
INTO id_test
FROM TINSPECCION
WHERE tInspeccion.des = n_des_ins;
IF (des_test = 0)
THEN
RAISE dup_des;
END IF;


--verificamos si ya existe la descripcin 
SELECT COUNT (*)
INTO des_test
FROM TINSPECCION
WHERE tInspeccion.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;

--verificamos si existe el estao
SELECT COUNT (*)
INTO estado_test
FROM estados
WHERE estados.id = n_estado;
IF (estado_test = 0)
THEN
RAISE dup_estado; 
END IF;


-- modificamos el registro  de inspeccion
UPDATE  tinspeccion
SET
des = n_des_ins
,estado = n_estado
,fechaEstado = n_fechaEstado_ins
WHERE
tinspeccion.id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta Tipo Inspeccion  OK: '
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins); 
    rst:='OK, Alta Tipo Inspeccion  OK: ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'ALTA Tipo Inspeccion: ' 
    || n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el id tipo Inspeccin ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'Modifica Tipo Inspeccion: ' 
    	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
    	|| ' Estado: ' 
    	|| n_estado
    	||' fechaEstado: ' 
    	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_des
THEN
    rst := 'ERROR: Ya  existe la descripcion ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'Modifica Tipo Inspeccion: ' 
    || ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'Modifica Tipo Inspeccion: ' 
    	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
    || ' Estado: ' 
    || n_estado
    ||' fechaEstado: ' 
    || n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: Hay campos NO nulos:  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica Tipo Inspeccion: ' 
	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
|| ' Estado: ' 
|| n_estado
||' fechaEstado: ' 
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica Tipo Inspeccion: '
	|| ' n_id '
	|| n_id
	|| 'n_des'
	|| n_des_ins
|| ' Estado: ' 
|| n_estado
||' fechaEstado: ' 
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

END modificaTipoInspeccion;
/
CREATE OR REPLACE
PROCEDURE modificaTipoLectura (
n_id    IN NUMBER,
n_des   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaTipoLectura 
PROPSITO: gestiona la modificacin  de un tipo de lecturas
PARAMETERS:  n_id, n_des, rst
INPUT:  n_id, n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaTipoLectura (1,'PRESENCIAL', rst);
******************************************************************************/
n_des_ins         VARCHAR2 ( 50 CHAR);

id_test           INTEGER;
des_test          INTEGER;

err_msg           VARCHAR2 (100);

dup_id            EXCEPTION;
dup_des           EXCEPTION;
dup_null          EXCEPTION;

BEGIN
-- comprobamos longitud de cadenas
n_des_ins       := SUBSTR (n_des, 1, 50);
--comprobamos campos no nulos que no esten vacios
IF (n_id  IS NULL)
OR (n_des IS NULL)
THEN
RAISE dup_null;
END IF;

--Verificamos que  exista el  codigo del tipo de  lectura 
SELECT COUNT (*)
INTO id_test
FROM tLectura
WHERE tLectura.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--verificamos que no exista la descripcion del tipo de lectura
SELECT COUNT (*)
INTO des_test
FROM TLECTURA
WHERE tLectura.des = n_des_ins;
IF (des_test > 0)
THEN
RAISE dup_des;
END IF;


-- modificamos tipo de lectura
UPDATE tLectura
SET
id = n_id,
des = n_des
WHERE 
tlectura.id = n_id;

-- Fin de las operaciones
DBMS_OUTPUT.PUT_LINE('');  
DBMS_OUTPUT.PUT_LINE('n_id:' || n_id ||' des: '||n_des );  
DBMS_OUTPUT.PUT_LINE(rst);


rst := 'OK';

altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: ' 
|| n_id
||' n_des: '
|| n_des
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe  este id de tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_des: '
|| n_des
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_des
THEN
    rst := 'ERROR: Ya existe esta descripcion del tipo de lectura';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_des
||' n_des: '
|| n_des
, 'rst', rst, rst);
ROLLBACK;



WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaTipoLectura ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaPais', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
||n_id
||' n_des'
||n_des

, 'rst', rst, rst);
ROLLBACK;
END modificaTipoLectura ;
/
CREATE OR REPLACE
PROCEDURE modificaUbicaciones (
n_id		    IN NUMBER,
n_via               IN NUMBER,
n_dir               IN VARCHAR2,
n_num               IN VARCHAR2,
n_pis               IN VARCHAR2,
n_pta               IN VARCHAR2,
n_codigoPostal      IN VARCHAR,
n_localidad         IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaUbicaciones 
PROPSITO: gestiona la modificacin  de una Ubicacion en la tabla ubicaciones
PARAMETERS: n_id, n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad, rst
INPUT: n_id,n_via, n_dir,n_num,n_pis,n_pta,n_codigoPostal,n_localidad
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaUbicacion(1,1,'del pez','2','1r','2a','08330',1, rst);
******************************************************************************/
n_dir_ins           VARCHAR2 (50);
n_num_ins           VARCHAR2 (5);
n_pis_ins           VARCHAR2 (5);
n_pta_ins           VARCHAR2 (10);
n_codigoPostal_ins  VARCHAR  (10);

id_test		  INTEGER;
via_test          INTEGER;
localidad_test    INTEGER;
dup_id		  EXCEPTION;
dup_via           EXCEPTION;
dup_localidad     EXCEPTION;
err_msg           VARCHAR2 (100);
des_nulo          EXCEPTION;

BEGIN
-- controlar la longitud de las entradas
n_dir_ins               := SUBSTR (n_dir, 1, 50);
n_num_ins               := SUBSTR (n_num, 1, 5);
n_pis_ins               := SUBSTR (n_pis, 1, 5);
n_pta_ins               := SUBSTR (n_pta, 1, 10);
n_codigoPostal_ins      := SUBSTR (n_codigoPostal, 1, 10);


--verificamos que los campos no nulos no sean nulos
IF (n_id              IS NULL)
OR (n_via             IS NULL)
OR (n_dir             IS NULL)
OR (n_num             IS NULL)
OR (n_codigoPostal    IS NULL)
OR (n_localidad       IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista la ubicacin 
SELECT COUNT (*)
INTO id_test
FROM ubicaciones
WHERE ubicaciones.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--Verificamos que exista la via
SELECT COUNT (*)
INTO via_test
FROM via
WHERE via.id = n_via;
IF (via_test = 0)
THEN
RAISE dup_via;
END IF;


--verificamos que exista la localidad

SELECT COUNT (*)
INTO localidad_test
FROM localidad
WHERE localidad.id = n_localidad;
IF (localidad_test = 0)
THEN
RAISE dup_localidad;
END IF;

-- insertamos la nueva ubicacion
INSERT INTO ubicaciones(
via
,dir
,num
,pis
,pta
,codigoPostal
,localidad)
VALUES (n_via
,n_dir_ins
,n_num_ins
,n_pis_ins
,n_pta_ins
,n_codigoPostal_ins
,n_localidad);
-- Fin de las operaciones
rst := 'OK. Modificacin de ubicacin ';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');
        DBMS_OUTPUT.PUT_LINE(
        'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad);
        
        DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN dup_via
THEN
      rst := 'ERROR: No existe este cdigo de via';
      DBMS_OUTPUT.ENABLE;    
      DBMS_OUTPUT.PUT_LINE('');  
      DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_localidad
THEN
    rst := 'ERROR: NO  existe localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;

WHEN des_nulo
THEN
        rst := 'ERROR: hay campos nulos que no tienen datos';
        DBMS_OUTPUT.ENABLE;
	DBMS_OUTPUT.PUT_LINE('');  
        DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Modifica ubicacin:'
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaUbicacion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc: altaUbicacion: ' 
|| ' n_id ' 
|| n_id
|| ' n_via ' 
|| n_via
|| ' n_dir '
|| n_dir_ins
|| ' n_num '
|| n_num_ins
|| ' n_piso '
||  n_pis_ins
|| ' n_pta ' 
||  n_pta_ins
|| ' n_codigoPostal ' 
|| n_codigoPostal_ins
|| ' n_localidad '
||  n_localidad
, 'rst', rst, rst);
ROLLBACK;
END modificaUbicaciones ;
/
create or replace PROCEDURE modificaVia(
n_id    IN NUMBER,
n_des   IN VARCHAR2,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaVia
PROPSITO: gestiona la modificacin  de una via
PARAMETERS: n_id,n_des, rst
INPUT: n_id, n_des
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaVia(1,'Rambla', rst);
******************************************************************************/
n_des_ins       VARCHAR2 (50);
id_test        INTEGER;
des_test        INTEGER;
err_msg         VARCHAR2 (100);
dup_idVia       EXCEPTION;
desVia_nulo      EXCEPTION;
BEGIN
n_des_ins := SUBSTR (n_des, 1, 50);
--verificamos campos nulos
IF ( n_id  IS NULL)
OR (n_des_ins IS NULL) THEN
RAISE desVia_nulo;
END IF;
--verificamos si existe la via
SELECT COUNT (*)
INTO id_test
FROM VIA
WHERE via.id  = n_id;
IF (id_test = 0)
THEN
RAISE dup_idVia;
END IF;


-- modificamos la via
UPDATE via
SET
via.des = n_des_ins
where
via.id = n_id; 

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modificacin via: ' || n_id); 
    rst:='Ok, Modificacin Via ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via:' || n_des, 'rst', rst, rst);
COMMIT;
EXCEPTION
WHEN dup_idVia
THEN
    rst := 'ERROR: No existe esta Via';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_id, 'rst', rst, rst);
ROLLBACK;
WHEN desVia_nulo
THEN
    rst := 'ERROR: el tipo de via  no debe ser nulo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_des, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaVia', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de Via: ' || n_des, 'rst', rst, rst);
ROLLBACK;
END modificaVia;
/* FIN_GESTOR_MODIFICA */
/
/* GESTOR_BAJAS */
CREATE OR REPLACE
PROCEDURE bajaCentral(
n_id		IN NUMBER,
n_fechaEstado	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaCentral
PROPSITO: gestiona la baja lgica de una  Central
PARAMETERS: n_id,n_estado,n_fechaEstado, rst
INPUT: n_id,n_estado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaCentral(1,to_char(sysdate,'DD/MM/YYYY'),  rst);
******************************************************************************/
n_estado				INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;

err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	EXCEPTION;



BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11);

--verificamos que los campos nulos no sean nulos
IF   		(n_id 		IS NULL)
	OR 	(n_fechaEstado	IS NULL)
THEN
RAISE dup_null;
END IF;

-- verificamos que la Central a modificar exista

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM centrales
WHERE centrales.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;

-- cambio a estado de baja
UPDATE centrales
SET
centrales.ESTADO = estado_test,
centrales.FECHAESTADO =n_fechaEstado_ins
WHERE
centrales.ID = n_id;

-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('BAJA Lgica de la Central OK: ' || n_id); 
    rst:='OK, BAJA LOGICA DE LA  CENTRAL ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_estado: '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
COMMIT;

EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: NO existe esta  central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||' n_estado: '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral: ' 
|| 'n_id: '
||  n_id
|| ' n_estad0: '
||  n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: No existe el estado BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral: ' 
|| 'n_id: '
||  n_id
|| ' n_estad0: '
||  n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Proc. bajaCentral' 
||  n_id
|| ' n_estad0: '
||  n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins 
, 'rst', rst, rst);
ROLLBACK;

END bajaCentral;
/
CREATE OR REPLACE
PROCEDURE bajaClientes(
n_id                IN NUMBER,
n_fechaMod          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaClientes
PROPSITO: gestiona la baja lgica de  un cliente en la tabla clientes
PARAMETERS: n_id,n_fechaMod, rst
INPUT: n_id,n_fechaMod
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaClientes(3,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/

n_fechaMod_ins      VARCHAR2(11 CHAR);
n_estado			NUMBER;
id_test             INTEGER;
estado_test         INTEGER;
err_msg             VARCHAR2(100);
dup_id              EXCEPTION;
dup_estado          EXCEPTION;
dup_null             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas

n_fechaMod_ins      := SUBSTR (n_fechaMod, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_id              IS NULL)
OR (n_fechaMod		IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM CLIENTES
WHERE clientes.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;


-- modificamos el cliente ESTADO A BAJA
UPDATE CLIENTES
SET
estado      = n_estado,
fechaMod    = n_fechaMod_ins
WHERE
clientes.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id: ' || n_id ); 
    rst:='Ok, BAJA logica del cliente realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
|| ', '
||'n_estado: '
|| n_estado 
|| ', ' 
||'n_fechaModificacion: ' 
|| n_fechaMod
, 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el CODIGO DEL CLIENTE';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el  CODIGO DEL CLIENTE ';
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id : ' || n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado : ' || n_estado 
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaClientes', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id: '
|| n_id 
, 'rst', rst, rst);
ROLLBACK;
END bajaClientes;
/
CREATE OR REPLACE
PROCEDURE bajaContadores(

n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:     bajaContadores
PROPSITO:  gestiona la baja lgica del contador ( cambio de estado en la tabla contadores
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT:      n_id,n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaContadores(1,to_char(sysdate,'DD/MM/YYYY'),  rst);
******************************************************************************/
n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;

err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	        EXCEPTION;

BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos no nulos no sean nulos
IF (n_id		      IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM contadores
WHERE contadores.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;



-- cambio a estado de baja
UPDATE CONTADORES 
SET
contadores.ESTADO = estado_test,
contadores.FECHAESTADO =n_fechaEstado_ins
WHERE
contadores.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id ); 
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || estado_test ); 
    rst:='Ok, cambio de estado a BAJA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
 , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: No existe el Contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id  
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  );
    rst := 'ERROR: No existe el Estado de BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_estado ' || n_estado
|| ', '
||'n_fechaEstado: ' || n_fechaEstado 
, 'rst', rst, rst);

ROLLBACK;
WHEN dup_null
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaContadores', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;
END bajaContadores;

/
CREATE OR REPLACE
PROCEDURE bajaContratos(
n_id			IN NUMBER,
n_fechaEstado       	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaContratos
PROPSITO: gestiona la baja lgica de un contraato en la tabla contratos
PARAMETERS: n_id, n_fechaEstado, rst
INPUT: n_id, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaContratos(1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/

n_fechaEstado_ins     VARCHAR2(11 CHAR);
n_contador              NUMBER;
id_test			INTEGER;
n_estado		NUMBER;
estado_test         	INTEGER;
err_msg             	VARCHAR2(100);
dup_id              	EXCEPTION;
dup_estado          	EXCEPTION;
dup_null                EXCEPTION;

BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  	:= SUBSTR (n_fechaEstado, 1, 11);
--verificamos que los campos no nulos no sean nulos
IF (n_id        		IS NULL)
OR (n_fechaEstado_ins           IS NULL)
THEN
RAISE dup_null;
END IF;
--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM contratos
WHERE contratos.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;
--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;
-- modificamos el contrato  A BAJA
UPDATE contratos
SET
estado       = n_estado,
fechaEstado  = n_fechaEstado_ins
WHERE
contratos.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
 ); 
    rst:='Ok, Baja Lgica del contrato  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
COMMIT;

-- tratamiento de excepciones

EXCEPTION

WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id : ' || n_id  ); 
     rst := 'ERROR: NO existe el CONTRATO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el CONTRATO ';
altaLog('Proc. bajaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_contador: ' || n_contador  ); 
     rst := 'ERROR:  NO  existe el Estado de BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el estado de BAJA';
altaLog('Proc. bajaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;



WHEN dup_null
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaContratos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaContratos',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;
END bajaContratos;
/
CREATE OR REPLACE
PROCEDURE bajaEmpresa(
n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaEmpresa
PROPSITO: gestiona la baja lgica de una empresa
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT:      n_id,n_estado, n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaEmpresa(1,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null                        EXCEPTION;


BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos no nulos no sean nulos
IF (n_id		      IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM empresas
WHERE empresas.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;



-- cambio a estado de baja
UPDATE empresas
SET
empresas.ESTADO = estado_test,
empresas.FECHAESTADO = n_fechaEstado_ins
WHERE
empresas.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
        'Baja Empresa: '
 	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins); 
    rst:='Ok, Baja EMPRESA  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: NO existe la empresa';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins

, 'rst', rst, rst);
ROLLBACK;


WHEN dup_estado
THEN
    rst := 'ERROR: NO existe el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: Hay campos nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaEmpresa', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

END bajaEmpresa;
/
CREATE OR REPLACE
PROCEDURE bajaLinea(
n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaLinea
PROPSITO: gestiona la baja lgica de una linea  
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT: n_id, n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaLineas(1,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/

n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);

--verificamos si hay campos no nulos: nulos
IF 	     (n_id     		     IS NULL)
          OR (n_fechaEstado		IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM linea
WHERE linea.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;



-- cambio a estado de baja
UPDATE linea
SET
linea.ESTADO = estado_test,
linea.FECHAESTADO = n_fechaEstado_ins
WHERE
linea.ID = n_id;

-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Baja de linea: '
	||'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    ); 
    rst:='OK, Baja de linea  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe Linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	 
	 n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	 
	 n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

END bajaLinea;
/
CREATE OR REPLACE
PROCEDURE bajaLineas(

n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaLineas
PROPSITO: gestiona la baja lgica de lineas  conectadas
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT: n_id,n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaLineas(1,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/

n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	EXCEPTION;

BEGIN
-- comprobar longitudes
n_fechaEstado_ins := SUBSTR (n_fechaEstado, 1, 11);

--verificamos si hay campos no nulos: nulos
IF 	     (n_id     		IS NULL)
          OR (n_fechaEstado	IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM lineas
WHERE lineas.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;
-- cambio a estado de baja
UPDATE lineas
SET
lineas.ESTADO = estado_test,
lineas.FECHAESTADO = n_fechaEstado_ins
WHERE
lineas.ID = n_id;

-- Fin de las operaciones


    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
    'Baja de linea: '
	||'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    ); 
    rst:='OK, Baja de lineas lgica  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
COMMIT;

-- tratamos las excepciones
EXCEPTION
WHEN dup_id
THEN
    rst := 'ERROR: No existe Lineas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	 
	 n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos nulos vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	 
	 n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaLineas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),	
        'n_id: ' 
	||n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

END bajaLineas;
/
CREATE OR REPLACE
PROCEDURE bajaModelos(
n_id         	        IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaModelos
PROPSITO: gestiona la baja lgica de un modelo en la tabla modelos
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT:      n_id,n_estado, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaModelos(1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/
n_estado				INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	EXCEPTION;


BEGIN

n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos no nulos no sean nulos
IF (n_id		      IS NULL)
OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM modelos
WHERE modelos.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;



-- cambio a estado de baja
UPDATE modelos
SET
modelos.ESTADO = estado_test,
modelos.FECHAESTADO = n_fechaEstado_ins
WHERE
modelos.ID = n_id;

-- Fin de las operaciones    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins  
    ); 
    rst:='Ok, baja Modelo   realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
    
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
		'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
        , 'rst', rst, rst);
COMMIT;
-- tratamiento de excepciones

EXCEPTION

WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
        	'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
        , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_estado : ' || n_estado  ); 
     rst := 'ERROR: NO existe ESTADO';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe el ESTADO ';
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
	, 'rst', rst, rst);
ROLLBACK;


WHEN dup_id
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
		'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins  ); 
     rst := 'ERROR: NO existe el modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: No existe la EMPRESA ';
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      	'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
	, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaModelos', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
		'n_id: ' 
		|| n_id 
		||' n_estado  : '
		|| n_estado
		||' n_fechaEstado: '
		|| n_fechaEstado_ins
        , 'rst', rst, rst);
ROLLBACK;
END bajaModelos;
/
CREATE OR REPLACE
PROCEDURE bajaTipoCentral(
n_id				IN NUMBER,
n_fechaEstado       	IN VARCHAR2,

rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaTipoCentral
PROPSITO: gestiona la baja lgica de un TIPO  de Central
PARAMETERS: n_id, n_fechaEstado, rst
INPUT: n_id, n_fechaEstado
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: bajaTipoCentral(1,to_char(sysdate,'DD/MM/YYYY'), rst);
******************************************************************************/
n_fechaEstado_ins     VARCHAR2(11 CHAR);

n_contador              NUMBER;
id_test			INTEGER;
n_estado			NUMBER;
estado_test         	INTEGER;
err_msg             	VARCHAR2(100);
dup_id              	EXCEPTION;
dup_estado          	EXCEPTION;
dup_null             EXCEPTION;


BEGIN
-- controlamos la longitud de entrada de las cadenas
n_fechaEstado_ins  	:= SUBSTR (n_fechaEstado, 1, 11);


--verificamos que los campos no nulos no sean nulos

IF (n_id        		IS NULL)
OR (n_fechaEstado_ins           IS NULL)
THEN
RAISE dup_null;
END IF;

--comprobar que existe el id a modificar
SELECT COUNT (*)
INTO id_test
FROM tCentral
WHERE tCentral.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;


-- Fin de las operaciones
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Baja de tipo de tcentral: '
||'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado); 
    rst:='Ok, Baja Tipo tcentral  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral:'
|| ' n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
,'rst',rst, rst);
COMMIT;
EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el tipo de  tcentral';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: '
|| 'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
  DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
	'n_id: '
	|| n_id
	||'n_estado  : ' 
	|| n_estado  
	||'n_fechaEstado: ' 
	|| n_fechaEstado   ); 
     rst := 'ERROR:  NO  existe el Estado de BAJA';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);

rst := 'ERROR: NO  existe el estado de BAJA';
altaLog('Proc. bajaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado
, 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: hay campos no nulos sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: ' 
||'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaTipoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Tipo de tcentral: '
||'n_id: '
|| n_id
||'n_estado  : ' 
|| n_estado  
||'n_fechaEstado: ' 
|| n_fechaEstado, 'rst', rst, rst);
ROLLBACK;
END bajaTipoCentral;
/
CREATE OR REPLACE
PROCEDURE bajaTipoInspeccion(
n_id         	     IN NUMBER,
n_fechaEstado      	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaTipoInspeccion
PROPSITO: gestiona la baja lgica de un tipo de inspeccin
PARAMETERS: n_id,n_estado, n_fechaEstado,rst
INPUT: n_id,n_estado, n_fechaEstado	
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exitosa, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: bajaTipoInspeccion(1,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
n_estado			INTEGER; 			
n_fechaEstado_ins       	VARCHAR2(11 CHAR);
id_test				INTEGER;
estado_test             	INTEGER;
err_msg                 	VARCHAR2(100);
dup_id              		EXCEPTION;
dup_estado              	EXCEPTION;
dup_null               	        EXCEPTION;

BEGIN
n_fechaEstado_ins   := SUBSTR(n_fechaEstado,1,11); 

--verificamos que los campos nulos no sean nulos
IF                 (n_id IS NULL)
		OR (n_fechaEstado_ins IS NULL)
THEN
RAISE dup_null;
END IF;



--comprobar existe el id
SELECT COUNT (*)
INTO id_test
FROM tInspeccion
WHERE tInspeccion.id = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;

--obtenemos el codigo de baja del estado
SELECT  (estados.id)
INTO estado_test
FROM ESTADOS
WHERE estados.des = 'BAJA';
IF (estado_test = 0)
THEN
RAISE dup_estado;
END IF;
n_estado := estado_test;


-- cambio a estado de baja
UPDATE tInspeccion
SET
tInspeccion.ESTADO = estado_test,
tInspeccion.FECHAESTADO =n_fechaEstado_ins
WHERE
tInspeccion.ID = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Baja  Tipo Inspeccion  OK: '
	||'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins); 
    rst:='OK, Baja Tipo Inspeccion  OK: ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
    , 'rst', rst, rst);

COMMIT;

EXCEPTION

WHEN dup_id
THEN
    rst := 'ERROR: No existe el tipo de inspeccin ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_estado
THEN
    rst := 'ERROR: NO exsite el Estado';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
	'n_id: ' 
	|| n_id 
	||' n_estado  : '
	|| n_estado
	||' n_fechaEstado: '
	|| n_fechaEstado_ins
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_null
THEN
    rst := 'ERROR: Hay campos NO nulos:  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaTipoInspeccion', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' 
|| n_id 
||' n_estado  : '
|| n_estado
||' n_fechaEstado: '
|| n_fechaEstado_ins
, 'rst', rst, rst);
ROLLBACK;
END bajaTipoInspeccion;
/* FIN_GESTOR_BAJAS */
/
/* GESTOR_DE_FUNCIONES */
CREATE OR REPLACE FUNCTION getCentralEmax(n_id    NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getCentralEmax
PROPSITO:  para conocer la energia mxima que puede producir la central
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getCentralEmax (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         NUMBER;
BEGIN
SELECT      centrales.EMAX 
INTO ret
FROM centrales
WHERE
centrales.ID = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getCentralEmax', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getCentralEmax;
----------------------------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoCentral(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoCentral
PROPSITO:  para conocer el consumo la central -contadores conectados-, activa
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getConsumoCentral (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;
BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM estados, linea, lineas, contadores, centrales, consumos
WHERE
lineas.C1             = centrales.ID    -- conectadas
AND lineas.C2         = contadores.ID   -- con contadores
AND lineas.LINEA      = linea.ID      
AND consumos.CONTADOR = contadores.ID
AND centrales.ESTADO  =   1         -- activas
AND contadores.ESTADO =   1         -- activos
AND lineas.ESTADO     =   1         -- activas
AND Linea.ESTADO      =   1         -- activos
--AND centrales.CLASE   =   1         -- central de distribucion
GROUP BY centrales.ID
HAVING   SUM(consumos.CONSUMO)>-1 AND 
centrales.id = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoCentral', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoCentral;
----------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoCentralAnyo(n_id  NUMBER, n_anyo  NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoCentralAnyo
PROPSITO:  para conocer el consumo en un ao determinado de una la central de produccin
PARAMETERS: n_id, n_anyo
INPUT:      n_id, n_ayo
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getConsumoCentralAnyo (2,2011)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;
BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM estados, linea, lineas, contadores, centrales, consumos
WHERE
lineas.C1             = centrales.ID    -- central conectada
AND lineas.C2         = contadores.ID   --contadores conectados
AND lineas.LINEA      = linea.ID
AND consumos.CONTADOR = contadores.ID
AND centrales.ESTADO  =   1         -- activas
AND contadores.ESTADO =   1         -- activos
AND lineas.ESTADO     =   1         -- activas
AND Linea.ESTADO      =   1         -- activa
AND centrales.CLASE   =   2         -- produccion
AND consumos.ANYO     =   n_anyo
GROUP BY centrales.ID
HAVING   SUM(consumos.CONSUMO)>-1 AND 
centrales.id = n_id ;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoCentralAnyo', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:  ' || n_id 
||' n_anyo:  ' || n_anyo 
, 'rst', rst, rst);
ROLLBACK;
END getConsumoCentralAnyo;
-------------------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoCliente(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoMedioCliente
PROPSITO:  para conocer el consumo de un cliente en alta, contadores activos y conectados
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret 
RETORNA:    ret ( variable con el consumo medio del cliente )
EJEMPLO DE USO: getConsumoMedioCliente (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         	NUMBER;

BEGIN

SELECT  sum (consumos.consumo)
INTO ret
FROM CONSUMOS,   contadores, lineas, contratos, clientes
WHERE
contadores.ESTADO     = 1       -- en alta
and contratos.ESTADO  = 1       -- vigentes
and  clientes.ESTADO  = 1       -- en alta
and  lineas.ESTADO    = 1       -- en servicio
and  contadores.ID    = lineas.C2               -- conectados
and  contadores.ID    = contratos.CONTADOR      -- con contrato
and  clientes.ID      = contratos.CLIENTE       -- con el cliente    
and contadores.ID     = consumos.CONTADOR
and consumos.consumo >0
and clientes.ID = n_id;

RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoMedioCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoCliente;
--------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoContador(n_id  NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoContador
PROPSITO:  para conocer el consumo de un contador, activo y conectado
PARAMETERS: n_id
INPUT:      n_id
OUTPUT: -
RETORNA:    ret ( variable con el consumo total del contador )
EJEMPLO DE USO: getConsumoContador (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         	NUMBER;

BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM estados, linea, lineas, contadores,  consumos
WHERE
lineas.C2              	 = contadores.ID 	-- conectado
AND lineas.LINEA       	 = linea.ID	
AND consumos.CONTADOR  	 = contadores.ID
AND contadores.ESTADO   	=   1		-- en alta
AND lineas.ESTADO       	=   1		-- en alta	
AND Linea.ESTADO        	=   1		-- en alta
GROUP BY consumos.CONTADOR
HAVING   SUM(consumos.CONSUMO)>-1 AND 	        -- con consumo
consumos.CONTADOR = n_id;			
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoContador', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoContador;
-------------------------------------------
/
CREATE OR REPLACE
FUNCTION getConsumoContadorFecha(n_id  NUMBER,n_anyo NUMBER,n_mes NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoContadorFecha
PROPSITO:  para conocer el consumo del contador en un ao y mes determinado
PARAMETERS: n_id, n_anyo, n_mes
INPUT:      n_id, n_ayo, n_mes
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo   )
EJEMPLO DE USO: getConsumoContadorFecha (2,2011,1)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;

BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM    consumos
WHERE
 consumos.CONTADOR      = n_id
AND consumos.ANYO       = n_anyo
AND consumos.MES        = n_mes;

RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoContadorFecha', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:  ' || n_id 
||' n_anyo:  ' || n_anyo 
||' n_mes:  ' || n_mes
, 'rst', rst, rst);
END getConsumoContadorFecha;
------------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoLinea(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoCentral
PROPSITO:  para conocer el consumo la linea -contadores conectados-, activa
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getConsumoLinea (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         NUMBER;
BEGIN
select  sum (consumos.CONSUMO)
INTO ret
from linea, lineas, contadores, consumos, estados
where
linea.ID                  = lineas.LINEA
and lineas.C2             = contadores.ID
and contadores.id         = consumos.CONTADOR
and estados.ID            = contadores.ESTADO
--and contadores.ESTADO     = 1
--and linea.ESTADO          = 1
--and lineas.ESTADO         = 1
group by linea.id
HAVING   SUM(consumos.CONSUMO)>-1 AND 
linea.ID = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoLinea', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoLinea;
/
CREATE OR REPLACE
FUNCTION getConsumoLocalidadFecha(n_id NUMBER, n_anyo NUMBER, n_mes VARCHAR2)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoLocalidadFecha
PROPSITO:  para conocer el consumo en un ao determinado de una la central de produccin
PARAMETERS: n_id, n_anyo, n_mes
INPUT:      n_id, n_ayo, n_mes
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo   )
EJEMPLO DE USO: getConsumoLocalidadFecha (2,2011,1)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;
consumos_test   INTEGER;
BEGIN

SELECT sum(consumos.CONSUMO)
--SELECT   consumos.id, consumos.anyo, consumos.mes, consumos.CONSUMO, consumos.CONTADOR
INTO ret
FROM CONSUMOS, localidad, contadores, lineas, linea
WHERE
     contadores.ESTADO    =   1             -- vigentes
and linea.ESTADO          =   1             -- activa
and lineas.ESTADO         =   1             -- conexin activa
and linea.ID              = lineas.LINEA
and contadores.ID         = consumos.CONTADOR
and lineas.C2             = consumos.CONTADOR   -- que esten conectados
and localidad.ID           =  n_id    -- de la localidad que buscamos
and consumos.ANYO         = n_anyo    -- anyo de consumo
and consumos.MES          = n_mes     -- mes de consumo
and consumos.consumo >0;              -- con consumo
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoLocalidadFecha', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:  ' || n_id 
||' n_anyo:  ' || n_anyo 
||' n_mes:  ' || n_mes
, 'rst', rst, rst);
END getConsumoLocalidadFecha;
-------------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoMedioCliente(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoMedioCliente
PROPSITO:  para conocer el consumo medio de un cliente en alta, contadores activos y conectados
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret 
RETORNA:    ret ( variable con el consumo medio del cliente )
EJEMPLO DE USO: getConsumoMedioCliente (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         	NUMBER;

BEGIN

SELECT  avg (consumos.consumo)
INTO ret
FROM CONSUMOS,   contadores, lineas, contratos, clientes
WHERE
contadores.ESTADO     = 1       -- en alta
and contratos.ESTADO  = 1       -- vigentes
and  clientes.ESTADO  = 1       -- en alta
and  lineas.ESTADO    = 1       -- en servicio
and  contadores.ID    = lineas.C2               -- conectados
and  contadores.ID    = contratos.CONTADOR      -- con contrato
and  clientes.ID      = contratos.CLIENTE       -- con el cliente    
and contadores.ID     = consumos.CONTADOR
and consumos.consumo >0
and clientes.ID = n_id;

RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoMedioCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getConsumoMedioCliente;
--------------------------------
/
CREATE OR REPLACE
FUNCTION getConsumoMedioLocalidadFecha(n_id NUMBER, n_anyo NUMBER, n_mes VARCHAR2)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoMedioLocalidadFecha
PROPSITO:  para conocer el consumo en un ao determinado de una la central de produccin
PARAMETERS: n_id, n_anyo, n_mes
INPUT:      n_id, n_ayo, n_mes
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo   )
EJEMPLO DE USO: getConsumoMedioLocalidadFecha (2,2011,1)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER(9,2);
consumos_test   INTEGER;
BEGIN

SELECT avg(consumos.CONSUMO)
--SELECT   consumos.id, consumos.anyo, consumos.mes, consumos.CONSUMO, consumos.CONTADOR
INTO ret
FROM CONSUMOS, localidad, contadores, lineas, linea
WHERE
     contadores.ESTADO    =   1             -- vigentes
and linea.ESTADO          =   1             -- activa
and lineas.ESTADO         =   1             -- conexin activa
and linea.ID              = lineas.LINEA
and contadores.ID         = consumos.CONTADOR
and lineas.C2             = consumos.CONTADOR   -- que esten conectados
and localidad.ID           =  n_id    -- de la localidad que buscamos
and consumos.ANYO         = n_anyo    -- anyo de consumo
and consumos.MES          = n_mes     -- mes de consumo
and consumos.consumo >0;              -- con consumo
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getConsumoLocalidadFecha', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:  ' || n_id 
||' n_anyo:  ' || n_anyo 
||' n_mes:  ' || n_mes
, 'rst', rst, rst);
END getConsumoMedioLocalidadFecha;
-------------------------------------
/
CREATE OR REPLACE FUNCTION getLineaCmax(n_id    NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getLineaCmax
PROPSITO:  para conocer la energia mxima que tiene la linea 
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( variable con la capaciad  )
EJEMPLO DE USO: getLineaCmax (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         NUMBER;
BEGIN
SELECT      linea.CMAX 
INTO ret
FROM linea
WHERE
linea.ID = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getLineaCmax', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getLineaCmax;
----------------------------------------------------
/
CREATE OR REPLACE FUNCTION getLineaConsumo(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoCentral
PROPSITO:  para conocer el consumo la linea -contadores conectados-, activa
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getLineaConsumo (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret         NUMBER;
BEGIN
 SELECT  sum (consumos.CONSUMO)
INTO ret
 FROM
 linea, lineas, contadores, consumos
 WHERE
 linea.id = lineas.LINEA
 and contadores.ID = lineas.C2
 and lineas.C2 = consumos.CONTADOR
 and linea.ID = 1
 group by linea.id
 having  sum (consumos.CONSUMO) > 0;

RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getLineaConsumo', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getLineaConsumo;
/
CREATE OR REPLACE FUNCTION getNomCliente(n_id NUMBER)
RETURN      VARCHAR2
IS
/******************************************************************************
NOMBRE:     getNomCliente
PROPSITO:  conocer los apellidos y nombre del cliente
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret 
RETORNA:    ret ( contiene los apellidos y nombre  del cliente )
EJEMPLO DE USO: getNomCliente (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             VARCHAR2 (150);

BEGIN

SELECT  (clientes.APE1 ||' ' || clientes.APE2 ||','|| clientes.NOM)
INTO ret
FROM  clientes
WHERE
clientes.ID = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getNomCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getNomCliente;
----------------------------------------
/
CREATE OR REPLACE FUNCTION getUbica(n_id IN NUMBER)
RETURN     Varchar2
IS
/******************************************************************************
NOMBRE:     getUbica
PROPSITO:  conocer los datos de la ubicacin
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret
RETORNA:    ret ( contiene los datos de la ubicacin: direccin, num, piso,
                  puerta, localidad, cdigo postal, provincia y pais )
EJEMPLO DE USO: getUbica (2)
******************************************************************************/
err_msg     VARCHAR2 (100);
rst 	    VARCHAR2 (100);
ret         VARCHAR2 (100);
BEGIN
SELECT  
via.DES
|| ubicaciones.DIR ||' '
|| ubicaciones.NUM ||' '
|| ubicaciones.PIS ||' '
|| ubicaciones.PTA ||' '
|| localidad.DES   ||' ('
|| ubicaciones.CODIGOPOSTAL   ||') '
|| provincia.DES   ||' '
|| pais.DES
INTO ret
FROM via, ubicaciones, localidad, provincia, pais
WHERE 
via.ID              =   ubicaciones.VIA
AND localidad.ID    =   ubicaciones.LOCALIDAD
AND provincia.ID    =   localidad.PROVINCIA
AND pais.ID         =   provincia.PAIS
AND ubicaciones.ID  =   n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getUbica', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getUbica;
/
CREATE OR REPLACE FUNCTION getIdCliente(n_id NUMBER)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getIdCliente
PROPSITO:  conocer el codigo del cliente
PARAMETERS: n_id
INPUT:      n_id
OUTPUT:     ret 
RETORNA:    ret ( el codigo del cliente )
EJEMPLO DE USO: getIdCliente (2)
******************************************************************************/
err_msg 	VARCHAR2 (100);
rst 	        VARCHAR2 (100);
ret             NUMBER;

BEGIN

SELECT  clientes.id
INTO ret
FROM  clientes
WHERE
clientes.ID = n_id;
RETURN ret;
EXCEPTION
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Func. getNomCliente', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id:  ' || n_id
, 'rst', rst, rst);
ROLLBACK;
END getIdCliente;
----------------------------------------
/
CREATE OR REPLACE FUNCTION getConsumoLineaAnyo(
n_id    NUMBER,
n_anyo  NUMBER
)
RETURN      NUMBER
IS
/******************************************************************************
NOMBRE:     getConsumoLineaAnyo
PROPSITO:  para conocer el consumo de una linea en una ao concreto
PARAMETERS: n_id, n_anyo
INPUT:      n_id, n_anyo
OUTPUT:     ret
RETORNA:    ret ( variable con el consumo  )
EJEMPLO DE USO: getConsumoLineaAnyo (2,2011);
******************************************************************************/
ret         NUMBER;
BEGIN
SELECT      sum(consumos.CONSUMO) 
INTO ret
FROM estados, linea, lineas, contadores,  consumos
WHERE
lineas.C2         = contadores.ID -- contadores conectados
AND lineas.LINEA      = linea.ID
AND consumos.CONTADOR = contadores.ID
AND contadores.ESTADO  =   1
AND lineas.ESTADO     =   1
AND Linea.ESTADO      =   1
AND consumos.ANYO     =   n_anyo
GROUP BY linea.ID
HAVING   SUM(consumos.CONSUMO)>-1 AND 
linea.id = n_id ;
IF (ret = 0)
THEN ret :=1;
END IF;
RETURN ret;
END getConsumoLineaAnyo;
---------------------------
/
/* FIN GESTOR_DE_FUNCIONES */

/* GESTOR_ESTADISTICAS */
CREATE OR REPLACE
PROCEDURE altaE1(
n_central				IN NUMBER,
n_consumoContadores			IN NUMBER,
n_fecha                                 IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE1
PROPSITO: gestiona el alta en la tabla estadstica E1
Dada una central de produccin, el consumo de los contadores que dependen de la central.
PARAMETERS: n_central, n_consumoContadores, rst
INPUT: n_central, n_consumoContadores
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE1(1,300,to_char(sysdate,'DD/MM/YYYY'),rst)
******************************************************************************/
--definicion de variables
n_fecha_ins     VARCHAR2(11);
central_test	INTEGER;
clase_test      INTEGER;
err_msg       	VARCHAR2 (100);
des_nulo      	EXCEPTION;
dup_clase	EXCEPTION;
dup_central	EXCEPTION;

BEGIN
-- comprobar logitudes
n_fecha_ins  := SUBSTR (n_fecha ,1,11);

--verificamos si hay campos no nulos: nulos
IF 	   (n_central			IS NULL)
	OR (n_consumoContadores 	IS NULL)
        OR (n_fecha_ins          	IS NULL)
THEN
RAISE des_nulo;
END IF;

--obtener el codigo de la clase y verificar que es central de produccin 
--obtenemos el codigo de la clase

SELECT ccentral.ID
INTO clase_test
FROM ccentral
WHERE ccentral.DES = 'PRODUCCION' OR 
      ccentral.DES = 'PRODUCCIN';
IF (clase_test = 0)
THEN
RAISE dup_clase;
END IF;
--comprobar que la central existe
SELECT COUNT(*)
INTO central_test
FROM centrales
WHERE centrales.ID = n_central
and centrales.CLASE = clase_test;
IF (central_test=0)
THEN
RAISE dup_central;
END IF;

-- insertamos en E1
INSERT INTO E_1(central,consumoContadores,fecha)
VALUES (n_central, n_consumoContadores,n_fecha_ins);

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E1: '  || 'n_central: '  ||  n_central|| ' '||n_fecha_ins); 
    rst:='OK, Alta de E1  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
   , 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_clase
THEN
    rst := 'ERROR: NO existe clase de Central de Produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || clase_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central
THEN
    rst := 'ERROR: NO existe la central de produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_central: ' || n_central, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
    , 'rst', rst, rst);
ROLLBACK;
end altaE1;
/
CREATE OR REPLACE
PROCEDURE altaE2(
n_linea				IN NUMBER,
n_anyo  			IN NUMBER,
n_consumoEnergiaMedio           IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE2
PROPSITO: gestiona el alta en la tabla estadstica E_2
Dada una lnea de comunicacin y un ao en concreto, el valor medio de la energa consumida
si el contador hace servir dos lineas, computa en las dos
PARAMETERS: n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio, rst
INPUT:      n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE2(1,20112,50,rst);
******************************************************************************/
--definicion de variables
linea_test	INTEGER;
err_msg       	VARCHAR2 (100);
dup_linea	EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN
--verificamos si hay campos no nulos: nulos
IF 	   (n_linea			IS NULL)
--	OR (n_consumoContadores 	IS NULL)
      	OR (n_consumoEnergiaMedio 	IS NULL)
THEN
RAISE des_nulo;
END IF;
--comprobar que la linea existe
SELECT count(*)
INTO linea_test
FROM linea
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
--actualizamos la tabla E_2
INSERT INTO E_2(linea, anyo, consumoEnergiaMedio)
VALUES (n_linea,n_anyo, n_consumoEnergiaMedio);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E2: '  || 'n_linea: '  ||  n_linea || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio ); 
    
    rst:='OK, Alta de E2  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
   , 'rst', rst, rst);
COMMIT;
-- control de excepciones
EXCEPTION
WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_linea
THEN
    rst := 'ERROR: NO existe la linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_anyo: '
    ||  n_anyo
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;
END altaE2;
/
CREATE OR REPLACE
PROCEDURE altaE3(
n_linea				IN NUMBER,
n_consumoContadores             IN NUMBER,
n_fecha                         IN VARCHAR,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE3
PROPSITO: gestiona el alta en la tabla estadstica E_3
PARAMETERS: n_lina,n_anyo, n_consumoContadores, n_fecharst
INPUT:      n_lina,n_anyo, n_consumoContadores, n_fecha
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE3(1,200,to_char(sysdate,'DD/MM/YYYY'),rst);
******************************************************************************/
--definicion de variables
n_fecha_ins     VARCHAR2(11);
linea_test	INTEGER;
err_msg       	VARCHAR2 (100);
dup_linea	EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN
-- comprobar logitudes
n_fecha_ins  := SUBSTR (n_fecha ,1,11);

--verificamos si hay campos no nulos: nulos
IF 	   (n_linea			IS NULL)
	OR (n_consumoContadores 	IS NULL)
        OR (n_fecha_ins          	IS NULL)
THEN
RAISE des_nulo;
END IF;



--comprobar que la linea existe
SELECT count(*)
INTO linea_test
FROM linea
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;
-- insertamos en E3
INSERT INTO E_3(linea,consumoContadores,fecha)
VALUES (n_linea,n_consumoContadores,n_fecha_ins);
-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E3: '  || 'n_linea: '  ||  n_linea); 
    DBMS_OUTPUT.PUT_LINE('Alta de E3: '  || 'n_consumoContadores: '  ||  n_consumoContadores); 
    DBMS_OUTPUT.PUT_LINE('Alta de E3: '  || 'n_fecha: '  ||  n_fecha_ins); 

    rst:='OK, Alta de E3  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_linea
THEN
    rst := 'ERROR: NO existe la linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_fecha: '
    ||  n_fecha_ins
    , 'rst', rst, rst);
ROLLBACK;
END altaE3;
/
CREATE OR REPLACE
PROCEDURE altaE4(
n_anyo  		IN NUMBER,
n_perLineaMas50         IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE4
PROPSITO: gestiona el alta en la tabla estadstica 
            Dado un ao en concreto: porcentaje de lineas que superan 50% de energia consumida.
PARAMETERS: n_anyo, n_perLineaMas50, rst
INPUT:      n_anyo, n_perLineaMas50
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE4(2012,90,rst);
******************************************************************************/
--definicion de variables
--n_anyo_ins        VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;

BEGIN
--control de la longitud de cadenas
--n_anyo_ins := SUBSTR (n_anyo, 1, 4);

--verificamos si hay campos no nulos: nulos
IF 	   (n_anyo			IS NULL)
	OR (n_perLineaMas50 	        IS NULL)
THEN
RAISE des_nulo;
END IF;
-- insertamos en E4
INSERT INTO E_4(anyo,perLineaMas50) VALUES (n_anyo, n_perLineaMas50);

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E4: '  || 'n_anyo: '  ||  n_anyo); 
    DBMS_OUTPUT.PUT_LINE('Alta de E4: '  || 'n_perLineaMas50: '  ||  n_perLineaMas50); 
    rst:='OK, Alta de E4  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    ' n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      ' n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
    , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      ' n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
    , 'rst', rst, rst);
ROLLBACK;
END altaE4;
/
CREATE OR REPLACE
PROCEDURE altaE5(
n_anyo  		        IN NUMBER,
n_cenProduccionMenos30          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE5
PROPSITO: gestiona el alta en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_anyo, cenProduccionMenos30, rst
INPUT:      n_anyo, cenProduccionMenos30 
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE5('2012',90,rst);
******************************************************************************/
--definicion de variables
--n_anyo_ins        VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;

BEGIN
--control de la longitud de cadenas
--n_anyo_ins := SUBSTR (n_anyo, 1, 4);

--verificamos si hay campos no nulos: nulos
IF 	   (n_anyo			        IS NULL)
	OR (n_cenProduccionMenos30 	        IS NULL)
THEN
RAISE des_nulo;
END IF;
-- insertamos en E4
INSERT INTO E_5(anyo,cenProduccionMenos30) VALUES (n_anyo, n_cenProduccionMenos30);

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E5: '  || 'n_anyo: '  ||  n_anyo); 
    DBMS_OUTPUT.PUT_LINE('Alta de E5: '  || 'n_cenProduccionMenos30: '  ||  n_cenProduccionMenos30); 
    rst:='OK, Alta de E5  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
    , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
    , 'rst', rst, rst);
ROLLBACK;
END altaE5;
/
CREATE OR REPLACE
PROCEDURE altaE6(
n_contador  	IN NUMBER,
n_consumo       IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE6
PROPSITO: gestiona el alta en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_contador,n_consumo, rst
INPUT:      n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE6('2012',90,rst);
******************************************************************************/
--definicion de variables
contador_test     VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
dup_contador      EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_contador        IS NULL)
	OR (n_consumo         IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

-- insertamos en E6
INSERT INTO E_6(contador,consumo) VALUES (n_contador, n_consumo);

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E6: '  || 'n_contador: '  ||  n_contador); 
    DBMS_OUTPUT.PUT_LINE('Alta de E6: '  || 'n_consumo: '  ||  n_consumo); 
    rst:='OK, Alta de E6  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
    , 'rst', rst, rst);
ROLLBACK;
END altaE6;
/
CREATE OR REPLACE
PROCEDURE altaE7(
n_cliente  	      IN NUMBER,
n_consumoMedio        IN NUMBER,
rst OUT VARCHAR2
)
IS

/******************************************************************************
NOMBRE: altaE7
PROPSITO: gestiona el alta en la tabla estadstica E_7
            Consumo medio de todos los clientes.
PARAMETERS: n_contador,n_consumo, rst
INPUT:      n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaE7(2,90,rst);
******************************************************************************/
--definicion de variables
cliente_test      INTEGER;
err_msg       	  VARCHAR2 (100);
dup_cliente       EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_cliente           IS NULL)
	OR (n_consumoMedio      IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista el  cliente 
SELECT COUNT (*)
INTO cliente_test
FROM clientes
WHERE clientes.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

-- insertamos en E7
INSERT INTO E_7(cliente,consumoMedio) VALUES (n_cliente, n_consumoMedio);

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E_7: '  || 'n_cliente: '  ||  n_cliente); 
    DBMS_OUTPUT.PUT_LINE('Alta de E_7: '  || 'n_consumoMedio : '  ||  n_consumoMedio ); 
    rst:='OK, Alta de E_7  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. altaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_cliente
THEN
    rst := 'ERROR: NO existe el Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
    , 'rst', rst, rst);
ROLLBACK;
END altaE7;
/
CREATE OR REPLACE
PROCEDURE bajaE1(
n_id				IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE1
PROPSITO: gestiona el borrado del registro en la tabla estadstica E1
PARAMETERS: n_id, rst
INPUT: n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE1(1,rst)
******************************************************************************/
--definicion de variables
id_test		INTEGER;
err_msg       	VARCHAR2 (100);
des_nulo      	EXCEPTION;
dup_id		EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
IF 	   (n_id IS NULL)
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_1
WHERE E_1.id = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--borramos en E1
DELETE
FROM E_1
WHERE id=n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Baja/borrado en E1: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Borrado del registro en E1  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
   , 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_id: ' || n_id, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;

END bajaE1;
/
CREATE OR REPLACE
PROCEDURE bajaE2(
n_id				IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE2
PROPSITO: baja del registro en la  la tabla estadstica E_2
Dada una lnea de comunicacin y un ao en concreto, el valor medio de la energa consumida
si el contador hace servir dos lineas, computa en las dos
PARAMETERS: n_id, rst
INPUT: n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE2(1,rst);
******************************************************************************/
--definicion de variables

id_test         INTEGER;
err_msg       	VARCHAR2 (100);
dup_id          EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
 	   
IF 	   (n_id  IS NULL)

THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_2
WHERE E_2.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--borramos registro de  E2
DELETE
FROM E_2
WHERE id=n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Baja del registro  E_2: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Baja del registro E_2:  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_id: '
    ||  n_id
     , 'rst', rst, rst);
ROLLBACK;
END bajaE2;
/
CREATE OR REPLACE
PROCEDURE bajaE3(

n_id 	IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE3
PROPSITO: gestiona la baja la tabla estadstica E_3
PARAMETERS: n_id,rst
INPUT:      n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE3(1,rst);
******************************************************************************/
--definicion de variables
id_test INTEGER;
err_msg       	VARCHAR2 (100);
dup_id EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
IF (n_id		IS NULL)

THEN
RAISE des_nulo;
END IF;



--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_3
WHERE E_3.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;


--borrar registro  E3
DELETE FROM E_3
WHERE id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Borrar registro  E3: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Borrar registro de E3  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
	'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;



WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
	'n_id: '
    ||  n_id
   , 'rst', rst, rst);
ROLLBACK;



WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. BajaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
	'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;
END bajaE3;
/
CREATE OR REPLACE
PROCEDURE bajaE4(
n_id		IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE4
PROPSITO: gestiona la baja del registro  de la  tabla estadstica 
            Dado un ao en concreto: porcentaje de lineas que superan 50% de energia consumida.
PARAMETERS: n_id,n_anyo, n_perLineaMas50, rst
INPUT:      n_id,n_anyo, n_perLineaMas50
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE4(1,rst);
******************************************************************************/
--definicion de variables
id_test       INTEGER;
err_msg       	  VARCHAR2 (100);
dup_id		EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_id              IS NULL)  
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_4
WHERE E_4.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

-- baja del registro en E4
DELETE FROM E_4
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Borrado registro de  E4: '  || 'n_id: '  ||  n_id);  
    rst:='OK, Borrado resgistro de   E4  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
    
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE4',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
   , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;
END bajaE4;
/
CREATE OR REPLACE
PROCEDURE bajaE5(
n_id				IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE5
PROPSITO: gestiona la baja del registro en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_id, rst
INPUT:      n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE5(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test		INTEGER;
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;
dup_id			EXCEPTION;
BEGIN

--verificamos si hay campos no nulos: nulos
IF 	  (n_id                   IS NULL)
THEN
RAISE des_nulo;
END IF;
--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_5
WHERE E_5.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--boramos el registro de  E5
DELETE FROM  E_5
WHERE id = n_id;
-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Borrado registro de   E_5: '  || 'n_id: '  ||  n_id);  
    rst:='OK, Borrado registro de   E_5  realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
       , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE5',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
   , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_id: '
    ||  n_id
      , 'rst', rst, rst);
ROLLBACK;
END bajaE5;
/
CREATE OR REPLACE
PROCEDURE bajaE6(
n_id			IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE6
PROPSITO: gestiona el borrado del registro en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_id,n_contador,n_consumo, rst
INPUT:      n_id,n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE6(1,rst);
******************************************************************************/
--definicion de variables
id_test			INTEGER;
err_msg       	  VARCHAR2 (100);
dup_id            EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_id 			IS NULL)
	
THEN
RAISE des_nulo;
END IF;



--Verificamos exista el  registro 
SELECT COUNT (*)
INTO id_test
FROM E_6
WHERE E_6.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


--borramos el registro de E_6
DELETE FROM  E_6
WHERE id = n_id;

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Borrar el registro de  E6: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Modifica de E6  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
    , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el Registro';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 	'n_id: '
    ||  n_id
, 'rst', rst, rst);
ROLLBACK;


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;
END bajaE6;
/
CREATE OR REPLACE
PROCEDURE bajaE7(
n_id		      IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: bajaE7
PROPSITO: gestiona la baja del registro  en la tabla estadstica E_7
            Consumo medio de todos los clientes.
PARAMETERS: n_id,rst
INPUT:      n_id
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: bajaE7(1,rst);
******************************************************************************/
--definicion de variables
id_test		  INTEGER;
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;
dup_id		  EXCEPTION;
BEGIN


--verificamos si hay campos no nulos: nulos
    IF 	   (n_id 	        IS NULL)
THEN
RAISE des_nulo;
END IF;


--Borrar registro de  E7
DELETE FROM E_7
WHERE id = n_id;

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Borrar registro de  E_7: '  || 'n_id: '  ||  n_id); 
    rst:='OK, Borrar registro de E7 realizado con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. bajaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id : '
    ||  n_id
       , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. bajaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_id: '
    ||  n_id
       , 'rst', rst, rst);
ROLLBACK;


WHEN dup_id
THEN
    rst := 'ERROR: NO existe el Registro';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. bajaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. bajaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_id: '
    ||  n_id
    , 'rst', rst, rst);
ROLLBACK;
END bajaE7;
/
CREATE OR REPLACE
PROCEDURE modificaE1(
n_id				IN NUMBER,
n_central			IN NUMBER,
n_consumoContadores		IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE1
PROPSITO: gestiona la modificacion en la tabla estadstica E1
PARAMETERS: n_id,n_central, n_consumoContadores, rst
INPUT: n_id,n_central, n_consumoContadores
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE1(1,1,300,rst)
******************************************************************************/
--definicion de variables
central_test	INTEGER;
clase_test      INTEGER;
id_test		INTEGER;
err_msg       	VARCHAR2 (100);
des_nulo      	EXCEPTION;
dup_clase	EXCEPTION;
dup_central	EXCEPTION;
dup_id		EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
IF 	   (n_id			IS NULL)
	OR (n_central			IS NULL)
	OR (n_consumoContadores 	IS NULL)
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM centrales
WHERE centrales.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;


--obtener el codigo de la clase y verificar que es central de produccin 
--obtenemos el codigo de la clase

SELECT ccentral.ID
INTO clase_test
FROM ccentral
WHERE ccentral.DES = 'PRODUCCION' OR 
      ccentral.DES = 'PRODUCCIN';
IF (clase_test = 0)
THEN
RAISE dup_clase;
END IF;
--comprobar que la central existe
SELECT COUNT(*)
INTO central_test
FROM centrales
WHERE centrales.ID = n_central
and centrales.CLASE = clase_test;
IF (central_test=0)
THEN
RAISE dup_central;
END IF;


--modificamos E1
UPDATE E_1
SET
central=n_central,
consumoContadores=n_consumoContadores
WHERE id = n_id;


-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modificado  E1: '  || 'n_central: '  ||  n_central); 
    rst:='OK, Modificado de E1  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
   , 'rst', rst, rst);
COMMIT;

EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_clase
THEN
    rst := 'ERROR: NO existe clase de Central de Produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'Clase de Central: ' || clase_test, 'rst', rst, rst);
ROLLBACK;

WHEN dup_central
THEN
    rst := 'ERROR: NO existe la central de produccin';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_central: ' || n_central, 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe la central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_central: ' || n_central, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_central: '
    ||  n_central
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    , 'rst', rst, rst);
ROLLBACK;

END modificaE1;
/
CREATE OR REPLACE
PROCEDURE modificaE2(
n_id				IN NUMBER,
n_linea				IN NUMBER,
n_anyo  			IN VARCHAR2,
n_consumoContadores             IN NUMBER,
n_consumoEnergiaMedio           IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE2
PROPSITO: modifica la tabla estadstica E_2
Dada una lnea de comunicacin y un ao en concreto, el valor medio de la energa consumida
si el contador hace servir dos lineas, computa en las dos
PARAMETERS: n_id,n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio, rst
INPUT: n_id,n_lina,n_anyo, n_consumoContadores,n_consumoEnergiaMedio
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE2(1,1,'2012',90,50,rst);
******************************************************************************/
--definicion de variables
linea_test	INTEGER;
id_test         INTEGER;
err_msg       	VARCHAR2 (100);
dup_id          EXCEPTION;
dup_linea	EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
 	   
IF 	   (n_id			IS NULL)
	OR (n_linea			IS NULL)
	OR (n_consumoContadores 	IS NULL)
      	OR (n_consumoEnergiaMedio 	IS NULL)

THEN
RAISE des_nulo;
END IF;

--comprobar que la linea existe
SELECT count(*)
INTO linea_test
FROM linea
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_2
WHERE E_2.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--modificamos E2
UPDATE E_2
SET
linea= n_linea,
anyo = n_anyo, 
consumoContadores = n_consumoContadores,
consumoEnergiaMedio= n_consumoEnergiaMedio
WHERE id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modificacion de E_2: '  || 'n_linea: '  ||  n_linea); 
    rst:='OK, Modificacion de E_2:  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_linea
THEN
    rst := 'ERROR: NO existe la linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe la central ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    || '  n_consumoEnergiaMedio: '
    ||  n_consumoEnergiaMedio
    , 'rst', rst, rst);
ROLLBACK;
END modificaE2;
/
CREATE OR REPLACE
PROCEDURE modificaE3(

n_id 	IN NUMBER,
n_linea				IN NUMBER,
n_consumoContadores             IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaE2
PROPSITO: gestiona el alta en la tabla estadstica E_3
PARAMETERS: n_lina,n_anyo, n_consumoContadores rst
INPUT:      n_lina,n_anyo, n_consumoContadores
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE3(1,200,rst);
******************************************************************************/
--definicion de variables
id_test INTEGER;
linea_test	INTEGER;
err_msg       	VARCHAR2 (100);
dup_id EXCEPTION;
dup_linea	EXCEPTION;
des_nulo      	EXCEPTION;

BEGIN

--verificamos si hay campos no nulos: nulos
IF (n_id		IS NULL)
	 OR  (n_linea			IS NULL)
	OR (n_consumoContadores 	IS NULL)
THEN
RAISE des_nulo;
END IF;

--comprobar que la linea existe
SELECT count(*)
INTO linea_test
FROM linea
WHERE linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;


--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_3
WHERE E_3.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;


--modificamos E3
UPDATE E_3
SET
linea= n_linea,
consumoContadores = n_consumoContadores
WHERE id = n_id;

-- Fin de las operaciones

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('modifica  E3: '  || 'n_linea: '  ||  n_linea); 
    DBMS_OUTPUT.PUT_LINE('modifica  E3: '  || 'n_consumoContadores: '  ||  n_consumoContadores); 
    rst:='OK, Alta de E3  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    , 'rst', rst, rst);
ROLLBACK;


WHEN dup_linea
THEN
    rst := 'ERROR: NO existe la linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
   , 'rst', rst, rst);
ROLLBACK;



WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaE2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_linea: '
    ||  n_linea
    || '  n_consumoContadores: '
    ||  n_consumoContadores
    , 'rst', rst, rst);
ROLLBACK;
END modificaE3;
/
CREATE OR REPLACE
PROCEDURE modificaE4(
n_id		IN NUMBER,
n_anyo  		IN VARCHAR2,
n_perLineaMas50         IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE4
PROPSITO: gestiona la modificacin de la  tabla estadstica 
            Dado un ao en concreto: porcentaje de lineas que superan 50% de energia consumida.
PARAMETERS: n_id,n_anyo, n_perLineaMas50, rst
INPUT:      n_id,n_anyo, n_perLineaMas50
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE4(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test       INTEGER;
n_anyo_ins        VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
dup_id		EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN
--control de la longitud de cadenas
n_anyo_ins := SUBSTR (n_anyo, 1, 4);

--verificamos si hay campos no nulos: nulos
IF 	   (n_id              IS NULL)  
       OR (n_anyo_ins	      IS NULL)
	OR (n_perLineaMas50   IS NULL)
THEN
RAISE des_nulo;
END IF;

--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_4
WHERE E_4.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;



-- modificamos en E4
UPDATE E_4
SET
anyo = n_anyo,
perLineaMas50= n_perLineaMas50
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica E4: '  || 'n_anyo: '  ||  n_anyo); 
    DBMS_OUTPUT.PUT_LINE('Modifica E4: '  || 'n_perLineaMas50: '  ||  n_perLineaMas50); 
    rst:='OK, Modifica  E4  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE4',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
   , 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_perLineaMas50: '
    ||  n_perLineaMas50
    , 'rst', rst, rst);
ROLLBACK;
END modificaE4;
/
CREATE OR REPLACE
PROCEDURE modificaE5(
n_id				IN NUMBER,
n_anyo  		        IN VARCHAR2,
n_cenProduccionMenos30          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE5
PROPSITO: gestiona la modificacin en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_id,n_anyo, cenProduccionMenos30, rst
INPUT:      n_id,n_anyo, cenProduccionMenos30 
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE5(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test		INTEGER;
n_anyo_ins        VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
des_nulo      	  EXCEPTION;
dup_id			EXCEPTION;
BEGIN
--control de la longitud de cadenas
n_anyo_ins := SUBSTR (n_anyo, 1, 4);

--verificamos si hay campos no nulos: nulos
IF 	  (n_id                   IS NULL)
      OR  (n_anyo_ins		  IS NULL)
      OR (n_cenProduccionMenos30  IS NULL)
THEN
RAISE des_nulo;
END IF;
--verfico que existe el id 
SELECT COUNT(*)
INTO id_test
FROM E_5
WHERE E_5.ID = n_id;
IF (id_test=0)
THEN
RAISE dup_id;
END IF;

--modificamos E5
UPDATE E_5
SET
anyo = n_anyo,
cenProduccionMenos30 = n_cenProduccionMenos30
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica  E_5: '  || 'n_anyo: '  ||  n_anyo); 
    DBMS_OUTPUT.PUT_LINE('Modifica  E_5: '  || 'n_cenProduccionMenos30: '  ||  n_cenProduccionMenos30); 
    rst:='OK, Modifica  E_5  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
    , 'rst', rst, rst);
ROLLBACK;
WHEN dup_id
THEN
    rst := 'ERROR: NO existe el registro ';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE5',to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
   , 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
      'n_anyo: '
    ||  n_anyo
    || '  n_cenProduccionMenos30: '
    ||  n_cenProduccionMenos30
    , 'rst', rst, rst);
ROLLBACK;
END modificaE5;
/
CREATE OR REPLACE
PROCEDURE modificaE6(
n_id			IN NUMBER,
n_contador  	IN NUMBER,
n_consumo       IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: modificaE6
PROPSITO: gestiona la modificacin en la tabla estadstica 
            Dado un ao en concreto: el numero de centrales de produccion que generan menos del  30% de produccin.
PARAMETERS: n_id,n_contador,n_consumo, rst
INPUT:      n_id,n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE6(1,'2012',90,rst);
******************************************************************************/
--definicion de variables
id_test			INTEGER;
contador_test     VARCHAR2(4 CHAR);
err_msg       	  VARCHAR2 (100);
dup_contador      EXCEPTION;
dup_id            EXCEPTION;
des_nulo      	  EXCEPTION;

BEGIN


--verificamos si hay campos no nulos: nulos
IF 	   (n_id 			IS NULL)
	OR (n_contador       IS NULL)
	OR (n_consumo        IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista el  contador 
SELECT COUNT (*)
INTO contador_test
FROM CONTADORES
WHERE CONTADORES.ID = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--Verificamos exista el  registro 
SELECT COUNT (*)
INTO id_test
FROM E_6
WHERE E_6.ID = n_id;
IF (id_test = 0)
THEN
RAISE dup_id;
END IF;


--modificamos E_6
UPDATE E_6
SET
contador= n_contador,
consumo= n_consumo
WHERE id = n_id;

-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Modifica E6: '  || 'n_contador: '  ||  n_contador); 
    DBMS_OUTPUT.PUT_LINE('Modifica E6: '  || 'n_consumo: '  ||  n_consumo); 
    rst:='OK, Modifica de E6  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_id
THEN
    rst := 'ERROR: NO existe el Registro';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_contador
THEN
    rst := 'ERROR: NO existe el CONTADOR';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_contador: '
    ||  n_contador
    || '  n_consumo: '
    ||  n_consumo
    , 'rst', rst, rst);
ROLLBACK;
END modificaE6;
/
CREATE OR REPLACE
PROCEDURE modificaE7(
n_id		      IN NUMBER,
n_cliente  	      IN NUMBER,
n_consumoMedio        IN NUMBER,
rst OUT VARCHAR2
)
IS

/******************************************************************************
NOMBRE: modificaE7
PROPSITO: gestiona el alta en la tabla estadstica E_7
            Consumo medio de todos los clientes.
PARAMETERS: n_id,n_contador,n_consumo, rst
INPUT:      n_id,n_contador,n_consumo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: modificaE7(1,2,90,rst);
******************************************************************************/
--definicion de variables
id_test		  INTEGER;
cliente_test      INTEGER;
err_msg       	  VARCHAR2 (100);
dup_cliente       EXCEPTION;
des_nulo      	  EXCEPTION;
dup_id		  EXCEPTION;
BEGIN


--verificamos si hay campos no nulos: nulos
    IF 	   (n_id 	        IS NULL)
	OR (n_cliente           IS NULL)
	OR (n_consumoMedio      IS NULL)
THEN
RAISE des_nulo;
END IF;

--Verificamos exista el  cliente 
SELECT COUNT (*)
INTO cliente_test
FROM clientes
WHERE clientes.ID = n_cliente;
IF (cliente_test = 0)
THEN
RAISE dup_cliente;
END IF;

--modificamos E7
UPDATE E_7
SET
cliente= n_cliente,
consumoMedio= n_consumoMedio
WHERE id = n_id;


-- Fin de las operaciones
-- pantalla
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('Alta de E_7: '  || 'n_cliente: '  ||  n_cliente); 
    DBMS_OUTPUT.PUT_LINE('Alta de E_7: '  || 'n_consumoMedio : '  ||  n_consumoMedio ); 
    rst:='OK, Alta de E_7  realizada con exito';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 

--rst := 'OK';
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
   , 'rst', rst, rst);
COMMIT;

-- control de excepciones
EXCEPTION

WHEN des_nulo
THEN
    rst := 'ERROR: hay campos no nulos: vacios';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
     'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
    , 'rst', rst, rst);
ROLLBACK;

WHEN dup_cliente
THEN
    rst := 'ERROR: NO existe el Cliente';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_id
THEN
    rst := 'ERROR: NO existe el Registro';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
   'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. modificaE7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
    'n_cliente: '
    ||  n_cliente
    || '  n_consumoMedio: '
    ||  n_consumoMedio
    , 'rst', rst, rst);
ROLLBACK;
END modificaE7;
/
CREATE OR REPLACE
PROCEDURE altaEstadisticas(
n_anyo   IN  NUMBER,
rst     OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaEstadisticas
PROPSITO: gestiona la actualizacion de las estadisticas
PARAMETERS: n_anyo ,rst
INPUT:  n_anyo
OUTPUT: rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaEstadisticas(2011,rst);

******************************************************************************/

-- variables para E_2 y E6
n_contador  NUMBER;
n_consumo   NUMBER;
n_anyo_ins  NUMBER; -- para E_2
e7_test                 INTEGER;
central_test            INTEGER;
lineas_test             INTEGER;
i                       INTEGER;
lMax                    INTEGER; 
iMax                    INTEGER;
porcentaje              NUMBER;
tipo_test               INTEGER;
err_msg                 VARCHAR2(100);

dup_central             EXCEPTION;
dup_lineas              EXCEPTION;
dup_null                EXCEPTION;

-- para actualizar E_2
CURSOR c2 IS
select distinct linea.id, consumos.ANYO, avg(consumos.CONTADOR)
from linea, lineas, consumos
where
linea.ID = lineas.LINEA
AND lineas.C2 = consumos.CONTADOR
AND consumos.ANYO = n_anyo
group by linea.id, consumos.ANYO
order by linea.id;

-- cursor para extraer los datos de Estadistica E6
CURSOR c1 IS
select consumos.CONTADOR,sum(consumos.consumo)
from consumos
group  by consumos.contador 
having sum(consumos.consumo) >0 
order by sum(consumos.consumo) desc;

---------
--proceso
---------
BEGIN
--inicializar variables
i :=1;

-------------------------------
-- actualizar estadisticas E_1
--------------------------------

-- obtenemos el numero de centrales de produccin activas
select  count (distinct centrales.id)
INTO central_test
FROM centrales, ccentral, lineas, linea, consumos, contadores
WHERE
    ccentral.ID     = centrales.CLASE
AND centrales.CLASE = 2                 --produccion
and linea.id = lineas.LINEA
and centrales.ID = lineas.C1            -- conectadas
and consumos.CONTADOR = lineas.C2       -- miro consumos
and contadores.id = lineas.c2           -- conectadas
and linea.ESTADO =1                     -- en alta
and lineas.ESTADO =1                    --en alta
and centrales.ESTADO =1                 --activas
and contadores.ESTADO =1                --en alta
and consumos.CONSUMO > 0;               -- con consumo

IF (central_test = 0)
THEN
RAISE dup_central;
END IF;

--actualizar registros
WHILE (i <= central_test)  LOOP  
--  altaE1(centrales.id,getConsumoCentral(centrales.id),to_char(sysdate,'DD/MM/YYYY'),rst);  -- actualizar el registro
  altaE1(i,getConsumoCentral(i),to_char(sysdate,'DD/MM/YYYY'),rst);  -- actualizar el registro
  --  DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('total_Centrales:' || central_test ||'central: '||central:  || i|| ' consumo:' ||getConsumoCentral(i)||' fecha: '|| to_char(sysdate,'DD/MM/YYYY') );
    i := i + 1;
END LOOP;
-- Fin de las operaciones
rst := 'OK: Actualizo E_1';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');
altaLog('Proc. altaEstadisticas_E1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_2
-------------------------------
--inicializar variables
--i :=0;
n_contador  :=0;  -- variable reutilizada para linea
n_consumo   :=0;  -- variable reutilizada para guardar el consumo medio de la linea
n_anyo_ins :=n_anyo;

 OPEN c2;
               FETCH c2 INTO n_contador ,n_anyo_ins ,n_consumo ;
               WHILE c2%FOUND  LOOP
                               
 --DBMS_OUTPUT.PUT_LINE('');
   DBMS_OUTPUT.PUT_LINE('   linea: ' || n_contador || '  n_anyo: ' || n_anyo || '  consumo_medio: ' || n_consumo );
              FETCH c2 INTO n_contador ,n_anyo_ins ,n_consumo ;
                altaE2(n_contador ,n_anyo_ins, n_consumo,rst);  -- actualizar  el registro
                end loop;
        CLOSE c2;
 -- Fin de las operaciones

rst := 'OK: Actualizo E_2';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
 ||'   n_contador'
 || n_contador
 || '  n_anyo: '
 || n_anyo
 || '  n_consumo: '
 || n_consumo
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_3
------------------------------
i     := 1;
lMax  := 0;
iMax  := 0;
-- obtener numero de lineas conectadas
select  count (distinct linea.ID)
INTO lineas_test
FROM lineas, linea
WHERE
    lineas.LINEA = linea.ID;
IF (lineas_test = 0)
THEN
RAISE dup_lineas;
END IF;
WHILE (i < lineas_test)  LOOP  
 IF (getConsumoLinea(i) > lMax)
    THEN    lMax := getConsumoLinea(i); -- buscar el consumo mximo
            iMax := i;                  -- id de la linea mxima
    END IF;
     i := i + 1;  --avanza
END LOOP;
  altaE3(i,getConsumoLinea(i),to_char(sysdate,'DD/MM/YYYY'),rst);  -- actualizar  el registro
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('Consumo Maximo : '||i ||', '|| lMax );
   -- DBMS_OUTPUT.PUT_LINE('Linea consumo Maximo : '||i ||', '|| getConsumoLinea(i) );
-- Fin de las operaciones

rst := 'OK: Actualizo E_3';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_4
-------------------------------

--lineas_test -> lineas conectadas
i    := 2;
lMax := 0;  --contador si linea supera el 50%
porcentaje := 0;  -- porcentaje final de lineas
    
WHILE (i < lineas_test)  LOOP  
 IF  (getConsumoLineaAnyo(i,n_anyo) > getLineaCMax(i)/2)
    THEN    lMax := lMax +1; -- incrementamos el contador de lina que supera el 50%
      -- DBMS_OUTPUT.PUT_LINE('lineas_test  : '|| lineas_test );
      -- DBMS_OUTPUT.PUT_LINE('lMax  : '|| lMax );
      -- DBMS_OUTPUT.PUT_LINE('i  : '|| i );

        END IF;
     i := i + 1;  --avanza
END LOOP;
 
 porcentaje :=  lMax*100/lineas_test;
 

 altaE4(n_anyo, iMax,rst);  -- actualizar  el registro
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('lineas_test  : '|| lineas_test );
   -- DBMS_OUTPUT.PUT_LINE('n_anyo  : '||i ||', '|| n_anyo );
   -- DBMS_OUTPUT.PUT_LINE('Porcentaje de lineas que superan el 50% : '||porcentaje ||'%'  );
-- Fin de las operaciones

rst := 'OK: Actualizo E_4';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

----------------------------------
-- actualizar estadstica E_5
-----------------------------------
i     := 1;
iMax  := 0;
WHILE (i < central_test)  LOOP  
 IF (getConsumoCentralAnyo(i ,n_anyo) < getCentralEmax(i) * 0.3)  -- produccion < del 30% de eMax de la central
    THEN    
            iMax := iMax+1;                  -- acumulo el numero de centrales
    END IF;
   i := i + 1;
END LOOP;
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('n_anyo : ' || n_anyo );
   -- DBMS_OUTPUT.PUT_LINE('iMax : ' || iMax );

altaE5(n_anyo,iMax,rst); -- actualizar el registro

-- Fin de las operaciones
rst := 'OK: Actualizo E_5';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;

------------------------------
-- actualizar estadstica E_6
-------------------------------
--inicializar contador
i :=0;
--verificamos que los campos no nulos no sean nulos
 OPEN c1;
               FETCH c1 INTO n_contador,n_consumo ;
               WHILE (c1%FOUND and ( c1%ROWCOUNT <= 10)) LOOP
                               
 DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
 DBMS_OUTPUT.PUT_LINE('   n_contador: ' || n_contador  || '  n_consumo: ' || n_consumo );
               FETCH c1 INTO n_contador,n_consumo ;
                altaE6(n_contador, n_consumo,rst);  -- actualizar  el registro
                end loop;
        CLOSE c1;
 -- Fin de las operaciones

rst := 'OK: Actualizo E_6';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
 ||'   n_contador'
 || n_contador
 || '  n_consumo: '
 || n_consumo
, 'rst', rst, rst);
COMMIT;

---------------------------------
-- actualizar estadstica E_7
---------------------------------
i :=1;
--obterner el numero de clientes 
select count(distinct clientes.id)
into e7_test
from contratos, clientes, contadores, consumos
where clientes.ID   = contratos.CLIENTE
and  contadores.ID  = contratos.CONTADOR
and  contadores.ID  = consumos.CONTADOR;
WHILE (i < e7_test)  LOOP  
altaE7(getIdCliente(i), getConsumoMedioCliente(i),rst);  -- actualizar el registro
i := i + 1;
   -- DBMS_OUTPUT.PUT_LINE('');
   -- DBMS_OUTPUT.PUT_LINE('Cliente y consumo medio : '||getIdCliente(i) ||', '|| getConsumoMedioCliente(i) );
END LOOP;

-- Fin de las operaciones
rst := 'OK: Actualizo E_7';
DBMS_OUTPUT.PUT_LINE('------------------------------------');
DBMS_OUTPUT.PUT_LINE(rst);
DBMS_OUTPUT.PUT_LINE('------------------------------------');

altaLog('Proc. altaEstadisticas_E7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
COMMIT;
---------------------------------------------


EXCEPTION
WHEN dup_central
THEN
    rst := 'ERROR: No hay centrales';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEstadistica E_1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;
WHEN dup_lineas
THEN
    rst := 'ERROR: No hay lineas conectadas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst); 
altaLog('Proc. altaEstadistica_E_3 ', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    rst := 'ERROR: hay campos NO nulos, sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaEstadisticas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
 err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaEstadisticas', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'alta Estadisticas'
, 'rst', rst, rst);
ROLLBACK;
END altaEstadisticas;
/* FIN GESTOR_ESTADISTICAS*/
/
/* GESTOR_CONSULTAS*/
CREATE OR REPLACE
PROCEDURE altaC1(
n_contrato            IN NUMBER,
n_pContratada         IN NUMBER,
n_tpConsumo           IN NUMBER,
n_mConsumo            IN NUMBER,
n_anyo                IN NUMBER,
n_mes                 IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: altaC1 
PROPSITO: Alta registro en la tabla C1
PARAMETERS: n_contrato, n_pContratada , n_tpConsumo, n_mConsumo, n_anyo, n_mes,rst
INPUT:      n_contrato, n_pContratada , n_tpConsumo, n_mConsumo, n_anyo, n_mes
OUTPUT: ,rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaC1(1,12,12.30,12,2011,7, rst);
******************************************************************************/
contrato_test           INTEGER;
err_msg                 VARCHAR2(100);
dup_contrato            EXCEPTION;
dup_null                EXCEPTION;

BEGIN

--verificamos que los campos no nulos no sean nulos
IF (n_contrato        IS NULL)
OR (n_pContratada     IS NULL)
OR (n_tpConsumo       IS NULL)
OR (n_mConsumo        IS NULL)
OR (n_anyo            IS NULL)
OR (n_mes             IS NULL)
THEN RAISE dup_null;
END IF;
-- comprobar contrato
SELECT COUNT(*)
INTO contrato_test
FROM contratos
WHERE
contratos.id = n_contrato;
IF      (contrato_test = 0)
   THEN RAISE dup_contrato;
END IF;
--insertamos en la tabla de C1 contadoresCiudadFecha
INSERT INTO C1 ( contrato, pContratada, tpConsumo, mConsumo, anyo, mes )
VALUES ( n_contrato, n_pContratada, n_tpConsumo, n_mConsumo, n_anyo, n_mes); 
-- Fin de las operaciones
      rst:='Ok, C1 con exito';
      DBMS_OUTPUT.PUT_LINE('');
      DBMS_OUTPUT.PUT_LINE(rst);
       DBMS_OUTPUT.PUT_LINE(
  'n_contrato: '
 || n_contrato
 || ' n_pContratada: '
 || n_pContratada
 || ' n_tpConsumo: '
 ||n_tpConsumo 
 || ' n_mConsumo: '
 ||  n_mConsumo
 || ' n_anyo: ' 
 || n_anyo
 );
    
altaLog('Proc. altaC1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contrato: '
 || n_contrato
 || ' n_pContratada: '
 || n_pContratada
 || ' n_tpConsumo: '
 ||n_tpConsumo 
 || ' n_mConsumo: '
 ||  n_mConsumo
 || ' n_anyo: ' 
 || n_anyo
  || ' n_mes: ' 
 || n_mes
, 'rst', rst, rst);

COMMIT;
-- controlamos las excepciones
EXCEPTION

WHEN dup_contrato
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(
 'n_contrato: '
 || n_contrato
 || ' n_pContratada: '
 || n_pContratada
 || ' n_tpConsumo: '
 ||n_tpConsumo 
 || ' n_mConsumo: '
 ||  n_mConsumo
 || ' n_anyo: ' 
 || n_anyo
  || ' n_mes: ' 
 || n_mes
  ); 
     rst := 'ERROR: No existe el contrato';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaC1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contrato: '
 || n_contrato
 || ' n_pContratada: '
 || n_pContratada
 || ' n_tpConsumo: '
 ||n_tpConsumo 
 || ' n_mConsumo: '
 ||  n_mConsumo
 || ' n_anyo: ' 
 || n_anyo
  || ' n_mes: ' 
 || n_mes

, 'rst', rst, rst);
ROLLBACK;
WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaC1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contrato: '
 || n_contrato
 || ' n_pContratada: '
 || n_pContratada
 || ' n_tpConsumo: '
 ||n_tpConsumo 
 || ' n_mConsumo: '
 ||  n_mConsumo
 || ' n_anyo: ' 
 || n_anyo
  || ' n_mes: ' 
 || n_mes

, 'rst', rst, rst);
ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaC1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
 'n_contrato: '
 || n_contrato
 || ' n_pContratada: '
 || n_pContratada
 || ' n_tpConsumo: '
 ||n_tpConsumo 
 || ' n_mConsumo: '
 ||  n_mConsumo
 || ' n_anyo: ' 
 || n_anyo
  || ' n_mes: ' 
 || n_mes
, 'rst', rst, rst);
ROLLBACK;
END altaC1;
/
/*
--prueba de uso
declare rst varchar2(250);
begin
--n_contrato, n_pContratada , n_tpConsumo, n_mConsumo, n_anyo, n_mes
altaC1(1,12,12.30,12,2011,7, rst);
end;
*/
CREATE OR REPLACE
PROCEDURE altaC2(
n_central		IN NUMBER,
n_ubica    	IN NUMBER,
n_eEmitida		IN NUMBER,
n_eMax 		IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  altaC2 
PROPSITO:  consultarCentralesDistribucionMasEnergia
PARAMETERS: n_central,n_ubica,n_eEmitida,n_eMax ,rst
INPUT:  n_central,n_ubica,n_eEmitida,n_eMax 
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaC2(1,10,10,30, rst);
******************************************************************************/

err_msg             VARCHAR2(100);

central_test	INTEGER;
ubica_test		INTEGER;
dup_central       EXCEPTION;
dup_ubica		EXCEPTION;
dup_null        EXCEPTION;
            
BEGIN


--verificamos que los campos no nulos no sean nulos
IF (n_central		IS NULL)
OR (n_ubica		IS NULL)
OR (n_eEmitida		IS NULL)
OR (n_eMax 		IS NULL)

THEN RAISE dup_null;
END IF;

-- verificar central y ubicacin 

SELECT count(*)
INTO central_test
FROM centrales
WHERE 
centrales.id = n_central;
IF (central_test = 0)
THEN
RAISE dup_central;
END IF;

SELECT count(*)
INTO ubica_test
FROM ubicaciones
WHERE 
ubicaciones.id = n_ubica;
IF (ubica_test = 0)
THEN
RAISE dup_ubica;
END IF;


 DBMS_OUTPUT.ENABLE;
 DBMS_OUTPUT.PUT_LINE('');
 DBMS_OUTPUT.PUT_LINE('consultarCentralesDistribucionMasEnergia' 
||' n_central:'
||n_central
||' n_ubica'
|| n_central
|| ' n_eEmitida:'
|| n_eEmitida
|| ' n_eMax :'
|| n_eMax 
) ;
 DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
 DBMS_OUTPUT.PUT_LINE('');
  

--insertamos en la tabla de C3 
 
INSERT INTO C2 (central,ubica,eEmitida,eMax)  
VALUES(n_central,n_ubica,n_eEmitida,n_eMax );

-- Fin de las operaciones
 
    rst:='Ok, AltaconsultarCentralesDistribucionMasEnergia';
       
altaLog('Proc. altaC2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central:'
||n_central
||' n_ubica'
|| n_central
|| ' n_eEmitida:'
|| n_eEmitida
|| ' n_eMax :'
|| n_eMax 
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_central
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('consultarClientesContadoresAltaDisponibiliad' 
||' n_central:'
||n_central
||' n_ubica'
|| n_central
|| ' n_eEmitida:'
|| n_eEmitida
|| ' n_eMax :'
|| n_eMax 
) ;
    rst := 'ERROR: No hay central';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaC2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central:'
||n_central
||' n_ubica'
|| n_central
|| ' n_eEmitida:'
|| n_eEmitida
|| ' n_eMax :'
|| n_eMax 
, 'rst', rst, rst);

ROLLBACK;


WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central:'
||n_central
||' n_ubica'
|| n_central
|| ' n_eEmitida:'
|| n_eEmitida
|| ' n_eMax :'
|| n_eMax 
, 'rst', rst, rst);

ROLLBACK;

WHEN dup_ubica
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: No hay ubicacion';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central:'
||n_central
||' n_ubica'
|| n_central
|| ' n_eEmitida:'
|| n_eEmitida
|| ' n_eMax :'
|| n_eMax 
, 'rst', rst, rst);

ROLLBACK;


ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaC2', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central:'
||n_central
||' n_ubica'
|| n_central
|| ' n_eEmitida:'
|| n_eEmitida
|| ' n_eMax :'
|| n_eMax 
, 'rst', rst, rst);
ROLLBACK;
END altaC2;
/
CREATE OR REPLACE
PROCEDURE altaC3(
n_linea               IN NUMBER,
n_cLinea              IN NUMBER,
n_eAmplia             IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  altaC3 
PROPSITO:  alta en la tabla C3
PARAMETERS: n_linea,n_cLinea,n_eAmplia,rst
INPUT:  n_linea,n_cLinea,n_eAmplia
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaC3(1,20,30, rst);
******************************************************************************/

err_msg             VARCHAR2(100);

linea_test		INTEGER;
max_test		INTEGER;

dup_linea       EXCEPTION;
dup_max		EXCEPTION;
dup_null        EXCEPTION;
            
BEGIN


--verificamos que los campos no nulos no sean nulos
IF (n_linea   			IS NULL)
OR (n_cLinea              IS NULL)
OR (n_eAmplia             IS NULL)

THEN RAISE dup_null;
END IF;

-- verificar linea y carga mxima de lnea

SELECT count(*)
INTO linea_test
FROM linea
WHERE 
linea.id = n_linea;
IF (linea_test = 0)
THEN
RAISE dup_linea;
END IF;

SELECT count(*)
INTO max_test
FROM linea
WHERE 
linea.cMax <  n_cLinea;
IF (max_test = 1)
THEN
RAISE dup_max;
END IF;

/*-- solo en fase de desarrollo para comprobar la salida
 DBMS_OUTPUT.ENABLE;
 DBMS_OUTPUT.PUT_LINE('');
 DBMS_OUTPUT.PUT_LINE('consultarLineasMasCargadasCapacidadMaxima' 
||' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
) ;
 DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
 DBMS_OUTPUT.PUT_LINE('');
*/

--insertamos en la tabla de C3 
 
INSERT INTO C3 (
 linea,cLinea, eAmplia)  
VALUES(n_linea,n_cLinea,n_eAmplia);

-- Fin de las operaciones
 
    rst:='Ok, alta C3: AltaconsultarLineasMasCargadasCapacidadMaxima';
    DBMS_OUTPUT.PUT_LINE('--------------------------------------------');
    DBMS_OUTPUT.PUT_LINE(rst);  
    DBMS_OUTPUT.PUT_LINE('---------------------------------------------');
 
       
altaLog('Proc. altaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
, 'rst', rst, rst);

ROLLBACK;

WHEN dup_linea
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: No hay linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
, 'rst', rst, rst);

ROLLBACK;

WHEN dup_max
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: Sobrepasa la carga mxima de linea';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_linea:'
||n_linea
||' n_cLinea'
|| n_cLinea
|| ' n_eAmplia:'
|| n_eAmplia
, 'rst', rst, rst);
ROLLBACK;
END altaC3;
/
CREATE OR REPLACE
PROCEDURE altaC4(
n_dni		          IN VARCHAR2,
n_contrato            IN NUMBER,
n_modelo			IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  altaC4 
PROPSITO:  consultarClientesContadoresAltaDisponibiliad 
PARAMETERS: n_dni,n_contrato,n_modelo ,rst
INPUT:  n_dni,n_contrato,n_modelo
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: altaC4('48023076',1,1, rst);
******************************************************************************/
n_dni_ins      VARCHAR2(10);

err_msg             VARCHAR2(100);

dni_test	INTEGER;
contrato_test	INTEGER;
modelo_test	INTEGER;
dup_dni           EXCEPTION;
dup_contrato		EXCEPTION;
dup_modelo			EXCEPTION;
dup_null            EXCEPTION;
            
BEGIN

--comprobamos la longitud de las cadenas
n_dni_ins   := SUBSTR (n_dni, 1, 10);

--verificamos que los campos no nulos no sean nulos
IF (n_dni_ins   IS NULL)
OR (n_contrato   IS NULL)
OR (n_modelo   IS NULL)

THEN RAISE dup_null;
END IF;

-- verificar dni, contrato y modelo

SELECT count(*)
INTO dni_test
FROM clientes
WHERE 
clientes.NIFCIF = n_dni;
IF (dni_test = 0)
THEN
RAISE dup_dni;
END IF;

SELECT count(*)
INTO contrato_test
FROM contratos
WHERE 
contratos.id = n_contrato;
IF (contrato_test = 0)
THEN
RAISE dup_contrato;
END IF;

SELECT count(*)
INTO modelo_test
FROM modelos
WHERE 
modelos.id = n_modelo;
IF (modelo_test = 0)
THEN
RAISE dup_modelo;
END IF;


 DBMS_OUTPUT.ENABLE;
 DBMS_OUTPUT.PUT_LINE('');
 DBMS_OUTPUT.PUT_LINE('consultarClientesContadoresAltaDisponibiliad' 
||' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
) ;
 DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
 DBMS_OUTPUT.PUT_LINE('');
  

--insertamos en la tabla de C4 
 
INSERT INTO C4 (dni,contrato,modelo)
VALUES(n_dni_ins,n_contrato,n_modelo);

-- Fin de las operaciones
 
    rst:='Ok, Alta consultarClientesContadoresAltaDisponibiliad';
       
altaLog('Proc. altaC4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_contrato
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('consultarClientesContadoresAltaDisponibiliad' 
||' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
) ;
    rst := 'ERROR: No hay contrato';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaC4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
, 'rst', rst, rst);

ROLLBACK;


WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
, 'rst', rst, rst);

ROLLBACK;

WHEN dup_modelo
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: No hay modelo';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
, 'rst', rst, rst);

ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaC4', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_dni:'
||n_dni
||' n_contrato'
|| n_contrato
|| ' n_modelo:'
|| n_modelo
, 'rst', rst, rst);
ROLLBACK;
END altaC4;
/
CREATE OR REPLACE
PROCEDURE altaC5(
n_id         	IN NUMBER,
n_contador		IN NUMBER,
n_consumo		IN NUMBER,
n_eProd		IN NUMBER,
n_ini		  	IN VARCHAR2,
n_fin		  	IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  altaC5 
PROPSITO:  Alta en la tabla C5
PARAMETERS: n_id, n_contador, n_consumo, n_eProd, n_ini, n_fin ,rst
INPUT:    n_id, n_contador, n_consumo, n_eProd, n_ini, n_fin 
OUTPUT:     rst
RETORNA:    'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaC5(1,2,30,40,'01/01/2012','01/06/2012', rst);
******************************************************************************/
n_ini_ins   VARCHAR2(11);
n_fin_ins   VARCHAR2(11);

err_msg             VARCHAR2(100);
dup_null            EXCEPTION;
            
BEGIN

--comprobamos la longitud de las cadenas
n_ini_ins   := SUBSTR (n_ini, 1, 11);
n_fin_ins   := SUBSTR (n_fin, 1, 11);


--verificamos que los campos no nulos no sean nulos
IF (n_id IS NULL)
OR ( n_contador  IS NULL)
OR  (n_consumo  IS NULL)
OR  (n_eProd  IS NULL)
OR ( n_ini_ins IS NULL)
OR  (n_fin_ins  IS NULL)
THEN RAISE dup_null;
END IF;

  
--insertamos en la tabla de C5 
 
INSERT INTO C5 (central, contador, consumo, eProd, pInicial ,pFinal)
VALUES(n_id, n_contador,n_consumo,n_eProd ,n_ini_ins,n_fin_ins);

-- Fin de las operaciones
 
    rst:='OK, Alta C5';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
       
altaLog('Proc. altaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id'
|| n_id
||'  n_contador: '
|| n_contador
||'  n_consumo  : '
|| n_consumo
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION


WHEN dup_null
THEN
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id'
|| n_id
||'  n_contador: ' 
|| n_contador 
||'  n_consumo  : '
|| n_consumo
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id'
|| n_id
||'  n_contador: ' 
|| n_contador 
||'  n_consumo  : '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END altaC5;
/
CREATE OR REPLACE
PROCEDURE altaC7(
n_contador	   IN NUMBER,
n_anyo             IN NUMBER,
n_fabrica          IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  altaC7 
PROPSITO:  alta en la tabla de consultas C7: contadores, aos de antiguedad 
PARAMETERS: n_contador, n_anyo, n_fabrica , sysdate,rst
INPUT:  n_contador, n_anyo, n_fabrica
RETORNA: 'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: altaC7(2,7,'1997', rst);
******************************************************************************/
err_msg       VARCHAR2(100);
contador_test INTEGER;
dup_contador  EXCEPTION;
dup_null            EXCEPTION;
 
 
            
BEGIN

--verificamos que los campos no nulos no sean nulos
IF (n_contador   IS NULL)
OR (n_anyo   IS NULL)
THEN RAISE dup_null;
END IF;

-- verificar que existe el contador
SELECT count(*)
INTO contador_test
FROM contadores
WHERE 
contadores.id = n_contador;
IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;

--insertamos en la tabla de C7 
 
INSERT INTO C7 (contador, anyos,fabrica, fechaConsulta)
VALUES(n_contador, n_anyo, n_fabrica,to_char(sysdate,'DD/MM/YYYY'));


-- Fin de las operaciones
 
    rst:='Ok, alta C7 Alta consultarContadoresAntiguedad';
    DBMS_OUTPUT.PUT_LINE('--------------------------------------------');
    DBMS_OUTPUT.PUT_LINE(rst);  
    DBMS_OUTPUT.PUT_LINE('---------------------------------------------');

       
altaLog('Proc. altaC7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_contador:'
||n_contador
||' n_anyo'
|| n_anyo
|| ' n_fabrica'
|| n_fabrica
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_contador
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('ERROR: No existe el contador' 
||' n_contador:'
||n_contador
||' n_anyo'
|| n_anyo
|| ' n_fabrica'
|| n_fabrica
) ;
    rst := 'ERROR: No existe el contador';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. altaC7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_contador:'
||n_contador
||' n_anyo'
|| n_anyo
|| ' n_fabrica'
|| n_fabrica
, 'rst', rst, rst);

ROLLBACK;
WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. altaC7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_contador:'
||n_contador
||' n_anyo'
|| n_anyo
|| ' n_fabrica'
|| n_fabrica
, 'rst', rst, rst);

ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaC7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_contador:'
||n_contador
||' n_anyo'
|| n_anyo
|| 'n_fabrica'
|| n_fabrica
, 'rst', rst, rst);
ROLLBACK;
END altaC7;
/
CREATE OR REPLACE
PROCEDURE consultaC1(
n_localidad_des   IN VARCHAR2,
n_anyo        IN NUMBER,
n_mes         IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: consultaC1 
PROPSITO: Dada una ciudad y una fecha , los contadores donde el consumo mensual en la fecha 
supere  el 80% del consumo medio de todos los contadores de la ciudad en ese periodoDonada una ciutat i una data com a parmetres, el llistat de

        Codi de contracte.
        La potncia mxima contractada.
        El tant per cent de consum elctric consumit en relaci al consum mitj.
        Tot aix ordenat de forma ascendent pel tant per cent de consum elctric consumit.
PARAMETERS: n_anyos,rst
INPUT: n_localidad_des, anyo, n_mes
OUTPUT: n_localidad_des, anyo, n_mes ,rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: consultaC1('TERRASSA',2011,7, rst);
******************************************************************************/

localidad_test    INTEGER;
n_contrato        NUMERIC;
n_potencia        NUMERIC;
n_contador        NUMERIC;
n_consumo         NUMERIC; 
n_tpConsumo       NUMERIC(9,2);
n_mConsumo        NUMERIC(9,2);
n_localidad_des_ins VARCHAR2(50);
err_msg           VARCHAR2(100);
dup_localidad    EXCEPTION;
dup_null         EXCEPTION;

CURSOR C1 IS
select distinct contratos.ID , contratos.PCONTRATO , contratos.CONTADOR, sum(consumos.consumo) --(distinct contadores.ID)
from contadores, consumos, lineas, linea, contratos, localidad
WHERE 
contadores.ESTADO  = 1 -- activos
and localidad.ID =  localidad_test             -- de la localidad
and linea.id = lineas.LINEA
and lineas.C2 = consumos.CONTADOR               -- que esten conectados y tengan consumo
and contratos.CONTADOR = consumos.CONTADOR      --con contrato
and consumos.ANYO = n_anyo
and consumos.MES =  n_mes
group by contratos.ID,contratos.PCONTRATO,contratos.CONTADOR,(consumos.consumo)
having sum(consumos.CONTADOR) > 0
order by sum(consumos.consumo) asc; --en forma ascendent

-----------------------------------------

BEGIN
n_localidad_des_ins :=  SUBSTR (n_localidad_des, 1, 50);
--verificamos que los campos no nulos no sean nulos
    IF  (n_localidad_des  IS NULL)
    OR  (n_anyo        IS NULL)
    OR  (n_mes         IS NULL)
THEN RAISE dup_null;
END IF;


--obtener el cdigo de la localidad

SELECT localidad.ID
INTO localidad_test
FROM localidad
WHERE
localidad.DES = n_localidad_des;
IF      (localidad_test = 0)
   THEN RAISE dup_localidad;
END IF;
  
 OPEN c1;
               FETCH C1  INTO n_contrato, n_potencia, n_contador, n_consumo ;

                WHILE (c1%FOUND) --and (getConsumoContadorFecha(n_contador,n_anyo,n_mes) > 0.8*getConsumoMedioLocalidadFecha(n_localidad,n_anyo,n_mes)))
                 LOOP                  
                      FETCH C1   INTO n_contrato, n_potencia, n_contador, n_consumo ;

--actualizo variables con las operaciones
 n_tpConsumo  := 100*getConsumoContadorFecha(n_contador,n_anyo,n_mes)/getConsumoMedioLocalidadFecha(localidad_test,n_anyo,n_mes);
 n_mConsumo   := getConsumoContadorFecha(n_contador,n_anyo,n_mes);
 
--n_contrato, n_pContratada , n_tpConsumo, n_mConsumo, n_anyo, n_mes
 altaC1(n_contrato, n_potencia, n_tpConsumo,n_mConsumo,n_anyo, n_mes,rst);
 
  DBMS_OUTPUT.ENABLE(250);
  DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
  DBMS_OUTPUT.PUT_LINE(
 ' Codigo contrato: '
 ||n_contrato
 || ' Potencia contratada: '
 || n_potencia
 || ' % consumo respecto consumo medio : '
 || n_tpConsumo
 ||' Consumo contador: '
 ||n_mConsumo
 || ' Anyo: '
 || n_anyo
 || ' Mes: '
 || n_mes);
               END LOOP;
          CLOSE c1;
--end cursorLocalidad;
-- Fin de las operaciones
    rst:='Ok, Alta C1   realizada con exito';
 altaLog('Proc. altaC1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: ' 
|| n_contador 
||'n_anyo  : '
|| n_anyo
, 'rst', rst, rst);

COMMIT;
-- controlamos las excepciones
EXCEPTION
WHEN dup_localidad
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: NO existe la localidad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaC1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_localidad' 
|| localidad_test
|| 'n_fecha'
|| n_anyo
, 'rst', rst, rst);
ROLLBACK;

WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
altaLog('Proc. altaC1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_localidad' 
|| localidad_test
|| 'n_fecha'
|| n_anyo
, 'rst', rst, rst);
ROLLBACK;

WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. altaC1', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_anyos ' || n_anyo 
, 'rst', rst, rst);
ROLLBACK;
END consultaC1;
/
CREATE OR REPLACE
PROCEDURE consultaC3(
n_top       IN INTEGER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  consultaC3 
PROPSITO:  Consulta de las 10 lineas ms cargadas en relacin a su capacidad mxima
PARAMETERS: n_linea,n_cLinea,n_eAmplia,rst
INPUT:  n_linea,n_cLinea,n_eAmplia
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: consultaC3(10, rst);
******************************************************************************/

err_msg           VARCHAR2(100);
linea_test	  INTEGER;
n_id              NUMBER;
n_consumo         NUMBER(9,2);
n_amplia          NUMBER(9,2);
dup_null          EXCEPTION;
  

CURSOR c1 IS
Select linea.id, 100*getLineaConsumo(linea.id)/getLineaCmax(linea.id), getLineaCmax(linea.id)-getLineaConsumo(linea.id)
from linea
group by linea.id, linea.CMAX
order by linea.CMAX;

BEGIN

-- abrimos el cursor para actualizar los resultados
OPEN c1;
               FETCH c1 INTO n_id, n_consumo, n_amplia ;
               WHILE (c1%FOUND and ( c1%ROWCOUNT <= n_top)) LOOP  
                   FETCH c1 INTO n_id, n_consumo, n_amplia ;
                      DBMS_OUTPUT.PUT_LINE(' linea: ' || n_id ||' porcentaje ocupacin  : '|| n_consumo ||' puede ampliar:  '  || n_amplia ||' KW' );
                      rst :='OK, alta C3';
                      altaC3(n_id, n_consumo, n_amplia,rst);
                  END LOOP;
       CLOSE c1;

-- Fin de las operaciones
 
    rst:='OK';
       
altaLog('Proc. consultaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:'
||n_id
||' tanto por ciento '
|| n_consumo
|| ' n_amplia'
|| n_amplia
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION


WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. consultaC3', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_id:'
||n_id
||' tanto por ciento '
|| n_consumo
|| ' n_amplia'
|| n_amplia

, 'rst', rst, rst);
ROLLBACK;
END consultaC3;
/
CREATE OR REPLACE
PROCEDURE consultaC5(
n_central        IN NUMBER,
n_ini            IN VARCHAR2,
n_fin            IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  consultaC5 
PROPSITO:  Dada una central de produccin y un intervalo de tiempo,
            consumo producido por los contadores que dependen de la central
            y la energia producida por la central en el periodo de tiempo.
PARAMETERS: n_central, n_pInicial, n_pFinal ,rst
INPUT:      n_central, n_pInicial, n_pFinal 
OUTPUT:     rst
RETORNA:    'OK' si la operacin ha tenido xito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: consultaC5(1,'01/01/2010','01/07/2012', rst);
******************************************************************************/
n_ini_ins   VARCHAR2(11);
n_fin_ins   VARCHAR2(11);
n_aIni      Varchar2(4);
n_aFin      VARCHAR2(4);
n_mIni      VARCHAR2(2);
n_mFin      VARCHAR2(2);

nn_aIni number;
nn_aFin number;
nn_mIni number;
nn_mFin number;

prod_test           INTEGER;
central_test        INTEGER;
contador_test       INTEGER;
contador            INTEGER;
n_contador          NUMBER;
n_central_ins       NUMBER;
n_consumo           NUMBER(9,2);
eProd               NUMBER(9,2);
eProducida               NUMBER(9,2);
err_msg             VARCHAR2(100);

dup_contador        EXCEPTION;
dup_null            EXCEPTION;
 
CURSOR c1 IS 
SELECT  distinct (contadores.ID) ,sum(consumos.CONSUMO), centrales.EMAX ,n_ini,n_fin
FROM
centrales,  contadores , consumos, estados, linea, lineas, modelos
WHERE
    consumos.ANYO BETWEEN nn_aIni and nn_aFin
and consumos.MES  BETWEEN nn_mIni and nn_mFin
and centrales.ID  = lineas.C1
and contadores.ID = lineas.C2
and contadores.ID = consumos.CONTADOR
and linea.ID      = lineas.LINEA
and estados.ID    = centrales.ESTADO
and estados.ID    = contadores.ESTADO
and estados.ID    = lineas.ESTADO
and estados.ID    = linea.ESTADO
and centrales.ID =  n_central 
group by  contadores.ID,(consumos.CONSUMO),  centrales.EMAX
having sum(consumos.consumo) > 0
order by contadores.id asc;

         
BEGIN
-- inicializar varables
contador := 1;
--comprobamos la longitud de las cadenas
n_ini_ins   := SUBSTR (n_ini, 1, 11);
n_fin_ins   := SUBSTR (n_fin, 1, 11);

n_aIni    := SUBSTR(n_ini_ins, 7, 4);
n_aFin    := SUBSTR(n_fin_ins, 7, 4);
n_mIni    := SUBSTR(n_ini_ins, 5, 1);
n_mFin    := SUBSTR(n_fin_ins, 5, 1);
nn_mIni   := to_number(n_mIni,99);
nn_mFin   := to_number(n_mFin,99);

nn_aIni   := to_number(n_aIni,9999);
nn_aFin   := to_number(n_aFin,9999);

    
-- verificar que existe la central
SELECT count(*)
INTO contador_test
FROM
centrales, linea, lineas, contadores, consumos, estados
WHERE
  
   consumos.ANYO BETWEEN n_aIni and n_aFin
and consumos.MES  BETWEEN nn_mIni and nn_mFin
and centrales.ID  = lineas.C1
and contadores.ID = lineas.C2
and contadores.ID = consumos.CONTADOR
and linea.ID      = lineas.LINEA
and estados.ID    = centrales.ESTADO
and estados.ID    = contadores.ESTADO
and estados.ID    = lineas.ESTADO
and estados.ID    = linea.ESTADO
and  centrales.ID = n_central;

IF (contador_test = 0)
THEN
RAISE dup_contador;
END IF;


eProducida := 0;
  --abrir el cursor e insertar en la tabla correspondiente
        OPEN c1;
               FETCH c1 INTO n_contador, n_consumo, eProd, n_ini_ins, n_fin_ins ;
               WHILE c1%FOUND  LOOP
               FETCH c1 INTO n_contador, n_consumo, eProd, n_ini_ins, n_fin_ins ;
                      DBMS_OUTPUT.ENABLE(250);
                      DBMS_OUTPUT.PUT_LINE(' Central: ' ||n_central||' Contador: ' ||n_contador ||' Consumo contador:  ' ||n_consumo
                      ||' Energia Mxima : ' ||eProd ||' n_ini_ins:  ' ||n_ini_ins ||' n_fin_ins:  ' ||n_fin_ins   );
                     eProducida := eProducida + n_consumo;
                    -- alta registro en la tabla                                  
                     altaC5(n_central, n_contador, n_consumo,  eProducida , n_ini_ins,  n_fin_ins,  rst);
                     END LOOP;
       
       DBMS_OUTPUT.PUT_LINE('------------------------------------------------------------------------------------------------------------------------ '    );
       DBMS_OUTPUT.PUT_LINE('Energia Producida: Central : ' ||n_central ||' , '
       || ' periodo inicial :'
       || n_ini_ins
       || ' ,periodo final :'
       || n_fin_ins
       ||' ,energia producida: '
       || eProducida   );
       DBMS_OUTPUT.PUT_LINE('------------------------------------------------------------------------------------------------------------------------ '    );
       CLOSE c1;

rst :='OK, Proc. consultaC5';     
altaLog('Proc. consultaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central'
|| n_central
||'  n_contador: '
|| n_contador
||'  n_consumo  : '
|| n_consumo
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_contador
THEN
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_central : ' || n_central  ); 
    rst := 'ERROR: La central no tiene contadores conectados';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. consultaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central'
|| n_central
, 'rst', rst, rst);

ROLLBACK;


WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. consultaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central'
|| n_central
||'  n_contador: ' 
|| n_contador 
||'  n_consumo  : '
|| n_consumo
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. consultaC5', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_central'
|| n_central
||'  n_contador: ' 
|| n_contador 
||'  n_consumo  : '
|| n_consumo
, 'rst', rst, rst);
ROLLBACK;
END consultaC5;
/
CREATE OR REPLACE
PROCEDURE consultaC6(
n_pInicial          IN VARCHAR2,
n_pFinal            IN VARCHAR2,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE:  consultaC6 
PROPSITO:  Consulta para obtener porcentaje de  lecturas de contadores  efectuades de forma
            presencial y de forma telemtica en un perodo de tiempo
PARAMETERS: n_pInicial, n_pFinal ,rst
INPUT:  n_pInicial, n_pFinal
OUTPUT: tTelema,tPresent,n_pTelematica,n_pPresencial,n_total,n_pInicial_ins,n_pFinal_ins,rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en caso contrario
EJEMPLO DE USO: consultaC6('01/01/2012','01/06/2012', rst);
******************************************************************************/
n_pInicial_ins      VARCHAR2(11);
n_pFinal_ins        VARCHAR2(11);
n_total             NUMBER(9,2);
tPresent            INTEGER;
tTelema             INTEGER;
contador_test       INTEGER;
n_presencial        NUMBER(9,2);
n_telematica        NUMBER(9,2);
n_pPresencial       NUMBER(9,2);
n_pTelematica       NUMBER(9,2);
err_msg             VARCHAR2(100);

dup_total           EXCEPTION;
dup_null            EXCEPTION;
            
BEGIN

--comprobamos la longitud de las cadenas
n_pInicial_ins   := SUBSTR (n_pInicial, 1, 11);
n_pFinal_ins     := SUBSTR (n_pFinal, 1, 11);

--verificamos que los campos no nulos no sean nulos
IF (n_pInicial_ins   IS NULL)
OR (n_pFinal_ins   IS NULL)
THEN RAISE dup_null;
END IF;

-- obtener tipo lectura y el numero de lecturas

SELECT tLectura.id
INTO tPresent
FROM TLECTURA
WHERE 
tlectura.des = 'PRESENCIAL';


select COUNT(lecturas.TIPO) 
INTO n_presencial
FROM lecturas, tlectura
WHERE 
tLectura.id = lecturas.tipo
and tlectura.ID = tPresent
and lecturas.FECHALECTURA BETWEEN n_pInicial and n_pFinal;


SELECT tLectura.id
INTO tTelema
FROM TLECTURA
WHERE 
tlectura.des = 'TELEMATICA' OR tlectura.des = 'TELEMTICA';

SELECT COUNT(lecturas.TIPO) 
INTO n_telematica
FROM lecturas, tlectura
WHERE 
tLectura.id = tTelema;



SELECT count(*)
INTO contador_test
FROM
centrales, linea, lineas, contadores, consumos, estados
WHERE
   centrales.ID = 1
and consumos.ANYO BETWEEN '2010' and '2012'
and consumos.MES  BETWEEN 1 and 7
and centrales.ID  = lineas.C1
and contadores.ID = lineas.C2
and contadores.ID = consumos.CONTADOR
and linea.ID      = lineas.LINEA
and estados.ID    = centrales.ESTADO
and estados.ID    = contadores.ESTADO
and estados.ID    = lineas.ESTADO
and estados.ID    = linea.ESTADO;


SELECT COUNT(lecturas.TIPO) 
INTO  n_total
FROM lecturas, tlectura
WHERE 
tLectura.id = lecturas.tipo
--and tlectura.des = 'TELEMATICA' OR tlectura.des = 'TELEMTICA' OR tlectura.des = 'PRESENCIAL';
and tlectura.ID = tPresent OR tlectura.ID = tTelema;

n_pPresencial := n_presencial * 100 / n_total;         

n_pTelematica := n_telematica * 100 / n_total;   



 DBMS_OUTPUT.ENABLE;
 DBMS_OUTPUT.PUT_LINE('');
 DBMS_OUTPUT.PUT_LINE('Consulta para obtener porcentaje de  lecturas de contadores ' || n_total) ;
 DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
 DBMS_OUTPUT.PUT_LINE('');
 DBMS_OUTPUT.PUT_LINE('Total lecturas        : ' || n_total);
 DBMS_OUTPUT.PUT_LINE('Lecturas presenciales : ' || n_presencial);
 DBMS_OUTPUT.PUT_LINE('Lecturas telemticas  : ' || n_telematica);
  DBMS_OUTPUT.PUT_LINE('% lecturas telemticas  : ' || n_pPresencial);
  DBMS_OUTPUT.PUT_LINE('%lecturas telemticas   : ' || n_pTelematica);
 
 DBMS_OUTPUT.PUT_LINE('');

IF (n_total = 0)
THEN
RAISE dup_total;
END IF;

--insertamos en la tabla de C6 porcentaje de  lecturas de contadores
 
INSERT INTO C6 (telematica,presencial,pTelematica,pPresencial,total,pInicial,pFinal)
VALUES(tTelema,tPresent,n_pTelematica,n_pPresencial,n_total,n_pInicial_ins,n_pFinal_ins);

-- Fin de las operaciones
 
    rst:='Ok,alta C6 Alta porcentajes lecturas  realizada con exito';
     DBMS_OUTPUT.PUT_LINE('--------------------------------------------------------------------');
     DBMS_OUTPUT.PUT_LINE(rst);
     DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------------------');  
altaLog('Proc. consultaC6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_total'
|| n_total
||'n_pTelematica: ' 
|| n_pTelematica 
||'n_pPresencial  : '
|| n_pPresencial
|| n_pInicial 
||'n_pInicial  : '
|| 'n_pFinal' 
|| n_pFinal
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_total
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE('n_total : ' || n_total  ); 
    rst := 'ERROR: No hay lecturas';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. consultaC6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_total'
|| n_total
||'n_pTelematica: ' 
|| n_pTelematica 
||'n_pPresencial  : '
|| n_pPresencial
|| n_pInicial 
||'n_pInicial  : '
|| 'n_pFinal' 
|| n_pFinal
, 'rst', rst, rst);

ROLLBACK;


WHEN dup_null
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. consultaC6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_total'
|| n_total
||'n_pTelematica: ' 
|| n_pTelematica 
||'n_pPresencial  : '
|| n_pPresencial
|| n_pInicial 
||'n_pInicial  : '
|| 'n_pFinal' 
|| n_pFinal
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. consultaC6', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_total'
|| n_total
||'n_pTelematica: ' 
|| n_pTelematica 
||'n_pPresencial  : '
|| n_pPresencial
|| n_pInicial 
||'n_pInicial  : '
|| 'n_pFinal' 
|| n_pFinal 
, 'rst', rst, rst);
ROLLBACK;
END consultaC6;
/
CREATE OR REPLACE
PROCEDURE consultaC7(
n_anyos          IN NUMBER,
rst OUT VARCHAR2
)
IS
/******************************************************************************
NOMBRE: consultarContadoresAntiguedad
PROPSITO:  Consulta para obtener el listado todos los contadores de un numero de aos de antiguedad
            la antiguedad considerada por la fecha de fabricacion del modelo
PARAMETERS: n_anyos,rst
INPUT: n_anyos
OUTPUT: n_id, n_contador, n_anyos,rst
RETORNA: 'OK' si la operacin ha tenido exito, 'ERROR: Tipo de Error' en
caso contrario
EJEMPLO DE USO: consultaC7(8, rst);
******************************************************************************/
n_contador                NUMBER;
n_anyo                    NUMBER;
n_anyos_ins               NUMBER;
n_fabrica                 VARCHAR2(4);
contador                  INTEGER;
contadores_test           INTEGER;
err_msg                   VARCHAR2(100);
dup_contadores            EXCEPTION;
dup_des                   EXCEPTION;


CURSOR c1 IS
select contadores.ID, n_anyos,modelos.ANYOFABRICA
from contadores, modelos
where contadores.MODELO = modelos.ID
and   modelos.ANYOFABRICA < (to_char(sysdate,'YYYY')- n_anyos );


BEGIN
contador := 1;
--verificamos que los campos no nulos no sean nulos
IF (n_anyos   IS NULL)
THEN RAISE dup_des;
END IF;

select count(*)
INTO contadores_test 
from contadores, modelos
where contadores.MODELO = modelos.ID
and   modelos.ANYOFABRICA < (to_char(sysdate,'YYYY') - n_anyos );
IF (contadores_test = 0)
THEN
RAISE dup_contadores;
END IF;
 DBMS_OUTPUT.ENABLE(250);
 DBMS_OUTPUT.PUT_LINE('');
 DBMS_OUTPUT.PUT_LINE('CONSULTA DE CONTADORES CON ANTIGEDAD DE ' || n_anyos || ' aos') ;
 DBMS_OUTPUT.PUT_LINE('-------------------------------------------------');
  --abrir el cursor e insertar en la tabla correspondiente
        OPEN c1;
               FETCH c1 INTO n_contador ,n_anyos_ins, n_fabrica ;
               WHILE c1%FOUND  LOOP
                   FETCH c1 INTO n_contador, n_anyos_ins,n_fabrica ;
                      DBMS_OUTPUT.PUT_LINE(' Contador: ' ||n_contador||' Num. aos: ' ||n_anyos_ins ||' Fabricado en:  ' ||n_fabrica);
                      rst :='OK';
                      altaC7(n_contador, n_anyos, n_fabrica,rst);
                  END LOOP;
       CLOSE c1;

-- Fin de las operaciones
 
    rst:='Ok, Alta consultarContadoresAntiguedad   realizada con exito';
       
altaLog('Proc. consultaC7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_contador: ' 
|| n_contador 
||' n_anyo  : '
|| n_anyo
, 'rst', rst, rst);

COMMIT;

-- controlamos las excepciones
EXCEPTION

WHEN dup_contadores
THEN

    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    DBMS_OUTPUT.PUT_LINE(' n_contador : ' || n_contador  ); 
     rst := 'ERROR: No hay contadores con los aos de antigedad';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
    
altaLog('Proc. consultaC7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
' n_anyos '
|| n_anyos
, 'rst', rst, rst);

ROLLBACK;

WHEN dup_des
THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('');
    rst := 'ERROR: hay campos no nulos  sin contenido';
    DBMS_OUTPUT.PUT_LINE('');  
    DBMS_OUTPUT.PUT_LINE(rst);
  
altaLog('Proc. consultaC7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_anyos' 
|| n_anyos
, 'rst', rst, rst);

ROLLBACK;
WHEN OTHERS
THEN
err_msg := SUBSTR (SQLERRM, 1, 100);
rst := 'ERROR:'
|| err_msg;
altaLog('Proc. consultaC7', to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'),
'n_anyos ' || n_anyos 
, 'rst', rst, rst);
ROLLBACK;
END consultaC7;
/* FIN GESTOR_CONSULTAS*/


